/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_d0hf(Libderiv_t *, prim_data *);

  /* Computes derivatives of (d0|hf) integrals */

void d12hrr_order_d0hf(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[2][8][11] = int_stack + 0;
 Libderiv->deriv_classes[2][8][10] = int_stack + 270;
 Libderiv->deriv_classes[2][8][9] = int_stack + 540;
 Libderiv->deriv_classes[2][8][8] = int_stack + 810;
 Libderiv->deriv_classes[2][8][7] = int_stack + 1080;
 Libderiv->dvrr_classes[2][7] = int_stack + 1350;
 Libderiv->deriv_classes[2][8][6] = int_stack + 1566;
 Libderiv->deriv_classes[2][8][2] = int_stack + 1836;
 Libderiv->deriv_classes[2][8][1] = int_stack + 2106;
 Libderiv->deriv_classes[2][8][0] = int_stack + 2376;
 Libderiv->deriv2_classes[2][5][143] = int_stack + 2646;
 Libderiv->deriv2_classes[2][6][143] = int_stack + 2772;
 Libderiv->deriv2_classes[2][7][143] = int_stack + 2940;
 Libderiv->deriv2_classes[2][8][143] = int_stack + 3156;
 Libderiv->deriv2_classes[2][5][131] = int_stack + 3426;
 Libderiv->deriv2_classes[2][6][131] = int_stack + 3552;
 Libderiv->deriv2_classes[2][7][131] = int_stack + 3720;
 Libderiv->deriv2_classes[2][8][131] = int_stack + 3936;
 Libderiv->deriv2_classes[2][5][130] = int_stack + 4206;
 Libderiv->deriv2_classes[2][6][130] = int_stack + 4332;
 Libderiv->deriv2_classes[2][7][130] = int_stack + 4500;
 Libderiv->deriv2_classes[2][8][130] = int_stack + 4716;
 Libderiv->deriv2_classes[2][5][119] = int_stack + 4986;
 Libderiv->deriv2_classes[2][6][119] = int_stack + 5112;
 Libderiv->deriv2_classes[2][7][119] = int_stack + 5280;
 Libderiv->deriv2_classes[2][8][119] = int_stack + 5496;
 Libderiv->deriv2_classes[2][5][118] = int_stack + 5766;
 Libderiv->deriv2_classes[2][6][118] = int_stack + 5892;
 Libderiv->deriv2_classes[2][7][118] = int_stack + 6060;
 Libderiv->deriv2_classes[2][8][118] = int_stack + 6276;
 Libderiv->deriv2_classes[2][5][117] = int_stack + 6546;
 Libderiv->deriv2_classes[2][6][117] = int_stack + 6672;
 Libderiv->deriv2_classes[2][7][117] = int_stack + 6840;
 Libderiv->deriv2_classes[2][8][117] = int_stack + 7056;
 Libderiv->deriv2_classes[2][5][107] = int_stack + 7326;
 Libderiv->deriv2_classes[2][6][107] = int_stack + 7452;
 Libderiv->deriv2_classes[2][7][107] = int_stack + 7620;
 Libderiv->deriv2_classes[2][8][107] = int_stack + 7836;
 Libderiv->deriv2_classes[2][5][106] = int_stack + 8106;
 Libderiv->deriv2_classes[2][6][106] = int_stack + 8232;
 Libderiv->deriv2_classes[2][7][106] = int_stack + 8400;
 Libderiv->deriv2_classes[2][8][106] = int_stack + 8616;
 Libderiv->deriv2_classes[2][5][105] = int_stack + 8886;
 Libderiv->deriv2_classes[2][6][105] = int_stack + 9012;
 Libderiv->deriv2_classes[2][7][105] = int_stack + 9180;
 Libderiv->deriv2_classes[2][8][105] = int_stack + 9396;
 Libderiv->deriv2_classes[2][5][104] = int_stack + 9666;
 Libderiv->deriv2_classes[2][6][104] = int_stack + 9792;
 Libderiv->deriv2_classes[2][7][104] = int_stack + 9960;
 Libderiv->deriv2_classes[2][8][104] = int_stack + 10176;
 Libderiv->deriv2_classes[2][5][95] = int_stack + 10446;
 Libderiv->deriv2_classes[2][6][95] = int_stack + 10572;
 Libderiv->deriv2_classes[2][7][95] = int_stack + 10740;
 Libderiv->deriv2_classes[2][8][95] = int_stack + 10956;
 Libderiv->deriv2_classes[2][5][94] = int_stack + 11226;
 Libderiv->deriv2_classes[2][6][94] = int_stack + 11352;
 Libderiv->deriv2_classes[2][7][94] = int_stack + 11520;
 Libderiv->deriv2_classes[2][8][94] = int_stack + 11736;
 Libderiv->deriv2_classes[2][5][93] = int_stack + 12006;
 Libderiv->deriv2_classes[2][6][93] = int_stack + 12132;
 Libderiv->deriv2_classes[2][7][93] = int_stack + 12300;
 Libderiv->deriv2_classes[2][8][93] = int_stack + 12516;
 Libderiv->deriv2_classes[2][5][92] = int_stack + 12786;
 Libderiv->deriv2_classes[2][6][92] = int_stack + 12912;
 Libderiv->deriv2_classes[2][7][92] = int_stack + 13080;
 Libderiv->deriv2_classes[2][8][92] = int_stack + 13296;
 Libderiv->deriv2_classes[2][5][91] = int_stack + 13566;
 Libderiv->deriv2_classes[2][6][91] = int_stack + 13692;
 Libderiv->deriv2_classes[2][7][91] = int_stack + 13860;
 Libderiv->deriv2_classes[2][8][91] = int_stack + 14076;
 Libderiv->deriv_classes[2][5][11] = int_stack + 14346;
 Libderiv->deriv2_classes[2][5][83] = int_stack + 14472;
 Libderiv->deriv_classes[2][6][11] = int_stack + 14598;
 Libderiv->deriv2_classes[2][6][83] = int_stack + 14766;
 Libderiv->deriv_classes[2][7][11] = int_stack + 14934;
 Libderiv->deriv2_classes[2][7][83] = int_stack + 15150;
 Libderiv->deriv2_classes[2][8][83] = int_stack + 15366;
 Libderiv->deriv_classes[2][5][10] = int_stack + 15636;
 Libderiv->deriv2_classes[2][5][82] = int_stack + 15762;
 Libderiv->deriv_classes[2][6][10] = int_stack + 15888;
 Libderiv->deriv2_classes[2][6][82] = int_stack + 16056;
 Libderiv->deriv_classes[2][7][10] = int_stack + 16224;
 Libderiv->deriv2_classes[2][7][82] = int_stack + 16440;
 Libderiv->deriv2_classes[2][8][82] = int_stack + 16656;
 Libderiv->deriv_classes[2][5][9] = int_stack + 16926;
 Libderiv->deriv2_classes[2][5][81] = int_stack + 17052;
 Libderiv->deriv_classes[2][6][9] = int_stack + 17178;
 Libderiv->deriv2_classes[2][6][81] = int_stack + 17346;
 Libderiv->deriv_classes[2][7][9] = int_stack + 17514;
 Libderiv->deriv2_classes[2][7][81] = int_stack + 17730;
 Libderiv->deriv2_classes[2][8][81] = int_stack + 17946;
 Libderiv->deriv_classes[2][5][8] = int_stack + 18216;
 Libderiv->deriv2_classes[2][5][80] = int_stack + 18342;
 Libderiv->deriv_classes[2][6][8] = int_stack + 18468;
 Libderiv->deriv2_classes[2][6][80] = int_stack + 18636;
 Libderiv->deriv_classes[2][7][8] = int_stack + 18804;
 Libderiv->deriv2_classes[2][7][80] = int_stack + 19020;
 Libderiv->deriv2_classes[2][8][80] = int_stack + 19236;
 Libderiv->deriv_classes[2][5][7] = int_stack + 19506;
 Libderiv->deriv2_classes[2][5][79] = int_stack + 19632;
 Libderiv->deriv_classes[2][6][7] = int_stack + 19758;
 Libderiv->deriv2_classes[2][6][79] = int_stack + 19926;
 Libderiv->deriv_classes[2][7][7] = int_stack + 20094;
 Libderiv->deriv2_classes[2][7][79] = int_stack + 20310;
 Libderiv->deriv2_classes[2][8][79] = int_stack + 20526;
 Libderiv->dvrr_classes[2][5] = int_stack + 20796;
 Libderiv->deriv_classes[2][5][6] = int_stack + 20922;
 Libderiv->deriv2_classes[2][5][78] = int_stack + 21048;
 Libderiv->dvrr_classes[2][6] = int_stack + 21174;
 Libderiv->deriv_classes[2][6][6] = int_stack + 21342;
 Libderiv->deriv2_classes[2][6][78] = int_stack + 21510;
 Libderiv->deriv_classes[2][7][6] = int_stack + 21678;
 Libderiv->deriv2_classes[2][7][78] = int_stack + 21894;
 Libderiv->deriv2_classes[2][8][78] = int_stack + 22110;
 Libderiv->deriv2_classes[2][5][35] = int_stack + 22380;
 Libderiv->deriv2_classes[2][6][35] = int_stack + 22506;
 Libderiv->deriv2_classes[2][7][35] = int_stack + 22674;
 Libderiv->deriv2_classes[2][8][35] = int_stack + 22890;
 Libderiv->deriv2_classes[2][5][34] = int_stack + 23160;
 Libderiv->deriv2_classes[2][6][34] = int_stack + 23286;
 Libderiv->deriv2_classes[2][7][34] = int_stack + 23454;
 Libderiv->deriv2_classes[2][8][34] = int_stack + 23670;
 Libderiv->deriv2_classes[2][5][33] = int_stack + 23940;
 Libderiv->deriv2_classes[2][6][33] = int_stack + 24066;
 Libderiv->deriv2_classes[2][7][33] = int_stack + 24234;
 Libderiv->deriv2_classes[2][8][33] = int_stack + 24450;
 Libderiv->deriv2_classes[2][5][32] = int_stack + 24720;
 Libderiv->deriv2_classes[2][6][32] = int_stack + 24846;
 Libderiv->deriv2_classes[2][7][32] = int_stack + 25014;
 Libderiv->deriv2_classes[2][8][32] = int_stack + 25230;
 Libderiv->deriv2_classes[2][5][31] = int_stack + 25500;
 Libderiv->deriv2_classes[2][6][31] = int_stack + 25626;
 Libderiv->deriv2_classes[2][7][31] = int_stack + 25794;
 Libderiv->deriv2_classes[2][8][31] = int_stack + 26010;
 Libderiv->deriv_classes[2][5][2] = int_stack + 26280;
 Libderiv->deriv2_classes[2][5][30] = int_stack + 26406;
 Libderiv->deriv_classes[2][6][2] = int_stack + 26532;
 Libderiv->deriv2_classes[2][6][30] = int_stack + 26700;
 Libderiv->deriv_classes[2][7][2] = int_stack + 26868;
 Libderiv->deriv2_classes[2][7][30] = int_stack + 27084;
 Libderiv->deriv2_classes[2][8][30] = int_stack + 27300;
 Libderiv->deriv2_classes[2][5][26] = int_stack + 27570;
 Libderiv->deriv2_classes[2][6][26] = int_stack + 27696;
 Libderiv->deriv2_classes[2][7][26] = int_stack + 27864;
 Libderiv->deriv2_classes[2][8][26] = int_stack + 28080;
 Libderiv->deriv2_classes[2][5][23] = int_stack + 28350;
 Libderiv->deriv2_classes[2][6][23] = int_stack + 28476;
 Libderiv->deriv2_classes[2][7][23] = int_stack + 28644;
 Libderiv->deriv2_classes[2][8][23] = int_stack + 28860;
 Libderiv->deriv2_classes[2][5][22] = int_stack + 29130;
 Libderiv->deriv2_classes[2][6][22] = int_stack + 29256;
 Libderiv->deriv2_classes[2][7][22] = int_stack + 29424;
 Libderiv->deriv2_classes[2][8][22] = int_stack + 29640;
 Libderiv->deriv2_classes[2][5][21] = int_stack + 29910;
 Libderiv->deriv2_classes[2][6][21] = int_stack + 30036;
 Libderiv->deriv2_classes[2][7][21] = int_stack + 30204;
 Libderiv->deriv2_classes[2][8][21] = int_stack + 30420;
 Libderiv->deriv2_classes[2][5][20] = int_stack + 30690;
 Libderiv->deriv2_classes[2][6][20] = int_stack + 30816;
 Libderiv->deriv2_classes[2][7][20] = int_stack + 30984;
 Libderiv->deriv2_classes[2][8][20] = int_stack + 31200;
 Libderiv->deriv2_classes[2][5][19] = int_stack + 31470;
 Libderiv->deriv2_classes[2][6][19] = int_stack + 31596;
 Libderiv->deriv2_classes[2][7][19] = int_stack + 31764;
 Libderiv->deriv2_classes[2][8][19] = int_stack + 31980;
 Libderiv->deriv_classes[2][5][1] = int_stack + 32250;
 Libderiv->deriv2_classes[2][5][18] = int_stack + 32376;
 Libderiv->deriv_classes[2][6][1] = int_stack + 32502;
 Libderiv->deriv2_classes[2][6][18] = int_stack + 32670;
 Libderiv->deriv_classes[2][7][1] = int_stack + 32838;
 Libderiv->deriv2_classes[2][7][18] = int_stack + 33054;
 Libderiv->deriv2_classes[2][8][18] = int_stack + 33270;
 Libderiv->deriv2_classes[2][5][14] = int_stack + 33540;
 Libderiv->deriv2_classes[2][6][14] = int_stack + 33666;
 Libderiv->deriv2_classes[2][7][14] = int_stack + 33834;
 Libderiv->deriv2_classes[2][8][14] = int_stack + 34050;
 Libderiv->deriv2_classes[2][5][13] = int_stack + 34320;
 Libderiv->deriv2_classes[2][6][13] = int_stack + 34446;
 Libderiv->deriv2_classes[2][7][13] = int_stack + 34614;
 Libderiv->deriv2_classes[2][8][13] = int_stack + 34830;
 Libderiv->deriv2_classes[2][5][11] = int_stack + 35100;
 Libderiv->deriv2_classes[2][6][11] = int_stack + 35226;
 Libderiv->deriv2_classes[2][7][11] = int_stack + 35394;
 Libderiv->deriv2_classes[2][8][11] = int_stack + 35610;
 Libderiv->deriv2_classes[2][5][10] = int_stack + 35880;
 Libderiv->deriv2_classes[2][6][10] = int_stack + 36006;
 Libderiv->deriv2_classes[2][7][10] = int_stack + 36174;
 Libderiv->deriv2_classes[2][8][10] = int_stack + 36390;
 Libderiv->deriv2_classes[2][5][9] = int_stack + 36660;
 Libderiv->deriv2_classes[2][6][9] = int_stack + 36786;
 Libderiv->deriv2_classes[2][7][9] = int_stack + 36954;
 Libderiv->deriv2_classes[2][8][9] = int_stack + 37170;
 Libderiv->deriv2_classes[2][5][8] = int_stack + 37440;
 Libderiv->deriv2_classes[2][6][8] = int_stack + 37566;
 Libderiv->deriv2_classes[2][7][8] = int_stack + 37734;
 Libderiv->deriv2_classes[2][8][8] = int_stack + 37950;
 Libderiv->deriv2_classes[2][5][7] = int_stack + 38220;
 Libderiv->deriv2_classes[2][6][7] = int_stack + 38346;
 Libderiv->deriv2_classes[2][7][7] = int_stack + 38514;
 Libderiv->deriv2_classes[2][8][7] = int_stack + 38730;
 Libderiv->deriv_classes[2][5][0] = int_stack + 39000;
 Libderiv->deriv2_classes[2][5][6] = int_stack + 39126;
 Libderiv->deriv_classes[2][6][0] = int_stack + 39252;
 Libderiv->deriv2_classes[2][6][6] = int_stack + 39420;
 Libderiv->deriv_classes[2][7][0] = int_stack + 39588;
 Libderiv->deriv2_classes[2][7][6] = int_stack + 39804;
 Libderiv->deriv2_classes[2][8][6] = int_stack + 40020;
 Libderiv->deriv2_classes[2][5][2] = int_stack + 40290;
 Libderiv->deriv2_classes[2][6][2] = int_stack + 40416;
 Libderiv->deriv2_classes[2][7][2] = int_stack + 40584;
 Libderiv->deriv2_classes[2][8][2] = int_stack + 40800;
 Libderiv->deriv2_classes[2][5][1] = int_stack + 41070;
 Libderiv->deriv2_classes[2][6][1] = int_stack + 41196;
 Libderiv->deriv2_classes[2][7][1] = int_stack + 41364;
 Libderiv->deriv2_classes[2][8][1] = int_stack + 41580;
 Libderiv->deriv2_classes[2][5][0] = int_stack + 41850;
 Libderiv->deriv2_classes[2][6][0] = int_stack + 41976;
 Libderiv->deriv2_classes[2][7][0] = int_stack + 42144;
 Libderiv->deriv2_classes[2][8][0] = int_stack + 42360;
 memset(int_stack,0,341040);

 Libderiv->dvrr_stack = int_stack + 106314;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_d0hf(Libderiv, Data);
   Data++;
 }

 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+42630,int_stack+21174,int_stack+20796,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+43008,int_stack+1350,int_stack+21174,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+43512,int_stack+43008,int_stack+42630,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+44268,int_stack+14598,int_stack+14346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20796,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+44646,int_stack+14934,int_stack+14598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21174,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+45150,int_stack+44646,int_stack+44268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42630,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+45906,int_stack+0,int_stack+14934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1350,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+46554,int_stack+45906,int_stack+44646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43008,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+45906,int_stack+15888,int_stack+15636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20796, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+47562,int_stack+16224,int_stack+15888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21174, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+48066,int_stack+47562,int_stack+45906, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42630, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+48822,int_stack+270,int_stack+16224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1350, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+49470,int_stack+48822,int_stack+47562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43008, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48822,int_stack+17178,int_stack+16926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20796, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+17514,int_stack+17178, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21174, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+50478,int_stack+0,int_stack+48822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42630, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+51234,int_stack+540,int_stack+17514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1350, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+51882,int_stack+51234,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43008, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+51234,int_stack+18468,int_stack+18216, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+52890,int_stack+18804,int_stack+18468, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+53394,int_stack+52890,int_stack+51234, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+54150,int_stack+810,int_stack+18804, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+54798,int_stack+54150,int_stack+52890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+54150,int_stack+19758,int_stack+19506, 0.0, zero_stack, 1.0, int_stack+20796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+504,int_stack+20094,int_stack+19758, 0.0, zero_stack, 1.0, int_stack+21174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+55806,int_stack+504,int_stack+54150, 0.0, zero_stack, 1.0, int_stack+42630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+56562,int_stack+1080,int_stack+20094, 0.0, zero_stack, 1.0, int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+57210,int_stack+56562,int_stack+504, 0.0, zero_stack, 1.0, int_stack+43008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+56562,int_stack+21342,int_stack+20922, 1.0, int_stack+20796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+58218,int_stack+21678,int_stack+21342, 1.0, int_stack+21174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+58722,int_stack+58218,int_stack+56562, 1.0, int_stack+42630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+59478,int_stack+1566,int_stack+21678, 1.0, int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+60126,int_stack+59478,int_stack+58218, 1.0, int_stack+43008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+59478,int_stack+26532,int_stack+26280,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+42630,int_stack+26868,int_stack+26532,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1008,int_stack+42630,int_stack+59478,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+61134,int_stack+1836,int_stack+26868,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+61782,int_stack+61134,int_stack+42630,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+43134,int_stack+32502,int_stack+32250,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+61134,int_stack+32838,int_stack+32502,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+62790,int_stack+61134,int_stack+43134,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+63546,int_stack+2106,int_stack+32838,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+64194,int_stack+63546,int_stack+61134,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+63546,int_stack+39252,int_stack+39000,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1764,int_stack+39588,int_stack+39252,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+65202,int_stack+1764,int_stack+63546,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+65958,int_stack+2376,int_stack+39588,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+66606,int_stack+65958,int_stack+1764,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2268,int_stack+2772,int_stack+2646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+14346,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+65958,int_stack+2940,int_stack+2772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+14598,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+67614,int_stack+65958,int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+44268,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2268,int_stack+3156,int_stack+2940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+14934,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+68370,int_stack+2268,int_stack+65958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+44646,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+65958,int_stack+3552,int_stack+3426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14346, 1.0, int_stack+15636,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2268,int_stack+3720,int_stack+3552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14598, 1.0, int_stack+15888,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2772,int_stack+2268,int_stack+65958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44268, 1.0, int_stack+45906,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+65958,int_stack+3936,int_stack+3720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14934, 1.0, int_stack+16224,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+69378,int_stack+65958,int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44646, 1.0, int_stack+47562,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2268,int_stack+4332,int_stack+4206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+15636, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+65958,int_stack+4500,int_stack+4332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+15888, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3528,int_stack+65958,int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+45906, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+70386,int_stack+4716,int_stack+4500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+16224, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+71034,int_stack+70386,int_stack+65958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+47562, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+65958,int_stack+5112,int_stack+4986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14346, 0.0, zero_stack, 1.0, int_stack+16926,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2268,int_stack+5280,int_stack+5112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14598, 0.0, zero_stack, 1.0, int_stack+17178,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4284,int_stack+2268,int_stack+65958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44268, 0.0, zero_stack, 1.0, int_stack+48822,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+65958,int_stack+5496,int_stack+5280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14934, 0.0, zero_stack, 1.0, int_stack+17514,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+72042,int_stack+65958,int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44646, 0.0, zero_stack, 1.0, int_stack+0,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2268,int_stack+5892,int_stack+5766, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15636, 1.0, int_stack+16926, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+65958,int_stack+6060,int_stack+5892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15888, 1.0, int_stack+17178, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5040,int_stack+65958,int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45906, 1.0, int_stack+48822, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+70386,int_stack+6276,int_stack+6060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16224, 1.0, int_stack+17514, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+73050,int_stack+70386,int_stack+65958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47562, 1.0, int_stack+0, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+65958,int_stack+6672,int_stack+6546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+16926, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2268,int_stack+6840,int_stack+6672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+17178, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5796,int_stack+2268,int_stack+65958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+48822, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+65958,int_stack+7056,int_stack+6840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+17514, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+74058,int_stack+65958,int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2268,int_stack+7452,int_stack+7326, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14346, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18216,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+65958,int_stack+7620,int_stack+7452, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14598, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18468,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6552,int_stack+65958,int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44268, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51234,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+70386,int_stack+7836,int_stack+7620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14934, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18804,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+75066,int_stack+70386,int_stack+65958, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44646, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52890,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+65958,int_stack+8232,int_stack+8106, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15636, 0.0, zero_stack, 1.0, int_stack+18216, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2268,int_stack+8400,int_stack+8232, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15888, 0.0, zero_stack, 1.0, int_stack+18468, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7308,int_stack+2268,int_stack+65958, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45906, 0.0, zero_stack, 1.0, int_stack+51234, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+65958,int_stack+8616,int_stack+8400, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16224, 0.0, zero_stack, 1.0, int_stack+18804, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+76074,int_stack+65958,int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47562, 0.0, zero_stack, 1.0, int_stack+52890, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2268,int_stack+9012,int_stack+8886, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16926, 1.0, int_stack+18216, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+65958,int_stack+9180,int_stack+9012, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17178, 1.0, int_stack+18468, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8064,int_stack+65958,int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48822, 1.0, int_stack+51234, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+70386,int_stack+9396,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17514, 1.0, int_stack+18804, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+77082,int_stack+70386,int_stack+65958, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+52890, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+65958,int_stack+9792,int_stack+9666, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+18216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2268,int_stack+9960,int_stack+9792, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+18468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8820,int_stack+2268,int_stack+65958, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+51234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+65958,int_stack+10176,int_stack+9960, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+18804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+78090,int_stack+65958,int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+52890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2268,int_stack+10572,int_stack+10446, 0.0, zero_stack, 1.0, int_stack+14346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19506,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+65958,int_stack+10740,int_stack+10572, 0.0, zero_stack, 1.0, int_stack+14598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19758,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9576,int_stack+65958,int_stack+2268, 0.0, zero_stack, 1.0, int_stack+44268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54150,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+70386,int_stack+10956,int_stack+10740, 0.0, zero_stack, 1.0, int_stack+14934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20094,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+79098,int_stack+70386,int_stack+65958, 0.0, zero_stack, 1.0, int_stack+44646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+504,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+65958,int_stack+11352,int_stack+11226, 0.0, zero_stack, 1.0, int_stack+15636, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19506, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2268,int_stack+11520,int_stack+11352, 0.0, zero_stack, 1.0, int_stack+15888, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19758, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10332,int_stack+2268,int_stack+65958, 0.0, zero_stack, 1.0, int_stack+45906, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54150, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+65958,int_stack+11736,int_stack+11520, 0.0, zero_stack, 1.0, int_stack+16224, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20094, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+80106,int_stack+65958,int_stack+2268, 0.0, zero_stack, 1.0, int_stack+47562, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+504, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2268,int_stack+12132,int_stack+12006, 0.0, zero_stack, 1.0, int_stack+16926, 0.0, zero_stack, 1.0, int_stack+19506, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+65958,int_stack+12300,int_stack+12132, 0.0, zero_stack, 1.0, int_stack+17178, 0.0, zero_stack, 1.0, int_stack+19758, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11088,int_stack+65958,int_stack+2268, 0.0, zero_stack, 1.0, int_stack+48822, 0.0, zero_stack, 1.0, int_stack+54150, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+70386,int_stack+12516,int_stack+12300, 0.0, zero_stack, 1.0, int_stack+17514, 0.0, zero_stack, 1.0, int_stack+20094, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+81114,int_stack+70386,int_stack+65958, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+504, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+65958,int_stack+12912,int_stack+12786, 0.0, zero_stack, 1.0, int_stack+18216, 1.0, int_stack+19506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2268,int_stack+13080,int_stack+12912, 0.0, zero_stack, 1.0, int_stack+18468, 1.0, int_stack+19758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11844,int_stack+2268,int_stack+65958, 0.0, zero_stack, 1.0, int_stack+51234, 1.0, int_stack+54150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+65958,int_stack+13296,int_stack+13080, 0.0, zero_stack, 1.0, int_stack+18804, 1.0, int_stack+20094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+82122,int_stack+65958,int_stack+2268, 0.0, zero_stack, 1.0, int_stack+52890, 1.0, int_stack+504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2268,int_stack+13692,int_stack+13566, 0.0, zero_stack, 2.0, int_stack+19506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+65958,int_stack+13860,int_stack+13692, 0.0, zero_stack, 2.0, int_stack+19758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12600,int_stack+65958,int_stack+2268, 0.0, zero_stack, 2.0, int_stack+54150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+70386,int_stack+14076,int_stack+13860, 0.0, zero_stack, 2.0, int_stack+20094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+83130,int_stack+70386,int_stack+65958, 0.0, zero_stack, 2.0, int_stack+504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+65958,int_stack+14766,int_stack+14472, 1.0, int_stack+14346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20922,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2268,int_stack+15150,int_stack+14766, 1.0, int_stack+14598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21342,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13356,int_stack+2268,int_stack+65958, 1.0, int_stack+44268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56562,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+65958,int_stack+15366,int_stack+15150, 1.0, int_stack+14934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21678,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+14112,int_stack+65958,int_stack+2268, 1.0, int_stack+44646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58218,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2268,int_stack+16056,int_stack+15762, 1.0, int_stack+15636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20922, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+65958,int_stack+16440,int_stack+16056, 1.0, int_stack+15888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21342, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+44268,int_stack+65958,int_stack+2268, 1.0, int_stack+45906, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56562, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+45906,int_stack+16656,int_stack+16440, 1.0, int_stack+16224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21678, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+15120,int_stack+45906,int_stack+65958, 1.0, int_stack+47562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58218, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47562,int_stack+17346,int_stack+17052, 1.0, int_stack+16926, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20922, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2268,int_stack+17730,int_stack+17346, 1.0, int_stack+17178, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21342, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+16128,int_stack+2268,int_stack+47562, 1.0, int_stack+48822, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56562, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+48822,int_stack+17946,int_stack+17730, 1.0, int_stack+17514, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21678, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+16884,int_stack+48822,int_stack+2268, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58218, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+18636,int_stack+18342, 1.0, int_stack+18216, 0.0, zero_stack, 1.0, int_stack+20922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2268,int_stack+19020,int_stack+18636, 1.0, int_stack+18468, 0.0, zero_stack, 1.0, int_stack+21342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+17892,int_stack+2268,int_stack+0, 1.0, int_stack+51234, 0.0, zero_stack, 1.0, int_stack+56562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+51234,int_stack+19236,int_stack+19020, 1.0, int_stack+18804, 0.0, zero_stack, 1.0, int_stack+21678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+84138,int_stack+51234,int_stack+2268, 1.0, int_stack+52890, 0.0, zero_stack, 1.0, int_stack+58218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+52890,int_stack+19926,int_stack+19632, 1.0, int_stack+19506, 1.0, int_stack+20922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2268,int_stack+20310,int_stack+19926, 1.0, int_stack+19758, 1.0, int_stack+21342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+18648,int_stack+2268,int_stack+52890, 1.0, int_stack+54150, 1.0, int_stack+56562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+54150,int_stack+20526,int_stack+20310, 1.0, int_stack+20094, 1.0, int_stack+21678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+19404,int_stack+54150,int_stack+2268, 1.0, int_stack+504, 1.0, int_stack+58218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2268,int_stack+21510,int_stack+21048, 2.0, int_stack+20922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+52890,int_stack+21894,int_stack+21510, 2.0, int_stack+21342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+52890,int_stack+2268, 2.0, int_stack+56562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+56562,int_stack+22110,int_stack+21894, 2.0, int_stack+21678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+20412,int_stack+56562,int_stack+52890, 2.0, int_stack+58218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+58218,int_stack+22506,int_stack+22380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26280,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+52890,int_stack+22674,int_stack+22506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26532,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+21420,int_stack+52890,int_stack+58218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59478,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+56562,int_stack+22890,int_stack+22674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26868,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+85146,int_stack+56562,int_stack+52890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42630,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+52890,int_stack+23286,int_stack+23160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26280, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+58218,int_stack+23454,int_stack+23286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26532, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+22176,int_stack+58218,int_stack+52890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59478, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+56562,int_stack+23670,int_stack+23454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26868, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+22932,int_stack+56562,int_stack+58218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42630, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+58218,int_stack+24066,int_stack+23940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26280, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+52890,int_stack+24234,int_stack+24066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26532, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+86154,int_stack+52890,int_stack+58218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59478, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+56562,int_stack+24450,int_stack+24234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26868, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+86910,int_stack+56562,int_stack+52890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42630, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+52890,int_stack+24846,int_stack+24720, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+58218,int_stack+25014,int_stack+24846, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+23940,int_stack+58218,int_stack+52890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+56562,int_stack+25230,int_stack+25014, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+87918,int_stack+56562,int_stack+58218, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+58218,int_stack+25626,int_stack+25500, 0.0, zero_stack, 1.0, int_stack+26280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+52890,int_stack+25794,int_stack+25626, 0.0, zero_stack, 1.0, int_stack+26532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+24696,int_stack+52890,int_stack+58218, 0.0, zero_stack, 1.0, int_stack+59478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+56562,int_stack+26010,int_stack+25794, 0.0, zero_stack, 1.0, int_stack+26868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+88926,int_stack+56562,int_stack+52890, 0.0, zero_stack, 1.0, int_stack+42630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+52890,int_stack+26700,int_stack+26406, 1.0, int_stack+26280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+58218,int_stack+27084,int_stack+26700, 1.0, int_stack+26532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+25452,int_stack+58218,int_stack+52890, 1.0, int_stack+59478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+59478,int_stack+27300,int_stack+27084, 1.0, int_stack+26868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+26208,int_stack+59478,int_stack+58218, 1.0, int_stack+42630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+42630,int_stack+27696,int_stack+27570,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+58218,int_stack+27864,int_stack+27696,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+89934,int_stack+58218,int_stack+42630,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+59478,int_stack+28080,int_stack+27864,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+27216,int_stack+59478,int_stack+58218,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+58218,int_stack+28476,int_stack+28350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32250,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+42630,int_stack+28644,int_stack+28476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32502,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+90690,int_stack+42630,int_stack+58218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43134,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+59478,int_stack+28860,int_stack+28644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32838,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+91446,int_stack+59478,int_stack+42630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61134,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+42630,int_stack+29256,int_stack+29130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32250, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+58218,int_stack+29424,int_stack+29256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32502, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+28224,int_stack+58218,int_stack+42630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43134, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+59478,int_stack+29640,int_stack+29424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32838, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+92454,int_stack+59478,int_stack+58218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61134, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+58218,int_stack+30036,int_stack+29910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32250, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+42630,int_stack+30204,int_stack+30036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32502, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+28980,int_stack+42630,int_stack+58218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43134, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+59478,int_stack+30420,int_stack+30204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32838, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+93462,int_stack+59478,int_stack+42630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61134, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+42630,int_stack+30816,int_stack+30690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+58218,int_stack+30984,int_stack+30816, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29736,int_stack+58218,int_stack+42630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+59478,int_stack+31200,int_stack+30984, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+94470,int_stack+59478,int_stack+58218, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+58218,int_stack+31596,int_stack+31470, 0.0, zero_stack, 1.0, int_stack+32250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+42630,int_stack+31764,int_stack+31596, 0.0, zero_stack, 1.0, int_stack+32502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30492,int_stack+42630,int_stack+58218, 0.0, zero_stack, 1.0, int_stack+43134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+59478,int_stack+31980,int_stack+31764, 0.0, zero_stack, 1.0, int_stack+32838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+95478,int_stack+59478,int_stack+42630, 0.0, zero_stack, 1.0, int_stack+61134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+42630,int_stack+32670,int_stack+32376, 1.0, int_stack+32250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+58218,int_stack+33054,int_stack+32670, 1.0, int_stack+32502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+31248,int_stack+58218,int_stack+42630, 1.0, int_stack+43134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+59478,int_stack+33270,int_stack+33054, 1.0, int_stack+32838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+32004,int_stack+59478,int_stack+58218, 1.0, int_stack+61134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+61134,int_stack+33666,int_stack+33540,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+58218,int_stack+33834,int_stack+33666,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+42630,int_stack+58218,int_stack+61134,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+61134,int_stack+34050,int_stack+33834,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+33012,int_stack+61134,int_stack+58218,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+58218,int_stack+34446,int_stack+34320,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+52890,int_stack+34614,int_stack+34446,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+96486,int_stack+52890,int_stack+58218,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+61134,int_stack+34830,int_stack+34614,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+34020,int_stack+61134,int_stack+52890,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+52890,int_stack+35226,int_stack+35100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39000,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+58218,int_stack+35394,int_stack+35226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39252,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+97242,int_stack+58218,int_stack+52890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63546,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+61134,int_stack+35610,int_stack+35394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39588,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+97998,int_stack+61134,int_stack+58218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1764,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+58218,int_stack+36006,int_stack+35880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39000, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+52890,int_stack+36174,int_stack+36006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39252, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+35028,int_stack+52890,int_stack+58218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63546, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+61134,int_stack+36390,int_stack+36174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39588, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+99006,int_stack+61134,int_stack+52890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1764, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+52890,int_stack+36786,int_stack+36660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39000, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+58218,int_stack+36954,int_stack+36786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39252, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+35784,int_stack+58218,int_stack+52890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63546, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+61134,int_stack+37170,int_stack+36954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39588, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+100014,int_stack+61134,int_stack+58218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1764, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+58218,int_stack+37566,int_stack+37440, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+52890,int_stack+37734,int_stack+37566, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+36540,int_stack+52890,int_stack+58218, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+61134,int_stack+37950,int_stack+37734, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+101022,int_stack+61134,int_stack+52890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+52890,int_stack+38346,int_stack+38220, 0.0, zero_stack, 1.0, int_stack+39000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+58218,int_stack+38514,int_stack+38346, 0.0, zero_stack, 1.0, int_stack+39252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+37296,int_stack+58218,int_stack+52890, 0.0, zero_stack, 1.0, int_stack+63546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+61134,int_stack+38730,int_stack+38514, 0.0, zero_stack, 1.0, int_stack+39588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+102030,int_stack+61134,int_stack+58218, 0.0, zero_stack, 1.0, int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+58218,int_stack+39420,int_stack+39126, 1.0, int_stack+39000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+52890,int_stack+39804,int_stack+39420, 1.0, int_stack+39252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+38052,int_stack+52890,int_stack+58218, 1.0, int_stack+63546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+63546,int_stack+40020,int_stack+39804, 1.0, int_stack+39588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+38808,int_stack+63546,int_stack+52890, 1.0, int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1764,int_stack+40416,int_stack+40290,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+52890,int_stack+40584,int_stack+40416,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+39816,int_stack+52890,int_stack+1764,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+63546,int_stack+40800,int_stack+40584,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1764,int_stack+63546,int_stack+52890,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+52890,int_stack+41196,int_stack+41070,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+58218,int_stack+41364,int_stack+41196,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+40572,int_stack+58218,int_stack+52890,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+63546,int_stack+41580,int_stack+41364,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+103038,int_stack+63546,int_stack+58218,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+58218,int_stack+41976,int_stack+41850,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+52890,int_stack+42144,int_stack+41976,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+41328,int_stack+52890,int_stack+58218,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+63546,int_stack+42360,int_stack+42144,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+104046,int_stack+63546,int_stack+52890,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+105054,int_stack+46554,int_stack+45150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43512,6);
     Libderiv->ABCD[11] = int_stack + 105054;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+45906,int_stack+49470,int_stack+48066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43512, 0.0, zero_stack,6);
     Libderiv->ABCD[10] = int_stack + 45906;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48822,int_stack+51882,int_stack+50478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43512, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[9] = int_stack + 48822;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+51234,int_stack+54798,int_stack+53394, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[8] = int_stack + 51234;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+54150,int_stack+57210,int_stack+55806, 0.0, zero_stack, 1.0, int_stack+43512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[7] = int_stack + 54150;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+56562,int_stack+60126,int_stack+58722, 1.0, int_stack+43512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[6] = int_stack + 56562;
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+59478,int_stack+61782,int_stack+1008,6);
     Libderiv->ABCD[2] = int_stack + 59478;
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+60738,int_stack+64194,int_stack+62790,6);
     Libderiv->ABCD[1] = int_stack + 60738;
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+63546,int_stack+66606,int_stack+65202,6);
     Libderiv->ABCD[0] = int_stack + 63546;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+65958,int_stack+68370,int_stack+67614, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+45150,6);
     Libderiv->ABCD[155] = int_stack + 65958;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+67218,int_stack+69378,int_stack+2772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45150, 1.0, int_stack+48066,6);
     Libderiv->ABCD[143] = int_stack + 67218;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+68478,int_stack+71034,int_stack+3528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+48066, 0.0, zero_stack,6);
     Libderiv->ABCD[142] = int_stack + 68478;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2772,int_stack+72042,int_stack+4284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45150, 0.0, zero_stack, 1.0, int_stack+50478,6);
     Libderiv->ABCD[131] = int_stack + 2772;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+69738,int_stack+73050,int_stack+5040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48066, 1.0, int_stack+50478, 0.0, zero_stack,6);
     Libderiv->ABCD[130] = int_stack + 69738;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4032,int_stack+74058,int_stack+5796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+50478, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[129] = int_stack + 4032;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5292,int_stack+75066,int_stack+6552, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53394,6);
     Libderiv->ABCD[119] = int_stack + 5292;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+70998,int_stack+76074,int_stack+7308, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48066, 0.0, zero_stack, 1.0, int_stack+53394, 0.0, zero_stack,6);
     Libderiv->ABCD[118] = int_stack + 70998;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6552,int_stack+77082,int_stack+8064, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50478, 1.0, int_stack+53394, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[117] = int_stack + 6552;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+72258,int_stack+78090,int_stack+8820, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+53394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[116] = int_stack + 72258;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7812,int_stack+79098,int_stack+9576, 0.0, zero_stack, 1.0, int_stack+45150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55806,6);
     Libderiv->ABCD[107] = int_stack + 7812;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+9072,int_stack+80106,int_stack+10332, 0.0, zero_stack, 1.0, int_stack+48066, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55806, 0.0, zero_stack,6);
     Libderiv->ABCD[106] = int_stack + 9072;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+73518,int_stack+81114,int_stack+11088, 0.0, zero_stack, 1.0, int_stack+50478, 0.0, zero_stack, 1.0, int_stack+55806, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[105] = int_stack + 73518;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10332,int_stack+82122,int_stack+11844, 0.0, zero_stack, 1.0, int_stack+53394, 1.0, int_stack+55806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[104] = int_stack + 10332;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+74778,int_stack+83130,int_stack+12600, 0.0, zero_stack, 2.0, int_stack+55806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[103] = int_stack + 74778;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11592,int_stack+14112,int_stack+13356, 1.0, int_stack+45150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58722,6);
     Libderiv->ABCD[95] = int_stack + 11592;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12852,int_stack+15120,int_stack+44268, 1.0, int_stack+48066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58722, 0.0, zero_stack,6);
     Libderiv->ABCD[94] = int_stack + 12852;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+14112,int_stack+16884,int_stack+16128, 1.0, int_stack+50478, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58722, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[93] = int_stack + 14112;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+15372,int_stack+84138,int_stack+17892, 1.0, int_stack+53394, 0.0, zero_stack, 1.0, int_stack+58722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[92] = int_stack + 15372;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+16632,int_stack+19404,int_stack+18648, 1.0, int_stack+55806, 1.0, int_stack+58722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[91] = int_stack + 16632;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+17892,int_stack+20412,int_stack+0, 2.0, int_stack+58722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[90] = int_stack + 17892;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+19152,int_stack+85146,int_stack+21420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1008,6);
     Libderiv->ABCD[47] = int_stack + 19152;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+20412,int_stack+22932,int_stack+22176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1008, 0.0, zero_stack,6);
     Libderiv->ABCD[46] = int_stack + 20412;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+21672,int_stack+86910,int_stack+86154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1008, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[45] = int_stack + 21672;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+43386,int_stack+87918,int_stack+23940, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[44] = int_stack + 43386;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+44646,int_stack+88926,int_stack+24696, 0.0, zero_stack, 1.0, int_stack+1008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[43] = int_stack + 44646;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+22932,int_stack+26208,int_stack+25452, 1.0, int_stack+1008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[42] = int_stack + 22932;
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+27216,int_stack+89934,6);
     Libderiv->ABCD[38] = int_stack + 0;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+24192,int_stack+91446,int_stack+90690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62790,6);
     Libderiv->ABCD[35] = int_stack + 24192;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+25452,int_stack+92454,int_stack+28224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62790, 0.0, zero_stack,6);
     Libderiv->ABCD[34] = int_stack + 25452;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+26712,int_stack+93462,int_stack+28980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62790, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[33] = int_stack + 26712;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+27972,int_stack+94470,int_stack+29736, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[32] = int_stack + 27972;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+29232,int_stack+95478,int_stack+30492, 0.0, zero_stack, 1.0, int_stack+62790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[31] = int_stack + 29232;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+57822,int_stack+32004,int_stack+31248, 1.0, int_stack+62790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[30] = int_stack + 57822;
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+30492,int_stack+33012,int_stack+42630,6);
     Libderiv->ABCD[26] = int_stack + 30492;
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+31752,int_stack+34020,int_stack+96486,6);
     Libderiv->ABCD[25] = int_stack + 31752;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+33012,int_stack+97998,int_stack+97242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65202,6);
     Libderiv->ABCD[23] = int_stack + 33012;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+61998,int_stack+99006,int_stack+35028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65202, 0.0, zero_stack,6);
     Libderiv->ABCD[22] = int_stack + 61998;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+34272,int_stack+100014,int_stack+35784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65202, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[21] = int_stack + 34272;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+42084,int_stack+101022,int_stack+36540, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[20] = int_stack + 42084;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+35532,int_stack+102030,int_stack+37296, 0.0, zero_stack, 1.0, int_stack+65202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[19] = int_stack + 35532;
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+36792,int_stack+38808,int_stack+38052, 1.0, int_stack+65202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[18] = int_stack + 36792;
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+38052,int_stack+1764,int_stack+39816,6);
     Libderiv->ABCD[14] = int_stack + 38052;
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+39312,int_stack+103038,int_stack+40572,6);
     Libderiv->ABCD[13] = int_stack + 39312;
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1260,int_stack+104046,int_stack+41328,6);
     Libderiv->ABCD[12] = int_stack + 1260;

}
