/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_ddhg(Libderiv_t *, prim_data *);

  /* Computes derivatives of (dd|hg) integrals */

void d1hrr_order_ddhg(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[2][5][11] = int_stack + 0;
 Libderiv->deriv_classes[2][6][11] = int_stack + 126;
 Libderiv->deriv_classes[2][7][11] = int_stack + 294;
 Libderiv->deriv_classes[2][8][11] = int_stack + 510;
 Libderiv->deriv_classes[2][9][11] = int_stack + 780;
 Libderiv->deriv_classes[3][5][11] = int_stack + 1110;
 Libderiv->deriv_classes[3][6][11] = int_stack + 1320;
 Libderiv->deriv_classes[3][7][11] = int_stack + 1600;
 Libderiv->deriv_classes[3][8][11] = int_stack + 1960;
 Libderiv->deriv_classes[3][9][11] = int_stack + 2410;
 Libderiv->deriv_classes[4][5][11] = int_stack + 2960;
 Libderiv->deriv_classes[4][6][11] = int_stack + 3275;
 Libderiv->deriv_classes[4][7][11] = int_stack + 3695;
 Libderiv->deriv_classes[4][8][11] = int_stack + 4235;
 Libderiv->deriv_classes[4][9][11] = int_stack + 4910;
 Libderiv->deriv_classes[2][5][10] = int_stack + 5735;
 Libderiv->deriv_classes[2][6][10] = int_stack + 5861;
 Libderiv->deriv_classes[2][7][10] = int_stack + 6029;
 Libderiv->deriv_classes[2][8][10] = int_stack + 6245;
 Libderiv->deriv_classes[2][9][10] = int_stack + 6515;
 Libderiv->deriv_classes[3][5][10] = int_stack + 6845;
 Libderiv->deriv_classes[3][6][10] = int_stack + 7055;
 Libderiv->deriv_classes[3][7][10] = int_stack + 7335;
 Libderiv->deriv_classes[3][8][10] = int_stack + 7695;
 Libderiv->deriv_classes[3][9][10] = int_stack + 8145;
 Libderiv->deriv_classes[4][5][10] = int_stack + 8695;
 Libderiv->deriv_classes[4][6][10] = int_stack + 9010;
 Libderiv->deriv_classes[4][7][10] = int_stack + 9430;
 Libderiv->deriv_classes[4][8][10] = int_stack + 9970;
 Libderiv->deriv_classes[4][9][10] = int_stack + 10645;
 Libderiv->deriv_classes[2][5][9] = int_stack + 11470;
 Libderiv->deriv_classes[2][6][9] = int_stack + 11596;
 Libderiv->deriv_classes[2][7][9] = int_stack + 11764;
 Libderiv->deriv_classes[2][8][9] = int_stack + 11980;
 Libderiv->deriv_classes[2][9][9] = int_stack + 12250;
 Libderiv->deriv_classes[3][5][9] = int_stack + 12580;
 Libderiv->deriv_classes[3][6][9] = int_stack + 12790;
 Libderiv->deriv_classes[3][7][9] = int_stack + 13070;
 Libderiv->deriv_classes[3][8][9] = int_stack + 13430;
 Libderiv->deriv_classes[3][9][9] = int_stack + 13880;
 Libderiv->deriv_classes[4][5][9] = int_stack + 14430;
 Libderiv->deriv_classes[4][6][9] = int_stack + 14745;
 Libderiv->deriv_classes[4][7][9] = int_stack + 15165;
 Libderiv->deriv_classes[4][8][9] = int_stack + 15705;
 Libderiv->deriv_classes[4][9][9] = int_stack + 16380;
 Libderiv->deriv_classes[2][5][8] = int_stack + 17205;
 Libderiv->deriv_classes[2][6][8] = int_stack + 17331;
 Libderiv->deriv_classes[2][7][8] = int_stack + 17499;
 Libderiv->deriv_classes[2][8][8] = int_stack + 17715;
 Libderiv->deriv_classes[2][9][8] = int_stack + 17985;
 Libderiv->deriv_classes[3][5][8] = int_stack + 18315;
 Libderiv->deriv_classes[3][6][8] = int_stack + 18525;
 Libderiv->deriv_classes[3][7][8] = int_stack + 18805;
 Libderiv->deriv_classes[3][8][8] = int_stack + 19165;
 Libderiv->deriv_classes[3][9][8] = int_stack + 19615;
 Libderiv->deriv_classes[4][5][8] = int_stack + 20165;
 Libderiv->deriv_classes[4][6][8] = int_stack + 20480;
 Libderiv->deriv_classes[4][7][8] = int_stack + 20900;
 Libderiv->deriv_classes[4][8][8] = int_stack + 21440;
 Libderiv->deriv_classes[4][9][8] = int_stack + 22115;
 Libderiv->deriv_classes[2][5][7] = int_stack + 22940;
 Libderiv->deriv_classes[2][6][7] = int_stack + 23066;
 Libderiv->deriv_classes[2][7][7] = int_stack + 23234;
 Libderiv->deriv_classes[2][8][7] = int_stack + 23450;
 Libderiv->deriv_classes[2][9][7] = int_stack + 23720;
 Libderiv->deriv_classes[3][5][7] = int_stack + 24050;
 Libderiv->deriv_classes[3][6][7] = int_stack + 24260;
 Libderiv->deriv_classes[3][7][7] = int_stack + 24540;
 Libderiv->deriv_classes[3][8][7] = int_stack + 24900;
 Libderiv->deriv_classes[3][9][7] = int_stack + 25350;
 Libderiv->deriv_classes[4][5][7] = int_stack + 25900;
 Libderiv->deriv_classes[4][6][7] = int_stack + 26215;
 Libderiv->deriv_classes[4][7][7] = int_stack + 26635;
 Libderiv->deriv_classes[4][8][7] = int_stack + 27175;
 Libderiv->deriv_classes[4][9][7] = int_stack + 27850;
 Libderiv->deriv_classes[2][5][6] = int_stack + 28675;
 Libderiv->deriv_classes[2][6][6] = int_stack + 28801;
 Libderiv->deriv_classes[2][7][6] = int_stack + 28969;
 Libderiv->deriv_classes[2][8][6] = int_stack + 29185;
 Libderiv->deriv_classes[2][9][6] = int_stack + 29455;
 Libderiv->deriv_classes[3][5][6] = int_stack + 29785;
 Libderiv->deriv_classes[3][6][6] = int_stack + 29995;
 Libderiv->deriv_classes[3][7][6] = int_stack + 30275;
 Libderiv->deriv_classes[3][8][6] = int_stack + 30635;
 Libderiv->deriv_classes[3][9][6] = int_stack + 31085;
 Libderiv->dvrr_classes[4][5] = int_stack + 31635;
 Libderiv->deriv_classes[4][5][6] = int_stack + 31950;
 Libderiv->dvrr_classes[4][6] = int_stack + 32265;
 Libderiv->deriv_classes[4][6][6] = int_stack + 32685;
 Libderiv->dvrr_classes[4][7] = int_stack + 33105;
 Libderiv->deriv_classes[4][7][6] = int_stack + 33645;
 Libderiv->dvrr_classes[4][8] = int_stack + 34185;
 Libderiv->deriv_classes[4][8][6] = int_stack + 34860;
 Libderiv->deriv_classes[4][9][6] = int_stack + 35535;
 Libderiv->deriv_classes[2][5][2] = int_stack + 36360;
 Libderiv->deriv_classes[2][6][2] = int_stack + 36486;
 Libderiv->deriv_classes[2][7][2] = int_stack + 36654;
 Libderiv->deriv_classes[2][8][2] = int_stack + 36870;
 Libderiv->deriv_classes[2][9][2] = int_stack + 37140;
 Libderiv->deriv_classes[3][5][2] = int_stack + 37470;
 Libderiv->deriv_classes[3][6][2] = int_stack + 37680;
 Libderiv->deriv_classes[3][7][2] = int_stack + 37960;
 Libderiv->deriv_classes[3][8][2] = int_stack + 38320;
 Libderiv->deriv_classes[3][9][2] = int_stack + 38770;
 Libderiv->deriv_classes[4][5][2] = int_stack + 39320;
 Libderiv->deriv_classes[4][6][2] = int_stack + 39635;
 Libderiv->deriv_classes[4][7][2] = int_stack + 40055;
 Libderiv->deriv_classes[4][8][2] = int_stack + 40595;
 Libderiv->deriv_classes[4][9][2] = int_stack + 41270;
 Libderiv->deriv_classes[2][5][1] = int_stack + 42095;
 Libderiv->deriv_classes[2][6][1] = int_stack + 42221;
 Libderiv->deriv_classes[2][7][1] = int_stack + 42389;
 Libderiv->deriv_classes[2][8][1] = int_stack + 42605;
 Libderiv->deriv_classes[2][9][1] = int_stack + 42875;
 Libderiv->deriv_classes[3][5][1] = int_stack + 43205;
 Libderiv->deriv_classes[3][6][1] = int_stack + 43415;
 Libderiv->deriv_classes[3][7][1] = int_stack + 43695;
 Libderiv->deriv_classes[3][8][1] = int_stack + 44055;
 Libderiv->deriv_classes[3][9][1] = int_stack + 44505;
 Libderiv->deriv_classes[4][5][1] = int_stack + 45055;
 Libderiv->deriv_classes[4][6][1] = int_stack + 45370;
 Libderiv->deriv_classes[4][7][1] = int_stack + 45790;
 Libderiv->deriv_classes[4][8][1] = int_stack + 46330;
 Libderiv->deriv_classes[4][9][1] = int_stack + 47005;
 Libderiv->dvrr_classes[2][5] = int_stack + 47830;
 Libderiv->dvrr_classes[2][6] = int_stack + 47956;
 Libderiv->dvrr_classes[2][7] = int_stack + 48124;
 Libderiv->dvrr_classes[2][8] = int_stack + 48340;
 Libderiv->dvrr_classes[2][9] = int_stack + 48610;
 Libderiv->deriv_classes[2][5][0] = int_stack + 48940;
 Libderiv->deriv_classes[2][6][0] = int_stack + 49066;
 Libderiv->deriv_classes[2][7][0] = int_stack + 49234;
 Libderiv->deriv_classes[2][8][0] = int_stack + 49450;
 Libderiv->deriv_classes[2][9][0] = int_stack + 49720;
 Libderiv->dvrr_classes[3][5] = int_stack + 50050;
 Libderiv->dvrr_classes[3][6] = int_stack + 50260;
 Libderiv->dvrr_classes[3][7] = int_stack + 50540;
 Libderiv->dvrr_classes[3][8] = int_stack + 50900;
 Libderiv->dvrr_classes[3][9] = int_stack + 51350;
 Libderiv->deriv_classes[3][5][0] = int_stack + 51900;
 Libderiv->deriv_classes[3][6][0] = int_stack + 52110;
 Libderiv->deriv_classes[3][7][0] = int_stack + 52390;
 Libderiv->deriv_classes[3][8][0] = int_stack + 52750;
 Libderiv->deriv_classes[3][9][0] = int_stack + 53200;
 Libderiv->deriv_classes[4][5][0] = int_stack + 53750;
 Libderiv->deriv_classes[4][6][0] = int_stack + 54065;
 Libderiv->deriv_classes[4][7][0] = int_stack + 54485;
 Libderiv->deriv_classes[4][8][0] = int_stack + 55025;
 Libderiv->deriv_classes[4][9][0] = int_stack + 55700;
 memset(int_stack,0,452200);

 Libderiv->dvrr_stack = int_stack + 201926;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_ddhg(Libderiv, Data);
   Data++;
 }

 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+56525,int_stack+47956,int_stack+47830,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+56903,int_stack+48124,int_stack+47956,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+57407,int_stack+56903,int_stack+56525,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+58163,int_stack+48340,int_stack+48124,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+58811,int_stack+58163,int_stack+56903,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+59819,int_stack+58811,int_stack+57407,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+61079,int_stack+126,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47830,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+61457,int_stack+294,int_stack+126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47956,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+61961,int_stack+61457,int_stack+61079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56525,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+62717,int_stack+510,int_stack+294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48124,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+63365,int_stack+62717,int_stack+61457, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56903,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+64373,int_stack+63365,int_stack+61961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57407,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+61079,int_stack+780,int_stack+510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48340,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+65633,int_stack+61079,int_stack+62717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58163,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+61079,int_stack+65633,int_stack+63365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58811,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+65633,int_stack+61079,int_stack+64373, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59819,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+61079,int_stack+50260,int_stack+50050,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+61709,int_stack+50540,int_stack+50260,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+62549,int_stack+61709,int_stack+61079,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+63809,int_stack+50900,int_stack+50540,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+67523,int_stack+63809,int_stack+61709,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+69203,int_stack+67523,int_stack+62549,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+64889,int_stack+1320,int_stack+1110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50050,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+1600,int_stack+1320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50260,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+71303,int_stack+0,int_stack+64889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61079,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+72563,int_stack+1960,int_stack+1600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50540,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+73643,int_stack+72563,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61709,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+75323,int_stack+73643,int_stack+71303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62549,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+2410,int_stack+1960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50900,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+77423,int_stack+0,int_stack+72563, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63809,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+77423,int_stack+73643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67523,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+71303,int_stack+0,int_stack+75323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69203,10);
 /*--- compute (dp|hg) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+74453,int_stack+71303,int_stack+65633,315);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+32265,int_stack+31635,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+945,int_stack+33105,int_stack+32265,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+64889,int_stack+945,int_stack+0,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+80123,int_stack+34185,int_stack+33105,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+81743,int_stack+80123,int_stack+945,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+84263,int_stack+81743,int_stack+64889,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+87413,int_stack+3275,int_stack+2960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31635,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+88358,int_stack+3695,int_stack+3275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32265,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+89618,int_stack+88358,int_stack+87413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+91508,int_stack+4235,int_stack+3695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33105,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+93128,int_stack+91508,int_stack+88358, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+945,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+95648,int_stack+93128,int_stack+89618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64889,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+87413,int_stack+4910,int_stack+4235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34185,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2205,int_stack+87413,int_stack+91508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80123,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+87413,int_stack+2205,int_stack+93128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81743,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+98798,int_stack+87413,int_stack+95648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84263,15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+87413,int_stack+98798,int_stack+71303,315);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+71303,int_stack+5861,int_stack+5735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47830, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+71681,int_stack+6029,int_stack+5861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47956, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+72185,int_stack+71681,int_stack+71303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56525, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+72941,int_stack+6245,int_stack+6029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48124, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+96863,int_stack+72941,int_stack+71681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56903, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+97871,int_stack+96863,int_stack+72185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57407, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+71303,int_stack+6515,int_stack+6245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48340, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+99131,int_stack+71303,int_stack+72941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58163, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+71303,int_stack+99131,int_stack+96863, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58811, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+99131,int_stack+71303,int_stack+97871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59819, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+71303,int_stack+7055,int_stack+6845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50050, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+71933,int_stack+7335,int_stack+7055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50260, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+72773,int_stack+71933,int_stack+71303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61079, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+96863,int_stack+7695,int_stack+7335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50540, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+101021,int_stack+96863,int_stack+71933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61709, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2205,int_stack+101021,int_stack+72773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62549, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+71303,int_stack+8145,int_stack+7695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50900, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4305,int_stack+71303,int_stack+96863, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63809, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+71303,int_stack+4305,int_stack+101021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67523, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4305,int_stack+71303,int_stack+2205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69203, 0.0, zero_stack,10);
 /*--- compute (dp|hg) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+101021,int_stack+4305,int_stack+99131,315);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2205,int_stack+9010,int_stack+8695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31635, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+71303,int_stack+9430,int_stack+9010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32265, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+72563,int_stack+71303,int_stack+2205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2205,int_stack+9970,int_stack+9430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33105, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+96863,int_stack+2205,int_stack+71303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+945, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+106691,int_stack+96863,int_stack+72563, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64889, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+71303,int_stack+10645,int_stack+9970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34185, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7455,int_stack+71303,int_stack+2205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80123, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+109841,int_stack+7455,int_stack+96863, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81743, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+114041,int_stack+109841,int_stack+106691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84263, 0.0, zero_stack,15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+118766,int_stack+114041,int_stack+4305,315);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+106691,int_stack+11596,int_stack+11470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47830, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+107069,int_stack+11764,int_stack+11596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47956, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+107573,int_stack+107069,int_stack+106691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56525, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+108329,int_stack+11980,int_stack+11764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48124, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+108977,int_stack+108329,int_stack+107069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56903, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+109985,int_stack+108977,int_stack+107573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57407, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+106691,int_stack+12250,int_stack+11980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48340, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+111245,int_stack+106691,int_stack+108329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58163, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+106691,int_stack+111245,int_stack+108977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58811, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+111245,int_stack+106691,int_stack+109985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59819, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+106691,int_stack+12790,int_stack+12580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50050, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+107321,int_stack+13070,int_stack+12790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50260, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+108161,int_stack+107321,int_stack+106691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61079, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+109421,int_stack+13430,int_stack+13070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50540, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+113135,int_stack+109421,int_stack+107321, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61709, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+114815,int_stack+113135,int_stack+108161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62549, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+106691,int_stack+13880,int_stack+13430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50900, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+96863,int_stack+106691,int_stack+109421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63809, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+106691,int_stack+96863,int_stack+113135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67523, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+71303,int_stack+106691,int_stack+114815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69203, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hg) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+2205,int_stack+71303,int_stack+111245,315);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+106691,int_stack+14745,int_stack+14430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31635, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+107636,int_stack+15165,int_stack+14745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32265, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+108896,int_stack+107636,int_stack+106691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+110786,int_stack+15705,int_stack+15165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33105, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+112406,int_stack+110786,int_stack+107636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+945, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+114926,int_stack+112406,int_stack+108896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64889, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+106691,int_stack+16380,int_stack+15705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34185, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+96863,int_stack+106691,int_stack+110786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80123, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+106691,int_stack+96863,int_stack+112406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81743, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7875,int_stack+106691,int_stack+114926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84263, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+106691,int_stack+7875,int_stack+71303,315);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+71303,int_stack+17331,int_stack+17205, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+71681,int_stack+17499,int_stack+17331, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+72185,int_stack+71681,int_stack+71303, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+72941,int_stack+17715,int_stack+17499, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7875,int_stack+72941,int_stack+71681, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56903, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8883,int_stack+7875,int_stack+72185, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+57407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+71303,int_stack+17985,int_stack+17715, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10143,int_stack+71303,int_stack+72941, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58163, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+71303,int_stack+10143,int_stack+7875, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58811, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10143,int_stack+71303,int_stack+8883, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+71303,int_stack+18525,int_stack+18315, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+71933,int_stack+18805,int_stack+18525, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+72773,int_stack+71933,int_stack+71303, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7875,int_stack+19165,int_stack+18805, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12033,int_stack+7875,int_stack+71933, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61709, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13713,int_stack+12033,int_stack+72773, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+71303,int_stack+19615,int_stack+19165, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+15813,int_stack+71303,int_stack+7875, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+71303,int_stack+15813,int_stack+12033, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+15813,int_stack+71303,int_stack+13713, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hg) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+128216,int_stack+15813,int_stack+10143,315);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+71303,int_stack+20480,int_stack+20165, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+72248,int_stack+20900,int_stack+20480, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+18963,int_stack+72248,int_stack+71303, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7875,int_stack+21440,int_stack+20900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+9495,int_stack+7875,int_stack+72248, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+71303,int_stack+9495,int_stack+18963, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+18963,int_stack+22115,int_stack+21440, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12015,int_stack+18963,int_stack+7875, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+133886,int_stack+12015,int_stack+9495, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7875,int_stack+133886,int_stack+71303, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+84263, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+133886,int_stack+7875,int_stack+15813,315);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7875,int_stack+23066,int_stack+22940, 0.0, zero_stack, 1.0, int_stack+47830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8253,int_stack+23234,int_stack+23066, 0.0, zero_stack, 1.0, int_stack+47956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8757,int_stack+8253,int_stack+7875, 0.0, zero_stack, 1.0, int_stack+56525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+9513,int_stack+23450,int_stack+23234, 0.0, zero_stack, 1.0, int_stack+48124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10161,int_stack+9513,int_stack+8253, 0.0, zero_stack, 1.0, int_stack+56903, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11169,int_stack+10161,int_stack+8757, 0.0, zero_stack, 1.0, int_stack+57407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7875,int_stack+23720,int_stack+23450, 0.0, zero_stack, 1.0, int_stack+48340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12429,int_stack+7875,int_stack+9513, 0.0, zero_stack, 1.0, int_stack+58163, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7875,int_stack+12429,int_stack+10161, 0.0, zero_stack, 1.0, int_stack+58811, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12429,int_stack+7875,int_stack+11169, 0.0, zero_stack, 1.0, int_stack+59819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7875,int_stack+24260,int_stack+24050, 0.0, zero_stack, 1.0, int_stack+50050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8505,int_stack+24540,int_stack+24260, 0.0, zero_stack, 1.0, int_stack+50260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9345,int_stack+8505,int_stack+7875, 0.0, zero_stack, 1.0, int_stack+61079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10605,int_stack+24900,int_stack+24540, 0.0, zero_stack, 1.0, int_stack+50540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+14319,int_stack+10605,int_stack+8505, 0.0, zero_stack, 1.0, int_stack+61709, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+15999,int_stack+14319,int_stack+9345, 0.0, zero_stack, 1.0, int_stack+62549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7875,int_stack+25350,int_stack+24900, 0.0, zero_stack, 1.0, int_stack+50900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+18099,int_stack+7875,int_stack+10605, 0.0, zero_stack, 1.0, int_stack+63809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7875,int_stack+18099,int_stack+14319, 0.0, zero_stack, 1.0, int_stack+67523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+71303,int_stack+7875,int_stack+15999, 0.0, zero_stack, 1.0, int_stack+69203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hg) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+14319,int_stack+71303,int_stack+12429,315);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7875,int_stack+26215,int_stack+25900, 0.0, zero_stack, 1.0, int_stack+31635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8820,int_stack+26635,int_stack+26215, 0.0, zero_stack, 1.0, int_stack+32265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10080,int_stack+8820,int_stack+7875, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11970,int_stack+27175,int_stack+26635, 0.0, zero_stack, 1.0, int_stack+33105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+19989,int_stack+11970,int_stack+8820, 0.0, zero_stack, 1.0, int_stack+945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+22509,int_stack+19989,int_stack+10080, 0.0, zero_stack, 1.0, int_stack+64889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7875,int_stack+27850,int_stack+27175, 0.0, zero_stack, 1.0, int_stack+34185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+96863,int_stack+7875,int_stack+11970, 0.0, zero_stack, 1.0, int_stack+80123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7875,int_stack+96863,int_stack+19989, 0.0, zero_stack, 1.0, int_stack+81743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+143336,int_stack+7875,int_stack+22509, 0.0, zero_stack, 1.0, int_stack+84263, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+148061,int_stack+143336,int_stack+71303,315);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+71303,int_stack+28801,int_stack+28675, 1.0, int_stack+47830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+71681,int_stack+28969,int_stack+28801, 1.0, int_stack+47956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+72185,int_stack+71681,int_stack+71303, 1.0, int_stack+56525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+72941,int_stack+29185,int_stack+28969, 1.0, int_stack+48124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+143336,int_stack+72941,int_stack+71681, 1.0, int_stack+56903, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+144344,int_stack+143336,int_stack+72185, 1.0, int_stack+57407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+56525,int_stack+29455,int_stack+29185, 1.0, int_stack+48340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+71303,int_stack+56525,int_stack+72941, 1.0, int_stack+58163, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+72599,int_stack+71303,int_stack+143336, 1.0, int_stack+58811, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+145604,int_stack+72599,int_stack+144344, 1.0, int_stack+59819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+143336,int_stack+29995,int_stack+29785, 1.0, int_stack+50050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+143966,int_stack+30275,int_stack+29995, 1.0, int_stack+50260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+71303,int_stack+143966,int_stack+143336, 1.0, int_stack+61079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+72563,int_stack+30635,int_stack+30275, 1.0, int_stack+50540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7875,int_stack+72563,int_stack+143966, 1.0, int_stack+61709, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+143336,int_stack+7875,int_stack+71303, 1.0, int_stack+62549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+61079,int_stack+31085,int_stack+30635, 1.0, int_stack+50900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+9555,int_stack+61079,int_stack+72563, 1.0, int_stack+63809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+71303,int_stack+9555,int_stack+7875, 1.0, int_stack+67523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7875,int_stack+71303,int_stack+143336, 1.0, int_stack+69203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (dp|hg) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+19989,int_stack+7875,int_stack+145604,315);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+143336,int_stack+32685,int_stack+31950, 1.0, int_stack+31635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+144281,int_stack+33645,int_stack+32685, 1.0, int_stack+32265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+145541,int_stack+144281,int_stack+143336, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+71303,int_stack+34860,int_stack+33645, 1.0, int_stack+33105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11025,int_stack+71303,int_stack+144281, 1.0, int_stack+945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+25659,int_stack+11025,int_stack+145541, 1.0, int_stack+64889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+64889,int_stack+35535,int_stack+34860, 1.0, int_stack+34185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+143336,int_stack+64889,int_stack+71303, 1.0, int_stack+80123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+28809,int_stack+143336,int_stack+11025, 1.0, int_stack+81743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+143336,int_stack+28809,int_stack+25659, 1.0, int_stack+84263, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+25659,int_stack+143336,int_stack+7875,315);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7875,int_stack+48610,int_stack+48340,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+8685,int_stack+7875,int_stack+58163,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+9981,int_stack+8685,int_stack+58811,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7875,int_stack+9981,int_stack+59819,6);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+9765,int_stack+51350,int_stack+50900,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+11115,int_stack+9765,int_stack+63809,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+143336,int_stack+11115,int_stack+67523,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+71303,int_stack+143336,int_stack+69203,10);
 /*--- compute (dp|hg) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+80123,int_stack+71303,int_stack+7875,315);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+143336,int_stack+36486,int_stack+36360,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+143714,int_stack+36654,int_stack+36486,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+144218,int_stack+143714,int_stack+143336,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+144974,int_stack+36870,int_stack+36654,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+145622,int_stack+144974,int_stack+143714,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+146630,int_stack+145622,int_stack+144218,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+143336,int_stack+37140,int_stack+36870,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+9765,int_stack+143336,int_stack+144974,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+143336,int_stack+9765,int_stack+145622,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+9765,int_stack+143336,int_stack+146630,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+143336,int_stack+37680,int_stack+37470,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+143966,int_stack+37960,int_stack+37680,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+144806,int_stack+143966,int_stack+143336,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+146066,int_stack+38320,int_stack+37960,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+11655,int_stack+146066,int_stack+143966,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+35109,int_stack+11655,int_stack+144806,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+143336,int_stack+38770,int_stack+38320,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+143336,int_stack+146066,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+143336,int_stack+0,int_stack+11655,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+56525,int_stack+143336,int_stack+35109,10);
 /*--- compute (dp|hg) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+59675,int_stack+56525,int_stack+9765, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+9765,int_stack+39635,int_stack+39320,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+10710,int_stack+40055,int_stack+39635,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+11970,int_stack+10710,int_stack+9765,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+85793,int_stack+40595,int_stack+40055,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+35109,int_stack+85793,int_stack+10710,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+143336,int_stack+35109,int_stack+11970,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+9765,int_stack+41270,int_stack+40595,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+37629,int_stack+9765,int_stack+85793,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+9765,int_stack+37629,int_stack+35109,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+35109,int_stack+9765,int_stack+143336,15);
 /*--- compute (fp|hg) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+157511,int_stack+35109,int_stack+56525, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+56525,int_stack+42221,int_stack+42095,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+56903,int_stack+42389,int_stack+42221,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+57407,int_stack+56903,int_stack+56525,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+58163,int_stack+42605,int_stack+42389,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+35109,int_stack+58163,int_stack+56903,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+36117,int_stack+35109,int_stack+57407,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+56525,int_stack+42875,int_stack+42605,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+37377,int_stack+56525,int_stack+58163,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+56525,int_stack+37377,int_stack+35109,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+37377,int_stack+56525,int_stack+36117,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+56525,int_stack+43415,int_stack+43205,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+57155,int_stack+43695,int_stack+43415,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+57995,int_stack+57155,int_stack+56525,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+35109,int_stack+44055,int_stack+43695,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+39267,int_stack+35109,int_stack+57155,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+40947,int_stack+39267,int_stack+57995,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+56525,int_stack+44505,int_stack+44055,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+143336,int_stack+56525,int_stack+35109,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+56525,int_stack+143336,int_stack+39267,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+143336,int_stack+56525,int_stack+40947,10);
 /*--- compute (dp|hg) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+39267,int_stack+143336,int_stack+37377, 0.0, zero_stack, 1.0, int_stack+7875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+56525,int_stack+45370,int_stack+45055,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+57470,int_stack+45790,int_stack+45370,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+35109,int_stack+57470,int_stack+56525,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+85793,int_stack+46330,int_stack+45790,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+9765,int_stack+85793,int_stack+57470,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+56525,int_stack+9765,int_stack+35109,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+35109,int_stack+47005,int_stack+46330,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+44937,int_stack+35109,int_stack+85793,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+65345,int_stack+44937,int_stack+9765,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+166961,int_stack+65345,int_stack+56525,15);
 /*--- compute (fp|hg) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+171686,int_stack+166961,int_stack+143336, 0.0, zero_stack, 1.0, int_stack+71303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+143336,int_stack+49066,int_stack+48940,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+143714,int_stack+49234,int_stack+49066,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+144218,int_stack+143714,int_stack+143336,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+144974,int_stack+49450,int_stack+49234,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+145622,int_stack+144974,int_stack+143714,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+146630,int_stack+145622,int_stack+144218,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+143336,int_stack+49720,int_stack+49450,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+166961,int_stack+143336,int_stack+144974,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+143336,int_stack+166961,int_stack+145622,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+166961,int_stack+143336,int_stack+146630,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+143336,int_stack+52110,int_stack+51900,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+143966,int_stack+52390,int_stack+52110,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+144806,int_stack+143966,int_stack+143336,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+146066,int_stack+52750,int_stack+52390,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+168851,int_stack+146066,int_stack+143966,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+56525,int_stack+168851,int_stack+144806,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+143336,int_stack+53200,int_stack+52750,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+65345,int_stack+143336,int_stack+146066,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+143336,int_stack+65345,int_stack+168851,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+65345,int_stack+143336,int_stack+56525,10);
 /*--- compute (dp|hg) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+44937,int_stack+65345,int_stack+166961, 1.0, int_stack+7875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7875,int_stack+54065,int_stack+53750,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+8820,int_stack+54485,int_stack+54065,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+10080,int_stack+8820,int_stack+7875,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+85793,int_stack+55025,int_stack+54485,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+166961,int_stack+85793,int_stack+8820,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+56525,int_stack+166961,int_stack+10080,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7875,int_stack+55700,int_stack+55025,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+9900,int_stack+7875,int_stack+85793,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+143336,int_stack+9900,int_stack+166961,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+166961,int_stack+143336,int_stack+56525,15);
 /*--- compute (fp|hg) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+181136,int_stack+166961,int_stack+65345, 1.0, int_stack+71303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (dd|hg) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+190586,int_stack+87413,int_stack+74453,315);
     Libderiv->ABCD[11] = int_stack + 190586;
 /*--- compute (dd|hg) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+65345,int_stack+118766,int_stack+101021,315);
     Libderiv->ABCD[10] = int_stack + 65345;
 /*--- compute (dd|hg) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+85793,int_stack+106691,int_stack+2205,315);
     Libderiv->ABCD[9] = int_stack + 85793;
 /*--- compute (dd|hg) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+97133,int_stack+133886,int_stack+128216,315);
     Libderiv->ABCD[8] = int_stack + 97133;
 /*--- compute (dd|hg) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+108473,int_stack+148061,int_stack+14319,315);
     Libderiv->ABCD[7] = int_stack + 108473;
 /*--- compute (dd|hg) ---*/
   hrr1_build_dd(Libderiv->AB,int_stack+119813,int_stack+25659,int_stack+19989,315);
     Libderiv->ABCD[6] = int_stack + 119813;
 /*--- compute (dd|hg) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+131153,int_stack+157511,int_stack+59675, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[2] = int_stack + 131153;
 /*--- compute (dd|hg) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+142493,int_stack+171686,int_stack+39267, 0.0, zero_stack, 1.0, int_stack+80123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[1] = int_stack + 142493;
 /*--- compute (dd|hg) ---*/
   d1hrr1_build_dd(Libderiv->AB,int_stack+153833,int_stack+181136,int_stack+44937, 1.0, int_stack+80123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[0] = int_stack + 153833;

}
