/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_fdif(Libderiv_t *, prim_data *);

  /* Computes derivatives of (fd|if) integrals */

void d1hrr_order_fdif(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[3][6][11] = int_stack + 0;
 Libderiv->deriv_classes[3][7][11] = int_stack + 280;
 Libderiv->deriv_classes[3][8][11] = int_stack + 640;
 Libderiv->deriv_classes[3][9][11] = int_stack + 1090;
 Libderiv->deriv_classes[4][6][11] = int_stack + 1640;
 Libderiv->deriv_classes[4][7][11] = int_stack + 2060;
 Libderiv->deriv_classes[4][8][11] = int_stack + 2600;
 Libderiv->deriv_classes[4][9][11] = int_stack + 3275;
 Libderiv->deriv_classes[5][6][11] = int_stack + 4100;
 Libderiv->deriv_classes[5][7][11] = int_stack + 4688;
 Libderiv->deriv_classes[5][8][11] = int_stack + 5444;
 Libderiv->deriv_classes[5][9][11] = int_stack + 6389;
 Libderiv->deriv_classes[3][6][10] = int_stack + 7544;
 Libderiv->deriv_classes[3][7][10] = int_stack + 7824;
 Libderiv->deriv_classes[3][8][10] = int_stack + 8184;
 Libderiv->deriv_classes[3][9][10] = int_stack + 8634;
 Libderiv->deriv_classes[4][6][10] = int_stack + 9184;
 Libderiv->deriv_classes[4][7][10] = int_stack + 9604;
 Libderiv->deriv_classes[4][8][10] = int_stack + 10144;
 Libderiv->deriv_classes[4][9][10] = int_stack + 10819;
 Libderiv->deriv_classes[5][6][10] = int_stack + 11644;
 Libderiv->deriv_classes[5][7][10] = int_stack + 12232;
 Libderiv->deriv_classes[5][8][10] = int_stack + 12988;
 Libderiv->deriv_classes[5][9][10] = int_stack + 13933;
 Libderiv->deriv_classes[3][6][9] = int_stack + 15088;
 Libderiv->deriv_classes[3][7][9] = int_stack + 15368;
 Libderiv->deriv_classes[3][8][9] = int_stack + 15728;
 Libderiv->deriv_classes[3][9][9] = int_stack + 16178;
 Libderiv->deriv_classes[4][6][9] = int_stack + 16728;
 Libderiv->deriv_classes[4][7][9] = int_stack + 17148;
 Libderiv->deriv_classes[4][8][9] = int_stack + 17688;
 Libderiv->deriv_classes[4][9][9] = int_stack + 18363;
 Libderiv->deriv_classes[5][6][9] = int_stack + 19188;
 Libderiv->deriv_classes[5][7][9] = int_stack + 19776;
 Libderiv->deriv_classes[5][8][9] = int_stack + 20532;
 Libderiv->deriv_classes[5][9][9] = int_stack + 21477;
 Libderiv->deriv_classes[3][6][8] = int_stack + 22632;
 Libderiv->deriv_classes[3][7][8] = int_stack + 22912;
 Libderiv->deriv_classes[3][8][8] = int_stack + 23272;
 Libderiv->deriv_classes[3][9][8] = int_stack + 23722;
 Libderiv->deriv_classes[4][6][8] = int_stack + 24272;
 Libderiv->deriv_classes[4][7][8] = int_stack + 24692;
 Libderiv->deriv_classes[4][8][8] = int_stack + 25232;
 Libderiv->deriv_classes[4][9][8] = int_stack + 25907;
 Libderiv->deriv_classes[5][6][8] = int_stack + 26732;
 Libderiv->deriv_classes[5][7][8] = int_stack + 27320;
 Libderiv->deriv_classes[5][8][8] = int_stack + 28076;
 Libderiv->deriv_classes[5][9][8] = int_stack + 29021;
 Libderiv->deriv_classes[3][6][7] = int_stack + 30176;
 Libderiv->deriv_classes[3][7][7] = int_stack + 30456;
 Libderiv->deriv_classes[3][8][7] = int_stack + 30816;
 Libderiv->deriv_classes[3][9][7] = int_stack + 31266;
 Libderiv->deriv_classes[4][6][7] = int_stack + 31816;
 Libderiv->deriv_classes[4][7][7] = int_stack + 32236;
 Libderiv->deriv_classes[4][8][7] = int_stack + 32776;
 Libderiv->deriv_classes[4][9][7] = int_stack + 33451;
 Libderiv->deriv_classes[5][6][7] = int_stack + 34276;
 Libderiv->deriv_classes[5][7][7] = int_stack + 34864;
 Libderiv->deriv_classes[5][8][7] = int_stack + 35620;
 Libderiv->deriv_classes[5][9][7] = int_stack + 36565;
 Libderiv->deriv_classes[3][6][6] = int_stack + 37720;
 Libderiv->deriv_classes[3][7][6] = int_stack + 38000;
 Libderiv->deriv_classes[3][8][6] = int_stack + 38360;
 Libderiv->deriv_classes[3][9][6] = int_stack + 38810;
 Libderiv->deriv_classes[4][6][6] = int_stack + 39360;
 Libderiv->deriv_classes[4][7][6] = int_stack + 39780;
 Libderiv->deriv_classes[4][8][6] = int_stack + 40320;
 Libderiv->deriv_classes[4][9][6] = int_stack + 40995;
 Libderiv->dvrr_classes[5][6] = int_stack + 41820;
 Libderiv->deriv_classes[5][6][6] = int_stack + 42408;
 Libderiv->dvrr_classes[5][7] = int_stack + 42996;
 Libderiv->deriv_classes[5][7][6] = int_stack + 43752;
 Libderiv->dvrr_classes[5][8] = int_stack + 44508;
 Libderiv->deriv_classes[5][8][6] = int_stack + 45453;
 Libderiv->deriv_classes[5][9][6] = int_stack + 46398;
 Libderiv->deriv_classes[3][6][2] = int_stack + 47553;
 Libderiv->deriv_classes[3][7][2] = int_stack + 47833;
 Libderiv->deriv_classes[3][8][2] = int_stack + 48193;
 Libderiv->deriv_classes[3][9][2] = int_stack + 48643;
 Libderiv->deriv_classes[4][6][2] = int_stack + 49193;
 Libderiv->deriv_classes[4][7][2] = int_stack + 49613;
 Libderiv->deriv_classes[4][8][2] = int_stack + 50153;
 Libderiv->deriv_classes[4][9][2] = int_stack + 50828;
 Libderiv->deriv_classes[5][6][2] = int_stack + 51653;
 Libderiv->deriv_classes[5][7][2] = int_stack + 52241;
 Libderiv->deriv_classes[5][8][2] = int_stack + 52997;
 Libderiv->deriv_classes[5][9][2] = int_stack + 53942;
 Libderiv->deriv_classes[3][6][1] = int_stack + 55097;
 Libderiv->deriv_classes[3][7][1] = int_stack + 55377;
 Libderiv->deriv_classes[3][8][1] = int_stack + 55737;
 Libderiv->deriv_classes[3][9][1] = int_stack + 56187;
 Libderiv->deriv_classes[4][6][1] = int_stack + 56737;
 Libderiv->deriv_classes[4][7][1] = int_stack + 57157;
 Libderiv->deriv_classes[4][8][1] = int_stack + 57697;
 Libderiv->deriv_classes[4][9][1] = int_stack + 58372;
 Libderiv->deriv_classes[5][6][1] = int_stack + 59197;
 Libderiv->deriv_classes[5][7][1] = int_stack + 59785;
 Libderiv->deriv_classes[5][8][1] = int_stack + 60541;
 Libderiv->deriv_classes[5][9][1] = int_stack + 61486;
 Libderiv->dvrr_classes[3][6] = int_stack + 62641;
 Libderiv->dvrr_classes[3][7] = int_stack + 62921;
 Libderiv->dvrr_classes[3][8] = int_stack + 63281;
 Libderiv->dvrr_classes[3][9] = int_stack + 63731;
 Libderiv->deriv_classes[3][6][0] = int_stack + 64281;
 Libderiv->deriv_classes[3][7][0] = int_stack + 64561;
 Libderiv->deriv_classes[3][8][0] = int_stack + 64921;
 Libderiv->deriv_classes[3][9][0] = int_stack + 65371;
 Libderiv->dvrr_classes[4][6] = int_stack + 65921;
 Libderiv->dvrr_classes[4][7] = int_stack + 66341;
 Libderiv->dvrr_classes[4][8] = int_stack + 66881;
 Libderiv->dvrr_classes[4][9] = int_stack + 67556;
 Libderiv->deriv_classes[4][6][0] = int_stack + 68381;
 Libderiv->deriv_classes[4][7][0] = int_stack + 68801;
 Libderiv->deriv_classes[4][8][0] = int_stack + 69341;
 Libderiv->deriv_classes[4][9][0] = int_stack + 70016;
 Libderiv->deriv_classes[5][6][0] = int_stack + 70841;
 Libderiv->deriv_classes[5][7][0] = int_stack + 71429;
 Libderiv->deriv_classes[5][8][0] = int_stack + 72185;
 Libderiv->deriv_classes[5][9][0] = int_stack + 73130;
 memset(int_stack,0,594280);

 Libderiv->dvrr_stack = int_stack + 272631;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_fdif(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+74285,int_stack+62921,int_stack+62641,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+75125,int_stack+63281,int_stack+62921,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+76205,int_stack+75125,int_stack+74285,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+77885,int_stack+280,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62641,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+78725,int_stack+640,int_stack+280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62921,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+79805,int_stack+78725,int_stack+77885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74285,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+81485,int_stack+1090,int_stack+640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63281,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+82835,int_stack+81485,int_stack+78725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75125,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+84995,int_stack+82835,int_stack+79805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76205,10);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+77885,int_stack+66341,int_stack+65921,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+79145,int_stack+66881,int_stack+66341,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+80765,int_stack+79145,int_stack+77885,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+83285,int_stack+2060,int_stack+1640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65921,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+2600,int_stack+2060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66341,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+87795,int_stack+0,int_stack+83285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77885,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+90315,int_stack+3275,int_stack+2600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66881,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+92340,int_stack+90315,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79145,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+95580,int_stack+92340,int_stack+87795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80765,15);
 /*--- compute (fp|if) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+99780,int_stack+95580,int_stack+84995,280);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+42996,int_stack+41820,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1764,int_stack+44508,int_stack+42996,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+83285,int_stack+1764,int_stack+0,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+86813,int_stack+4688,int_stack+4100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41820,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+88577,int_stack+5444,int_stack+4688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42996,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+90845,int_stack+88577,int_stack+86813, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+108180,int_stack+6389,int_stack+5444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44508,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+111015,int_stack+108180,int_stack+88577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1764,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+115551,int_stack+111015,int_stack+90845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83285,21);
 /*--- compute (gp|if) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+121431,int_stack+115551,int_stack+95580,280);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+108180,int_stack+7824,int_stack+7544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62641, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+109020,int_stack+8184,int_stack+7824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62921, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+110100,int_stack+109020,int_stack+108180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74285, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+111780,int_stack+8634,int_stack+8184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63281, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+113130,int_stack+111780,int_stack+109020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75125, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+115290,int_stack+113130,int_stack+110100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76205, 0.0, zero_stack,10);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+108180,int_stack+9604,int_stack+9184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65921, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+109440,int_stack+10144,int_stack+9604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66341, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+111060,int_stack+109440,int_stack+108180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77885, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+118090,int_stack+10819,int_stack+10144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66881, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+86813,int_stack+118090,int_stack+109440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79145, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+90053,int_stack+86813,int_stack+111060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80765, 0.0, zero_stack,15);
 /*--- compute (fp|if) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+134031,int_stack+90053,int_stack+115290,280);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+86813,int_stack+12232,int_stack+11644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41820, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+108180,int_stack+12988,int_stack+12232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42996, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+110448,int_stack+108180,int_stack+86813, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+86813,int_stack+13933,int_stack+12988, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44508, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+113976,int_stack+86813,int_stack+108180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1764, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4032,int_stack+113976,int_stack+110448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83285, 0.0, zero_stack,21);
 /*--- compute (gp|if) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+108180,int_stack+4032,int_stack+90053,280);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4032,int_stack+15368,int_stack+15088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62641, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4872,int_stack+15728,int_stack+15368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62921, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5952,int_stack+4872,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74285, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7632,int_stack+16178,int_stack+15728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63281, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8982,int_stack+7632,int_stack+4872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75125, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11142,int_stack+8982,int_stack+5952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76205, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4032,int_stack+17148,int_stack+16728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65921, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5292,int_stack+17688,int_stack+17148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66341, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6912,int_stack+5292,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77885, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13942,int_stack+18363,int_stack+17688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66881, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+86813,int_stack+13942,int_stack+5292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79145, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13942,int_stack+86813,int_stack+6912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80765, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|if) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+86813,int_stack+13942,int_stack+11142,280);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+95213,int_stack+19776,int_stack+19188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41820, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+96977,int_stack+20532,int_stack+19776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42996, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4032,int_stack+96977,int_stack+95213, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7560,int_stack+21477,int_stack+20532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44508, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+142431,int_stack+7560,int_stack+96977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1764, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7560,int_stack+142431,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83285, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|if) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+142431,int_stack+7560,int_stack+13942,280);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4032,int_stack+22912,int_stack+22632, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4872,int_stack+23272,int_stack+22912, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5952,int_stack+4872,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7632,int_stack+23722,int_stack+23272, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63281, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8982,int_stack+7632,int_stack+4872, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11142,int_stack+8982,int_stack+5952, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4032,int_stack+24692,int_stack+24272, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5292,int_stack+25232,int_stack+24692, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6912,int_stack+5292,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13942,int_stack+25907,int_stack+25232, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+15967,int_stack+13942,int_stack+5292, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+19207,int_stack+15967,int_stack+6912, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|if) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+155031,int_stack+19207,int_stack+11142,280);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4032,int_stack+27320,int_stack+26732, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5796,int_stack+28076,int_stack+27320, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8064,int_stack+5796,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11592,int_stack+29021,int_stack+28076, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+44508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+14427,int_stack+11592,int_stack+5796, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+23407,int_stack+14427,int_stack+8064, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|if) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+4032,int_stack+23407,int_stack+19207,280);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+16632,int_stack+30456,int_stack+30176, 0.0, zero_stack, 1.0, int_stack+62641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+17472,int_stack+30816,int_stack+30456, 0.0, zero_stack, 1.0, int_stack+62921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+18552,int_stack+17472,int_stack+16632, 0.0, zero_stack, 1.0, int_stack+74285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+20232,int_stack+31266,int_stack+30816, 0.0, zero_stack, 1.0, int_stack+63281, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+21582,int_stack+20232,int_stack+17472, 0.0, zero_stack, 1.0, int_stack+75125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+23742,int_stack+21582,int_stack+18552, 0.0, zero_stack, 1.0, int_stack+76205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+16632,int_stack+32236,int_stack+31816, 0.0, zero_stack, 1.0, int_stack+65921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+17892,int_stack+32776,int_stack+32236, 0.0, zero_stack, 1.0, int_stack+66341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+19512,int_stack+17892,int_stack+16632, 0.0, zero_stack, 1.0, int_stack+77885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+26542,int_stack+33451,int_stack+32776, 0.0, zero_stack, 1.0, int_stack+66881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+28567,int_stack+26542,int_stack+17892, 0.0, zero_stack, 1.0, int_stack+79145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+95213,int_stack+28567,int_stack+19512, 0.0, zero_stack, 1.0, int_stack+80765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|if) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+163431,int_stack+95213,int_stack+23742,280);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+16632,int_stack+34864,int_stack+34276, 0.0, zero_stack, 1.0, int_stack+41820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+18396,int_stack+35620,int_stack+34864, 0.0, zero_stack, 1.0, int_stack+42996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+20664,int_stack+18396,int_stack+16632, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+24192,int_stack+36565,int_stack+35620, 0.0, zero_stack, 1.0, int_stack+44508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+27027,int_stack+24192,int_stack+18396, 0.0, zero_stack, 1.0, int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+31563,int_stack+27027,int_stack+20664, 0.0, zero_stack, 1.0, int_stack+83285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|if) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+16632,int_stack+31563,int_stack+95213,280);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+95213,int_stack+38000,int_stack+37720, 1.0, int_stack+62641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+96053,int_stack+38360,int_stack+38000, 1.0, int_stack+62921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+97133,int_stack+96053,int_stack+95213, 1.0, int_stack+74285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+29232,int_stack+38810,int_stack+38360, 1.0, int_stack+63281, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+30582,int_stack+29232,int_stack+96053, 1.0, int_stack+75125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+32742,int_stack+30582,int_stack+97133, 1.0, int_stack+76205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29232,int_stack+39780,int_stack+39360, 1.0, int_stack+65921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+30492,int_stack+40320,int_stack+39780, 1.0, int_stack+66341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+95213,int_stack+30492,int_stack+29232, 1.0, int_stack+77885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+97733,int_stack+40995,int_stack+40320, 1.0, int_stack+66881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+35542,int_stack+97733,int_stack+30492, 1.0, int_stack+79145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+171831,int_stack+35542,int_stack+95213, 1.0, int_stack+80765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|if) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+176031,int_stack+171831,int_stack+32742,280);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+95213,int_stack+43752,int_stack+42408, 1.0, int_stack+41820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+96977,int_stack+45453,int_stack+43752, 1.0, int_stack+42996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+29232,int_stack+96977,int_stack+95213, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+32760,int_stack+46398,int_stack+45453, 1.0, int_stack+44508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+35595,int_stack+32760,int_stack+96977, 1.0, int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+40131,int_stack+35595,int_stack+29232, 1.0, int_stack+83285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|if) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+184431,int_stack+40131,int_stack+171831,280);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+171831,int_stack+63731,int_stack+63281,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+173181,int_stack+171831,int_stack+75125,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+83285,int_stack+173181,int_stack+76205,10);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+171831,int_stack+67556,int_stack+66881,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+29232,int_stack+171831,int_stack+79145,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+171831,int_stack+29232,int_stack+80765,15);
 /*--- compute (fp|if) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+29232,int_stack+171831,int_stack+83285,280);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+37632,int_stack+47833,int_stack+47553,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+38472,int_stack+48193,int_stack+47833,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+39552,int_stack+38472,int_stack+37632,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+41232,int_stack+48643,int_stack+48193,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+42582,int_stack+41232,int_stack+38472,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+44742,int_stack+42582,int_stack+39552,10);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+37632,int_stack+49613,int_stack+49193,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+38892,int_stack+50153,int_stack+49613,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+40512,int_stack+38892,int_stack+37632,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+47542,int_stack+50828,int_stack+50153,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+47542,int_stack+38892,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+95213,int_stack+0,int_stack+40512,15);
 /*--- compute (fp|if) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+74285,int_stack+95213,int_stack+44742, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+52241,int_stack+51653,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1764,int_stack+52997,int_stack+52241,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+37632,int_stack+1764,int_stack+0,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+41160,int_stack+53942,int_stack+52997,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+43995,int_stack+41160,int_stack+1764,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+48531,int_stack+43995,int_stack+37632,21);
 /*--- compute (gp|if) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+197031,int_stack+48531,int_stack+95213, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171831, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+95213,int_stack+55377,int_stack+55097,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+96053,int_stack+55737,int_stack+55377,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+97133,int_stack+96053,int_stack+95213,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+37632,int_stack+56187,int_stack+55737,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+38982,int_stack+37632,int_stack+96053,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+41142,int_stack+38982,int_stack+97133,10);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+37632,int_stack+57157,int_stack+56737,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+38892,int_stack+57697,int_stack+57157,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+95213,int_stack+38892,int_stack+37632,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+97733,int_stack+58372,int_stack+57697,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+43942,int_stack+97733,int_stack+38892,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+47182,int_stack+43942,int_stack+95213,15);
 /*--- compute (fp|if) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+209631,int_stack+47182,int_stack+41142, 0.0, zero_stack, 1.0, int_stack+83285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+95213,int_stack+59785,int_stack+59197,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+96977,int_stack+60541,int_stack+59785,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+37632,int_stack+96977,int_stack+95213,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+41160,int_stack+61486,int_stack+60541,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+51382,int_stack+41160,int_stack+96977,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+41160,int_stack+51382,int_stack+37632,21);
 /*--- compute (gp|if) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+51382,int_stack+41160,int_stack+47182, 0.0, zero_stack, 1.0, int_stack+171831, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+37632,int_stack+64561,int_stack+64281,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+38472,int_stack+64921,int_stack+64561,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+39552,int_stack+38472,int_stack+37632,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+41232,int_stack+65371,int_stack+64921,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+42582,int_stack+41232,int_stack+38472,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+44742,int_stack+42582,int_stack+39552,10);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+37632,int_stack+68801,int_stack+68381,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+38892,int_stack+69341,int_stack+68801,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+40512,int_stack+38892,int_stack+37632,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+47542,int_stack+70016,int_stack+69341,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+63982,int_stack+47542,int_stack+38892,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+95213,int_stack+63982,int_stack+40512,15);
 /*--- compute (fp|if) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+218031,int_stack+95213,int_stack+44742, 1.0, int_stack+83285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+63982,int_stack+71429,int_stack+70841,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+65746,int_stack+72185,int_stack+71429,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+68014,int_stack+65746,int_stack+63982,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+37632,int_stack+73130,int_stack+72185,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+40467,int_stack+37632,int_stack+65746,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+45003,int_stack+40467,int_stack+68014,21);
 /*--- compute (gp|if) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+226431,int_stack+45003,int_stack+95213, 1.0, int_stack+171831, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
 /*--- compute (fd|if) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+239031,int_stack+121431,int_stack+99780,280);
     Libderiv->ABCD[11] = int_stack + 239031;
 /*--- compute (fd|if) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+255831,int_stack+108180,int_stack+134031,280);
     Libderiv->ABCD[10] = int_stack + 255831;
 /*--- compute (fd|if) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+95213,int_stack+142431,int_stack+86813,280);
     Libderiv->ABCD[9] = int_stack + 95213;
 /*--- compute (fd|if) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+112013,int_stack+4032,int_stack+155031,280);
     Libderiv->ABCD[8] = int_stack + 112013;
 /*--- compute (fd|if) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+128813,int_stack+16632,int_stack+163431,280);
     Libderiv->ABCD[7] = int_stack + 128813;
 /*--- compute (fd|if) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+145613,int_stack+184431,int_stack+176031,280);
     Libderiv->ABCD[6] = int_stack + 145613;
 /*--- compute (fd|if) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+162413,int_stack+197031,int_stack+74285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
     Libderiv->ABCD[2] = int_stack + 162413;
 /*--- compute (fd|if) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+179213,int_stack+51382,int_stack+209631, 0.0, zero_stack, 1.0, int_stack+29232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
     Libderiv->ABCD[1] = int_stack + 179213;
 /*--- compute (fd|if) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+196013,int_stack+226431,int_stack+218031, 1.0, int_stack+29232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
     Libderiv->ABCD[0] = int_stack + 196013;

}
