/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_gfhf(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gf|hf) integrals */

void d1hrr_order_gfhf(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][5][11] = int_stack + 0;
 Libderiv->deriv_classes[4][6][11] = int_stack + 315;
 Libderiv->deriv_classes[4][7][11] = int_stack + 735;
 Libderiv->deriv_classes[4][8][11] = int_stack + 1275;
 Libderiv->deriv_classes[5][5][11] = int_stack + 1950;
 Libderiv->deriv_classes[5][6][11] = int_stack + 2391;
 Libderiv->deriv_classes[5][7][11] = int_stack + 2979;
 Libderiv->deriv_classes[5][8][11] = int_stack + 3735;
 Libderiv->deriv_classes[6][5][11] = int_stack + 4680;
 Libderiv->deriv_classes[6][6][11] = int_stack + 5268;
 Libderiv->deriv_classes[6][7][11] = int_stack + 6052;
 Libderiv->deriv_classes[6][8][11] = int_stack + 7060;
 Libderiv->deriv_classes[7][5][11] = int_stack + 8320;
 Libderiv->deriv_classes[7][6][11] = int_stack + 9076;
 Libderiv->deriv_classes[7][7][11] = int_stack + 10084;
 Libderiv->deriv_classes[7][8][11] = int_stack + 11380;
 Libderiv->deriv_classes[4][5][10] = int_stack + 13000;
 Libderiv->deriv_classes[4][6][10] = int_stack + 13315;
 Libderiv->deriv_classes[4][7][10] = int_stack + 13735;
 Libderiv->deriv_classes[4][8][10] = int_stack + 14275;
 Libderiv->deriv_classes[5][5][10] = int_stack + 14950;
 Libderiv->deriv_classes[5][6][10] = int_stack + 15391;
 Libderiv->deriv_classes[5][7][10] = int_stack + 15979;
 Libderiv->deriv_classes[5][8][10] = int_stack + 16735;
 Libderiv->deriv_classes[6][5][10] = int_stack + 17680;
 Libderiv->deriv_classes[6][6][10] = int_stack + 18268;
 Libderiv->deriv_classes[6][7][10] = int_stack + 19052;
 Libderiv->deriv_classes[6][8][10] = int_stack + 20060;
 Libderiv->deriv_classes[7][5][10] = int_stack + 21320;
 Libderiv->deriv_classes[7][6][10] = int_stack + 22076;
 Libderiv->deriv_classes[7][7][10] = int_stack + 23084;
 Libderiv->deriv_classes[7][8][10] = int_stack + 24380;
 Libderiv->deriv_classes[4][5][9] = int_stack + 26000;
 Libderiv->deriv_classes[4][6][9] = int_stack + 26315;
 Libderiv->deriv_classes[4][7][9] = int_stack + 26735;
 Libderiv->deriv_classes[4][8][9] = int_stack + 27275;
 Libderiv->deriv_classes[5][5][9] = int_stack + 27950;
 Libderiv->deriv_classes[5][6][9] = int_stack + 28391;
 Libderiv->deriv_classes[5][7][9] = int_stack + 28979;
 Libderiv->deriv_classes[5][8][9] = int_stack + 29735;
 Libderiv->deriv_classes[6][5][9] = int_stack + 30680;
 Libderiv->deriv_classes[6][6][9] = int_stack + 31268;
 Libderiv->deriv_classes[6][7][9] = int_stack + 32052;
 Libderiv->deriv_classes[6][8][9] = int_stack + 33060;
 Libderiv->deriv_classes[7][5][9] = int_stack + 34320;
 Libderiv->deriv_classes[7][6][9] = int_stack + 35076;
 Libderiv->deriv_classes[7][7][9] = int_stack + 36084;
 Libderiv->deriv_classes[7][8][9] = int_stack + 37380;
 Libderiv->deriv_classes[4][5][8] = int_stack + 39000;
 Libderiv->deriv_classes[4][6][8] = int_stack + 39315;
 Libderiv->deriv_classes[4][7][8] = int_stack + 39735;
 Libderiv->deriv_classes[4][8][8] = int_stack + 40275;
 Libderiv->deriv_classes[5][5][8] = int_stack + 40950;
 Libderiv->deriv_classes[5][6][8] = int_stack + 41391;
 Libderiv->deriv_classes[5][7][8] = int_stack + 41979;
 Libderiv->deriv_classes[5][8][8] = int_stack + 42735;
 Libderiv->deriv_classes[6][5][8] = int_stack + 43680;
 Libderiv->deriv_classes[6][6][8] = int_stack + 44268;
 Libderiv->deriv_classes[6][7][8] = int_stack + 45052;
 Libderiv->deriv_classes[6][8][8] = int_stack + 46060;
 Libderiv->deriv_classes[7][5][8] = int_stack + 47320;
 Libderiv->deriv_classes[7][6][8] = int_stack + 48076;
 Libderiv->deriv_classes[7][7][8] = int_stack + 49084;
 Libderiv->deriv_classes[7][8][8] = int_stack + 50380;
 Libderiv->deriv_classes[4][5][7] = int_stack + 52000;
 Libderiv->deriv_classes[4][6][7] = int_stack + 52315;
 Libderiv->deriv_classes[4][7][7] = int_stack + 52735;
 Libderiv->deriv_classes[4][8][7] = int_stack + 53275;
 Libderiv->deriv_classes[5][5][7] = int_stack + 53950;
 Libderiv->deriv_classes[5][6][7] = int_stack + 54391;
 Libderiv->deriv_classes[5][7][7] = int_stack + 54979;
 Libderiv->deriv_classes[5][8][7] = int_stack + 55735;
 Libderiv->deriv_classes[6][5][7] = int_stack + 56680;
 Libderiv->deriv_classes[6][6][7] = int_stack + 57268;
 Libderiv->deriv_classes[6][7][7] = int_stack + 58052;
 Libderiv->deriv_classes[6][8][7] = int_stack + 59060;
 Libderiv->deriv_classes[7][5][7] = int_stack + 60320;
 Libderiv->deriv_classes[7][6][7] = int_stack + 61076;
 Libderiv->deriv_classes[7][7][7] = int_stack + 62084;
 Libderiv->deriv_classes[7][8][7] = int_stack + 63380;
 Libderiv->deriv_classes[4][5][6] = int_stack + 65000;
 Libderiv->deriv_classes[4][6][6] = int_stack + 65315;
 Libderiv->deriv_classes[4][7][6] = int_stack + 65735;
 Libderiv->deriv_classes[4][8][6] = int_stack + 66275;
 Libderiv->deriv_classes[5][5][6] = int_stack + 66950;
 Libderiv->deriv_classes[5][6][6] = int_stack + 67391;
 Libderiv->deriv_classes[5][7][6] = int_stack + 67979;
 Libderiv->deriv_classes[5][8][6] = int_stack + 68735;
 Libderiv->deriv_classes[6][5][6] = int_stack + 69680;
 Libderiv->deriv_classes[6][6][6] = int_stack + 70268;
 Libderiv->deriv_classes[6][7][6] = int_stack + 71052;
 Libderiv->deriv_classes[6][8][6] = int_stack + 72060;
 Libderiv->dvrr_classes[7][5] = int_stack + 73320;
 Libderiv->deriv_classes[7][5][6] = int_stack + 74076;
 Libderiv->dvrr_classes[7][6] = int_stack + 74832;
 Libderiv->deriv_classes[7][6][6] = int_stack + 75840;
 Libderiv->dvrr_classes[7][7] = int_stack + 76848;
 Libderiv->deriv_classes[7][7][6] = int_stack + 78144;
 Libderiv->deriv_classes[7][8][6] = int_stack + 79440;
 Libderiv->deriv_classes[4][5][2] = int_stack + 81060;
 Libderiv->deriv_classes[4][6][2] = int_stack + 81375;
 Libderiv->deriv_classes[4][7][2] = int_stack + 81795;
 Libderiv->deriv_classes[4][8][2] = int_stack + 82335;
 Libderiv->deriv_classes[5][5][2] = int_stack + 83010;
 Libderiv->deriv_classes[5][6][2] = int_stack + 83451;
 Libderiv->deriv_classes[5][7][2] = int_stack + 84039;
 Libderiv->deriv_classes[5][8][2] = int_stack + 84795;
 Libderiv->deriv_classes[6][5][2] = int_stack + 85740;
 Libderiv->deriv_classes[6][6][2] = int_stack + 86328;
 Libderiv->deriv_classes[6][7][2] = int_stack + 87112;
 Libderiv->deriv_classes[6][8][2] = int_stack + 88120;
 Libderiv->deriv_classes[7][5][2] = int_stack + 89380;
 Libderiv->deriv_classes[7][6][2] = int_stack + 90136;
 Libderiv->deriv_classes[7][7][2] = int_stack + 91144;
 Libderiv->deriv_classes[7][8][2] = int_stack + 92440;
 Libderiv->deriv_classes[4][5][1] = int_stack + 94060;
 Libderiv->deriv_classes[4][6][1] = int_stack + 94375;
 Libderiv->deriv_classes[4][7][1] = int_stack + 94795;
 Libderiv->deriv_classes[4][8][1] = int_stack + 95335;
 Libderiv->deriv_classes[5][5][1] = int_stack + 96010;
 Libderiv->deriv_classes[5][6][1] = int_stack + 96451;
 Libderiv->deriv_classes[5][7][1] = int_stack + 97039;
 Libderiv->deriv_classes[5][8][1] = int_stack + 97795;
 Libderiv->deriv_classes[6][5][1] = int_stack + 98740;
 Libderiv->deriv_classes[6][6][1] = int_stack + 99328;
 Libderiv->deriv_classes[6][7][1] = int_stack + 100112;
 Libderiv->deriv_classes[6][8][1] = int_stack + 101120;
 Libderiv->deriv_classes[7][5][1] = int_stack + 102380;
 Libderiv->deriv_classes[7][6][1] = int_stack + 103136;
 Libderiv->deriv_classes[7][7][1] = int_stack + 104144;
 Libderiv->deriv_classes[7][8][1] = int_stack + 105440;
 Libderiv->dvrr_classes[4][5] = int_stack + 107060;
 Libderiv->dvrr_classes[4][6] = int_stack + 107375;
 Libderiv->dvrr_classes[4][7] = int_stack + 107795;
 Libderiv->dvrr_classes[4][8] = int_stack + 108335;
 Libderiv->deriv_classes[4][5][0] = int_stack + 109010;
 Libderiv->deriv_classes[4][6][0] = int_stack + 109325;
 Libderiv->deriv_classes[4][7][0] = int_stack + 109745;
 Libderiv->deriv_classes[4][8][0] = int_stack + 110285;
 Libderiv->dvrr_classes[5][5] = int_stack + 110960;
 Libderiv->dvrr_classes[5][6] = int_stack + 111401;
 Libderiv->dvrr_classes[5][7] = int_stack + 111989;
 Libderiv->dvrr_classes[5][8] = int_stack + 112745;
 Libderiv->deriv_classes[5][5][0] = int_stack + 113690;
 Libderiv->deriv_classes[5][6][0] = int_stack + 114131;
 Libderiv->deriv_classes[5][7][0] = int_stack + 114719;
 Libderiv->deriv_classes[5][8][0] = int_stack + 115475;
 Libderiv->dvrr_classes[6][5] = int_stack + 116420;
 Libderiv->dvrr_classes[6][6] = int_stack + 117008;
 Libderiv->dvrr_classes[6][7] = int_stack + 117792;
 Libderiv->dvrr_classes[6][8] = int_stack + 118800;
 Libderiv->deriv_classes[6][5][0] = int_stack + 120060;
 Libderiv->deriv_classes[6][6][0] = int_stack + 120648;
 Libderiv->deriv_classes[6][7][0] = int_stack + 121432;
 Libderiv->deriv_classes[6][8][0] = int_stack + 122440;
 Libderiv->deriv_classes[7][5][0] = int_stack + 123700;
 Libderiv->deriv_classes[7][6][0] = int_stack + 124456;
 Libderiv->deriv_classes[7][7][0] = int_stack + 125464;
 Libderiv->deriv_classes[7][8][0] = int_stack + 126760;
 memset(int_stack,0,1027040);

 Libderiv->dvrr_stack = int_stack + 574360;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_gfhf(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+128380,int_stack+107375,int_stack+107060,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+129325,int_stack+107795,int_stack+107375,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+130585,int_stack+129325,int_stack+128380,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+132475,int_stack+315,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107060,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+133420,int_stack+735,int_stack+315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107375,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+134680,int_stack+133420,int_stack+132475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+128380,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+136570,int_stack+1275,int_stack+735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107795,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+138190,int_stack+136570,int_stack+133420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129325,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+140710,int_stack+138190,int_stack+134680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130585,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+132475,int_stack+111401,int_stack+110960,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+133798,int_stack+111989,int_stack+111401,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+135562,int_stack+133798,int_stack+132475,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+138208,int_stack+2391,int_stack+1950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110960,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+2979,int_stack+2391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111401,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+143860,int_stack+0,int_stack+138208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132475,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+138208,int_stack+3735,int_stack+2979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111989,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+146506,int_stack+138208,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+133798,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+146506,int_stack+143860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135562,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+143860,int_stack+0,int_stack+140710,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+138208,int_stack+117008,int_stack+116420,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+139972,int_stack+117792,int_stack+117008,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+153310,int_stack+139972,int_stack+138208,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+156838,int_stack+5268,int_stack+4680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116420,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+158602,int_stack+6052,int_stack+5268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117008,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+160954,int_stack+158602,int_stack+156838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+138208,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+164482,int_stack+7060,int_stack+6052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117792,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+167506,int_stack+164482,int_stack+158602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139972,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+172210,int_stack+167506,int_stack+160954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153310,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+156838,int_stack+172210,int_stack+0,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+178090,int_stack+156838,int_stack+143860,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+74832,int_stack+73320,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2268,int_stack+76848,int_stack+74832,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+142324,int_stack+2268,int_stack+0,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5292,int_stack+9076,int_stack+8320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73320,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+146860,int_stack+10084,int_stack+9076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74832,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+196990,int_stack+146860,int_stack+5292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5292,int_stack+11380,int_stack+10084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76848,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+201526,int_stack+5292,int_stack+146860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2268,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5292,int_stack+201526,int_stack+196990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142324,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+196990,int_stack+5292,int_stack+172210,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+214630,int_stack+196990,int_stack+156838,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+156838,int_stack+13315,int_stack+13000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107060, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+157783,int_stack+13735,int_stack+13315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107375, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+159043,int_stack+157783,int_stack+156838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+128380, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+160933,int_stack+14275,int_stack+13735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107795, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+162553,int_stack+160933,int_stack+157783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129325, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+165073,int_stack+162553,int_stack+159043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130585, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+156838,int_stack+15391,int_stack+14950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110960, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+158161,int_stack+15979,int_stack+15391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111401, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+159925,int_stack+158161,int_stack+156838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132475, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+162571,int_stack+16735,int_stack+15979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111989, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+168223,int_stack+162571,int_stack+158161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+133798, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+171751,int_stack+168223,int_stack+159925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135562, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+196990,int_stack+171751,int_stack+165073,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+156838,int_stack+18268,int_stack+17680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116420, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+158602,int_stack+19052,int_stack+18268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117008, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+160954,int_stack+158602,int_stack+156838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+138208, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+164482,int_stack+20060,int_stack+19052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117792, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+206440,int_stack+164482,int_stack+158602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139972, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+164482,int_stack+206440,int_stack+160954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153310, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+5292,int_stack+164482,int_stack+171751,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+241090,int_stack+5292,int_stack+196990,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196990,int_stack+22076,int_stack+21320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73320, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+199258,int_stack+23084,int_stack+22076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74832, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+202282,int_stack+199258,int_stack+196990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+206818,int_stack+24380,int_stack+23084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76848, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+170362,int_stack+206818,int_stack+199258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2268, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+206818,int_stack+170362,int_stack+202282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142324, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+259990,int_stack+206818,int_stack+164482,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+277630,int_stack+259990,int_stack+5292,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5292,int_stack+26315,int_stack+26000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107060, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6237,int_stack+26735,int_stack+26315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107375, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7497,int_stack+6237,int_stack+5292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+128380, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+9387,int_stack+27275,int_stack+26735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107795, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+11007,int_stack+9387,int_stack+6237, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129325, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13527,int_stack+11007,int_stack+7497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130585, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5292,int_stack+28391,int_stack+27950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110960, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6615,int_stack+28979,int_stack+28391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111401, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8379,int_stack+6615,int_stack+5292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132475, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+11025,int_stack+29735,int_stack+28979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111989, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+16677,int_stack+11025,int_stack+6615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+133798, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+20205,int_stack+16677,int_stack+8379, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135562, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+259990,int_stack+20205,int_stack+13527,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5292,int_stack+31268,int_stack+30680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116420, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7056,int_stack+32052,int_stack+31268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117008, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9408,int_stack+7056,int_stack+5292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+138208, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12936,int_stack+33060,int_stack+32052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117792, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+24615,int_stack+12936,int_stack+7056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139972, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12936,int_stack+24615,int_stack+9408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153310, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+196990,int_stack+12936,int_stack+20205,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+156838,int_stack+196990,int_stack+259990,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+259990,int_stack+35076,int_stack+34320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73320, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+262258,int_stack+36084,int_stack+35076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74832, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+265282,int_stack+262258,int_stack+259990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+269818,int_stack+37380,int_stack+36084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76848, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+18816,int_stack+269818,int_stack+262258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2268, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+269818,int_stack+18816,int_stack+265282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142324, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+18816,int_stack+269818,int_stack+12936,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+304090,int_stack+18816,int_stack+196990,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196990,int_stack+39315,int_stack+39000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+197935,int_stack+39735,int_stack+39315, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+199195,int_stack+197935,int_stack+196990, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+128380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+201085,int_stack+40275,int_stack+39735, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+202705,int_stack+201085,int_stack+197935, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+205225,int_stack+202705,int_stack+199195, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196990,int_stack+41391,int_stack+40950, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+198313,int_stack+41979,int_stack+41391, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+200077,int_stack+198313,int_stack+196990, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+202723,int_stack+42735,int_stack+41979, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111989, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+208375,int_stack+202723,int_stack+198313, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+133798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+259990,int_stack+208375,int_stack+200077, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+264400,int_stack+259990,int_stack+205225,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196990,int_stack+44268,int_stack+43680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+175738,int_stack+45052,int_stack+44268, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+198754,int_stack+175738,int_stack+196990, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+138208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+202282,int_stack+46060,int_stack+45052, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+205306,int_stack+202282,int_stack+175738, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5292,int_stack+205306,int_stack+198754, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+196990,int_stack+5292,int_stack+259990,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+11172,int_stack+196990,int_stack+264400,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+259990,int_stack+48076,int_stack+47320, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+262258,int_stack+49084,int_stack+48076, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+265282,int_stack+262258,int_stack+259990, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+269818,int_stack+50380,int_stack+49084, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+30072,int_stack+269818,int_stack+262258, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+269818,int_stack+30072,int_stack+265282, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+30072,int_stack+269818,int_stack+5292,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+330550,int_stack+30072,int_stack+196990,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196990,int_stack+52315,int_stack+52000, 0.0, zero_stack, 1.0, int_stack+107060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+197935,int_stack+52735,int_stack+52315, 0.0, zero_stack, 1.0, int_stack+107375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+199195,int_stack+197935,int_stack+196990, 0.0, zero_stack, 1.0, int_stack+128380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+201085,int_stack+53275,int_stack+52735, 0.0, zero_stack, 1.0, int_stack+107795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+202705,int_stack+201085,int_stack+197935, 0.0, zero_stack, 1.0, int_stack+129325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+205225,int_stack+202705,int_stack+199195, 0.0, zero_stack, 1.0, int_stack+130585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196990,int_stack+54391,int_stack+53950, 0.0, zero_stack, 1.0, int_stack+110960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+198313,int_stack+54979,int_stack+54391, 0.0, zero_stack, 1.0, int_stack+111401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+200077,int_stack+198313,int_stack+196990, 0.0, zero_stack, 1.0, int_stack+132475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+202723,int_stack+55735,int_stack+54979, 0.0, zero_stack, 1.0, int_stack+111989, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+208375,int_stack+202723,int_stack+198313, 0.0, zero_stack, 1.0, int_stack+133798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+30072,int_stack+208375,int_stack+200077, 0.0, zero_stack, 1.0, int_stack+135562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+34482,int_stack+30072,int_stack+205225,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196990,int_stack+57268,int_stack+56680, 0.0, zero_stack, 1.0, int_stack+116420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+175738,int_stack+58052,int_stack+57268, 0.0, zero_stack, 1.0, int_stack+117008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+198754,int_stack+175738,int_stack+196990, 0.0, zero_stack, 1.0, int_stack+138208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+202282,int_stack+59060,int_stack+58052, 0.0, zero_stack, 1.0, int_stack+117792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+205306,int_stack+202282,int_stack+175738, 0.0, zero_stack, 1.0, int_stack+139972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5292,int_stack+205306,int_stack+198754, 0.0, zero_stack, 1.0, int_stack+153310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+196990,int_stack+5292,int_stack+30072,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+357010,int_stack+196990,int_stack+34482,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+30072,int_stack+61076,int_stack+60320, 0.0, zero_stack, 1.0, int_stack+73320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+32340,int_stack+62084,int_stack+61076, 0.0, zero_stack, 1.0, int_stack+74832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+35364,int_stack+32340,int_stack+30072, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+39900,int_stack+63380,int_stack+62084, 0.0, zero_stack, 1.0, int_stack+76848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+43788,int_stack+39900,int_stack+32340, 0.0, zero_stack, 1.0, int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+49836,int_stack+43788,int_stack+35364, 0.0, zero_stack, 1.0, int_stack+142324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+259990,int_stack+49836,int_stack+5292,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+30072,int_stack+259990,int_stack+196990,210);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196990,int_stack+65315,int_stack+65000, 1.0, int_stack+107060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+197935,int_stack+65735,int_stack+65315, 1.0, int_stack+107375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+199195,int_stack+197935,int_stack+196990, 1.0, int_stack+128380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+201085,int_stack+66275,int_stack+65735, 1.0, int_stack+107795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+202705,int_stack+201085,int_stack+197935, 1.0, int_stack+129325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+205225,int_stack+202705,int_stack+199195, 1.0, int_stack+130585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196990,int_stack+67391,int_stack+66950, 1.0, int_stack+110960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+198313,int_stack+67979,int_stack+67391, 1.0, int_stack+111401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+200077,int_stack+198313,int_stack+196990, 1.0, int_stack+132475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+202723,int_stack+68735,int_stack+67979, 1.0, int_stack+111989, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+208375,int_stack+202723,int_stack+198313, 1.0, int_stack+133798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+259990,int_stack+208375,int_stack+200077, 1.0, int_stack+135562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+264400,int_stack+259990,int_stack+205225,210);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+196990,int_stack+70268,int_stack+69680, 1.0, int_stack+116420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+175738,int_stack+71052,int_stack+70268, 1.0, int_stack+117008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+198754,int_stack+175738,int_stack+196990, 1.0, int_stack+138208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+202282,int_stack+72060,int_stack+71052, 1.0, int_stack+117792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+205306,int_stack+202282,int_stack+175738, 1.0, int_stack+139972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5292,int_stack+205306,int_stack+198754, 1.0, int_stack+153310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+196990,int_stack+5292,int_stack+259990,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+375910,int_stack+196990,int_stack+264400,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+259990,int_stack+75840,int_stack+74076, 1.0, int_stack+73320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+262258,int_stack+78144,int_stack+75840, 1.0, int_stack+74832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+265282,int_stack+262258,int_stack+259990, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+269818,int_stack+79440,int_stack+78144, 1.0, int_stack+76848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+56532,int_stack+269818,int_stack+262258, 1.0, int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+269818,int_stack+56532,int_stack+265282, 1.0, int_stack+142324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+56532,int_stack+269818,int_stack+5292,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+394810,int_stack+56532,int_stack+196990,210);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+196990,int_stack+108335,int_stack+107795,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+198610,int_stack+196990,int_stack+129325,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+201130,int_stack+198610,int_stack+130585,15);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+196990,int_stack+112745,int_stack+111989,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+204280,int_stack+196990,int_stack+133798,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+207808,int_stack+204280,int_stack+135562,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+56532,int_stack+207808,int_stack+201130,210);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+204280,int_stack+118800,int_stack+117792,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+65982,int_stack+204280,int_stack+139972,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+70686,int_stack+65982,int_stack+153310,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+259990,int_stack+70686,int_stack+207808,210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+128380,int_stack+259990,int_stack+56532,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+65982,int_stack+81375,int_stack+81060,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+66927,int_stack+81795,int_stack+81375,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+68187,int_stack+66927,int_stack+65982,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+204280,int_stack+82335,int_stack+81795,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+196990,int_stack+204280,int_stack+66927,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+204280,int_stack+196990,int_stack+68187,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+196990,int_stack+83451,int_stack+83010,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+198313,int_stack+84039,int_stack+83451,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+65982,int_stack+198313,int_stack+196990,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+212218,int_stack+84795,int_stack+84039,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+76566,int_stack+212218,int_stack+198313,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+273220,int_stack+76566,int_stack+65982,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+0,int_stack+273220,int_stack+204280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+201130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+204280,int_stack+86328,int_stack+85740,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+175738,int_stack+87112,int_stack+86328,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+65982,int_stack+175738,int_stack+204280,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+204280,int_stack+88120,int_stack+87112,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+76566,int_stack+204280,int_stack+175738,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+81270,int_stack+76566,int_stack+65982,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+421270,int_stack+81270,int_stack+273220, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+207808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+434500,int_stack+421270,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+90136,int_stack+89380,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2268,int_stack+91144,int_stack+90136,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+5292,int_stack+2268,int_stack+0,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+273220,int_stack+92440,int_stack+91144,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+87150,int_stack+273220,int_stack+2268,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+147280,int_stack+87150,int_stack+5292,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+453400,int_stack+147280,int_stack+81270, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+471040,int_stack+453400,int_stack+421270, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+421270,int_stack+94375,int_stack+94060,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+422215,int_stack+94795,int_stack+94375,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+423475,int_stack+422215,int_stack+421270,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+425365,int_stack+95335,int_stack+94795,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+426985,int_stack+425365,int_stack+422215,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+429505,int_stack+426985,int_stack+423475,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+421270,int_stack+96451,int_stack+96010,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+422593,int_stack+97039,int_stack+96451,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+424357,int_stack+422593,int_stack+421270,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+427003,int_stack+97795,int_stack+97039,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+204280,int_stack+427003,int_stack+422593,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+273220,int_stack+204280,int_stack+424357,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+453400,int_stack+273220,int_stack+429505, 0.0, zero_stack, 1.0, int_stack+201130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+204280,int_stack+99328,int_stack+98740,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+175738,int_stack+100112,int_stack+99328,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+421270,int_stack+175738,int_stack+204280,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+204280,int_stack+101120,int_stack+100112,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+65982,int_stack+204280,int_stack+175738,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+424798,int_stack+65982,int_stack+421270,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+76566,int_stack+424798,int_stack+273220, 0.0, zero_stack, 1.0, int_stack+207808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+497500,int_stack+76566,int_stack+453400, 0.0, zero_stack, 1.0, int_stack+56532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+453400,int_stack+103136,int_stack+102380,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+455668,int_stack+104144,int_stack+103136,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+458692,int_stack+455668,int_stack+453400,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+463228,int_stack+105440,int_stack+104144,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+147280,int_stack+463228,int_stack+455668,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+463228,int_stack+147280,int_stack+458692,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+89796,int_stack+463228,int_stack+424798, 0.0, zero_stack, 1.0, int_stack+70686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+516400,int_stack+89796,int_stack+76566, 0.0, zero_stack, 1.0, int_stack+259990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+76566,int_stack+109325,int_stack+109010,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+77511,int_stack+109745,int_stack+109325,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+78771,int_stack+77511,int_stack+76566,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+80661,int_stack+110285,int_stack+109745,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+82281,int_stack+80661,int_stack+77511,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+84801,int_stack+82281,int_stack+78771,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+76566,int_stack+114131,int_stack+113690,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+77889,int_stack+114719,int_stack+114131,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+79653,int_stack+77889,int_stack+76566,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+82299,int_stack+115475,int_stack+114719,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+204280,int_stack+82299,int_stack+77889,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+273220,int_stack+204280,int_stack+79653,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+87951,int_stack+273220,int_stack+84801, 1.0, int_stack+201130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+76566,int_stack+120648,int_stack+120060,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+175738,int_stack+121432,int_stack+120648,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+78330,int_stack+175738,int_stack+76566,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+81858,int_stack+122440,int_stack+121432,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+65982,int_stack+81858,int_stack+175738,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+81858,int_stack+65982,int_stack+78330,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+421270,int_stack+81858,int_stack+273220, 1.0, int_stack+207808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gd|hf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+97401,int_stack+421270,int_stack+87951, 1.0, int_stack+56532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+56532,int_stack+124456,int_stack+123700,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+58800,int_stack+125464,int_stack+124456,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+61824,int_stack+58800,int_stack+56532,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+66360,int_stack+126760,int_stack+125464,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+87738,int_stack+66360,int_stack+58800,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+116301,int_stack+87738,int_stack+61824,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+453400,int_stack+116301,int_stack+81858, 1.0, int_stack+70686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+56532,int_stack+453400,int_stack+421270, 1.0, int_stack+259990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+542860,int_stack+214630,int_stack+178090,210);
     Libderiv->ABCD[11] = int_stack + 542860;
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+175738,int_stack+277630,int_stack+241090,210);
     Libderiv->ABCD[10] = int_stack + 175738;
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+207238,int_stack+304090,int_stack+156838,210);
     Libderiv->ABCD[9] = int_stack + 207238;
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+238738,int_stack+330550,int_stack+11172,210);
     Libderiv->ABCD[8] = int_stack + 238738;
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+270238,int_stack+30072,int_stack+357010,210);
     Libderiv->ABCD[7] = int_stack + 270238;
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+301738,int_stack+394810,int_stack+375910,210);
     Libderiv->ABCD[6] = int_stack + 301738;
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+333238,int_stack+471040,int_stack+434500, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+128380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[2] = int_stack + 333238;
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+364738,int_stack+516400,int_stack+497500, 0.0, zero_stack, 1.0, int_stack+128380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[1] = int_stack + 364738;
 /*--- compute (gf|hf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+396238,int_stack+56532,int_stack+97401, 1.0, int_stack+128380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[0] = int_stack + 396238;

}
