/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_gphh(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gp|hh) integrals */

void d1hrr_order_gphh(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][5][11] = int_stack + 0;
 Libderiv->deriv_classes[4][6][11] = int_stack + 315;
 Libderiv->deriv_classes[4][7][11] = int_stack + 735;
 Libderiv->deriv_classes[4][8][11] = int_stack + 1275;
 Libderiv->deriv_classes[4][9][11] = int_stack + 1950;
 Libderiv->deriv_classes[4][10][11] = int_stack + 2775;
 Libderiv->deriv_classes[5][5][11] = int_stack + 3765;
 Libderiv->deriv_classes[5][6][11] = int_stack + 4206;
 Libderiv->deriv_classes[5][7][11] = int_stack + 4794;
 Libderiv->deriv_classes[5][8][11] = int_stack + 5550;
 Libderiv->deriv_classes[5][9][11] = int_stack + 6495;
 Libderiv->deriv_classes[5][10][11] = int_stack + 7650;
 Libderiv->deriv_classes[4][5][10] = int_stack + 9036;
 Libderiv->deriv_classes[4][6][10] = int_stack + 9351;
 Libderiv->deriv_classes[4][7][10] = int_stack + 9771;
 Libderiv->deriv_classes[4][8][10] = int_stack + 10311;
 Libderiv->deriv_classes[4][9][10] = int_stack + 10986;
 Libderiv->deriv_classes[4][10][10] = int_stack + 11811;
 Libderiv->deriv_classes[5][5][10] = int_stack + 12801;
 Libderiv->deriv_classes[5][6][10] = int_stack + 13242;
 Libderiv->deriv_classes[5][7][10] = int_stack + 13830;
 Libderiv->deriv_classes[5][8][10] = int_stack + 14586;
 Libderiv->deriv_classes[5][9][10] = int_stack + 15531;
 Libderiv->deriv_classes[5][10][10] = int_stack + 16686;
 Libderiv->deriv_classes[4][5][9] = int_stack + 18072;
 Libderiv->deriv_classes[4][6][9] = int_stack + 18387;
 Libderiv->deriv_classes[4][7][9] = int_stack + 18807;
 Libderiv->deriv_classes[4][8][9] = int_stack + 19347;
 Libderiv->deriv_classes[4][9][9] = int_stack + 20022;
 Libderiv->deriv_classes[4][10][9] = int_stack + 20847;
 Libderiv->deriv_classes[5][5][9] = int_stack + 21837;
 Libderiv->deriv_classes[5][6][9] = int_stack + 22278;
 Libderiv->deriv_classes[5][7][9] = int_stack + 22866;
 Libderiv->deriv_classes[5][8][9] = int_stack + 23622;
 Libderiv->deriv_classes[5][9][9] = int_stack + 24567;
 Libderiv->deriv_classes[5][10][9] = int_stack + 25722;
 Libderiv->deriv_classes[4][5][8] = int_stack + 27108;
 Libderiv->deriv_classes[4][6][8] = int_stack + 27423;
 Libderiv->deriv_classes[4][7][8] = int_stack + 27843;
 Libderiv->deriv_classes[4][8][8] = int_stack + 28383;
 Libderiv->deriv_classes[4][9][8] = int_stack + 29058;
 Libderiv->deriv_classes[4][10][8] = int_stack + 29883;
 Libderiv->deriv_classes[5][5][8] = int_stack + 30873;
 Libderiv->deriv_classes[5][6][8] = int_stack + 31314;
 Libderiv->deriv_classes[5][7][8] = int_stack + 31902;
 Libderiv->deriv_classes[5][8][8] = int_stack + 32658;
 Libderiv->deriv_classes[5][9][8] = int_stack + 33603;
 Libderiv->deriv_classes[5][10][8] = int_stack + 34758;
 Libderiv->deriv_classes[4][5][7] = int_stack + 36144;
 Libderiv->deriv_classes[4][6][7] = int_stack + 36459;
 Libderiv->deriv_classes[4][7][7] = int_stack + 36879;
 Libderiv->deriv_classes[4][8][7] = int_stack + 37419;
 Libderiv->deriv_classes[4][9][7] = int_stack + 38094;
 Libderiv->deriv_classes[4][10][7] = int_stack + 38919;
 Libderiv->deriv_classes[5][5][7] = int_stack + 39909;
 Libderiv->deriv_classes[5][6][7] = int_stack + 40350;
 Libderiv->deriv_classes[5][7][7] = int_stack + 40938;
 Libderiv->deriv_classes[5][8][7] = int_stack + 41694;
 Libderiv->deriv_classes[5][9][7] = int_stack + 42639;
 Libderiv->deriv_classes[5][10][7] = int_stack + 43794;
 Libderiv->deriv_classes[4][5][6] = int_stack + 45180;
 Libderiv->deriv_classes[4][6][6] = int_stack + 45495;
 Libderiv->deriv_classes[4][7][6] = int_stack + 45915;
 Libderiv->deriv_classes[4][8][6] = int_stack + 46455;
 Libderiv->deriv_classes[4][9][6] = int_stack + 47130;
 Libderiv->deriv_classes[4][10][6] = int_stack + 47955;
 Libderiv->dvrr_classes[5][5] = int_stack + 48945;
 Libderiv->deriv_classes[5][5][6] = int_stack + 49386;
 Libderiv->dvrr_classes[5][6] = int_stack + 49827;
 Libderiv->deriv_classes[5][6][6] = int_stack + 50415;
 Libderiv->dvrr_classes[5][7] = int_stack + 51003;
 Libderiv->deriv_classes[5][7][6] = int_stack + 51759;
 Libderiv->dvrr_classes[5][8] = int_stack + 52515;
 Libderiv->deriv_classes[5][8][6] = int_stack + 53460;
 Libderiv->dvrr_classes[5][9] = int_stack + 54405;
 Libderiv->deriv_classes[5][9][6] = int_stack + 55560;
 Libderiv->deriv_classes[5][10][6] = int_stack + 56715;
 Libderiv->deriv_classes[4][5][2] = int_stack + 58101;
 Libderiv->deriv_classes[4][6][2] = int_stack + 58416;
 Libderiv->deriv_classes[4][7][2] = int_stack + 58836;
 Libderiv->deriv_classes[4][8][2] = int_stack + 59376;
 Libderiv->deriv_classes[4][9][2] = int_stack + 60051;
 Libderiv->deriv_classes[4][10][2] = int_stack + 60876;
 Libderiv->deriv_classes[5][5][2] = int_stack + 61866;
 Libderiv->deriv_classes[5][6][2] = int_stack + 62307;
 Libderiv->deriv_classes[5][7][2] = int_stack + 62895;
 Libderiv->deriv_classes[5][8][2] = int_stack + 63651;
 Libderiv->deriv_classes[5][9][2] = int_stack + 64596;
 Libderiv->deriv_classes[5][10][2] = int_stack + 65751;
 Libderiv->deriv_classes[4][5][1] = int_stack + 67137;
 Libderiv->deriv_classes[4][6][1] = int_stack + 67452;
 Libderiv->deriv_classes[4][7][1] = int_stack + 67872;
 Libderiv->deriv_classes[4][8][1] = int_stack + 68412;
 Libderiv->deriv_classes[4][9][1] = int_stack + 69087;
 Libderiv->deriv_classes[4][10][1] = int_stack + 69912;
 Libderiv->deriv_classes[5][5][1] = int_stack + 70902;
 Libderiv->deriv_classes[5][6][1] = int_stack + 71343;
 Libderiv->deriv_classes[5][7][1] = int_stack + 71931;
 Libderiv->deriv_classes[5][8][1] = int_stack + 72687;
 Libderiv->deriv_classes[5][9][1] = int_stack + 73632;
 Libderiv->deriv_classes[5][10][1] = int_stack + 74787;
 Libderiv->dvrr_classes[4][5] = int_stack + 76173;
 Libderiv->dvrr_classes[4][6] = int_stack + 76488;
 Libderiv->dvrr_classes[4][7] = int_stack + 76908;
 Libderiv->dvrr_classes[4][8] = int_stack + 77448;
 Libderiv->dvrr_classes[4][9] = int_stack + 78123;
 Libderiv->dvrr_classes[4][10] = int_stack + 78948;
 Libderiv->deriv_classes[4][5][0] = int_stack + 79938;
 Libderiv->deriv_classes[4][6][0] = int_stack + 80253;
 Libderiv->deriv_classes[4][7][0] = int_stack + 80673;
 Libderiv->deriv_classes[4][8][0] = int_stack + 81213;
 Libderiv->deriv_classes[4][9][0] = int_stack + 81888;
 Libderiv->deriv_classes[4][10][0] = int_stack + 82713;
 Libderiv->deriv_classes[5][5][0] = int_stack + 83703;
 Libderiv->deriv_classes[5][6][0] = int_stack + 84144;
 Libderiv->deriv_classes[5][7][0] = int_stack + 84732;
 Libderiv->deriv_classes[5][8][0] = int_stack + 85488;
 Libderiv->deriv_classes[5][9][0] = int_stack + 86433;
 Libderiv->deriv_classes[5][10][0] = int_stack + 87588;
 memset(int_stack,0,711792);

 Libderiv->dvrr_stack = int_stack + 279765;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_gphh(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+88974,int_stack+76488,int_stack+76173,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+89919,int_stack+76908,int_stack+76488,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+91179,int_stack+89919,int_stack+88974,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+93069,int_stack+77448,int_stack+76908,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+94689,int_stack+93069,int_stack+89919,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+97209,int_stack+94689,int_stack+91179,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+100359,int_stack+78123,int_stack+77448,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+102384,int_stack+100359,int_stack+93069,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+105624,int_stack+102384,int_stack+94689,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+109824,int_stack+105624,int_stack+97209,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+114549,int_stack+315,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76173,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+115494,int_stack+735,int_stack+315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76488,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+116754,int_stack+115494,int_stack+114549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88974,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+118644,int_stack+1275,int_stack+735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76908,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+120264,int_stack+118644,int_stack+115494, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89919,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+122784,int_stack+120264,int_stack+116754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91179,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+114549,int_stack+1950,int_stack+1275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77448,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+125934,int_stack+114549,int_stack+118644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93069,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+129174,int_stack+125934,int_stack+120264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94689,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+116574,int_stack+129174,int_stack+122784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97209,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+121299,int_stack+2775,int_stack+1950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78123,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+133374,int_stack+121299,int_stack+114549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100359,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+137424,int_stack+133374,int_stack+125934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102384,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+121299,int_stack+137424,int_stack+129174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105624,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+127599,int_stack+121299,int_stack+116574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109824,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+114549,int_stack+49827,int_stack+48945,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+115872,int_stack+51003,int_stack+49827,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+117636,int_stack+115872,int_stack+114549,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+120282,int_stack+52515,int_stack+51003,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+122550,int_stack+120282,int_stack+115872,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+134214,int_stack+122550,int_stack+117636,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+138624,int_stack+54405,int_stack+52515,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+141459,int_stack+138624,int_stack+120282,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+145995,int_stack+141459,int_stack+122550,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+151875,int_stack+145995,int_stack+134214,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+126078,int_stack+4206,int_stack+3765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48945,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+4794,int_stack+4206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49827,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1764,int_stack+0,int_stack+126078, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114549,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+158490,int_stack+5550,int_stack+4794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51003,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+160758,int_stack+158490,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115872,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+164286,int_stack+160758,int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117636,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+6495,int_stack+5550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52515,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+168696,int_stack+0,int_stack+158490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120282,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+173232,int_stack+168696,int_stack+160758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122550,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+179112,int_stack+173232,int_stack+164286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+134214,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+158490,int_stack+7650,int_stack+6495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54405,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+161955,int_stack+158490,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+138624,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+161955,int_stack+168696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141459,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+158490,int_stack+0,int_stack+173232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145995,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+167310,int_stack+158490,int_stack+179112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151875,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+158490,int_stack+9351,int_stack+9036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76173, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+159435,int_stack+9771,int_stack+9351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76488, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+160695,int_stack+159435,int_stack+158490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88974, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+162585,int_stack+10311,int_stack+9771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76908, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+164205,int_stack+162585,int_stack+159435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89919, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+164205,int_stack+160695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91179, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+158490,int_stack+10986,int_stack+10311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77448, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3150,int_stack+158490,int_stack+162585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93069, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6390,int_stack+3150,int_stack+164205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94689, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+160515,int_stack+6390,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97209, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+11811,int_stack+10986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78123, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+176571,int_stack+0,int_stack+158490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100359, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+180621,int_stack+176571,int_stack+3150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102384, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+0,int_stack+180621,int_stack+6390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105624, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+176571,int_stack+0,int_stack+160515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109824, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+13242,int_stack+12801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48945, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1323,int_stack+13830,int_stack+13242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49827, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3087,int_stack+1323,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114549, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5733,int_stack+14586,int_stack+13830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51003, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001,int_stack+5733,int_stack+1323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115872, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+158490,int_stack+8001,int_stack+3087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117636, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+15531,int_stack+14586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52515, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+183186,int_stack+0,int_stack+5733, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120282, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+187722,int_stack+183186,int_stack+8001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122550, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2835,int_stack+187722,int_stack+158490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+134214, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+158490,int_stack+16686,int_stack+15531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54405, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+9450,int_stack+158490,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+138624, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+158490,int_stack+9450,int_stack+183186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141459, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+193602,int_stack+158490,int_stack+187722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145995, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+183186,int_stack+193602,int_stack+2835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151875, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+158490,int_stack+18387,int_stack+18072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76173, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+159435,int_stack+18807,int_stack+18387, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76488, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+160695,int_stack+159435,int_stack+158490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88974, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+162585,int_stack+19347,int_stack+18807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76908, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+164205,int_stack+162585,int_stack+159435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89919, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+192447,int_stack+164205,int_stack+160695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91179, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+158490,int_stack+20022,int_stack+19347, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77448, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+195597,int_stack+158490,int_stack+162585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93069, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+195597,int_stack+164205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94689, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+160515,int_stack+0,int_stack+192447, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97209, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+192447,int_stack+20847,int_stack+20022, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78123, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+198837,int_stack+192447,int_stack+158490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100359, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4200,int_stack+198837,int_stack+195597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102384, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+192447,int_stack+4200,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105624, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+0,int_stack+192447,int_stack+160515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109824, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+192447,int_stack+22278,int_stack+21837, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48945, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+193770,int_stack+22866,int_stack+22278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49827, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+195534,int_stack+193770,int_stack+192447, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114549, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+198180,int_stack+23622,int_stack+22866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51003, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6615,int_stack+198180,int_stack+193770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115872, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10143,int_stack+6615,int_stack+195534, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117636, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+192447,int_stack+24567,int_stack+23622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52515, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+14553,int_stack+192447,int_stack+198180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120282, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+195282,int_stack+14553,int_stack+6615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122550, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+158490,int_stack+195282,int_stack+10143, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+134214, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6615,int_stack+25722,int_stack+24567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54405, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+19089,int_stack+6615,int_stack+192447, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+138624, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6615,int_stack+19089,int_stack+14553, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141459, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+14175,int_stack+6615,int_stack+195282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145995, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+192447,int_stack+14175,int_stack+158490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151875, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+158490,int_stack+27423,int_stack+27108, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76173, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+159435,int_stack+27843,int_stack+27423, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+160695,int_stack+159435,int_stack+158490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+162585,int_stack+28383,int_stack+27843, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+164205,int_stack+162585,int_stack+159435, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6615,int_stack+164205,int_stack+160695, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+158490,int_stack+29058,int_stack+28383, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+9765,int_stack+158490,int_stack+162585, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13005,int_stack+9765,int_stack+164205, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+160515,int_stack+13005,int_stack+6615, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6615,int_stack+29883,int_stack+29058, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+17205,int_stack+6615,int_stack+158490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+21255,int_stack+17205,int_stack+9765, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6615,int_stack+21255,int_stack+13005, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12915,int_stack+6615,int_stack+160515, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6615,int_stack+31314,int_stack+30873, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7938,int_stack+31902,int_stack+31314, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49827, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9702,int_stack+7938,int_stack+6615, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+158490,int_stack+32658,int_stack+31902, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+160758,int_stack+158490,int_stack+7938, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+19530,int_stack+160758,int_stack+9702, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6615,int_stack+33603,int_stack+32658, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+23940,int_stack+6615,int_stack+158490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+201708,int_stack+23940,int_stack+160758, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+158490,int_stack+201708,int_stack+19530, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+134214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+9450,int_stack+34758,int_stack+33603, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+28476,int_stack+9450,int_stack+6615, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+138624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+207588,int_stack+28476,int_stack+23940, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+19530,int_stack+207588,int_stack+201708, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+201708,int_stack+19530,int_stack+158490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+151875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+158490,int_stack+36459,int_stack+36144, 0.0, zero_stack, 1.0, int_stack+76173, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+159435,int_stack+36879,int_stack+36459, 0.0, zero_stack, 1.0, int_stack+76488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+160695,int_stack+159435,int_stack+158490, 0.0, zero_stack, 1.0, int_stack+88974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+162585,int_stack+37419,int_stack+36879, 0.0, zero_stack, 1.0, int_stack+76908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+164205,int_stack+162585,int_stack+159435, 0.0, zero_stack, 1.0, int_stack+89919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+19530,int_stack+164205,int_stack+160695, 0.0, zero_stack, 1.0, int_stack+91179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+158490,int_stack+38094,int_stack+37419, 0.0, zero_stack, 1.0, int_stack+77448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+22680,int_stack+158490,int_stack+162585, 0.0, zero_stack, 1.0, int_stack+93069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+25920,int_stack+22680,int_stack+164205, 0.0, zero_stack, 1.0, int_stack+94689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+160515,int_stack+25920,int_stack+19530, 0.0, zero_stack, 1.0, int_stack+97209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+19530,int_stack+38919,int_stack+38094, 0.0, zero_stack, 1.0, int_stack+78123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+30120,int_stack+19530,int_stack+158490, 0.0, zero_stack, 1.0, int_stack+100359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+34170,int_stack+30120,int_stack+22680, 0.0, zero_stack, 1.0, int_stack+102384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6615,int_stack+34170,int_stack+25920, 0.0, zero_stack, 1.0, int_stack+105624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+19530,int_stack+6615,int_stack+160515, 0.0, zero_stack, 1.0, int_stack+109824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6615,int_stack+40350,int_stack+39909, 0.0, zero_stack, 1.0, int_stack+48945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7938,int_stack+40938,int_stack+40350, 0.0, zero_stack, 1.0, int_stack+49827, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9702,int_stack+7938,int_stack+6615, 0.0, zero_stack, 1.0, int_stack+114549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+158490,int_stack+41694,int_stack+40938, 0.0, zero_stack, 1.0, int_stack+51003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+160758,int_stack+158490,int_stack+7938, 0.0, zero_stack, 1.0, int_stack+115872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+26145,int_stack+160758,int_stack+9702, 0.0, zero_stack, 1.0, int_stack+117636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6615,int_stack+42639,int_stack+41694, 0.0, zero_stack, 1.0, int_stack+52515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+30555,int_stack+6615,int_stack+158490, 0.0, zero_stack, 1.0, int_stack+120282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+35091,int_stack+30555,int_stack+160758, 0.0, zero_stack, 1.0, int_stack+122550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+158490,int_stack+35091,int_stack+26145, 0.0, zero_stack, 1.0, int_stack+134214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+9450,int_stack+43794,int_stack+42639, 0.0, zero_stack, 1.0, int_stack+54405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+210969,int_stack+9450,int_stack+6615, 0.0, zero_stack, 1.0, int_stack+138624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+216639,int_stack+210969,int_stack+30555, 0.0, zero_stack, 1.0, int_stack+141459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+26145,int_stack+216639,int_stack+35091, 0.0, zero_stack, 1.0, int_stack+145995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+210969,int_stack+26145,int_stack+158490, 0.0, zero_stack, 1.0, int_stack+151875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+158490,int_stack+45495,int_stack+45180, 1.0, int_stack+76173, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+159435,int_stack+45915,int_stack+45495, 1.0, int_stack+76488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+160695,int_stack+159435,int_stack+158490, 1.0, int_stack+88974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+162585,int_stack+46455,int_stack+45915, 1.0, int_stack+76908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+164205,int_stack+162585,int_stack+159435, 1.0, int_stack+89919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+26145,int_stack+164205,int_stack+160695, 1.0, int_stack+91179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+88974,int_stack+47130,int_stack+46455, 1.0, int_stack+77448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+158490,int_stack+88974,int_stack+162585, 1.0, int_stack+93069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+29295,int_stack+158490,int_stack+164205, 1.0, int_stack+94689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+90999,int_stack+29295,int_stack+26145, 1.0, int_stack+97209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+26145,int_stack+47955,int_stack+47130, 1.0, int_stack+78123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+95724,int_stack+26145,int_stack+88974, 1.0, int_stack+100359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+161730,int_stack+95724,int_stack+158490, 1.0, int_stack+102384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6615,int_stack+161730,int_stack+29295, 1.0, int_stack+105624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+158490,int_stack+6615,int_stack+90999, 1.0, int_stack+109824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6615,int_stack+50415,int_stack+49386, 1.0, int_stack+48945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7938,int_stack+51759,int_stack+50415, 1.0, int_stack+49827, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9702,int_stack+7938,int_stack+6615, 1.0, int_stack+114549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+88974,int_stack+53460,int_stack+51759, 1.0, int_stack+51003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+91242,int_stack+88974,int_stack+7938, 1.0, int_stack+115872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+94770,int_stack+91242,int_stack+9702, 1.0, int_stack+117636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+114549,int_stack+55560,int_stack+53460, 1.0, int_stack+52515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6615,int_stack+114549,int_stack+88974, 1.0, int_stack+120282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+26145,int_stack+6615,int_stack+91242, 1.0, int_stack+122550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+117384,int_stack+26145,int_stack+94770, 1.0, int_stack+134214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+134214,int_stack+56715,int_stack+55560, 1.0, int_stack+54405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+88974,int_stack+134214,int_stack+114549, 1.0, int_stack+138624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+32025,int_stack+88974,int_stack+6615, 1.0, int_stack+141459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+88974,int_stack+32025,int_stack+26145, 1.0, int_stack+145995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+26145,int_stack+88974,int_stack+117384, 1.0, int_stack+151875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+88974,int_stack+78948,int_stack+78123,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+91449,int_stack+88974,int_stack+100359,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+95499,int_stack+91449,int_stack+102384,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6615,int_stack+95499,int_stack+105624,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+88974,int_stack+6615,int_stack+109824,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6615,int_stack+58416,int_stack+58101,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7560,int_stack+58836,int_stack+58416,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+8820,int_stack+7560,int_stack+6615,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+10710,int_stack+59376,int_stack+58836,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+95589,int_stack+10710,int_stack+7560,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+98109,int_stack+95589,int_stack+8820,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6615,int_stack+60051,int_stack+59376,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+101259,int_stack+6615,int_stack+10710,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+8640,int_stack+101259,int_stack+95589,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+104499,int_stack+8640,int_stack+98109,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+95589,int_stack+60876,int_stack+60051,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+109224,int_stack+95589,int_stack+6615,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+95589,int_stack+109224,int_stack+101259,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+109224,int_stack+95589,int_stack+8640,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+95589,int_stack+109224,int_stack+104499,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+102204,int_stack+62307,int_stack+61866,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+103527,int_stack+62895,int_stack+62307,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+105291,int_stack+103527,int_stack+102204,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+107937,int_stack+63651,int_stack+62895,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+110205,int_stack+107937,int_stack+103527,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+113733,int_stack+110205,int_stack+105291,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+102204,int_stack+64596,int_stack+63651,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+118143,int_stack+102204,int_stack+107937,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6615,int_stack+118143,int_stack+110205,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+105039,int_stack+6615,int_stack+113733,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+111654,int_stack+65751,int_stack+64596,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+35406,int_stack+111654,int_stack+102204,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+41076,int_stack+35406,int_stack+118143,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+111654,int_stack+41076,int_stack+6615,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+35406,int_stack+111654,int_stack+105039,21);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6615,int_stack+67452,int_stack+67137,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7560,int_stack+67872,int_stack+67452,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+8820,int_stack+7560,int_stack+6615,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+10710,int_stack+68412,int_stack+67872,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+44667,int_stack+10710,int_stack+7560,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+47187,int_stack+44667,int_stack+8820,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6615,int_stack+69087,int_stack+68412,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+50337,int_stack+6615,int_stack+10710,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+8640,int_stack+50337,int_stack+44667,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+53577,int_stack+8640,int_stack+47187,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+44667,int_stack+69912,int_stack+69087,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+58302,int_stack+44667,int_stack+6615,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+44667,int_stack+58302,int_stack+50337,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+58302,int_stack+44667,int_stack+8640,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+44667,int_stack+58302,int_stack+53577,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+51282,int_stack+71343,int_stack+70902,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+52605,int_stack+71931,int_stack+71343,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+54369,int_stack+52605,int_stack+51282,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+57015,int_stack+72687,int_stack+71931,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+59283,int_stack+57015,int_stack+52605,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+62811,int_stack+59283,int_stack+54369,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+51282,int_stack+73632,int_stack+72687,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+67221,int_stack+51282,int_stack+57015,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6615,int_stack+67221,int_stack+59283,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+54117,int_stack+6615,int_stack+62811,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+60732,int_stack+74787,int_stack+73632,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+71757,int_stack+60732,int_stack+51282,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+102204,int_stack+71757,int_stack+67221,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+60732,int_stack+102204,int_stack+6615,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+102204,int_stack+60732,int_stack+54117,21);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6615,int_stack+80253,int_stack+79938,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7560,int_stack+80673,int_stack+80253,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+8820,int_stack+7560,int_stack+6615,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+10710,int_stack+81213,int_stack+80673,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+111465,int_stack+10710,int_stack+7560,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+113985,int_stack+111465,int_stack+8820,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6615,int_stack+81888,int_stack+81213,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+117135,int_stack+6615,int_stack+10710,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+8640,int_stack+117135,int_stack+111465,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+120375,int_stack+8640,int_stack+113985,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+111465,int_stack+82713,int_stack+81888,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+51282,int_stack+111465,int_stack+6615,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+111465,int_stack+51282,int_stack+117135,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+51282,int_stack+111465,int_stack+8640,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+111465,int_stack+51282,int_stack+120375,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+51282,int_stack+84144,int_stack+83703,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+52605,int_stack+84732,int_stack+84144,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+54369,int_stack+52605,int_stack+51282,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+57015,int_stack+85488,int_stack+84732,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+59283,int_stack+57015,int_stack+52605,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+62811,int_stack+59283,int_stack+54369,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+51282,int_stack+86433,int_stack+85488,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+67221,int_stack+51282,int_stack+57015,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+71757,int_stack+67221,int_stack+59283,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+54117,int_stack+71757,int_stack+62811,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+60732,int_stack+87588,int_stack+86433,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+77637,int_stack+60732,int_stack+51282,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+118080,int_stack+77637,int_stack+67221,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+77637,int_stack+118080,int_stack+71757,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+118080,int_stack+77637,int_stack+54117,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+51282,int_stack+167310,int_stack+127599,441);
     Libderiv->ABCD[11] = int_stack + 51282;
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+127341,int_stack+183186,int_stack+176571,441);
     Libderiv->ABCD[10] = int_stack + 127341;
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+165105,int_stack+192447,int_stack+0,441);
     Libderiv->ABCD[9] = int_stack + 165105;
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+220230,int_stack+201708,int_stack+12915,441);
     Libderiv->ABCD[8] = int_stack + 220230;
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+184950,int_stack+210969,int_stack+19530,441);
     Libderiv->ABCD[7] = int_stack + 184950;
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+0,int_stack+26145,int_stack+158490,441);
     Libderiv->ABCD[6] = int_stack + 0;
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+240075,int_stack+35406,int_stack+95589, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[2] = int_stack + 240075;
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+19845,int_stack+102204,int_stack+44667, 0.0, zero_stack, 1.0, int_stack+88974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[1] = int_stack + 19845;
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+259920,int_stack+118080,int_stack+111465, 1.0, int_stack+88974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[0] = int_stack + 259920;

}
