/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_hpig(Libderiv_t *, prim_data *);

  /* Computes derivatives of (hp|ig) integrals */

void d1hrr_order_hpig(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[5][6][11] = int_stack + 0;
 Libderiv->deriv_classes[5][7][11] = int_stack + 588;
 Libderiv->deriv_classes[5][8][11] = int_stack + 1344;
 Libderiv->deriv_classes[5][9][11] = int_stack + 2289;
 Libderiv->deriv_classes[5][10][11] = int_stack + 3444;
 Libderiv->deriv_classes[6][6][11] = int_stack + 4830;
 Libderiv->deriv_classes[6][7][11] = int_stack + 5614;
 Libderiv->deriv_classes[6][8][11] = int_stack + 6622;
 Libderiv->deriv_classes[6][9][11] = int_stack + 7882;
 Libderiv->deriv_classes[6][10][11] = int_stack + 9422;
 Libderiv->deriv_classes[5][6][10] = int_stack + 11270;
 Libderiv->deriv_classes[5][7][10] = int_stack + 11858;
 Libderiv->deriv_classes[5][8][10] = int_stack + 12614;
 Libderiv->deriv_classes[5][9][10] = int_stack + 13559;
 Libderiv->deriv_classes[5][10][10] = int_stack + 14714;
 Libderiv->deriv_classes[6][6][10] = int_stack + 16100;
 Libderiv->deriv_classes[6][7][10] = int_stack + 16884;
 Libderiv->deriv_classes[6][8][10] = int_stack + 17892;
 Libderiv->deriv_classes[6][9][10] = int_stack + 19152;
 Libderiv->deriv_classes[6][10][10] = int_stack + 20692;
 Libderiv->deriv_classes[5][6][9] = int_stack + 22540;
 Libderiv->deriv_classes[5][7][9] = int_stack + 23128;
 Libderiv->deriv_classes[5][8][9] = int_stack + 23884;
 Libderiv->deriv_classes[5][9][9] = int_stack + 24829;
 Libderiv->deriv_classes[5][10][9] = int_stack + 25984;
 Libderiv->deriv_classes[6][6][9] = int_stack + 27370;
 Libderiv->deriv_classes[6][7][9] = int_stack + 28154;
 Libderiv->deriv_classes[6][8][9] = int_stack + 29162;
 Libderiv->deriv_classes[6][9][9] = int_stack + 30422;
 Libderiv->deriv_classes[6][10][9] = int_stack + 31962;
 Libderiv->deriv_classes[5][6][8] = int_stack + 33810;
 Libderiv->deriv_classes[5][7][8] = int_stack + 34398;
 Libderiv->deriv_classes[5][8][8] = int_stack + 35154;
 Libderiv->deriv_classes[5][9][8] = int_stack + 36099;
 Libderiv->deriv_classes[5][10][8] = int_stack + 37254;
 Libderiv->deriv_classes[6][6][8] = int_stack + 38640;
 Libderiv->deriv_classes[6][7][8] = int_stack + 39424;
 Libderiv->deriv_classes[6][8][8] = int_stack + 40432;
 Libderiv->deriv_classes[6][9][8] = int_stack + 41692;
 Libderiv->deriv_classes[6][10][8] = int_stack + 43232;
 Libderiv->deriv_classes[5][6][7] = int_stack + 45080;
 Libderiv->deriv_classes[5][7][7] = int_stack + 45668;
 Libderiv->deriv_classes[5][8][7] = int_stack + 46424;
 Libderiv->deriv_classes[5][9][7] = int_stack + 47369;
 Libderiv->deriv_classes[5][10][7] = int_stack + 48524;
 Libderiv->deriv_classes[6][6][7] = int_stack + 49910;
 Libderiv->deriv_classes[6][7][7] = int_stack + 50694;
 Libderiv->deriv_classes[6][8][7] = int_stack + 51702;
 Libderiv->deriv_classes[6][9][7] = int_stack + 52962;
 Libderiv->deriv_classes[6][10][7] = int_stack + 54502;
 Libderiv->deriv_classes[5][6][6] = int_stack + 56350;
 Libderiv->deriv_classes[5][7][6] = int_stack + 56938;
 Libderiv->deriv_classes[5][8][6] = int_stack + 57694;
 Libderiv->deriv_classes[5][9][6] = int_stack + 58639;
 Libderiv->deriv_classes[5][10][6] = int_stack + 59794;
 Libderiv->dvrr_classes[6][6] = int_stack + 61180;
 Libderiv->deriv_classes[6][6][6] = int_stack + 61964;
 Libderiv->dvrr_classes[6][7] = int_stack + 62748;
 Libderiv->deriv_classes[6][7][6] = int_stack + 63756;
 Libderiv->dvrr_classes[6][8] = int_stack + 64764;
 Libderiv->deriv_classes[6][8][6] = int_stack + 66024;
 Libderiv->dvrr_classes[6][9] = int_stack + 67284;
 Libderiv->deriv_classes[6][9][6] = int_stack + 68824;
 Libderiv->deriv_classes[6][10][6] = int_stack + 70364;
 Libderiv->deriv_classes[5][6][2] = int_stack + 72212;
 Libderiv->deriv_classes[5][7][2] = int_stack + 72800;
 Libderiv->deriv_classes[5][8][2] = int_stack + 73556;
 Libderiv->deriv_classes[5][9][2] = int_stack + 74501;
 Libderiv->deriv_classes[5][10][2] = int_stack + 75656;
 Libderiv->deriv_classes[6][6][2] = int_stack + 77042;
 Libderiv->deriv_classes[6][7][2] = int_stack + 77826;
 Libderiv->deriv_classes[6][8][2] = int_stack + 78834;
 Libderiv->deriv_classes[6][9][2] = int_stack + 80094;
 Libderiv->deriv_classes[6][10][2] = int_stack + 81634;
 Libderiv->deriv_classes[5][6][1] = int_stack + 83482;
 Libderiv->deriv_classes[5][7][1] = int_stack + 84070;
 Libderiv->deriv_classes[5][8][1] = int_stack + 84826;
 Libderiv->deriv_classes[5][9][1] = int_stack + 85771;
 Libderiv->deriv_classes[5][10][1] = int_stack + 86926;
 Libderiv->deriv_classes[6][6][1] = int_stack + 88312;
 Libderiv->deriv_classes[6][7][1] = int_stack + 89096;
 Libderiv->deriv_classes[6][8][1] = int_stack + 90104;
 Libderiv->deriv_classes[6][9][1] = int_stack + 91364;
 Libderiv->deriv_classes[6][10][1] = int_stack + 92904;
 Libderiv->dvrr_classes[5][6] = int_stack + 94752;
 Libderiv->dvrr_classes[5][7] = int_stack + 95340;
 Libderiv->dvrr_classes[5][8] = int_stack + 96096;
 Libderiv->dvrr_classes[5][9] = int_stack + 97041;
 Libderiv->dvrr_classes[5][10] = int_stack + 98196;
 Libderiv->deriv_classes[5][6][0] = int_stack + 99582;
 Libderiv->deriv_classes[5][7][0] = int_stack + 100170;
 Libderiv->deriv_classes[5][8][0] = int_stack + 100926;
 Libderiv->deriv_classes[5][9][0] = int_stack + 101871;
 Libderiv->deriv_classes[5][10][0] = int_stack + 103026;
 Libderiv->deriv_classes[6][6][0] = int_stack + 104412;
 Libderiv->deriv_classes[6][7][0] = int_stack + 105196;
 Libderiv->deriv_classes[6][8][0] = int_stack + 106204;
 Libderiv->deriv_classes[6][9][0] = int_stack + 107464;
 Libderiv->deriv_classes[6][10][0] = int_stack + 109004;
 memset(int_stack,0,886816);

 Libderiv->dvrr_stack = int_stack + 328678;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_hpig(Libderiv, Data);
   Data++;
 }

 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+110852,int_stack+95340,int_stack+94752,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+112616,int_stack+96096,int_stack+95340,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+114884,int_stack+112616,int_stack+110852,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+118412,int_stack+97041,int_stack+96096,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+121247,int_stack+118412,int_stack+112616,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+125783,int_stack+121247,int_stack+114884,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+131663,int_stack+588,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94752,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+133427,int_stack+1344,int_stack+588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95340,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+135695,int_stack+133427,int_stack+131663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110852,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+139223,int_stack+2289,int_stack+1344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96096,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+142058,int_stack+139223,int_stack+133427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112616,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+146594,int_stack+142058,int_stack+135695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114884,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+131663,int_stack+3444,int_stack+2289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97041,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+152474,int_stack+131663,int_stack+139223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118412,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+131663,int_stack+152474,int_stack+142058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121247,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+152474,int_stack+131663,int_stack+146594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125783,21);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+131663,int_stack+62748,int_stack+61180,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+134015,int_stack+64764,int_stack+62748,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+137039,int_stack+134015,int_stack+131663,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+141743,int_stack+67284,int_stack+64764,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+145523,int_stack+141743,int_stack+134015,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+161294,int_stack+145523,int_stack+137039,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+5614,int_stack+4830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61180,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2352,int_stack+6622,int_stack+5614, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62748,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+169134,int_stack+2352,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131663,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+173838,int_stack+7882,int_stack+6622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64764,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+177618,int_stack+173838,int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+134015,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+177618,int_stack+169134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+137039,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+169134,int_stack+9422,int_stack+7882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67284,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+183666,int_stack+169134,int_stack+173838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141743,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+191226,int_stack+183666,int_stack+177618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145523,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+169134,int_stack+191226,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161294,28);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+11858,int_stack+11270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94752, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1764,int_stack+12614,int_stack+11858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95340, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4032,int_stack+1764,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110852, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7560,int_stack+13559,int_stack+12614, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96096, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+180894,int_stack+7560,int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112616, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+185430,int_stack+180894,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114884, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+14714,int_stack+13559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97041, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10395,int_stack+0,int_stack+7560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118412, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+10395,int_stack+180894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121247, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+191310,int_stack+0,int_stack+185430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125783, 0.0, zero_stack,21);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+16884,int_stack+16100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61180, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2352,int_stack+17892,int_stack+16884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62748, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5376,int_stack+2352,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131663, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10080,int_stack+19152,int_stack+17892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64764, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+180894,int_stack+10080,int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+134015, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+200130,int_stack+180894,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+137039, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+20692,int_stack+19152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67284, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13860,int_stack+0,int_stack+10080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141743, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+13860,int_stack+180894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145523, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+10080,int_stack+0,int_stack+200130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161294, 0.0, zero_stack,28);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+200130,int_stack+23128,int_stack+22540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94752, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+201894,int_stack+23884,int_stack+23128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95340, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+204162,int_stack+201894,int_stack+200130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110852, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+24829,int_stack+23884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96096, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2835,int_stack+0,int_stack+201894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112616, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+180894,int_stack+2835,int_stack+204162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114884, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+200130,int_stack+25984,int_stack+24829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97041, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+203595,int_stack+200130,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118412, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+209265,int_stack+203595,int_stack+2835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121247, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+0,int_stack+209265,int_stack+180894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125783, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+180894,int_stack+28154,int_stack+27370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61180, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+183246,int_stack+29162,int_stack+28154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62748, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+186270,int_stack+183246,int_stack+180894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131663, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+200130,int_stack+30422,int_stack+29162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64764, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+203910,int_stack+200130,int_stack+183246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+134015, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+21840,int_stack+203910,int_stack+186270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+137039, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+180894,int_stack+31962,int_stack+30422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67284, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+209958,int_stack+180894,int_stack+200130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141743, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+180894,int_stack+209958,int_stack+203910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145523, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+200130,int_stack+180894,int_stack+21840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161294, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+21840,int_stack+34398,int_stack+33810, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+23604,int_stack+35154,int_stack+34398, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+25872,int_stack+23604,int_stack+21840, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+29400,int_stack+36099,int_stack+35154, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+180894,int_stack+29400,int_stack+23604, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+185430,int_stack+180894,int_stack+25872, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+21840,int_stack+37254,int_stack+36099, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+32235,int_stack+21840,int_stack+29400, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+21840,int_stack+32235,int_stack+180894, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+29400,int_stack+21840,int_stack+185430, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+21840,int_stack+39424,int_stack+38640, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+24192,int_stack+40432,int_stack+39424, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+180894,int_stack+24192,int_stack+21840, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+185598,int_stack+41692,int_stack+40432, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+211890,int_stack+185598,int_stack+24192, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+134015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+217938,int_stack+211890,int_stack+180894, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+137039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+180894,int_stack+43232,int_stack+41692, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+21840,int_stack+180894,int_stack+185598, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+180894,int_stack+21840,int_stack+211890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+225778,int_stack+180894,int_stack+217938, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+180894,int_stack+45668,int_stack+45080, 0.0, zero_stack, 1.0, int_stack+94752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+182658,int_stack+46424,int_stack+45668, 0.0, zero_stack, 1.0, int_stack+95340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+184926,int_stack+182658,int_stack+180894, 0.0, zero_stack, 1.0, int_stack+110852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+188454,int_stack+47369,int_stack+46424, 0.0, zero_stack, 1.0, int_stack+96096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+211890,int_stack+188454,int_stack+182658, 0.0, zero_stack, 1.0, int_stack+112616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+216426,int_stack+211890,int_stack+184926, 0.0, zero_stack, 1.0, int_stack+114884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+180894,int_stack+48524,int_stack+47369, 0.0, zero_stack, 1.0, int_stack+97041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+21840,int_stack+180894,int_stack+188454, 0.0, zero_stack, 1.0, int_stack+118412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+180894,int_stack+21840,int_stack+211890, 0.0, zero_stack, 1.0, int_stack+121247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+38220,int_stack+180894,int_stack+216426, 0.0, zero_stack, 1.0, int_stack+125783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+180894,int_stack+50694,int_stack+49910, 0.0, zero_stack, 1.0, int_stack+61180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+183246,int_stack+51702,int_stack+50694, 0.0, zero_stack, 1.0, int_stack+62748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+186270,int_stack+183246,int_stack+180894, 0.0, zero_stack, 1.0, int_stack+131663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+211890,int_stack+52962,int_stack+51702, 0.0, zero_stack, 1.0, int_stack+64764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+215670,int_stack+211890,int_stack+183246, 0.0, zero_stack, 1.0, int_stack+134015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+237538,int_stack+215670,int_stack+186270, 0.0, zero_stack, 1.0, int_stack+137039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+180894,int_stack+54502,int_stack+52962, 0.0, zero_stack, 1.0, int_stack+67284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+21840,int_stack+180894,int_stack+211890, 0.0, zero_stack, 1.0, int_stack+141743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+180894,int_stack+21840,int_stack+215670, 0.0, zero_stack, 1.0, int_stack+145523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+211890,int_stack+180894,int_stack+237538, 0.0, zero_stack, 1.0, int_stack+161294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+237538,int_stack+56938,int_stack+56350, 1.0, int_stack+94752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+239302,int_stack+57694,int_stack+56938, 1.0, int_stack+95340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+241570,int_stack+239302,int_stack+237538, 1.0, int_stack+110852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+180894,int_stack+58639,int_stack+57694, 1.0, int_stack+96096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+183729,int_stack+180894,int_stack+239302, 1.0, int_stack+112616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+21840,int_stack+183729,int_stack+241570, 1.0, int_stack+114884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+110852,int_stack+59794,int_stack+58639, 1.0, int_stack+97041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+237538,int_stack+110852,int_stack+180894, 1.0, int_stack+118412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+110852,int_stack+237538,int_stack+183729, 1.0, int_stack+121247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+180894,int_stack+110852,int_stack+21840, 1.0, int_stack+125783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+21840,int_stack+63756,int_stack+61964, 1.0, int_stack+61180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+24192,int_stack+66024,int_stack+63756, 1.0, int_stack+62748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+110852,int_stack+24192,int_stack+21840, 1.0, int_stack+131663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+237538,int_stack+68824,int_stack+66024, 1.0, int_stack+64764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+47040,int_stack+237538,int_stack+24192, 1.0, int_stack+134015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+53088,int_stack+47040,int_stack+110852, 1.0, int_stack+137039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+110852,int_stack+70364,int_stack+68824, 1.0, int_stack+67284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+21840,int_stack+110852,int_stack+237538, 1.0, int_stack+141743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+131663,int_stack+21840,int_stack+47040, 1.0, int_stack+145523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+237538,int_stack+131663,int_stack+53088, 1.0, int_stack+161294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+161294,int_stack+98196,int_stack+97041,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+131663,int_stack+161294,int_stack+118412,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+21840,int_stack+131663,int_stack+121247,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+131663,int_stack+21840,int_stack+125783,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+21840,int_stack+72800,int_stack+72212,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+23604,int_stack+73556,int_stack+72800,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+25872,int_stack+23604,int_stack+21840,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+140483,int_stack+74501,int_stack+73556,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+143318,int_stack+140483,int_stack+23604,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+161294,int_stack+143318,int_stack+25872,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+21840,int_stack+75656,int_stack+74501,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+47040,int_stack+21840,int_stack+140483,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+21840,int_stack+47040,int_stack+143318,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+47040,int_stack+21840,int_stack+161294,21);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+161294,int_stack+77826,int_stack+77042,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+163646,int_stack+78834,int_stack+77826,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+21840,int_stack+163646,int_stack+161294,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+55860,int_stack+80094,int_stack+78834,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+59640,int_stack+55860,int_stack+163646,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+161294,int_stack+59640,int_stack+21840,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+21840,int_stack+81634,int_stack+80094,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+65688,int_stack+21840,int_stack+55860,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+73248,int_stack+65688,int_stack+59640,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+55860,int_stack+73248,int_stack+161294,28);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+161294,int_stack+84070,int_stack+83482,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+163058,int_stack+84826,int_stack+84070,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+165326,int_stack+163058,int_stack+161294,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+67620,int_stack+85771,int_stack+84826,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+70455,int_stack+67620,int_stack+163058,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+74991,int_stack+70455,int_stack+165326,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+161294,int_stack+86926,int_stack+85771,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+80871,int_stack+161294,int_stack+67620,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+21840,int_stack+80871,int_stack+70455,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+140483,int_stack+21840,int_stack+74991,21);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+21840,int_stack+89096,int_stack+88312,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+24192,int_stack+90104,int_stack+89096,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+67620,int_stack+24192,int_stack+21840,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+72324,int_stack+91364,int_stack+90104,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+76104,int_stack+72324,int_stack+24192,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+161294,int_stack+76104,int_stack+67620,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+67620,int_stack+92904,int_stack+91364,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+21840,int_stack+67620,int_stack+72324,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+82152,int_stack+21840,int_stack+76104,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+67620,int_stack+82152,int_stack+161294,28);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+161294,int_stack+100170,int_stack+99582,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+163058,int_stack+100926,int_stack+100170,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+165326,int_stack+163058,int_stack+161294,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+21840,int_stack+101871,int_stack+100926,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+24675,int_stack+21840,int_stack+163058,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+79380,int_stack+24675,int_stack+165326,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+161294,int_stack+103026,int_stack+101871,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+85260,int_stack+161294,int_stack+21840,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+161294,int_stack+85260,int_stack+24675,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+85260,int_stack+161294,int_stack+79380,21);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+79380,int_stack+105196,int_stack+104412,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+81732,int_stack+106204,int_stack+105196,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+161294,int_stack+81732,int_stack+79380,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+94080,int_stack+107464,int_stack+106204,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+97860,int_stack+94080,int_stack+81732,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+110852,int_stack+97860,int_stack+161294,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+161294,int_stack+109004,int_stack+107464,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+21840,int_stack+161294,int_stack+94080,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+118692,int_stack+21840,int_stack+97860,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+94080,int_stack+118692,int_stack+110852,28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+249298,int_stack+169134,int_stack+152474,420);
     Libderiv->ABCD[11] = int_stack + 249298;
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+149303,int_stack+10080,int_stack+191310,420);
     Libderiv->ABCD[10] = int_stack + 149303;
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+275758,int_stack+200130,int_stack+0,420);
     Libderiv->ABCD[9] = int_stack + 275758;
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+0,int_stack+225778,int_stack+29400,420);
     Libderiv->ABCD[8] = int_stack + 0;
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+302218,int_stack+211890,int_stack+38220,420);
     Libderiv->ABCD[7] = int_stack + 302218;
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+189714,int_stack+237538,int_stack+180894,420);
     Libderiv->ABCD[6] = int_stack + 189714;
 /*--- compute (hp|ig) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+216174,int_stack+55860,int_stack+47040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[2] = int_stack + 216174;
 /*--- compute (hp|ig) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+26460,int_stack+67620,int_stack+140483, 0.0, zero_stack, 1.0, int_stack+131663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[1] = int_stack + 26460;
 /*--- compute (hp|ig) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+52920,int_stack+94080,int_stack+85260, 1.0, int_stack+131663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[0] = int_stack + 52920;

}
