/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include "libint.h"
#include "hrr_header.h"

extern "C" {
REALTYPE *(*build_eri[11][11][11][11])(Libint_t *, int);
int libint_stack_size[11];

/* This function initializes a matrix of pointers to routines */
/* for computing ERI classes up to (zs|zs) - the base of the library */

void init_libint_base()
{
  build_eri[0][0][1][0] = hrr_order_00p0;
  build_eri[0][0][2][0] = hrr_order_00d0;
  build_eri[0][0][1][1] = hrr_order_00pp;
  build_eri[0][0][3][0] = hrr_order_00f0;
  build_eri[0][0][2][1] = hrr_order_00dp;
  build_eri[0][0][4][0] = hrr_order_00g0;
  build_eri[0][0][3][1] = hrr_order_00fp;
  build_eri[0][0][2][2] = hrr_order_00dd;
  build_eri[0][0][5][0] = hrr_order_00h0;
  build_eri[0][0][4][1] = hrr_order_00gp;
  build_eri[0][0][3][2] = hrr_order_00fd;
  build_eri[0][0][6][0] = hrr_order_00i0;
  build_eri[0][0][5][1] = hrr_order_00hp;
  build_eri[0][0][4][2] = hrr_order_00gd;
  build_eri[0][0][3][3] = hrr_order_00ff;
  build_eri[0][0][7][0] = hrr_order_00k0;
  build_eri[0][0][6][1] = hrr_order_00ip;
  build_eri[0][0][5][2] = hrr_order_00hd;
  build_eri[0][0][4][3] = hrr_order_00gf;
  build_eri[0][0][8][0] = hrr_order_00l0;
  build_eri[0][0][7][1] = hrr_order_00kp;
  build_eri[0][0][6][2] = hrr_order_00id;
  build_eri[0][0][5][3] = hrr_order_00hf;
  build_eri[0][0][4][4] = hrr_order_00gg;
  build_eri[0][0][9][0] = hrr_order_00m0;
  build_eri[0][0][8][1] = hrr_order_00lp;
  build_eri[0][0][7][2] = hrr_order_00kd;
  build_eri[0][0][6][3] = hrr_order_00if;
  build_eri[0][0][5][4] = hrr_order_00hg;
  build_eri[0][0][10][0] = hrr_order_00n0;
  build_eri[0][0][9][1] = hrr_order_00mp;
  build_eri[0][0][8][2] = hrr_order_00ld;
  build_eri[0][0][7][3] = hrr_order_00kf;
  build_eri[0][0][6][4] = hrr_order_00ig;
  build_eri[0][0][5][5] = hrr_order_00hh;
  build_eri[0][0][10][1] = hrr_order_00np;
  build_eri[0][0][9][2] = hrr_order_00md;
  build_eri[0][0][8][3] = hrr_order_00lf;
  build_eri[0][0][7][4] = hrr_order_00kg;
  build_eri[0][0][6][5] = hrr_order_00ih;
  build_eri[0][0][10][2] = hrr_order_00nd;
  build_eri[0][0][9][3] = hrr_order_00mf;
  build_eri[0][0][8][4] = hrr_order_00lg;
  build_eri[0][0][7][5] = hrr_order_00kh;
  build_eri[0][0][6][6] = hrr_order_00ii;
  build_eri[0][0][10][3] = hrr_order_00nf;
  build_eri[0][0][9][4] = hrr_order_00mg;
  build_eri[0][0][8][5] = hrr_order_00lh;
  build_eri[0][0][7][6] = hrr_order_00ki;
  build_eri[0][0][10][4] = hrr_order_00ng;
  build_eri[0][0][9][5] = hrr_order_00mh;
  build_eri[0][0][8][6] = hrr_order_00li;
  build_eri[0][0][7][7] = hrr_order_00kk;
  build_eri[0][0][10][5] = hrr_order_00nh;
  build_eri[0][0][9][6] = hrr_order_00mi;
  build_eri[0][0][8][7] = hrr_order_00lk;
  build_eri[0][0][10][6] = hrr_order_00ni;
  build_eri[0][0][9][7] = hrr_order_00mk;
  build_eri[0][0][8][8] = hrr_order_00ll;
  build_eri[0][0][10][7] = hrr_order_00nk;
  build_eri[0][0][9][8] = hrr_order_00ml;
  build_eri[0][0][10][8] = hrr_order_00nl;
  build_eri[0][0][9][9] = hrr_order_00mm;
  build_eri[0][0][10][9] = hrr_order_00nm;
  build_eri[0][0][10][10] = hrr_order_00nn;
  build_eri[1][0][1][0] = hrr_order_p0p0;
  build_eri[1][0][2][0] = hrr_order_p0d0;
  build_eri[1][0][1][1] = hrr_order_p0pp;
  build_eri[1][0][3][0] = hrr_order_p0f0;
  build_eri[1][0][2][1] = hrr_order_p0dp;
  build_eri[1][0][4][0] = hrr_order_p0g0;
  build_eri[1][0][3][1] = hrr_order_p0fp;
  build_eri[1][0][2][2] = hrr_order_p0dd;
  build_eri[1][0][5][0] = hrr_order_p0h0;
  build_eri[1][0][4][1] = hrr_order_p0gp;
  build_eri[1][0][3][2] = hrr_order_p0fd;
  build_eri[1][0][6][0] = hrr_order_p0i0;
  build_eri[1][0][5][1] = hrr_order_p0hp;
  build_eri[1][0][4][2] = hrr_order_p0gd;
  build_eri[1][0][3][3] = hrr_order_p0ff;
  build_eri[1][0][7][0] = hrr_order_p0k0;
  build_eri[1][0][6][1] = hrr_order_p0ip;
  build_eri[1][0][5][2] = hrr_order_p0hd;
  build_eri[1][0][4][3] = hrr_order_p0gf;
  build_eri[1][0][8][0] = hrr_order_p0l0;
  build_eri[1][0][7][1] = hrr_order_p0kp;
  build_eri[1][0][6][2] = hrr_order_p0id;
  build_eri[1][0][5][3] = hrr_order_p0hf;
  build_eri[1][0][4][4] = hrr_order_p0gg;
  build_eri[1][0][9][0] = hrr_order_p0m0;
  build_eri[1][0][8][1] = hrr_order_p0lp;
  build_eri[1][0][7][2] = hrr_order_p0kd;
  build_eri[1][0][6][3] = hrr_order_p0if;
  build_eri[1][0][5][4] = hrr_order_p0hg;
  build_eri[1][0][10][0] = hrr_order_p0n0;
  build_eri[1][0][9][1] = hrr_order_p0mp;
  build_eri[1][0][8][2] = hrr_order_p0ld;
  build_eri[1][0][7][3] = hrr_order_p0kf;
  build_eri[1][0][6][4] = hrr_order_p0ig;
  build_eri[1][0][5][5] = hrr_order_p0hh;
  build_eri[1][0][10][1] = hrr_order_p0np;
  build_eri[1][0][9][2] = hrr_order_p0md;
  build_eri[1][0][8][3] = hrr_order_p0lf;
  build_eri[1][0][7][4] = hrr_order_p0kg;
  build_eri[1][0][6][5] = hrr_order_p0ih;
  build_eri[1][0][10][2] = hrr_order_p0nd;
  build_eri[1][0][9][3] = hrr_order_p0mf;
  build_eri[1][0][8][4] = hrr_order_p0lg;
  build_eri[1][0][7][5] = hrr_order_p0kh;
  build_eri[1][0][6][6] = hrr_order_p0ii;
  build_eri[1][0][10][3] = hrr_order_p0nf;
  build_eri[1][0][9][4] = hrr_order_p0mg;
  build_eri[1][0][8][5] = hrr_order_p0lh;
  build_eri[1][0][7][6] = hrr_order_p0ki;
  build_eri[1][0][10][4] = hrr_order_p0ng;
  build_eri[1][0][9][5] = hrr_order_p0mh;
  build_eri[1][0][8][6] = hrr_order_p0li;
  build_eri[1][0][7][7] = hrr_order_p0kk;
  build_eri[1][0][10][5] = hrr_order_p0nh;
  build_eri[1][0][9][6] = hrr_order_p0mi;
  build_eri[1][0][8][7] = hrr_order_p0lk;
  build_eri[1][0][10][6] = hrr_order_p0ni;
  build_eri[1][0][9][7] = hrr_order_p0mk;
  build_eri[1][0][8][8] = hrr_order_p0ll;
  build_eri[1][0][10][7] = hrr_order_p0nk;
  build_eri[1][0][9][8] = hrr_order_p0ml;
  build_eri[1][0][10][8] = hrr_order_p0nl;
  build_eri[1][0][9][9] = hrr_order_p0mm;
  build_eri[1][0][10][9] = hrr_order_p0nm;
  build_eri[1][0][10][10] = hrr_order_p0nn;
  build_eri[2][0][2][0] = hrr_order_d0d0;
  build_eri[2][0][1][1] = hrr_order_d0pp;
  build_eri[2][0][3][0] = hrr_order_d0f0;
  build_eri[2][0][2][1] = hrr_order_d0dp;
  build_eri[2][0][4][0] = hrr_order_d0g0;
  build_eri[2][0][3][1] = hrr_order_d0fp;
  build_eri[2][0][2][2] = hrr_order_d0dd;
  build_eri[2][0][5][0] = hrr_order_d0h0;
  build_eri[2][0][4][1] = hrr_order_d0gp;
  build_eri[2][0][3][2] = hrr_order_d0fd;
  build_eri[2][0][6][0] = hrr_order_d0i0;
  build_eri[2][0][5][1] = hrr_order_d0hp;
  build_eri[2][0][4][2] = hrr_order_d0gd;
  build_eri[2][0][3][3] = hrr_order_d0ff;
  build_eri[2][0][7][0] = hrr_order_d0k0;
  build_eri[2][0][6][1] = hrr_order_d0ip;
  build_eri[2][0][5][2] = hrr_order_d0hd;
  build_eri[2][0][4][3] = hrr_order_d0gf;
  build_eri[2][0][8][0] = hrr_order_d0l0;
  build_eri[2][0][7][1] = hrr_order_d0kp;
  build_eri[2][0][6][2] = hrr_order_d0id;
  build_eri[2][0][5][3] = hrr_order_d0hf;
  build_eri[2][0][4][4] = hrr_order_d0gg;
  build_eri[2][0][9][0] = hrr_order_d0m0;
  build_eri[2][0][8][1] = hrr_order_d0lp;
  build_eri[2][0][7][2] = hrr_order_d0kd;
  build_eri[2][0][6][3] = hrr_order_d0if;
  build_eri[2][0][5][4] = hrr_order_d0hg;
  build_eri[2][0][10][0] = hrr_order_d0n0;
  build_eri[2][0][9][1] = hrr_order_d0mp;
  build_eri[2][0][8][2] = hrr_order_d0ld;
  build_eri[2][0][7][3] = hrr_order_d0kf;
  build_eri[2][0][6][4] = hrr_order_d0ig;
  build_eri[2][0][5][5] = hrr_order_d0hh;
  build_eri[2][0][10][1] = hrr_order_d0np;
  build_eri[2][0][9][2] = hrr_order_d0md;
  build_eri[2][0][8][3] = hrr_order_d0lf;
  build_eri[2][0][7][4] = hrr_order_d0kg;
  build_eri[2][0][6][5] = hrr_order_d0ih;
  build_eri[2][0][10][2] = hrr_order_d0nd;
  build_eri[2][0][9][3] = hrr_order_d0mf;
  build_eri[2][0][8][4] = hrr_order_d0lg;
  build_eri[2][0][7][5] = hrr_order_d0kh;
  build_eri[2][0][6][6] = hrr_order_d0ii;
  build_eri[2][0][10][3] = hrr_order_d0nf;
  build_eri[2][0][9][4] = hrr_order_d0mg;
  build_eri[2][0][8][5] = hrr_order_d0lh;
  build_eri[2][0][7][6] = hrr_order_d0ki;
  build_eri[2][0][10][4] = hrr_order_d0ng;
  build_eri[2][0][9][5] = hrr_order_d0mh;
  build_eri[2][0][8][6] = hrr_order_d0li;
  build_eri[2][0][7][7] = hrr_order_d0kk;
  build_eri[2][0][10][5] = hrr_order_d0nh;
  build_eri[2][0][9][6] = hrr_order_d0mi;
  build_eri[2][0][8][7] = hrr_order_d0lk;
  build_eri[2][0][10][6] = hrr_order_d0ni;
  build_eri[2][0][9][7] = hrr_order_d0mk;
  build_eri[2][0][8][8] = hrr_order_d0ll;
  build_eri[2][0][10][7] = hrr_order_d0nk;
  build_eri[2][0][9][8] = hrr_order_d0ml;
  build_eri[2][0][10][8] = hrr_order_d0nl;
  build_eri[2][0][9][9] = hrr_order_d0mm;
  build_eri[2][0][10][9] = hrr_order_d0nm;
  build_eri[2][0][10][10] = hrr_order_d0nn;
  build_eri[1][1][2][0] = hrr_order_ppd0;
  build_eri[1][1][1][1] = hrr_order_pppp;
  build_eri[1][1][3][0] = hrr_order_ppf0;
  build_eri[1][1][2][1] = hrr_order_ppdp;
  build_eri[1][1][4][0] = hrr_order_ppg0;
  build_eri[1][1][3][1] = hrr_order_ppfp;
  build_eri[1][1][2][2] = hrr_order_ppdd;
  build_eri[1][1][5][0] = hrr_order_pph0;
  build_eri[1][1][4][1] = hrr_order_ppgp;
  build_eri[1][1][3][2] = hrr_order_ppfd;
  build_eri[1][1][6][0] = hrr_order_ppi0;
  build_eri[1][1][5][1] = hrr_order_pphp;
  build_eri[1][1][4][2] = hrr_order_ppgd;
  build_eri[1][1][3][3] = hrr_order_ppff;
  build_eri[1][1][7][0] = hrr_order_ppk0;
  build_eri[1][1][6][1] = hrr_order_ppip;
  build_eri[1][1][5][2] = hrr_order_pphd;
  build_eri[1][1][4][3] = hrr_order_ppgf;
  build_eri[1][1][8][0] = hrr_order_ppl0;
  build_eri[1][1][7][1] = hrr_order_ppkp;
  build_eri[1][1][6][2] = hrr_order_ppid;
  build_eri[1][1][5][3] = hrr_order_pphf;
  build_eri[1][1][4][4] = hrr_order_ppgg;
  build_eri[1][1][9][0] = hrr_order_ppm0;
  build_eri[1][1][8][1] = hrr_order_pplp;
  build_eri[1][1][7][2] = hrr_order_ppkd;
  build_eri[1][1][6][3] = hrr_order_ppif;
  build_eri[1][1][5][4] = hrr_order_pphg;
  build_eri[1][1][10][0] = hrr_order_ppn0;
  build_eri[1][1][9][1] = hrr_order_ppmp;
  build_eri[1][1][8][2] = hrr_order_ppld;
  build_eri[1][1][7][3] = hrr_order_ppkf;
  build_eri[1][1][6][4] = hrr_order_ppig;
  build_eri[1][1][5][5] = hrr_order_pphh;
  build_eri[1][1][10][1] = hrr_order_ppnp;
  build_eri[1][1][9][2] = hrr_order_ppmd;
  build_eri[1][1][8][3] = hrr_order_pplf;
  build_eri[1][1][7][4] = hrr_order_ppkg;
  build_eri[1][1][6][5] = hrr_order_ppih;
  build_eri[1][1][10][2] = hrr_order_ppnd;
  build_eri[1][1][9][3] = hrr_order_ppmf;
  build_eri[1][1][8][4] = hrr_order_pplg;
  build_eri[1][1][7][5] = hrr_order_ppkh;
  build_eri[1][1][6][6] = hrr_order_ppii;
  build_eri[1][1][10][3] = hrr_order_ppnf;
  build_eri[1][1][9][4] = hrr_order_ppmg;
  build_eri[1][1][8][5] = hrr_order_pplh;
  build_eri[1][1][7][6] = hrr_order_ppki;
  build_eri[1][1][10][4] = hrr_order_ppng;
  build_eri[1][1][9][5] = hrr_order_ppmh;
  build_eri[1][1][8][6] = hrr_order_ppli;
  build_eri[1][1][7][7] = hrr_order_ppkk;
  build_eri[1][1][10][5] = hrr_order_ppnh;
  build_eri[1][1][9][6] = hrr_order_ppmi;
  build_eri[1][1][8][7] = hrr_order_pplk;
  build_eri[1][1][10][6] = hrr_order_ppni;
  build_eri[1][1][9][7] = hrr_order_ppmk;
  build_eri[1][1][8][8] = hrr_order_ppll;
  build_eri[1][1][10][7] = hrr_order_ppnk;
  build_eri[1][1][9][8] = hrr_order_ppml;
  build_eri[1][1][10][8] = hrr_order_ppnl;
  build_eri[1][1][9][9] = hrr_order_ppmm;
  build_eri[1][1][10][9] = hrr_order_ppnm;
  build_eri[1][1][10][10] = hrr_order_ppnn;
  build_eri[3][0][3][0] = hrr_order_f0f0;
  build_eri[3][0][2][1] = hrr_order_f0dp;
  build_eri[3][0][4][0] = hrr_order_f0g0;
  build_eri[3][0][3][1] = hrr_order_f0fp;
  build_eri[3][0][2][2] = hrr_order_f0dd;
  build_eri[3][0][5][0] = hrr_order_f0h0;
  build_eri[3][0][4][1] = hrr_order_f0gp;
  build_eri[3][0][3][2] = hrr_order_f0fd;
  build_eri[3][0][6][0] = hrr_order_f0i0;
  build_eri[3][0][5][1] = hrr_order_f0hp;
  build_eri[3][0][4][2] = hrr_order_f0gd;
  build_eri[3][0][3][3] = hrr_order_f0ff;
  build_eri[3][0][7][0] = hrr_order_f0k0;
  build_eri[3][0][6][1] = hrr_order_f0ip;
  build_eri[3][0][5][2] = hrr_order_f0hd;
  build_eri[3][0][4][3] = hrr_order_f0gf;
  build_eri[3][0][8][0] = hrr_order_f0l0;
  build_eri[3][0][7][1] = hrr_order_f0kp;
  build_eri[3][0][6][2] = hrr_order_f0id;
  build_eri[3][0][5][3] = hrr_order_f0hf;
  build_eri[3][0][4][4] = hrr_order_f0gg;
  build_eri[3][0][9][0] = hrr_order_f0m0;
  build_eri[3][0][8][1] = hrr_order_f0lp;
  build_eri[3][0][7][2] = hrr_order_f0kd;
  build_eri[3][0][6][3] = hrr_order_f0if;
  build_eri[3][0][5][4] = hrr_order_f0hg;
  build_eri[3][0][10][0] = hrr_order_f0n0;
  build_eri[3][0][9][1] = hrr_order_f0mp;
  build_eri[3][0][8][2] = hrr_order_f0ld;
  build_eri[3][0][7][3] = hrr_order_f0kf;
  build_eri[3][0][6][4] = hrr_order_f0ig;
  build_eri[3][0][5][5] = hrr_order_f0hh;
  build_eri[3][0][10][1] = hrr_order_f0np;
  build_eri[3][0][9][2] = hrr_order_f0md;
  build_eri[3][0][8][3] = hrr_order_f0lf;
  build_eri[3][0][7][4] = hrr_order_f0kg;
  build_eri[3][0][6][5] = hrr_order_f0ih;
  build_eri[3][0][10][2] = hrr_order_f0nd;
  build_eri[3][0][9][3] = hrr_order_f0mf;
  build_eri[3][0][8][4] = hrr_order_f0lg;
  build_eri[3][0][7][5] = hrr_order_f0kh;
  build_eri[3][0][6][6] = hrr_order_f0ii;
  build_eri[3][0][10][3] = hrr_order_f0nf;
  build_eri[3][0][9][4] = hrr_order_f0mg;
  build_eri[3][0][8][5] = hrr_order_f0lh;
  build_eri[3][0][7][6] = hrr_order_f0ki;
  build_eri[3][0][10][4] = hrr_order_f0ng;
  build_eri[3][0][9][5] = hrr_order_f0mh;
  build_eri[3][0][8][6] = hrr_order_f0li;
  build_eri[3][0][7][7] = hrr_order_f0kk;
  build_eri[3][0][10][5] = hrr_order_f0nh;
  build_eri[3][0][9][6] = hrr_order_f0mi;
  build_eri[3][0][8][7] = hrr_order_f0lk;
  build_eri[3][0][10][6] = hrr_order_f0ni;
  build_eri[3][0][9][7] = hrr_order_f0mk;
  build_eri[3][0][8][8] = hrr_order_f0ll;
  build_eri[3][0][10][7] = hrr_order_f0nk;
  build_eri[3][0][9][8] = hrr_order_f0ml;
  build_eri[3][0][10][8] = hrr_order_f0nl;
  build_eri[3][0][9][9] = hrr_order_f0mm;
  build_eri[3][0][10][9] = hrr_order_f0nm;
  build_eri[3][0][10][10] = hrr_order_f0nn;
  build_eri[2][1][3][0] = hrr_order_dpf0;
  build_eri[2][1][2][1] = hrr_order_dpdp;
  build_eri[2][1][4][0] = hrr_order_dpg0;
  build_eri[2][1][3][1] = hrr_order_dpfp;
  build_eri[2][1][2][2] = hrr_order_dpdd;
  build_eri[2][1][5][0] = hrr_order_dph0;
  build_eri[2][1][4][1] = hrr_order_dpgp;
  build_eri[2][1][3][2] = hrr_order_dpfd;
  build_eri[2][1][6][0] = hrr_order_dpi0;
  build_eri[2][1][5][1] = hrr_order_dphp;
  build_eri[2][1][4][2] = hrr_order_dpgd;
  build_eri[2][1][3][3] = hrr_order_dpff;
  build_eri[2][1][7][0] = hrr_order_dpk0;
  build_eri[2][1][6][1] = hrr_order_dpip;
  build_eri[2][1][5][2] = hrr_order_dphd;
  build_eri[2][1][4][3] = hrr_order_dpgf;
  build_eri[2][1][8][0] = hrr_order_dpl0;
  build_eri[2][1][7][1] = hrr_order_dpkp;
  build_eri[2][1][6][2] = hrr_order_dpid;
  build_eri[2][1][5][3] = hrr_order_dphf;
  build_eri[2][1][4][4] = hrr_order_dpgg;
  build_eri[2][1][9][0] = hrr_order_dpm0;
  build_eri[2][1][8][1] = hrr_order_dplp;
  build_eri[2][1][7][2] = hrr_order_dpkd;
  build_eri[2][1][6][3] = hrr_order_dpif;
  build_eri[2][1][5][4] = hrr_order_dphg;
  build_eri[2][1][10][0] = hrr_order_dpn0;
  build_eri[2][1][9][1] = hrr_order_dpmp;
  build_eri[2][1][8][2] = hrr_order_dpld;
  build_eri[2][1][7][3] = hrr_order_dpkf;
  build_eri[2][1][6][4] = hrr_order_dpig;
  build_eri[2][1][5][5] = hrr_order_dphh;
  build_eri[2][1][10][1] = hrr_order_dpnp;
  build_eri[2][1][9][2] = hrr_order_dpmd;
  build_eri[2][1][8][3] = hrr_order_dplf;
  build_eri[2][1][7][4] = hrr_order_dpkg;
  build_eri[2][1][6][5] = hrr_order_dpih;
  build_eri[2][1][10][2] = hrr_order_dpnd;
  build_eri[2][1][9][3] = hrr_order_dpmf;
  build_eri[2][1][8][4] = hrr_order_dplg;
  build_eri[2][1][7][5] = hrr_order_dpkh;
  build_eri[2][1][6][6] = hrr_order_dpii;
  build_eri[2][1][10][3] = hrr_order_dpnf;
  build_eri[2][1][9][4] = hrr_order_dpmg;
  build_eri[2][1][8][5] = hrr_order_dplh;
  build_eri[2][1][7][6] = hrr_order_dpki;
  build_eri[2][1][10][4] = hrr_order_dpng;
  build_eri[2][1][9][5] = hrr_order_dpmh;
  build_eri[2][1][8][6] = hrr_order_dpli;
  build_eri[2][1][7][7] = hrr_order_dpkk;
  build_eri[2][1][10][5] = hrr_order_dpnh;
  build_eri[2][1][9][6] = hrr_order_dpmi;
  build_eri[2][1][8][7] = hrr_order_dplk;
  build_eri[2][1][10][6] = hrr_order_dpni;
  build_eri[2][1][9][7] = hrr_order_dpmk;
  build_eri[2][1][8][8] = hrr_order_dpll;
  build_eri[2][1][10][7] = hrr_order_dpnk;
  build_eri[2][1][9][8] = hrr_order_dpml;
  build_eri[2][1][10][8] = hrr_order_dpnl;
  build_eri[2][1][9][9] = hrr_order_dpmm;
  build_eri[2][1][10][9] = hrr_order_dpnm;
  build_eri[2][1][10][10] = hrr_order_dpnn;
  build_eri[4][0][4][0] = hrr_order_g0g0;
  build_eri[4][0][3][1] = hrr_order_g0fp;
  build_eri[4][0][2][2] = hrr_order_g0dd;
  build_eri[4][0][5][0] = hrr_order_g0h0;
  build_eri[4][0][4][1] = hrr_order_g0gp;
  build_eri[4][0][3][2] = hrr_order_g0fd;
  build_eri[4][0][6][0] = hrr_order_g0i0;
  build_eri[4][0][5][1] = hrr_order_g0hp;
  build_eri[4][0][4][2] = hrr_order_g0gd;
  build_eri[4][0][3][3] = hrr_order_g0ff;
  build_eri[4][0][7][0] = hrr_order_g0k0;
  build_eri[4][0][6][1] = hrr_order_g0ip;
  build_eri[4][0][5][2] = hrr_order_g0hd;
  build_eri[4][0][4][3] = hrr_order_g0gf;
  build_eri[4][0][8][0] = hrr_order_g0l0;
  build_eri[4][0][7][1] = hrr_order_g0kp;
  build_eri[4][0][6][2] = hrr_order_g0id;
  build_eri[4][0][5][3] = hrr_order_g0hf;
  build_eri[4][0][4][4] = hrr_order_g0gg;
  build_eri[4][0][9][0] = hrr_order_g0m0;
  build_eri[4][0][8][1] = hrr_order_g0lp;
  build_eri[4][0][7][2] = hrr_order_g0kd;
  build_eri[4][0][6][3] = hrr_order_g0if;
  build_eri[4][0][5][4] = hrr_order_g0hg;
  build_eri[4][0][10][0] = hrr_order_g0n0;
  build_eri[4][0][9][1] = hrr_order_g0mp;
  build_eri[4][0][8][2] = hrr_order_g0ld;
  build_eri[4][0][7][3] = hrr_order_g0kf;
  build_eri[4][0][6][4] = hrr_order_g0ig;
  build_eri[4][0][5][5] = hrr_order_g0hh;
  build_eri[4][0][10][1] = hrr_order_g0np;
  build_eri[4][0][9][2] = hrr_order_g0md;
  build_eri[4][0][8][3] = hrr_order_g0lf;
  build_eri[4][0][7][4] = hrr_order_g0kg;
  build_eri[4][0][6][5] = hrr_order_g0ih;
  build_eri[4][0][10][2] = hrr_order_g0nd;
  build_eri[4][0][9][3] = hrr_order_g0mf;
  build_eri[4][0][8][4] = hrr_order_g0lg;
  build_eri[4][0][7][5] = hrr_order_g0kh;
  build_eri[4][0][6][6] = hrr_order_g0ii;
  build_eri[4][0][10][3] = hrr_order_g0nf;
  build_eri[4][0][9][4] = hrr_order_g0mg;
  build_eri[4][0][8][5] = hrr_order_g0lh;
  build_eri[4][0][7][6] = hrr_order_g0ki;
  build_eri[4][0][10][4] = hrr_order_g0ng;
  build_eri[4][0][9][5] = hrr_order_g0mh;
  build_eri[4][0][8][6] = hrr_order_g0li;
  build_eri[4][0][7][7] = hrr_order_g0kk;
  build_eri[4][0][10][5] = hrr_order_g0nh;
  build_eri[4][0][9][6] = hrr_order_g0mi;
  build_eri[4][0][8][7] = hrr_order_g0lk;
  build_eri[4][0][10][6] = hrr_order_g0ni;
  build_eri[4][0][9][7] = hrr_order_g0mk;
  build_eri[4][0][8][8] = hrr_order_g0ll;
  build_eri[4][0][10][7] = hrr_order_g0nk;
  build_eri[4][0][9][8] = hrr_order_g0ml;
  build_eri[4][0][10][8] = hrr_order_g0nl;
  build_eri[4][0][9][9] = hrr_order_g0mm;
  build_eri[4][0][10][9] = hrr_order_g0nm;
  build_eri[4][0][10][10] = hrr_order_g0nn;
  build_eri[3][1][4][0] = hrr_order_fpg0;
  build_eri[3][1][3][1] = hrr_order_fpfp;
  build_eri[3][1][2][2] = hrr_order_fpdd;
  build_eri[3][1][5][0] = hrr_order_fph0;
  build_eri[3][1][4][1] = hrr_order_fpgp;
  build_eri[3][1][3][2] = hrr_order_fpfd;
  build_eri[3][1][6][0] = hrr_order_fpi0;
  build_eri[3][1][5][1] = hrr_order_fphp;
  build_eri[3][1][4][2] = hrr_order_fpgd;
  build_eri[3][1][3][3] = hrr_order_fpff;
  build_eri[3][1][7][0] = hrr_order_fpk0;
  build_eri[3][1][6][1] = hrr_order_fpip;
  build_eri[3][1][5][2] = hrr_order_fphd;
  build_eri[3][1][4][3] = hrr_order_fpgf;
  build_eri[3][1][8][0] = hrr_order_fpl0;
  build_eri[3][1][7][1] = hrr_order_fpkp;
  build_eri[3][1][6][2] = hrr_order_fpid;
  build_eri[3][1][5][3] = hrr_order_fphf;
  build_eri[3][1][4][4] = hrr_order_fpgg;
  build_eri[3][1][9][0] = hrr_order_fpm0;
  build_eri[3][1][8][1] = hrr_order_fplp;
  build_eri[3][1][7][2] = hrr_order_fpkd;
  build_eri[3][1][6][3] = hrr_order_fpif;
  build_eri[3][1][5][4] = hrr_order_fphg;
  build_eri[3][1][10][0] = hrr_order_fpn0;
  build_eri[3][1][9][1] = hrr_order_fpmp;
  build_eri[3][1][8][2] = hrr_order_fpld;
  build_eri[3][1][7][3] = hrr_order_fpkf;
  build_eri[3][1][6][4] = hrr_order_fpig;
  build_eri[3][1][5][5] = hrr_order_fphh;
  build_eri[3][1][10][1] = hrr_order_fpnp;
  build_eri[3][1][9][2] = hrr_order_fpmd;
  build_eri[3][1][8][3] = hrr_order_fplf;
  build_eri[3][1][7][4] = hrr_order_fpkg;
  build_eri[3][1][6][5] = hrr_order_fpih;
  build_eri[3][1][10][2] = hrr_order_fpnd;
  build_eri[3][1][9][3] = hrr_order_fpmf;
  build_eri[3][1][8][4] = hrr_order_fplg;
  build_eri[3][1][7][5] = hrr_order_fpkh;
  build_eri[3][1][6][6] = hrr_order_fpii;
  build_eri[3][1][10][3] = hrr_order_fpnf;
  build_eri[3][1][9][4] = hrr_order_fpmg;
  build_eri[3][1][8][5] = hrr_order_fplh;
  build_eri[3][1][7][6] = hrr_order_fpki;
  build_eri[3][1][10][4] = hrr_order_fpng;
  build_eri[3][1][9][5] = hrr_order_fpmh;
  build_eri[3][1][8][6] = hrr_order_fpli;
  build_eri[3][1][7][7] = hrr_order_fpkk;
  build_eri[3][1][10][5] = hrr_order_fpnh;
  build_eri[3][1][9][6] = hrr_order_fpmi;
  build_eri[3][1][8][7] = hrr_order_fplk;
  build_eri[3][1][10][6] = hrr_order_fpni;
  build_eri[3][1][9][7] = hrr_order_fpmk;
  build_eri[3][1][8][8] = hrr_order_fpll;
  build_eri[3][1][10][7] = hrr_order_fpnk;
  build_eri[3][1][9][8] = hrr_order_fpml;
  build_eri[3][1][10][8] = hrr_order_fpnl;
  build_eri[3][1][9][9] = hrr_order_fpmm;
  build_eri[3][1][10][9] = hrr_order_fpnm;
  build_eri[3][1][10][10] = hrr_order_fpnn;
  build_eri[2][2][4][0] = hrr_order_ddg0;
  build_eri[2][2][3][1] = hrr_order_ddfp;
  build_eri[2][2][2][2] = hrr_order_dddd;
  build_eri[2][2][5][0] = hrr_order_ddh0;
  build_eri[2][2][4][1] = hrr_order_ddgp;
  build_eri[2][2][3][2] = hrr_order_ddfd;
  build_eri[2][2][6][0] = hrr_order_ddi0;
  build_eri[2][2][5][1] = hrr_order_ddhp;
  build_eri[2][2][4][2] = hrr_order_ddgd;
  build_eri[2][2][3][3] = hrr_order_ddff;
  build_eri[2][2][7][0] = hrr_order_ddk0;
  build_eri[2][2][6][1] = hrr_order_ddip;
  build_eri[2][2][5][2] = hrr_order_ddhd;
  build_eri[2][2][4][3] = hrr_order_ddgf;
  build_eri[2][2][8][0] = hrr_order_ddl0;
  build_eri[2][2][7][1] = hrr_order_ddkp;
  build_eri[2][2][6][2] = hrr_order_ddid;
  build_eri[2][2][5][3] = hrr_order_ddhf;
  build_eri[2][2][4][4] = hrr_order_ddgg;
  build_eri[2][2][9][0] = hrr_order_ddm0;
  build_eri[2][2][8][1] = hrr_order_ddlp;
  build_eri[2][2][7][2] = hrr_order_ddkd;
  build_eri[2][2][6][3] = hrr_order_ddif;
  build_eri[2][2][5][4] = hrr_order_ddhg;
  build_eri[2][2][10][0] = hrr_order_ddn0;
  build_eri[2][2][9][1] = hrr_order_ddmp;
  build_eri[2][2][8][2] = hrr_order_ddld;
  build_eri[2][2][7][3] = hrr_order_ddkf;
  build_eri[2][2][6][4] = hrr_order_ddig;
  build_eri[2][2][5][5] = hrr_order_ddhh;
  build_eri[2][2][10][1] = hrr_order_ddnp;
  build_eri[2][2][9][2] = hrr_order_ddmd;
  build_eri[2][2][8][3] = hrr_order_ddlf;
  build_eri[2][2][7][4] = hrr_order_ddkg;
  build_eri[2][2][6][5] = hrr_order_ddih;
  build_eri[2][2][10][2] = hrr_order_ddnd;
  build_eri[2][2][9][3] = hrr_order_ddmf;
  build_eri[2][2][8][4] = hrr_order_ddlg;
  build_eri[2][2][7][5] = hrr_order_ddkh;
  build_eri[2][2][6][6] = hrr_order_ddii;
  build_eri[2][2][10][3] = hrr_order_ddnf;
  build_eri[2][2][9][4] = hrr_order_ddmg;
  build_eri[2][2][8][5] = hrr_order_ddlh;
  build_eri[2][2][7][6] = hrr_order_ddki;
  build_eri[2][2][10][4] = hrr_order_ddng;
  build_eri[2][2][9][5] = hrr_order_ddmh;
  build_eri[2][2][8][6] = hrr_order_ddli;
  build_eri[2][2][7][7] = hrr_order_ddkk;
  build_eri[2][2][10][5] = hrr_order_ddnh;
  build_eri[2][2][9][6] = hrr_order_ddmi;
  build_eri[2][2][8][7] = hrr_order_ddlk;
  build_eri[2][2][10][6] = hrr_order_ddni;
  build_eri[2][2][9][7] = hrr_order_ddmk;
  build_eri[2][2][8][8] = hrr_order_ddll;
  build_eri[2][2][10][7] = hrr_order_ddnk;
  build_eri[2][2][9][8] = hrr_order_ddml;
  build_eri[2][2][10][8] = hrr_order_ddnl;
  build_eri[2][2][9][9] = hrr_order_ddmm;
  build_eri[2][2][10][9] = hrr_order_ddnm;
  build_eri[2][2][10][10] = hrr_order_ddnn;
  build_eri[5][0][5][0] = hrr_order_h0h0;
  build_eri[5][0][4][1] = hrr_order_h0gp;
  build_eri[5][0][3][2] = hrr_order_h0fd;
  build_eri[5][0][6][0] = hrr_order_h0i0;
  build_eri[5][0][5][1] = hrr_order_h0hp;
  build_eri[5][0][4][2] = hrr_order_h0gd;
  build_eri[5][0][3][3] = hrr_order_h0ff;
  build_eri[5][0][7][0] = hrr_order_h0k0;
  build_eri[5][0][6][1] = hrr_order_h0ip;
  build_eri[5][0][5][2] = hrr_order_h0hd;
  build_eri[5][0][4][3] = hrr_order_h0gf;
  build_eri[5][0][8][0] = hrr_order_h0l0;
  build_eri[5][0][7][1] = hrr_order_h0kp;
  build_eri[5][0][6][2] = hrr_order_h0id;
  build_eri[5][0][5][3] = hrr_order_h0hf;
  build_eri[5][0][4][4] = hrr_order_h0gg;
  build_eri[5][0][9][0] = hrr_order_h0m0;
  build_eri[5][0][8][1] = hrr_order_h0lp;
  build_eri[5][0][7][2] = hrr_order_h0kd;
  build_eri[5][0][6][3] = hrr_order_h0if;
  build_eri[5][0][5][4] = hrr_order_h0hg;
  build_eri[5][0][10][0] = hrr_order_h0n0;
  build_eri[5][0][9][1] = hrr_order_h0mp;
  build_eri[5][0][8][2] = hrr_order_h0ld;
  build_eri[5][0][7][3] = hrr_order_h0kf;
  build_eri[5][0][6][4] = hrr_order_h0ig;
  build_eri[5][0][5][5] = hrr_order_h0hh;
  build_eri[5][0][10][1] = hrr_order_h0np;
  build_eri[5][0][9][2] = hrr_order_h0md;
  build_eri[5][0][8][3] = hrr_order_h0lf;
  build_eri[5][0][7][4] = hrr_order_h0kg;
  build_eri[5][0][6][5] = hrr_order_h0ih;
  build_eri[5][0][10][2] = hrr_order_h0nd;
  build_eri[5][0][9][3] = hrr_order_h0mf;
  build_eri[5][0][8][4] = hrr_order_h0lg;
  build_eri[5][0][7][5] = hrr_order_h0kh;
  build_eri[5][0][6][6] = hrr_order_h0ii;
  build_eri[5][0][10][3] = hrr_order_h0nf;
  build_eri[5][0][9][4] = hrr_order_h0mg;
  build_eri[5][0][8][5] = hrr_order_h0lh;
  build_eri[5][0][7][6] = hrr_order_h0ki;
  build_eri[5][0][10][4] = hrr_order_h0ng;
  build_eri[5][0][9][5] = hrr_order_h0mh;
  build_eri[5][0][8][6] = hrr_order_h0li;
  build_eri[5][0][7][7] = hrr_order_h0kk;
  build_eri[5][0][10][5] = hrr_order_h0nh;
  build_eri[5][0][9][6] = hrr_order_h0mi;
  build_eri[5][0][8][7] = hrr_order_h0lk;
  build_eri[5][0][10][6] = hrr_order_h0ni;
  build_eri[5][0][9][7] = hrr_order_h0mk;
  build_eri[5][0][8][8] = hrr_order_h0ll;
  build_eri[5][0][10][7] = hrr_order_h0nk;
  build_eri[5][0][9][8] = hrr_order_h0ml;
  build_eri[5][0][10][8] = hrr_order_h0nl;
  build_eri[5][0][9][9] = hrr_order_h0mm;
  build_eri[5][0][10][9] = hrr_order_h0nm;
  build_eri[5][0][10][10] = hrr_order_h0nn;
  build_eri[4][1][5][0] = hrr_order_gph0;
  build_eri[4][1][4][1] = hrr_order_gpgp;
  build_eri[4][1][3][2] = hrr_order_gpfd;
  build_eri[4][1][6][0] = hrr_order_gpi0;
  build_eri[4][1][5][1] = hrr_order_gphp;
  build_eri[4][1][4][2] = hrr_order_gpgd;
  build_eri[4][1][3][3] = hrr_order_gpff;
  build_eri[4][1][7][0] = hrr_order_gpk0;
  build_eri[4][1][6][1] = hrr_order_gpip;
  build_eri[4][1][5][2] = hrr_order_gphd;
  build_eri[4][1][4][3] = hrr_order_gpgf;
  build_eri[4][1][8][0] = hrr_order_gpl0;
  build_eri[4][1][7][1] = hrr_order_gpkp;
  build_eri[4][1][6][2] = hrr_order_gpid;
  build_eri[4][1][5][3] = hrr_order_gphf;
  build_eri[4][1][4][4] = hrr_order_gpgg;
  build_eri[4][1][9][0] = hrr_order_gpm0;
  build_eri[4][1][8][1] = hrr_order_gplp;
  build_eri[4][1][7][2] = hrr_order_gpkd;
  build_eri[4][1][6][3] = hrr_order_gpif;
  build_eri[4][1][5][4] = hrr_order_gphg;
  build_eri[4][1][10][0] = hrr_order_gpn0;
  build_eri[4][1][9][1] = hrr_order_gpmp;
  build_eri[4][1][8][2] = hrr_order_gpld;
  build_eri[4][1][7][3] = hrr_order_gpkf;
  build_eri[4][1][6][4] = hrr_order_gpig;
  build_eri[4][1][5][5] = hrr_order_gphh;
  build_eri[4][1][10][1] = hrr_order_gpnp;
  build_eri[4][1][9][2] = hrr_order_gpmd;
  build_eri[4][1][8][3] = hrr_order_gplf;
  build_eri[4][1][7][4] = hrr_order_gpkg;
  build_eri[4][1][6][5] = hrr_order_gpih;
  build_eri[4][1][10][2] = hrr_order_gpnd;
  build_eri[4][1][9][3] = hrr_order_gpmf;
  build_eri[4][1][8][4] = hrr_order_gplg;
  build_eri[4][1][7][5] = hrr_order_gpkh;
  build_eri[4][1][6][6] = hrr_order_gpii;
  build_eri[4][1][10][3] = hrr_order_gpnf;
  build_eri[4][1][9][4] = hrr_order_gpmg;
  build_eri[4][1][8][5] = hrr_order_gplh;
  build_eri[4][1][7][6] = hrr_order_gpki;
  build_eri[4][1][10][4] = hrr_order_gpng;
  build_eri[4][1][9][5] = hrr_order_gpmh;
  build_eri[4][1][8][6] = hrr_order_gpli;
  build_eri[4][1][7][7] = hrr_order_gpkk;
  build_eri[4][1][10][5] = hrr_order_gpnh;
  build_eri[4][1][9][6] = hrr_order_gpmi;
  build_eri[4][1][8][7] = hrr_order_gplk;
  build_eri[4][1][10][6] = hrr_order_gpni;
  build_eri[4][1][9][7] = hrr_order_gpmk;
  build_eri[4][1][8][8] = hrr_order_gpll;
  build_eri[4][1][10][7] = hrr_order_gpnk;
  build_eri[4][1][9][8] = hrr_order_gpml;
  build_eri[4][1][10][8] = hrr_order_gpnl;
  build_eri[4][1][9][9] = hrr_order_gpmm;
  build_eri[4][1][10][9] = hrr_order_gpnm;
  build_eri[4][1][10][10] = hrr_order_gpnn;
  build_eri[3][2][5][0] = hrr_order_fdh0;
  build_eri[3][2][4][1] = hrr_order_fdgp;
  build_eri[3][2][3][2] = hrr_order_fdfd;
  build_eri[3][2][6][0] = hrr_order_fdi0;
  build_eri[3][2][5][1] = hrr_order_fdhp;
  build_eri[3][2][4][2] = hrr_order_fdgd;
  build_eri[3][2][3][3] = hrr_order_fdff;
  build_eri[3][2][7][0] = hrr_order_fdk0;
  build_eri[3][2][6][1] = hrr_order_fdip;
  build_eri[3][2][5][2] = hrr_order_fdhd;
  build_eri[3][2][4][3] = hrr_order_fdgf;
  build_eri[3][2][8][0] = hrr_order_fdl0;
  build_eri[3][2][7][1] = hrr_order_fdkp;
  build_eri[3][2][6][2] = hrr_order_fdid;
  build_eri[3][2][5][3] = hrr_order_fdhf;
  build_eri[3][2][4][4] = hrr_order_fdgg;
  build_eri[3][2][9][0] = hrr_order_fdm0;
  build_eri[3][2][8][1] = hrr_order_fdlp;
  build_eri[3][2][7][2] = hrr_order_fdkd;
  build_eri[3][2][6][3] = hrr_order_fdif;
  build_eri[3][2][5][4] = hrr_order_fdhg;
  build_eri[3][2][10][0] = hrr_order_fdn0;
  build_eri[3][2][9][1] = hrr_order_fdmp;
  build_eri[3][2][8][2] = hrr_order_fdld;
  build_eri[3][2][7][3] = hrr_order_fdkf;
  build_eri[3][2][6][4] = hrr_order_fdig;
  build_eri[3][2][5][5] = hrr_order_fdhh;
  build_eri[3][2][10][1] = hrr_order_fdnp;
  build_eri[3][2][9][2] = hrr_order_fdmd;
  build_eri[3][2][8][3] = hrr_order_fdlf;
  build_eri[3][2][7][4] = hrr_order_fdkg;
  build_eri[3][2][6][5] = hrr_order_fdih;
  build_eri[3][2][10][2] = hrr_order_fdnd;
  build_eri[3][2][9][3] = hrr_order_fdmf;
  build_eri[3][2][8][4] = hrr_order_fdlg;
  build_eri[3][2][7][5] = hrr_order_fdkh;
  build_eri[3][2][6][6] = hrr_order_fdii;
  build_eri[3][2][10][3] = hrr_order_fdnf;
  build_eri[3][2][9][4] = hrr_order_fdmg;
  build_eri[3][2][8][5] = hrr_order_fdlh;
  build_eri[3][2][7][6] = hrr_order_fdki;
  build_eri[3][2][10][4] = hrr_order_fdng;
  build_eri[3][2][9][5] = hrr_order_fdmh;
  build_eri[3][2][8][6] = hrr_order_fdli;
  build_eri[3][2][7][7] = hrr_order_fdkk;
  build_eri[3][2][10][5] = hrr_order_fdnh;
  build_eri[3][2][9][6] = hrr_order_fdmi;
  build_eri[3][2][8][7] = hrr_order_fdlk;
  build_eri[3][2][10][6] = hrr_order_fdni;
  build_eri[3][2][9][7] = hrr_order_fdmk;
  build_eri[3][2][8][8] = hrr_order_fdll;
  build_eri[3][2][10][7] = hrr_order_fdnk;
  build_eri[3][2][9][8] = hrr_order_fdml;
  build_eri[3][2][10][8] = hrr_order_fdnl;
  build_eri[3][2][9][9] = hrr_order_fdmm;
  build_eri[3][2][10][9] = hrr_order_fdnm;
  build_eri[3][2][10][10] = hrr_order_fdnn;
  build_eri[6][0][6][0] = hrr_order_i0i0;
  build_eri[6][0][5][1] = hrr_order_i0hp;
  build_eri[6][0][4][2] = hrr_order_i0gd;
  build_eri[6][0][3][3] = hrr_order_i0ff;
  build_eri[6][0][7][0] = hrr_order_i0k0;
  build_eri[6][0][6][1] = hrr_order_i0ip;
  build_eri[6][0][5][2] = hrr_order_i0hd;
  build_eri[6][0][4][3] = hrr_order_i0gf;
  build_eri[6][0][8][0] = hrr_order_i0l0;
  build_eri[6][0][7][1] = hrr_order_i0kp;
  build_eri[6][0][6][2] = hrr_order_i0id;
  build_eri[6][0][5][3] = hrr_order_i0hf;
  build_eri[6][0][4][4] = hrr_order_i0gg;
  build_eri[6][0][9][0] = hrr_order_i0m0;
  build_eri[6][0][8][1] = hrr_order_i0lp;
  build_eri[6][0][7][2] = hrr_order_i0kd;
  build_eri[6][0][6][3] = hrr_order_i0if;
  build_eri[6][0][5][4] = hrr_order_i0hg;
  build_eri[6][0][10][0] = hrr_order_i0n0;
  build_eri[6][0][9][1] = hrr_order_i0mp;
  build_eri[6][0][8][2] = hrr_order_i0ld;
  build_eri[6][0][7][3] = hrr_order_i0kf;
  build_eri[6][0][6][4] = hrr_order_i0ig;
  build_eri[6][0][5][5] = hrr_order_i0hh;
  build_eri[6][0][10][1] = hrr_order_i0np;
  build_eri[6][0][9][2] = hrr_order_i0md;
  build_eri[6][0][8][3] = hrr_order_i0lf;
  build_eri[6][0][7][4] = hrr_order_i0kg;
  build_eri[6][0][6][5] = hrr_order_i0ih;
  build_eri[6][0][10][2] = hrr_order_i0nd;
  build_eri[6][0][9][3] = hrr_order_i0mf;
  build_eri[6][0][8][4] = hrr_order_i0lg;
  build_eri[6][0][7][5] = hrr_order_i0kh;
  build_eri[6][0][6][6] = hrr_order_i0ii;
  build_eri[6][0][10][3] = hrr_order_i0nf;
  build_eri[6][0][9][4] = hrr_order_i0mg;
  build_eri[6][0][8][5] = hrr_order_i0lh;
  build_eri[6][0][7][6] = hrr_order_i0ki;
  build_eri[6][0][10][4] = hrr_order_i0ng;
  build_eri[6][0][9][5] = hrr_order_i0mh;
  build_eri[6][0][8][6] = hrr_order_i0li;
  build_eri[6][0][7][7] = hrr_order_i0kk;
  build_eri[6][0][10][5] = hrr_order_i0nh;
  build_eri[6][0][9][6] = hrr_order_i0mi;
  build_eri[6][0][8][7] = hrr_order_i0lk;
  build_eri[6][0][10][6] = hrr_order_i0ni;
  build_eri[6][0][9][7] = hrr_order_i0mk;
  build_eri[6][0][8][8] = hrr_order_i0ll;
  build_eri[6][0][10][7] = hrr_order_i0nk;
  build_eri[6][0][9][8] = hrr_order_i0ml;
  build_eri[6][0][10][8] = hrr_order_i0nl;
  build_eri[6][0][9][9] = hrr_order_i0mm;
  build_eri[6][0][10][9] = hrr_order_i0nm;
  build_eri[6][0][10][10] = hrr_order_i0nn;
  build_eri[5][1][6][0] = hrr_order_hpi0;
  build_eri[5][1][5][1] = hrr_order_hphp;
  build_eri[5][1][4][2] = hrr_order_hpgd;
  build_eri[5][1][3][3] = hrr_order_hpff;
  build_eri[5][1][7][0] = hrr_order_hpk0;
  build_eri[5][1][6][1] = hrr_order_hpip;
  build_eri[5][1][5][2] = hrr_order_hphd;
  build_eri[5][1][4][3] = hrr_order_hpgf;
  build_eri[5][1][8][0] = hrr_order_hpl0;
  build_eri[5][1][7][1] = hrr_order_hpkp;
  build_eri[5][1][6][2] = hrr_order_hpid;
  build_eri[5][1][5][3] = hrr_order_hphf;
  build_eri[5][1][4][4] = hrr_order_hpgg;
  build_eri[5][1][9][0] = hrr_order_hpm0;
  build_eri[5][1][8][1] = hrr_order_hplp;
  build_eri[5][1][7][2] = hrr_order_hpkd;
  build_eri[5][1][6][3] = hrr_order_hpif;
  build_eri[5][1][5][4] = hrr_order_hphg;
  build_eri[5][1][10][0] = hrr_order_hpn0;
  build_eri[5][1][9][1] = hrr_order_hpmp;
  build_eri[5][1][8][2] = hrr_order_hpld;
  build_eri[5][1][7][3] = hrr_order_hpkf;
  build_eri[5][1][6][4] = hrr_order_hpig;
  build_eri[5][1][5][5] = hrr_order_hphh;
  build_eri[5][1][10][1] = hrr_order_hpnp;
  build_eri[5][1][9][2] = hrr_order_hpmd;
  build_eri[5][1][8][3] = hrr_order_hplf;
  build_eri[5][1][7][4] = hrr_order_hpkg;
  build_eri[5][1][6][5] = hrr_order_hpih;
  build_eri[5][1][10][2] = hrr_order_hpnd;
  build_eri[5][1][9][3] = hrr_order_hpmf;
  build_eri[5][1][8][4] = hrr_order_hplg;
  build_eri[5][1][7][5] = hrr_order_hpkh;
  build_eri[5][1][6][6] = hrr_order_hpii;
  build_eri[5][1][10][3] = hrr_order_hpnf;
  build_eri[5][1][9][4] = hrr_order_hpmg;
  build_eri[5][1][8][5] = hrr_order_hplh;
  build_eri[5][1][7][6] = hrr_order_hpki;
  build_eri[5][1][10][4] = hrr_order_hpng;
  build_eri[5][1][9][5] = hrr_order_hpmh;
  build_eri[5][1][8][6] = hrr_order_hpli;
  build_eri[5][1][7][7] = hrr_order_hpkk;
  build_eri[5][1][10][5] = hrr_order_hpnh;
  build_eri[5][1][9][6] = hrr_order_hpmi;
  build_eri[5][1][8][7] = hrr_order_hplk;
  build_eri[5][1][10][6] = hrr_order_hpni;
  build_eri[5][1][9][7] = hrr_order_hpmk;
  build_eri[5][1][8][8] = hrr_order_hpll;
  build_eri[5][1][10][7] = hrr_order_hpnk;
  build_eri[5][1][9][8] = hrr_order_hpml;
  build_eri[5][1][10][8] = hrr_order_hpnl;
  build_eri[5][1][9][9] = hrr_order_hpmm;
  build_eri[5][1][10][9] = hrr_order_hpnm;
  build_eri[5][1][10][10] = hrr_order_hpnn;
  build_eri[4][2][6][0] = hrr_order_gdi0;
  build_eri[4][2][5][1] = hrr_order_gdhp;
  build_eri[4][2][4][2] = hrr_order_gdgd;
  build_eri[4][2][3][3] = hrr_order_gdff;
  build_eri[4][2][7][0] = hrr_order_gdk0;
  build_eri[4][2][6][1] = hrr_order_gdip;
  build_eri[4][2][5][2] = hrr_order_gdhd;
  build_eri[4][2][4][3] = hrr_order_gdgf;
  build_eri[4][2][8][0] = hrr_order_gdl0;
  build_eri[4][2][7][1] = hrr_order_gdkp;
  build_eri[4][2][6][2] = hrr_order_gdid;
  build_eri[4][2][5][3] = hrr_order_gdhf;
  build_eri[4][2][4][4] = hrr_order_gdgg;
  build_eri[4][2][9][0] = hrr_order_gdm0;
  build_eri[4][2][8][1] = hrr_order_gdlp;
  build_eri[4][2][7][2] = hrr_order_gdkd;
  build_eri[4][2][6][3] = hrr_order_gdif;
  build_eri[4][2][5][4] = hrr_order_gdhg;
  build_eri[4][2][10][0] = hrr_order_gdn0;
  build_eri[4][2][9][1] = hrr_order_gdmp;
  build_eri[4][2][8][2] = hrr_order_gdld;
  build_eri[4][2][7][3] = hrr_order_gdkf;
  build_eri[4][2][6][4] = hrr_order_gdig;
  build_eri[4][2][5][5] = hrr_order_gdhh;
  build_eri[4][2][10][1] = hrr_order_gdnp;
  build_eri[4][2][9][2] = hrr_order_gdmd;
  build_eri[4][2][8][3] = hrr_order_gdlf;
  build_eri[4][2][7][4] = hrr_order_gdkg;
  build_eri[4][2][6][5] = hrr_order_gdih;
  build_eri[4][2][10][2] = hrr_order_gdnd;
  build_eri[4][2][9][3] = hrr_order_gdmf;
  build_eri[4][2][8][4] = hrr_order_gdlg;
  build_eri[4][2][7][5] = hrr_order_gdkh;
  build_eri[4][2][6][6] = hrr_order_gdii;
  build_eri[4][2][10][3] = hrr_order_gdnf;
  build_eri[4][2][9][4] = hrr_order_gdmg;
  build_eri[4][2][8][5] = hrr_order_gdlh;
  build_eri[4][2][7][6] = hrr_order_gdki;
  build_eri[4][2][10][4] = hrr_order_gdng;
  build_eri[4][2][9][5] = hrr_order_gdmh;
  build_eri[4][2][8][6] = hrr_order_gdli;
  build_eri[4][2][7][7] = hrr_order_gdkk;
  build_eri[4][2][10][5] = hrr_order_gdnh;
  build_eri[4][2][9][6] = hrr_order_gdmi;
  build_eri[4][2][8][7] = hrr_order_gdlk;
  build_eri[4][2][10][6] = hrr_order_gdni;
  build_eri[4][2][9][7] = hrr_order_gdmk;
  build_eri[4][2][8][8] = hrr_order_gdll;
  build_eri[4][2][10][7] = hrr_order_gdnk;
  build_eri[4][2][9][8] = hrr_order_gdml;
  build_eri[4][2][10][8] = hrr_order_gdnl;
  build_eri[4][2][9][9] = hrr_order_gdmm;
  build_eri[4][2][10][9] = hrr_order_gdnm;
  build_eri[4][2][10][10] = hrr_order_gdnn;
  build_eri[3][3][6][0] = hrr_order_ffi0;
  build_eri[3][3][5][1] = hrr_order_ffhp;
  build_eri[3][3][4][2] = hrr_order_ffgd;
  build_eri[3][3][3][3] = hrr_order_ffff;
  build_eri[3][3][7][0] = hrr_order_ffk0;
  build_eri[3][3][6][1] = hrr_order_ffip;
  build_eri[3][3][5][2] = hrr_order_ffhd;
  build_eri[3][3][4][3] = hrr_order_ffgf;
  build_eri[3][3][8][0] = hrr_order_ffl0;
  build_eri[3][3][7][1] = hrr_order_ffkp;
  build_eri[3][3][6][2] = hrr_order_ffid;
  build_eri[3][3][5][3] = hrr_order_ffhf;
  build_eri[3][3][4][4] = hrr_order_ffgg;
  build_eri[3][3][9][0] = hrr_order_ffm0;
  build_eri[3][3][8][1] = hrr_order_fflp;
  build_eri[3][3][7][2] = hrr_order_ffkd;
  build_eri[3][3][6][3] = hrr_order_ffif;
  build_eri[3][3][5][4] = hrr_order_ffhg;
  build_eri[3][3][10][0] = hrr_order_ffn0;
  build_eri[3][3][9][1] = hrr_order_ffmp;
  build_eri[3][3][8][2] = hrr_order_ffld;
  build_eri[3][3][7][3] = hrr_order_ffkf;
  build_eri[3][3][6][4] = hrr_order_ffig;
  build_eri[3][3][5][5] = hrr_order_ffhh;
  build_eri[3][3][10][1] = hrr_order_ffnp;
  build_eri[3][3][9][2] = hrr_order_ffmd;
  build_eri[3][3][8][3] = hrr_order_fflf;
  build_eri[3][3][7][4] = hrr_order_ffkg;
  build_eri[3][3][6][5] = hrr_order_ffih;
  build_eri[3][3][10][2] = hrr_order_ffnd;
  build_eri[3][3][9][3] = hrr_order_ffmf;
  build_eri[3][3][8][4] = hrr_order_fflg;
  build_eri[3][3][7][5] = hrr_order_ffkh;
  build_eri[3][3][6][6] = hrr_order_ffii;
  build_eri[3][3][10][3] = hrr_order_ffnf;
  build_eri[3][3][9][4] = hrr_order_ffmg;
  build_eri[3][3][8][5] = hrr_order_fflh;
  build_eri[3][3][7][6] = hrr_order_ffki;
  build_eri[3][3][10][4] = hrr_order_ffng;
  build_eri[3][3][9][5] = hrr_order_ffmh;
  build_eri[3][3][8][6] = hrr_order_ffli;
  build_eri[3][3][7][7] = hrr_order_ffkk;
  build_eri[3][3][10][5] = hrr_order_ffnh;
  build_eri[3][3][9][6] = hrr_order_ffmi;
  build_eri[3][3][8][7] = hrr_order_fflk;
  build_eri[3][3][10][6] = hrr_order_ffni;
  build_eri[3][3][9][7] = hrr_order_ffmk;
  build_eri[3][3][8][8] = hrr_order_ffll;
  build_eri[3][3][10][7] = hrr_order_ffnk;
  build_eri[3][3][9][8] = hrr_order_ffml;
  build_eri[3][3][10][8] = hrr_order_ffnl;
  build_eri[3][3][9][9] = hrr_order_ffmm;
  build_eri[3][3][10][9] = hrr_order_ffnm;
  build_eri[3][3][10][10] = hrr_order_ffnn;
  build_eri[7][0][7][0] = hrr_order_k0k0;
  build_eri[7][0][6][1] = hrr_order_k0ip;
  build_eri[7][0][5][2] = hrr_order_k0hd;
  build_eri[7][0][4][3] = hrr_order_k0gf;
  build_eri[7][0][8][0] = hrr_order_k0l0;
  build_eri[7][0][7][1] = hrr_order_k0kp;
  build_eri[7][0][6][2] = hrr_order_k0id;
  build_eri[7][0][5][3] = hrr_order_k0hf;
  build_eri[7][0][4][4] = hrr_order_k0gg;
  build_eri[7][0][9][0] = hrr_order_k0m0;
  build_eri[7][0][8][1] = hrr_order_k0lp;
  build_eri[7][0][7][2] = hrr_order_k0kd;
  build_eri[7][0][6][3] = hrr_order_k0if;
  build_eri[7][0][5][4] = hrr_order_k0hg;
  build_eri[7][0][10][0] = hrr_order_k0n0;
  build_eri[7][0][9][1] = hrr_order_k0mp;
  build_eri[7][0][8][2] = hrr_order_k0ld;
  build_eri[7][0][7][3] = hrr_order_k0kf;
  build_eri[7][0][6][4] = hrr_order_k0ig;
  build_eri[7][0][5][5] = hrr_order_k0hh;
  build_eri[7][0][10][1] = hrr_order_k0np;
  build_eri[7][0][9][2] = hrr_order_k0md;
  build_eri[7][0][8][3] = hrr_order_k0lf;
  build_eri[7][0][7][4] = hrr_order_k0kg;
  build_eri[7][0][6][5] = hrr_order_k0ih;
  build_eri[7][0][10][2] = hrr_order_k0nd;
  build_eri[7][0][9][3] = hrr_order_k0mf;
  build_eri[7][0][8][4] = hrr_order_k0lg;
  build_eri[7][0][7][5] = hrr_order_k0kh;
  build_eri[7][0][6][6] = hrr_order_k0ii;
  build_eri[7][0][10][3] = hrr_order_k0nf;
  build_eri[7][0][9][4] = hrr_order_k0mg;
  build_eri[7][0][8][5] = hrr_order_k0lh;
  build_eri[7][0][7][6] = hrr_order_k0ki;
  build_eri[7][0][10][4] = hrr_order_k0ng;
  build_eri[7][0][9][5] = hrr_order_k0mh;
  build_eri[7][0][8][6] = hrr_order_k0li;
  build_eri[7][0][7][7] = hrr_order_k0kk;
  build_eri[7][0][10][5] = hrr_order_k0nh;
  build_eri[7][0][9][6] = hrr_order_k0mi;
  build_eri[7][0][8][7] = hrr_order_k0lk;
  build_eri[7][0][10][6] = hrr_order_k0ni;
  build_eri[7][0][9][7] = hrr_order_k0mk;
  build_eri[7][0][8][8] = hrr_order_k0ll;
  build_eri[7][0][10][7] = hrr_order_k0nk;
  build_eri[7][0][9][8] = hrr_order_k0ml;
  build_eri[7][0][10][8] = hrr_order_k0nl;
  build_eri[7][0][9][9] = hrr_order_k0mm;
  build_eri[7][0][10][9] = hrr_order_k0nm;
  build_eri[7][0][10][10] = hrr_order_k0nn;
  build_eri[6][1][7][0] = hrr_order_ipk0;
  build_eri[6][1][6][1] = hrr_order_ipip;
  build_eri[6][1][5][2] = hrr_order_iphd;
  build_eri[6][1][4][3] = hrr_order_ipgf;
  build_eri[6][1][8][0] = hrr_order_ipl0;
  build_eri[6][1][7][1] = hrr_order_ipkp;
  build_eri[6][1][6][2] = hrr_order_ipid;
  build_eri[6][1][5][3] = hrr_order_iphf;
  build_eri[6][1][4][4] = hrr_order_ipgg;
  build_eri[6][1][9][0] = hrr_order_ipm0;
  build_eri[6][1][8][1] = hrr_order_iplp;
  build_eri[6][1][7][2] = hrr_order_ipkd;
  build_eri[6][1][6][3] = hrr_order_ipif;
  build_eri[6][1][5][4] = hrr_order_iphg;
  build_eri[6][1][10][0] = hrr_order_ipn0;
  build_eri[6][1][9][1] = hrr_order_ipmp;
  build_eri[6][1][8][2] = hrr_order_ipld;
  build_eri[6][1][7][3] = hrr_order_ipkf;
  build_eri[6][1][6][4] = hrr_order_ipig;
  build_eri[6][1][5][5] = hrr_order_iphh;
  build_eri[6][1][10][1] = hrr_order_ipnp;
  build_eri[6][1][9][2] = hrr_order_ipmd;
  build_eri[6][1][8][3] = hrr_order_iplf;
  build_eri[6][1][7][4] = hrr_order_ipkg;
  build_eri[6][1][6][5] = hrr_order_ipih;
  build_eri[6][1][10][2] = hrr_order_ipnd;
  build_eri[6][1][9][3] = hrr_order_ipmf;
  build_eri[6][1][8][4] = hrr_order_iplg;
  build_eri[6][1][7][5] = hrr_order_ipkh;
  build_eri[6][1][6][6] = hrr_order_ipii;
  build_eri[6][1][10][3] = hrr_order_ipnf;
  build_eri[6][1][9][4] = hrr_order_ipmg;
  build_eri[6][1][8][5] = hrr_order_iplh;
  build_eri[6][1][7][6] = hrr_order_ipki;
  build_eri[6][1][10][4] = hrr_order_ipng;
  build_eri[6][1][9][5] = hrr_order_ipmh;
  build_eri[6][1][8][6] = hrr_order_ipli;
  build_eri[6][1][7][7] = hrr_order_ipkk;
  build_eri[6][1][10][5] = hrr_order_ipnh;
  build_eri[6][1][9][6] = hrr_order_ipmi;
  build_eri[6][1][8][7] = hrr_order_iplk;
  build_eri[6][1][10][6] = hrr_order_ipni;
  build_eri[6][1][9][7] = hrr_order_ipmk;
  build_eri[6][1][8][8] = hrr_order_ipll;
  build_eri[6][1][10][7] = hrr_order_ipnk;
  build_eri[6][1][9][8] = hrr_order_ipml;
  build_eri[6][1][10][8] = hrr_order_ipnl;
  build_eri[6][1][9][9] = hrr_order_ipmm;
  build_eri[6][1][10][9] = hrr_order_ipnm;
  build_eri[6][1][10][10] = hrr_order_ipnn;
  build_eri[5][2][7][0] = hrr_order_hdk0;
  build_eri[5][2][6][1] = hrr_order_hdip;
  build_eri[5][2][5][2] = hrr_order_hdhd;
  build_eri[5][2][4][3] = hrr_order_hdgf;
  build_eri[5][2][8][0] = hrr_order_hdl0;
  build_eri[5][2][7][1] = hrr_order_hdkp;
  build_eri[5][2][6][2] = hrr_order_hdid;
  build_eri[5][2][5][3] = hrr_order_hdhf;
  build_eri[5][2][4][4] = hrr_order_hdgg;
  build_eri[5][2][9][0] = hrr_order_hdm0;
  build_eri[5][2][8][1] = hrr_order_hdlp;
  build_eri[5][2][7][2] = hrr_order_hdkd;
  build_eri[5][2][6][3] = hrr_order_hdif;
  build_eri[5][2][5][4] = hrr_order_hdhg;
  build_eri[5][2][10][0] = hrr_order_hdn0;
  build_eri[5][2][9][1] = hrr_order_hdmp;
  build_eri[5][2][8][2] = hrr_order_hdld;
  build_eri[5][2][7][3] = hrr_order_hdkf;
  build_eri[5][2][6][4] = hrr_order_hdig;
  build_eri[5][2][5][5] = hrr_order_hdhh;
  build_eri[5][2][10][1] = hrr_order_hdnp;
  build_eri[5][2][9][2] = hrr_order_hdmd;
  build_eri[5][2][8][3] = hrr_order_hdlf;
  build_eri[5][2][7][4] = hrr_order_hdkg;
  build_eri[5][2][6][5] = hrr_order_hdih;
  build_eri[5][2][10][2] = hrr_order_hdnd;
  build_eri[5][2][9][3] = hrr_order_hdmf;
  build_eri[5][2][8][4] = hrr_order_hdlg;
  build_eri[5][2][7][5] = hrr_order_hdkh;
  build_eri[5][2][6][6] = hrr_order_hdii;
  build_eri[5][2][10][3] = hrr_order_hdnf;
  build_eri[5][2][9][4] = hrr_order_hdmg;
  build_eri[5][2][8][5] = hrr_order_hdlh;
  build_eri[5][2][7][6] = hrr_order_hdki;
  build_eri[5][2][10][4] = hrr_order_hdng;
  build_eri[5][2][9][5] = hrr_order_hdmh;
  build_eri[5][2][8][6] = hrr_order_hdli;
  build_eri[5][2][7][7] = hrr_order_hdkk;
  build_eri[5][2][10][5] = hrr_order_hdnh;
  build_eri[5][2][9][6] = hrr_order_hdmi;
  build_eri[5][2][8][7] = hrr_order_hdlk;
  build_eri[5][2][10][6] = hrr_order_hdni;
  build_eri[5][2][9][7] = hrr_order_hdmk;
  build_eri[5][2][8][8] = hrr_order_hdll;
  build_eri[5][2][10][7] = hrr_order_hdnk;
  build_eri[5][2][9][8] = hrr_order_hdml;
  build_eri[5][2][10][8] = hrr_order_hdnl;
  build_eri[5][2][9][9] = hrr_order_hdmm;
  build_eri[5][2][10][9] = hrr_order_hdnm;
  build_eri[5][2][10][10] = hrr_order_hdnn;
  build_eri[4][3][7][0] = hrr_order_gfk0;
  build_eri[4][3][6][1] = hrr_order_gfip;
  build_eri[4][3][5][2] = hrr_order_gfhd;
  build_eri[4][3][4][3] = hrr_order_gfgf;
  build_eri[4][3][8][0] = hrr_order_gfl0;
  build_eri[4][3][7][1] = hrr_order_gfkp;
  build_eri[4][3][6][2] = hrr_order_gfid;
  build_eri[4][3][5][3] = hrr_order_gfhf;
  build_eri[4][3][4][4] = hrr_order_gfgg;
  build_eri[4][3][9][0] = hrr_order_gfm0;
  build_eri[4][3][8][1] = hrr_order_gflp;
  build_eri[4][3][7][2] = hrr_order_gfkd;
  build_eri[4][3][6][3] = hrr_order_gfif;
  build_eri[4][3][5][4] = hrr_order_gfhg;
  build_eri[4][3][10][0] = hrr_order_gfn0;
  build_eri[4][3][9][1] = hrr_order_gfmp;
  build_eri[4][3][8][2] = hrr_order_gfld;
  build_eri[4][3][7][3] = hrr_order_gfkf;
  build_eri[4][3][6][4] = hrr_order_gfig;
  build_eri[4][3][5][5] = hrr_order_gfhh;
  build_eri[4][3][10][1] = hrr_order_gfnp;
  build_eri[4][3][9][2] = hrr_order_gfmd;
  build_eri[4][3][8][3] = hrr_order_gflf;
  build_eri[4][3][7][4] = hrr_order_gfkg;
  build_eri[4][3][6][5] = hrr_order_gfih;
  build_eri[4][3][10][2] = hrr_order_gfnd;
  build_eri[4][3][9][3] = hrr_order_gfmf;
  build_eri[4][3][8][4] = hrr_order_gflg;
  build_eri[4][3][7][5] = hrr_order_gfkh;
  build_eri[4][3][6][6] = hrr_order_gfii;
  build_eri[4][3][10][3] = hrr_order_gfnf;
  build_eri[4][3][9][4] = hrr_order_gfmg;
  build_eri[4][3][8][5] = hrr_order_gflh;
  build_eri[4][3][7][6] = hrr_order_gfki;
  build_eri[4][3][10][4] = hrr_order_gfng;
  build_eri[4][3][9][5] = hrr_order_gfmh;
  build_eri[4][3][8][6] = hrr_order_gfli;
  build_eri[4][3][7][7] = hrr_order_gfkk;
  build_eri[4][3][10][5] = hrr_order_gfnh;
  build_eri[4][3][9][6] = hrr_order_gfmi;
  build_eri[4][3][8][7] = hrr_order_gflk;
  build_eri[4][3][10][6] = hrr_order_gfni;
  build_eri[4][3][9][7] = hrr_order_gfmk;
  build_eri[4][3][8][8] = hrr_order_gfll;
  build_eri[4][3][10][7] = hrr_order_gfnk;
  build_eri[4][3][9][8] = hrr_order_gfml;
  build_eri[4][3][10][8] = hrr_order_gfnl;
  build_eri[4][3][9][9] = hrr_order_gfmm;
  build_eri[4][3][10][9] = hrr_order_gfnm;
  build_eri[4][3][10][10] = hrr_order_gfnn;
  build_eri[8][0][8][0] = hrr_order_l0l0;
  build_eri[8][0][7][1] = hrr_order_l0kp;
  build_eri[8][0][6][2] = hrr_order_l0id;
  build_eri[8][0][5][3] = hrr_order_l0hf;
  build_eri[8][0][4][4] = hrr_order_l0gg;
  build_eri[8][0][9][0] = hrr_order_l0m0;
  build_eri[8][0][8][1] = hrr_order_l0lp;
  build_eri[8][0][7][2] = hrr_order_l0kd;
  build_eri[8][0][6][3] = hrr_order_l0if;
  build_eri[8][0][5][4] = hrr_order_l0hg;
  build_eri[8][0][10][0] = hrr_order_l0n0;
  build_eri[8][0][9][1] = hrr_order_l0mp;
  build_eri[8][0][8][2] = hrr_order_l0ld;
  build_eri[8][0][7][3] = hrr_order_l0kf;
  build_eri[8][0][6][4] = hrr_order_l0ig;
  build_eri[8][0][5][5] = hrr_order_l0hh;
  build_eri[8][0][10][1] = hrr_order_l0np;
  build_eri[8][0][9][2] = hrr_order_l0md;
  build_eri[8][0][8][3] = hrr_order_l0lf;
  build_eri[8][0][7][4] = hrr_order_l0kg;
  build_eri[8][0][6][5] = hrr_order_l0ih;
  build_eri[8][0][10][2] = hrr_order_l0nd;
  build_eri[8][0][9][3] = hrr_order_l0mf;
  build_eri[8][0][8][4] = hrr_order_l0lg;
  build_eri[8][0][7][5] = hrr_order_l0kh;
  build_eri[8][0][6][6] = hrr_order_l0ii;
  build_eri[8][0][10][3] = hrr_order_l0nf;
  build_eri[8][0][9][4] = hrr_order_l0mg;
  build_eri[8][0][8][5] = hrr_order_l0lh;
  build_eri[8][0][7][6] = hrr_order_l0ki;
  build_eri[8][0][10][4] = hrr_order_l0ng;
  build_eri[8][0][9][5] = hrr_order_l0mh;
  build_eri[8][0][8][6] = hrr_order_l0li;
  build_eri[8][0][7][7] = hrr_order_l0kk;
  build_eri[8][0][10][5] = hrr_order_l0nh;
  build_eri[8][0][9][6] = hrr_order_l0mi;
  build_eri[8][0][8][7] = hrr_order_l0lk;
  build_eri[8][0][10][6] = hrr_order_l0ni;
  build_eri[8][0][9][7] = hrr_order_l0mk;
  build_eri[8][0][8][8] = hrr_order_l0ll;
  build_eri[8][0][10][7] = hrr_order_l0nk;
  build_eri[8][0][9][8] = hrr_order_l0ml;
  build_eri[8][0][10][8] = hrr_order_l0nl;
  build_eri[8][0][9][9] = hrr_order_l0mm;
  build_eri[8][0][10][9] = hrr_order_l0nm;
  build_eri[8][0][10][10] = hrr_order_l0nn;
  build_eri[7][1][8][0] = hrr_order_kpl0;
  build_eri[7][1][7][1] = hrr_order_kpkp;
  build_eri[7][1][6][2] = hrr_order_kpid;
  build_eri[7][1][5][3] = hrr_order_kphf;
  build_eri[7][1][4][4] = hrr_order_kpgg;
  build_eri[7][1][9][0] = hrr_order_kpm0;
  build_eri[7][1][8][1] = hrr_order_kplp;
  build_eri[7][1][7][2] = hrr_order_kpkd;
  build_eri[7][1][6][3] = hrr_order_kpif;
  build_eri[7][1][5][4] = hrr_order_kphg;
  build_eri[7][1][10][0] = hrr_order_kpn0;
  build_eri[7][1][9][1] = hrr_order_kpmp;
  build_eri[7][1][8][2] = hrr_order_kpld;
  build_eri[7][1][7][3] = hrr_order_kpkf;
  build_eri[7][1][6][4] = hrr_order_kpig;
  build_eri[7][1][5][5] = hrr_order_kphh;
  build_eri[7][1][10][1] = hrr_order_kpnp;
  build_eri[7][1][9][2] = hrr_order_kpmd;
  build_eri[7][1][8][3] = hrr_order_kplf;
  build_eri[7][1][7][4] = hrr_order_kpkg;
  build_eri[7][1][6][5] = hrr_order_kpih;
  build_eri[7][1][10][2] = hrr_order_kpnd;
  build_eri[7][1][9][3] = hrr_order_kpmf;
  build_eri[7][1][8][4] = hrr_order_kplg;
  build_eri[7][1][7][5] = hrr_order_kpkh;
  build_eri[7][1][6][6] = hrr_order_kpii;
  build_eri[7][1][10][3] = hrr_order_kpnf;
  build_eri[7][1][9][4] = hrr_order_kpmg;
  build_eri[7][1][8][5] = hrr_order_kplh;
  build_eri[7][1][7][6] = hrr_order_kpki;
  build_eri[7][1][10][4] = hrr_order_kpng;
  build_eri[7][1][9][5] = hrr_order_kpmh;
  build_eri[7][1][8][6] = hrr_order_kpli;
  build_eri[7][1][7][7] = hrr_order_kpkk;
  build_eri[7][1][10][5] = hrr_order_kpnh;
  build_eri[7][1][9][6] = hrr_order_kpmi;
  build_eri[7][1][8][7] = hrr_order_kplk;
  build_eri[7][1][10][6] = hrr_order_kpni;
  build_eri[7][1][9][7] = hrr_order_kpmk;
  build_eri[7][1][8][8] = hrr_order_kpll;
  build_eri[7][1][10][7] = hrr_order_kpnk;
  build_eri[7][1][9][8] = hrr_order_kpml;
  build_eri[7][1][10][8] = hrr_order_kpnl;
  build_eri[7][1][9][9] = hrr_order_kpmm;
  build_eri[7][1][10][9] = hrr_order_kpnm;
  build_eri[7][1][10][10] = hrr_order_kpnn;
  build_eri[6][2][8][0] = hrr_order_idl0;
  build_eri[6][2][7][1] = hrr_order_idkp;
  build_eri[6][2][6][2] = hrr_order_idid;
  build_eri[6][2][5][3] = hrr_order_idhf;
  build_eri[6][2][4][4] = hrr_order_idgg;
  build_eri[6][2][9][0] = hrr_order_idm0;
  build_eri[6][2][8][1] = hrr_order_idlp;
  build_eri[6][2][7][2] = hrr_order_idkd;
  build_eri[6][2][6][3] = hrr_order_idif;
  build_eri[6][2][5][4] = hrr_order_idhg;
  build_eri[6][2][10][0] = hrr_order_idn0;
  build_eri[6][2][9][1] = hrr_order_idmp;
  build_eri[6][2][8][2] = hrr_order_idld;
  build_eri[6][2][7][3] = hrr_order_idkf;
  build_eri[6][2][6][4] = hrr_order_idig;
  build_eri[6][2][5][5] = hrr_order_idhh;
  build_eri[6][2][10][1] = hrr_order_idnp;
  build_eri[6][2][9][2] = hrr_order_idmd;
  build_eri[6][2][8][3] = hrr_order_idlf;
  build_eri[6][2][7][4] = hrr_order_idkg;
  build_eri[6][2][6][5] = hrr_order_idih;
  build_eri[6][2][10][2] = hrr_order_idnd;
  build_eri[6][2][9][3] = hrr_order_idmf;
  build_eri[6][2][8][4] = hrr_order_idlg;
  build_eri[6][2][7][5] = hrr_order_idkh;
  build_eri[6][2][6][6] = hrr_order_idii;
  build_eri[6][2][10][3] = hrr_order_idnf;
  build_eri[6][2][9][4] = hrr_order_idmg;
  build_eri[6][2][8][5] = hrr_order_idlh;
  build_eri[6][2][7][6] = hrr_order_idki;
  build_eri[6][2][10][4] = hrr_order_idng;
  build_eri[6][2][9][5] = hrr_order_idmh;
  build_eri[6][2][8][6] = hrr_order_idli;
  build_eri[6][2][7][7] = hrr_order_idkk;
  build_eri[6][2][10][5] = hrr_order_idnh;
  build_eri[6][2][9][6] = hrr_order_idmi;
  build_eri[6][2][8][7] = hrr_order_idlk;
  build_eri[6][2][10][6] = hrr_order_idni;
  build_eri[6][2][9][7] = hrr_order_idmk;
  build_eri[6][2][8][8] = hrr_order_idll;
  build_eri[6][2][10][7] = hrr_order_idnk;
  build_eri[6][2][9][8] = hrr_order_idml;
  build_eri[6][2][10][8] = hrr_order_idnl;
  build_eri[6][2][9][9] = hrr_order_idmm;
  build_eri[6][2][10][9] = hrr_order_idnm;
  build_eri[6][2][10][10] = hrr_order_idnn;
  build_eri[5][3][8][0] = hrr_order_hfl0;
  build_eri[5][3][7][1] = hrr_order_hfkp;
  build_eri[5][3][6][2] = hrr_order_hfid;
  build_eri[5][3][5][3] = hrr_order_hfhf;
  build_eri[5][3][4][4] = hrr_order_hfgg;
  build_eri[5][3][9][0] = hrr_order_hfm0;
  build_eri[5][3][8][1] = hrr_order_hflp;
  build_eri[5][3][7][2] = hrr_order_hfkd;
  build_eri[5][3][6][3] = hrr_order_hfif;
  build_eri[5][3][5][4] = hrr_order_hfhg;
  build_eri[5][3][10][0] = hrr_order_hfn0;
  build_eri[5][3][9][1] = hrr_order_hfmp;
  build_eri[5][3][8][2] = hrr_order_hfld;
  build_eri[5][3][7][3] = hrr_order_hfkf;
  build_eri[5][3][6][4] = hrr_order_hfig;
  build_eri[5][3][5][5] = hrr_order_hfhh;
  build_eri[5][3][10][1] = hrr_order_hfnp;
  build_eri[5][3][9][2] = hrr_order_hfmd;
  build_eri[5][3][8][3] = hrr_order_hflf;
  build_eri[5][3][7][4] = hrr_order_hfkg;
  build_eri[5][3][6][5] = hrr_order_hfih;
  build_eri[5][3][10][2] = hrr_order_hfnd;
  build_eri[5][3][9][3] = hrr_order_hfmf;
  build_eri[5][3][8][4] = hrr_order_hflg;
  build_eri[5][3][7][5] = hrr_order_hfkh;
  build_eri[5][3][6][6] = hrr_order_hfii;
  build_eri[5][3][10][3] = hrr_order_hfnf;
  build_eri[5][3][9][4] = hrr_order_hfmg;
  build_eri[5][3][8][5] = hrr_order_hflh;
  build_eri[5][3][7][6] = hrr_order_hfki;
  build_eri[5][3][10][4] = hrr_order_hfng;
  build_eri[5][3][9][5] = hrr_order_hfmh;
  build_eri[5][3][8][6] = hrr_order_hfli;
  build_eri[5][3][7][7] = hrr_order_hfkk;
  build_eri[5][3][10][5] = hrr_order_hfnh;
  build_eri[5][3][9][6] = hrr_order_hfmi;
  build_eri[5][3][8][7] = hrr_order_hflk;
  build_eri[5][3][10][6] = hrr_order_hfni;
  build_eri[5][3][9][7] = hrr_order_hfmk;
  build_eri[5][3][8][8] = hrr_order_hfll;
  build_eri[5][3][10][7] = hrr_order_hfnk;
  build_eri[5][3][9][8] = hrr_order_hfml;
  build_eri[5][3][10][8] = hrr_order_hfnl;
  build_eri[5][3][9][9] = hrr_order_hfmm;
  build_eri[5][3][10][9] = hrr_order_hfnm;
  build_eri[5][3][10][10] = hrr_order_hfnn;
  build_eri[4][4][8][0] = hrr_order_ggl0;
  build_eri[4][4][7][1] = hrr_order_ggkp;
  build_eri[4][4][6][2] = hrr_order_ggid;
  build_eri[4][4][5][3] = hrr_order_gghf;
  build_eri[4][4][4][4] = hrr_order_gggg;
  build_eri[4][4][9][0] = hrr_order_ggm0;
  build_eri[4][4][8][1] = hrr_order_gglp;
  build_eri[4][4][7][2] = hrr_order_ggkd;
  build_eri[4][4][6][3] = hrr_order_ggif;
  build_eri[4][4][5][4] = hrr_order_gghg;
  build_eri[4][4][10][0] = hrr_order_ggn0;
  build_eri[4][4][9][1] = hrr_order_ggmp;
  build_eri[4][4][8][2] = hrr_order_ggld;
  build_eri[4][4][7][3] = hrr_order_ggkf;
  build_eri[4][4][6][4] = hrr_order_ggig;
  build_eri[4][4][5][5] = hrr_order_gghh;
  build_eri[4][4][10][1] = hrr_order_ggnp;
  build_eri[4][4][9][2] = hrr_order_ggmd;
  build_eri[4][4][8][3] = hrr_order_gglf;
  build_eri[4][4][7][4] = hrr_order_ggkg;
  build_eri[4][4][6][5] = hrr_order_ggih;
  build_eri[4][4][10][2] = hrr_order_ggnd;
  build_eri[4][4][9][3] = hrr_order_ggmf;
  build_eri[4][4][8][4] = hrr_order_gglg;
  build_eri[4][4][7][5] = hrr_order_ggkh;
  build_eri[4][4][6][6] = hrr_order_ggii;
  build_eri[4][4][10][3] = hrr_order_ggnf;
  build_eri[4][4][9][4] = hrr_order_ggmg;
  build_eri[4][4][8][5] = hrr_order_gglh;
  build_eri[4][4][7][6] = hrr_order_ggki;
  build_eri[4][4][10][4] = hrr_order_ggng;
  build_eri[4][4][9][5] = hrr_order_ggmh;
  build_eri[4][4][8][6] = hrr_order_ggli;
  build_eri[4][4][7][7] = hrr_order_ggkk;
  build_eri[4][4][10][5] = hrr_order_ggnh;
  build_eri[4][4][9][6] = hrr_order_ggmi;
  build_eri[4][4][8][7] = hrr_order_gglk;
  build_eri[4][4][10][6] = hrr_order_ggni;
  build_eri[4][4][9][7] = hrr_order_ggmk;
  build_eri[4][4][8][8] = hrr_order_ggll;
  build_eri[4][4][10][7] = hrr_order_ggnk;
  build_eri[4][4][9][8] = hrr_order_ggml;
  build_eri[4][4][10][8] = hrr_order_ggnl;
  build_eri[4][4][9][9] = hrr_order_ggmm;
  build_eri[4][4][10][9] = hrr_order_ggnm;
  build_eri[4][4][10][10] = hrr_order_ggnn;
  build_eri[9][0][9][0] = hrr_order_m0m0;
  build_eri[9][0][8][1] = hrr_order_m0lp;
  build_eri[9][0][7][2] = hrr_order_m0kd;
  build_eri[9][0][6][3] = hrr_order_m0if;
  build_eri[9][0][5][4] = hrr_order_m0hg;
  build_eri[9][0][10][0] = hrr_order_m0n0;
  build_eri[9][0][9][1] = hrr_order_m0mp;
  build_eri[9][0][8][2] = hrr_order_m0ld;
  build_eri[9][0][7][3] = hrr_order_m0kf;
  build_eri[9][0][6][4] = hrr_order_m0ig;
  build_eri[9][0][5][5] = hrr_order_m0hh;
  build_eri[9][0][10][1] = hrr_order_m0np;
  build_eri[9][0][9][2] = hrr_order_m0md;
  build_eri[9][0][8][3] = hrr_order_m0lf;
  build_eri[9][0][7][4] = hrr_order_m0kg;
  build_eri[9][0][6][5] = hrr_order_m0ih;
  build_eri[9][0][10][2] = hrr_order_m0nd;
  build_eri[9][0][9][3] = hrr_order_m0mf;
  build_eri[9][0][8][4] = hrr_order_m0lg;
  build_eri[9][0][7][5] = hrr_order_m0kh;
  build_eri[9][0][6][6] = hrr_order_m0ii;
  build_eri[9][0][10][3] = hrr_order_m0nf;
  build_eri[9][0][9][4] = hrr_order_m0mg;
  build_eri[9][0][8][5] = hrr_order_m0lh;
  build_eri[9][0][7][6] = hrr_order_m0ki;
  build_eri[9][0][10][4] = hrr_order_m0ng;
  build_eri[9][0][9][5] = hrr_order_m0mh;
  build_eri[9][0][8][6] = hrr_order_m0li;
  build_eri[9][0][7][7] = hrr_order_m0kk;
  build_eri[9][0][10][5] = hrr_order_m0nh;
  build_eri[9][0][9][6] = hrr_order_m0mi;
  build_eri[9][0][8][7] = hrr_order_m0lk;
  build_eri[9][0][10][6] = hrr_order_m0ni;
  build_eri[9][0][9][7] = hrr_order_m0mk;
  build_eri[9][0][8][8] = hrr_order_m0ll;
  build_eri[9][0][10][7] = hrr_order_m0nk;
  build_eri[9][0][9][8] = hrr_order_m0ml;
  build_eri[9][0][10][8] = hrr_order_m0nl;
  build_eri[9][0][9][9] = hrr_order_m0mm;
  build_eri[9][0][10][9] = hrr_order_m0nm;
  build_eri[9][0][10][10] = hrr_order_m0nn;
  build_eri[8][1][9][0] = hrr_order_lpm0;
  build_eri[8][1][8][1] = hrr_order_lplp;
  build_eri[8][1][7][2] = hrr_order_lpkd;
  build_eri[8][1][6][3] = hrr_order_lpif;
  build_eri[8][1][5][4] = hrr_order_lphg;
  build_eri[8][1][10][0] = hrr_order_lpn0;
  build_eri[8][1][9][1] = hrr_order_lpmp;
  build_eri[8][1][8][2] = hrr_order_lpld;
  build_eri[8][1][7][3] = hrr_order_lpkf;
  build_eri[8][1][6][4] = hrr_order_lpig;
  build_eri[8][1][5][5] = hrr_order_lphh;
  build_eri[8][1][10][1] = hrr_order_lpnp;
  build_eri[8][1][9][2] = hrr_order_lpmd;
  build_eri[8][1][8][3] = hrr_order_lplf;
  build_eri[8][1][7][4] = hrr_order_lpkg;
  build_eri[8][1][6][5] = hrr_order_lpih;
  build_eri[8][1][10][2] = hrr_order_lpnd;
  build_eri[8][1][9][3] = hrr_order_lpmf;
  build_eri[8][1][8][4] = hrr_order_lplg;
  build_eri[8][1][7][5] = hrr_order_lpkh;
  build_eri[8][1][6][6] = hrr_order_lpii;
  build_eri[8][1][10][3] = hrr_order_lpnf;
  build_eri[8][1][9][4] = hrr_order_lpmg;
  build_eri[8][1][8][5] = hrr_order_lplh;
  build_eri[8][1][7][6] = hrr_order_lpki;
  build_eri[8][1][10][4] = hrr_order_lpng;
  build_eri[8][1][9][5] = hrr_order_lpmh;
  build_eri[8][1][8][6] = hrr_order_lpli;
  build_eri[8][1][7][7] = hrr_order_lpkk;
  build_eri[8][1][10][5] = hrr_order_lpnh;
  build_eri[8][1][9][6] = hrr_order_lpmi;
  build_eri[8][1][8][7] = hrr_order_lplk;
  build_eri[8][1][10][6] = hrr_order_lpni;
  build_eri[8][1][9][7] = hrr_order_lpmk;
  build_eri[8][1][8][8] = hrr_order_lpll;
  build_eri[8][1][10][7] = hrr_order_lpnk;
  build_eri[8][1][9][8] = hrr_order_lpml;
  build_eri[8][1][10][8] = hrr_order_lpnl;
  build_eri[8][1][9][9] = hrr_order_lpmm;
  build_eri[8][1][10][9] = hrr_order_lpnm;
  build_eri[8][1][10][10] = hrr_order_lpnn;
  build_eri[7][2][9][0] = hrr_order_kdm0;
  build_eri[7][2][8][1] = hrr_order_kdlp;
  build_eri[7][2][7][2] = hrr_order_kdkd;
  build_eri[7][2][6][3] = hrr_order_kdif;
  build_eri[7][2][5][4] = hrr_order_kdhg;
  build_eri[7][2][10][0] = hrr_order_kdn0;
  build_eri[7][2][9][1] = hrr_order_kdmp;
  build_eri[7][2][8][2] = hrr_order_kdld;
  build_eri[7][2][7][3] = hrr_order_kdkf;
  build_eri[7][2][6][4] = hrr_order_kdig;
  build_eri[7][2][5][5] = hrr_order_kdhh;
  build_eri[7][2][10][1] = hrr_order_kdnp;
  build_eri[7][2][9][2] = hrr_order_kdmd;
  build_eri[7][2][8][3] = hrr_order_kdlf;
  build_eri[7][2][7][4] = hrr_order_kdkg;
  build_eri[7][2][6][5] = hrr_order_kdih;
  build_eri[7][2][10][2] = hrr_order_kdnd;
  build_eri[7][2][9][3] = hrr_order_kdmf;
  build_eri[7][2][8][4] = hrr_order_kdlg;
  build_eri[7][2][7][5] = hrr_order_kdkh;
  build_eri[7][2][6][6] = hrr_order_kdii;
  build_eri[7][2][10][3] = hrr_order_kdnf;
  build_eri[7][2][9][4] = hrr_order_kdmg;
  build_eri[7][2][8][5] = hrr_order_kdlh;
  build_eri[7][2][7][6] = hrr_order_kdki;
  build_eri[7][2][10][4] = hrr_order_kdng;
  build_eri[7][2][9][5] = hrr_order_kdmh;
  build_eri[7][2][8][6] = hrr_order_kdli;
  build_eri[7][2][7][7] = hrr_order_kdkk;
  build_eri[7][2][10][5] = hrr_order_kdnh;
  build_eri[7][2][9][6] = hrr_order_kdmi;
  build_eri[7][2][8][7] = hrr_order_kdlk;
  build_eri[7][2][10][6] = hrr_order_kdni;
  build_eri[7][2][9][7] = hrr_order_kdmk;
  build_eri[7][2][8][8] = hrr_order_kdll;
  build_eri[7][2][10][7] = hrr_order_kdnk;
  build_eri[7][2][9][8] = hrr_order_kdml;
  build_eri[7][2][10][8] = hrr_order_kdnl;
  build_eri[7][2][9][9] = hrr_order_kdmm;
  build_eri[7][2][10][9] = hrr_order_kdnm;
  build_eri[7][2][10][10] = hrr_order_kdnn;
  build_eri[6][3][9][0] = hrr_order_ifm0;
  build_eri[6][3][8][1] = hrr_order_iflp;
  build_eri[6][3][7][2] = hrr_order_ifkd;
  build_eri[6][3][6][3] = hrr_order_ifif;
  build_eri[6][3][5][4] = hrr_order_ifhg;
  build_eri[6][3][10][0] = hrr_order_ifn0;
  build_eri[6][3][9][1] = hrr_order_ifmp;
  build_eri[6][3][8][2] = hrr_order_ifld;
  build_eri[6][3][7][3] = hrr_order_ifkf;
  build_eri[6][3][6][4] = hrr_order_ifig;
  build_eri[6][3][5][5] = hrr_order_ifhh;
  build_eri[6][3][10][1] = hrr_order_ifnp;
  build_eri[6][3][9][2] = hrr_order_ifmd;
  build_eri[6][3][8][3] = hrr_order_iflf;
  build_eri[6][3][7][4] = hrr_order_ifkg;
  build_eri[6][3][6][5] = hrr_order_ifih;
  build_eri[6][3][10][2] = hrr_order_ifnd;
  build_eri[6][3][9][3] = hrr_order_ifmf;
  build_eri[6][3][8][4] = hrr_order_iflg;
  build_eri[6][3][7][5] = hrr_order_ifkh;
  build_eri[6][3][6][6] = hrr_order_ifii;
  build_eri[6][3][10][3] = hrr_order_ifnf;
  build_eri[6][3][9][4] = hrr_order_ifmg;
  build_eri[6][3][8][5] = hrr_order_iflh;
  build_eri[6][3][7][6] = hrr_order_ifki;
  build_eri[6][3][10][4] = hrr_order_ifng;
  build_eri[6][3][9][5] = hrr_order_ifmh;
  build_eri[6][3][8][6] = hrr_order_ifli;
  build_eri[6][3][7][7] = hrr_order_ifkk;
  build_eri[6][3][10][5] = hrr_order_ifnh;
  build_eri[6][3][9][6] = hrr_order_ifmi;
  build_eri[6][3][8][7] = hrr_order_iflk;
  build_eri[6][3][10][6] = hrr_order_ifni;
  build_eri[6][3][9][7] = hrr_order_ifmk;
  build_eri[6][3][8][8] = hrr_order_ifll;
  build_eri[6][3][10][7] = hrr_order_ifnk;
  build_eri[6][3][9][8] = hrr_order_ifml;
  build_eri[6][3][10][8] = hrr_order_ifnl;
  build_eri[6][3][9][9] = hrr_order_ifmm;
  build_eri[6][3][10][9] = hrr_order_ifnm;
  build_eri[6][3][10][10] = hrr_order_ifnn;
  build_eri[5][4][9][0] = hrr_order_hgm0;
  build_eri[5][4][8][1] = hrr_order_hglp;
  build_eri[5][4][7][2] = hrr_order_hgkd;
  build_eri[5][4][6][3] = hrr_order_hgif;
  build_eri[5][4][5][4] = hrr_order_hghg;
  build_eri[5][4][10][0] = hrr_order_hgn0;
  build_eri[5][4][9][1] = hrr_order_hgmp;
  build_eri[5][4][8][2] = hrr_order_hgld;
  build_eri[5][4][7][3] = hrr_order_hgkf;
  build_eri[5][4][6][4] = hrr_order_hgig;
  build_eri[5][4][5][5] = hrr_order_hghh;
  build_eri[5][4][10][1] = hrr_order_hgnp;
  build_eri[5][4][9][2] = hrr_order_hgmd;
  build_eri[5][4][8][3] = hrr_order_hglf;
  build_eri[5][4][7][4] = hrr_order_hgkg;
  build_eri[5][4][6][5] = hrr_order_hgih;
  build_eri[5][4][10][2] = hrr_order_hgnd;
  build_eri[5][4][9][3] = hrr_order_hgmf;
  build_eri[5][4][8][4] = hrr_order_hglg;
  build_eri[5][4][7][5] = hrr_order_hgkh;
  build_eri[5][4][6][6] = hrr_order_hgii;
  build_eri[5][4][10][3] = hrr_order_hgnf;
  build_eri[5][4][9][4] = hrr_order_hgmg;
  build_eri[5][4][8][5] = hrr_order_hglh;
  build_eri[5][4][7][6] = hrr_order_hgki;
  build_eri[5][4][10][4] = hrr_order_hgng;
  build_eri[5][4][9][5] = hrr_order_hgmh;
  build_eri[5][4][8][6] = hrr_order_hgli;
  build_eri[5][4][7][7] = hrr_order_hgkk;
  build_eri[5][4][10][5] = hrr_order_hgnh;
  build_eri[5][4][9][6] = hrr_order_hgmi;
  build_eri[5][4][8][7] = hrr_order_hglk;
  build_eri[5][4][10][6] = hrr_order_hgni;
  build_eri[5][4][9][7] = hrr_order_hgmk;
  build_eri[5][4][8][8] = hrr_order_hgll;
  build_eri[5][4][10][7] = hrr_order_hgnk;
  build_eri[5][4][9][8] = hrr_order_hgml;
  build_eri[5][4][10][8] = hrr_order_hgnl;
  build_eri[5][4][9][9] = hrr_order_hgmm;
  build_eri[5][4][10][9] = hrr_order_hgnm;
  build_eri[5][4][10][10] = hrr_order_hgnn;
  build_eri[10][0][10][0] = hrr_order_n0n0;
  build_eri[10][0][9][1] = hrr_order_n0mp;
  build_eri[10][0][8][2] = hrr_order_n0ld;
  build_eri[10][0][7][3] = hrr_order_n0kf;
  build_eri[10][0][6][4] = hrr_order_n0ig;
  build_eri[10][0][5][5] = hrr_order_n0hh;
  build_eri[10][0][10][1] = hrr_order_n0np;
  build_eri[10][0][9][2] = hrr_order_n0md;
  build_eri[10][0][8][3] = hrr_order_n0lf;
  build_eri[10][0][7][4] = hrr_order_n0kg;
  build_eri[10][0][6][5] = hrr_order_n0ih;
  build_eri[10][0][10][2] = hrr_order_n0nd;
  build_eri[10][0][9][3] = hrr_order_n0mf;
  build_eri[10][0][8][4] = hrr_order_n0lg;
  build_eri[10][0][7][5] = hrr_order_n0kh;
  build_eri[10][0][6][6] = hrr_order_n0ii;
  build_eri[10][0][10][3] = hrr_order_n0nf;
  build_eri[10][0][9][4] = hrr_order_n0mg;
  build_eri[10][0][8][5] = hrr_order_n0lh;
  build_eri[10][0][7][6] = hrr_order_n0ki;
  build_eri[10][0][10][4] = hrr_order_n0ng;
  build_eri[10][0][9][5] = hrr_order_n0mh;
  build_eri[10][0][8][6] = hrr_order_n0li;
  build_eri[10][0][7][7] = hrr_order_n0kk;
  build_eri[10][0][10][5] = hrr_order_n0nh;
  build_eri[10][0][9][6] = hrr_order_n0mi;
  build_eri[10][0][8][7] = hrr_order_n0lk;
  build_eri[10][0][10][6] = hrr_order_n0ni;
  build_eri[10][0][9][7] = hrr_order_n0mk;
  build_eri[10][0][8][8] = hrr_order_n0ll;
  build_eri[10][0][10][7] = hrr_order_n0nk;
  build_eri[10][0][9][8] = hrr_order_n0ml;
  build_eri[10][0][10][8] = hrr_order_n0nl;
  build_eri[10][0][9][9] = hrr_order_n0mm;
  build_eri[10][0][10][9] = hrr_order_n0nm;
  build_eri[10][0][10][10] = hrr_order_n0nn;
  build_eri[9][1][10][0] = hrr_order_mpn0;
  build_eri[9][1][9][1] = hrr_order_mpmp;
  build_eri[9][1][8][2] = hrr_order_mpld;
  build_eri[9][1][7][3] = hrr_order_mpkf;
  build_eri[9][1][6][4] = hrr_order_mpig;
  build_eri[9][1][5][5] = hrr_order_mphh;
  build_eri[9][1][10][1] = hrr_order_mpnp;
  build_eri[9][1][9][2] = hrr_order_mpmd;
  build_eri[9][1][8][3] = hrr_order_mplf;
  build_eri[9][1][7][4] = hrr_order_mpkg;
  build_eri[9][1][6][5] = hrr_order_mpih;
  build_eri[9][1][10][2] = hrr_order_mpnd;
  build_eri[9][1][9][3] = hrr_order_mpmf;
  build_eri[9][1][8][4] = hrr_order_mplg;
  build_eri[9][1][7][5] = hrr_order_mpkh;
  build_eri[9][1][6][6] = hrr_order_mpii;
  build_eri[9][1][10][3] = hrr_order_mpnf;
  build_eri[9][1][9][4] = hrr_order_mpmg;
  build_eri[9][1][8][5] = hrr_order_mplh;
  build_eri[9][1][7][6] = hrr_order_mpki;
  build_eri[9][1][10][4] = hrr_order_mpng;
  build_eri[9][1][9][5] = hrr_order_mpmh;
  build_eri[9][1][8][6] = hrr_order_mpli;
  build_eri[9][1][7][7] = hrr_order_mpkk;
  build_eri[9][1][10][5] = hrr_order_mpnh;
  build_eri[9][1][9][6] = hrr_order_mpmi;
  build_eri[9][1][8][7] = hrr_order_mplk;
  build_eri[9][1][10][6] = hrr_order_mpni;
  build_eri[9][1][9][7] = hrr_order_mpmk;
  build_eri[9][1][8][8] = hrr_order_mpll;
  build_eri[9][1][10][7] = hrr_order_mpnk;
  build_eri[9][1][9][8] = hrr_order_mpml;
  build_eri[9][1][10][8] = hrr_order_mpnl;
  build_eri[9][1][9][9] = hrr_order_mpmm;
  build_eri[9][1][10][9] = hrr_order_mpnm;
  build_eri[9][1][10][10] = hrr_order_mpnn;
  build_eri[8][2][10][0] = hrr_order_ldn0;
  build_eri[8][2][9][1] = hrr_order_ldmp;
  build_eri[8][2][8][2] = hrr_order_ldld;
  build_eri[8][2][7][3] = hrr_order_ldkf;
  build_eri[8][2][6][4] = hrr_order_ldig;
  build_eri[8][2][5][5] = hrr_order_ldhh;
  build_eri[8][2][10][1] = hrr_order_ldnp;
  build_eri[8][2][9][2] = hrr_order_ldmd;
  build_eri[8][2][8][3] = hrr_order_ldlf;
  build_eri[8][2][7][4] = hrr_order_ldkg;
  build_eri[8][2][6][5] = hrr_order_ldih;
  build_eri[8][2][10][2] = hrr_order_ldnd;
  build_eri[8][2][9][3] = hrr_order_ldmf;
  build_eri[8][2][8][4] = hrr_order_ldlg;
  build_eri[8][2][7][5] = hrr_order_ldkh;
  build_eri[8][2][6][6] = hrr_order_ldii;
  build_eri[8][2][10][3] = hrr_order_ldnf;
  build_eri[8][2][9][4] = hrr_order_ldmg;
  build_eri[8][2][8][5] = hrr_order_ldlh;
  build_eri[8][2][7][6] = hrr_order_ldki;
  build_eri[8][2][10][4] = hrr_order_ldng;
  build_eri[8][2][9][5] = hrr_order_ldmh;
  build_eri[8][2][8][6] = hrr_order_ldli;
  build_eri[8][2][7][7] = hrr_order_ldkk;
  build_eri[8][2][10][5] = hrr_order_ldnh;
  build_eri[8][2][9][6] = hrr_order_ldmi;
  build_eri[8][2][8][7] = hrr_order_ldlk;
  build_eri[8][2][10][6] = hrr_order_ldni;
  build_eri[8][2][9][7] = hrr_order_ldmk;
  build_eri[8][2][8][8] = hrr_order_ldll;
  build_eri[8][2][10][7] = hrr_order_ldnk;
  build_eri[8][2][9][8] = hrr_order_ldml;
  build_eri[8][2][10][8] = hrr_order_ldnl;
  build_eri[8][2][9][9] = hrr_order_ldmm;
  build_eri[8][2][10][9] = hrr_order_ldnm;
  build_eri[8][2][10][10] = hrr_order_ldnn;
  build_eri[7][3][10][0] = hrr_order_kfn0;
  build_eri[7][3][9][1] = hrr_order_kfmp;
  build_eri[7][3][8][2] = hrr_order_kfld;
  build_eri[7][3][7][3] = hrr_order_kfkf;
  build_eri[7][3][6][4] = hrr_order_kfig;
  build_eri[7][3][5][5] = hrr_order_kfhh;
  build_eri[7][3][10][1] = hrr_order_kfnp;
  build_eri[7][3][9][2] = hrr_order_kfmd;
  build_eri[7][3][8][3] = hrr_order_kflf;
  build_eri[7][3][7][4] = hrr_order_kfkg;
  build_eri[7][3][6][5] = hrr_order_kfih;
  build_eri[7][3][10][2] = hrr_order_kfnd;
  build_eri[7][3][9][3] = hrr_order_kfmf;
  build_eri[7][3][8][4] = hrr_order_kflg;
  build_eri[7][3][7][5] = hrr_order_kfkh;
  build_eri[7][3][6][6] = hrr_order_kfii;
  build_eri[7][3][10][3] = hrr_order_kfnf;
  build_eri[7][3][9][4] = hrr_order_kfmg;
  build_eri[7][3][8][5] = hrr_order_kflh;
  build_eri[7][3][7][6] = hrr_order_kfki;
  build_eri[7][3][10][4] = hrr_order_kfng;
  build_eri[7][3][9][5] = hrr_order_kfmh;
  build_eri[7][3][8][6] = hrr_order_kfli;
  build_eri[7][3][7][7] = hrr_order_kfkk;
  build_eri[7][3][10][5] = hrr_order_kfnh;
  build_eri[7][3][9][6] = hrr_order_kfmi;
  build_eri[7][3][8][7] = hrr_order_kflk;
  build_eri[7][3][10][6] = hrr_order_kfni;
  build_eri[7][3][9][7] = hrr_order_kfmk;
  build_eri[7][3][8][8] = hrr_order_kfll;
  build_eri[7][3][10][7] = hrr_order_kfnk;
  build_eri[7][3][9][8] = hrr_order_kfml;
  build_eri[7][3][10][8] = hrr_order_kfnl;
  build_eri[7][3][9][9] = hrr_order_kfmm;
  build_eri[7][3][10][9] = hrr_order_kfnm;
  build_eri[7][3][10][10] = hrr_order_kfnn;
  build_eri[6][4][10][0] = hrr_order_ign0;
  build_eri[6][4][9][1] = hrr_order_igmp;
  build_eri[6][4][8][2] = hrr_order_igld;
  build_eri[6][4][7][3] = hrr_order_igkf;
  build_eri[6][4][6][4] = hrr_order_igig;
  build_eri[6][4][5][5] = hrr_order_ighh;
  build_eri[6][4][10][1] = hrr_order_ignp;
  build_eri[6][4][9][2] = hrr_order_igmd;
  build_eri[6][4][8][3] = hrr_order_iglf;
  build_eri[6][4][7][4] = hrr_order_igkg;
  build_eri[6][4][6][5] = hrr_order_igih;
  build_eri[6][4][10][2] = hrr_order_ignd;
  build_eri[6][4][9][3] = hrr_order_igmf;
  build_eri[6][4][8][4] = hrr_order_iglg;
  build_eri[6][4][7][5] = hrr_order_igkh;
  build_eri[6][4][6][6] = hrr_order_igii;
  build_eri[6][4][10][3] = hrr_order_ignf;
  build_eri[6][4][9][4] = hrr_order_igmg;
  build_eri[6][4][8][5] = hrr_order_iglh;
  build_eri[6][4][7][6] = hrr_order_igki;
  build_eri[6][4][10][4] = hrr_order_igng;
  build_eri[6][4][9][5] = hrr_order_igmh;
  build_eri[6][4][8][6] = hrr_order_igli;
  build_eri[6][4][7][7] = hrr_order_igkk;
  build_eri[6][4][10][5] = hrr_order_ignh;
  build_eri[6][4][9][6] = hrr_order_igmi;
  build_eri[6][4][8][7] = hrr_order_iglk;
  build_eri[6][4][10][6] = hrr_order_igni;
  build_eri[6][4][9][7] = hrr_order_igmk;
  build_eri[6][4][8][8] = hrr_order_igll;
  build_eri[6][4][10][7] = hrr_order_ignk;
  build_eri[6][4][9][8] = hrr_order_igml;
  build_eri[6][4][10][8] = hrr_order_ignl;
  build_eri[6][4][9][9] = hrr_order_igmm;
  build_eri[6][4][10][9] = hrr_order_ignm;
  build_eri[6][4][10][10] = hrr_order_ignn;
  build_eri[5][5][10][0] = hrr_order_hhn0;
  build_eri[5][5][9][1] = hrr_order_hhmp;
  build_eri[5][5][8][2] = hrr_order_hhld;
  build_eri[5][5][7][3] = hrr_order_hhkf;
  build_eri[5][5][6][4] = hrr_order_hhig;
  build_eri[5][5][5][5] = hrr_order_hhhh;
  build_eri[5][5][10][1] = hrr_order_hhnp;
  build_eri[5][5][9][2] = hrr_order_hhmd;
  build_eri[5][5][8][3] = hrr_order_hhlf;
  build_eri[5][5][7][4] = hrr_order_hhkg;
  build_eri[5][5][6][5] = hrr_order_hhih;
  build_eri[5][5][10][2] = hrr_order_hhnd;
  build_eri[5][5][9][3] = hrr_order_hhmf;
  build_eri[5][5][8][4] = hrr_order_hhlg;
  build_eri[5][5][7][5] = hrr_order_hhkh;
  build_eri[5][5][6][6] = hrr_order_hhii;
  build_eri[5][5][10][3] = hrr_order_hhnf;
  build_eri[5][5][9][4] = hrr_order_hhmg;
  build_eri[5][5][8][5] = hrr_order_hhlh;
  build_eri[5][5][7][6] = hrr_order_hhki;
  build_eri[5][5][10][4] = hrr_order_hhng;
  build_eri[5][5][9][5] = hrr_order_hhmh;
  build_eri[5][5][8][6] = hrr_order_hhli;
  build_eri[5][5][7][7] = hrr_order_hhkk;
  build_eri[5][5][10][5] = hrr_order_hhnh;
  build_eri[5][5][9][6] = hrr_order_hhmi;
  build_eri[5][5][8][7] = hrr_order_hhlk;
  build_eri[5][5][10][6] = hrr_order_hhni;
  build_eri[5][5][9][7] = hrr_order_hhmk;
  build_eri[5][5][8][8] = hrr_order_hhll;
  build_eri[5][5][10][7] = hrr_order_hhnk;
  build_eri[5][5][9][8] = hrr_order_hhml;
  build_eri[5][5][10][8] = hrr_order_hhnl;
  build_eri[5][5][9][9] = hrr_order_hhmm;
  build_eri[5][5][10][9] = hrr_order_hhnm;
  build_eri[5][5][10][10] = hrr_order_hhnn;
  build_eri[10][1][10][1] = hrr_order_npnp;
  build_eri[10][1][9][2] = hrr_order_npmd;
  build_eri[10][1][8][3] = hrr_order_nplf;
  build_eri[10][1][7][4] = hrr_order_npkg;
  build_eri[10][1][6][5] = hrr_order_npih;
  build_eri[10][1][10][2] = hrr_order_npnd;
  build_eri[10][1][9][3] = hrr_order_npmf;
  build_eri[10][1][8][4] = hrr_order_nplg;
  build_eri[10][1][7][5] = hrr_order_npkh;
  build_eri[10][1][6][6] = hrr_order_npii;
  build_eri[10][1][10][3] = hrr_order_npnf;
  build_eri[10][1][9][4] = hrr_order_npmg;
  build_eri[10][1][8][5] = hrr_order_nplh;
  build_eri[10][1][7][6] = hrr_order_npki;
  build_eri[10][1][10][4] = hrr_order_npng;
  build_eri[10][1][9][5] = hrr_order_npmh;
  build_eri[10][1][8][6] = hrr_order_npli;
  build_eri[10][1][7][7] = hrr_order_npkk;
  build_eri[10][1][10][5] = hrr_order_npnh;
  build_eri[10][1][9][6] = hrr_order_npmi;
  build_eri[10][1][8][7] = hrr_order_nplk;
  build_eri[10][1][10][6] = hrr_order_npni;
  build_eri[10][1][9][7] = hrr_order_npmk;
  build_eri[10][1][8][8] = hrr_order_npll;
  build_eri[10][1][10][7] = hrr_order_npnk;
  build_eri[10][1][9][8] = hrr_order_npml;
  build_eri[10][1][10][8] = hrr_order_npnl;
  build_eri[10][1][9][9] = hrr_order_npmm;
  build_eri[10][1][10][9] = hrr_order_npnm;
  build_eri[10][1][10][10] = hrr_order_npnn;
  build_eri[9][2][10][1] = hrr_order_mdnp;
  build_eri[9][2][9][2] = hrr_order_mdmd;
  build_eri[9][2][8][3] = hrr_order_mdlf;
  build_eri[9][2][7][4] = hrr_order_mdkg;
  build_eri[9][2][6][5] = hrr_order_mdih;
  build_eri[9][2][10][2] = hrr_order_mdnd;
  build_eri[9][2][9][3] = hrr_order_mdmf;
  build_eri[9][2][8][4] = hrr_order_mdlg;
  build_eri[9][2][7][5] = hrr_order_mdkh;
  build_eri[9][2][6][6] = hrr_order_mdii;
  build_eri[9][2][10][3] = hrr_order_mdnf;
  build_eri[9][2][9][4] = hrr_order_mdmg;
  build_eri[9][2][8][5] = hrr_order_mdlh;
  build_eri[9][2][7][6] = hrr_order_mdki;
  build_eri[9][2][10][4] = hrr_order_mdng;
  build_eri[9][2][9][5] = hrr_order_mdmh;
  build_eri[9][2][8][6] = hrr_order_mdli;
  build_eri[9][2][7][7] = hrr_order_mdkk;
  build_eri[9][2][10][5] = hrr_order_mdnh;
  build_eri[9][2][9][6] = hrr_order_mdmi;
  build_eri[9][2][8][7] = hrr_order_mdlk;
  build_eri[9][2][10][6] = hrr_order_mdni;
  build_eri[9][2][9][7] = hrr_order_mdmk;
  build_eri[9][2][8][8] = hrr_order_mdll;
  build_eri[9][2][10][7] = hrr_order_mdnk;
  build_eri[9][2][9][8] = hrr_order_mdml;
  build_eri[9][2][10][8] = hrr_order_mdnl;
  build_eri[9][2][9][9] = hrr_order_mdmm;
  build_eri[9][2][10][9] = hrr_order_mdnm;
  build_eri[9][2][10][10] = hrr_order_mdnn;
  build_eri[8][3][10][1] = hrr_order_lfnp;
  build_eri[8][3][9][2] = hrr_order_lfmd;
  build_eri[8][3][8][3] = hrr_order_lflf;
  build_eri[8][3][7][4] = hrr_order_lfkg;
  build_eri[8][3][6][5] = hrr_order_lfih;
  build_eri[8][3][10][2] = hrr_order_lfnd;
  build_eri[8][3][9][3] = hrr_order_lfmf;
  build_eri[8][3][8][4] = hrr_order_lflg;
  build_eri[8][3][7][5] = hrr_order_lfkh;
  build_eri[8][3][6][6] = hrr_order_lfii;
  build_eri[8][3][10][3] = hrr_order_lfnf;
  build_eri[8][3][9][4] = hrr_order_lfmg;
  build_eri[8][3][8][5] = hrr_order_lflh;
  build_eri[8][3][7][6] = hrr_order_lfki;
  build_eri[8][3][10][4] = hrr_order_lfng;
  build_eri[8][3][9][5] = hrr_order_lfmh;
  build_eri[8][3][8][6] = hrr_order_lfli;
  build_eri[8][3][7][7] = hrr_order_lfkk;
  build_eri[8][3][10][5] = hrr_order_lfnh;
  build_eri[8][3][9][6] = hrr_order_lfmi;
  build_eri[8][3][8][7] = hrr_order_lflk;
  build_eri[8][3][10][6] = hrr_order_lfni;
  build_eri[8][3][9][7] = hrr_order_lfmk;
  build_eri[8][3][8][8] = hrr_order_lfll;
  build_eri[8][3][10][7] = hrr_order_lfnk;
  build_eri[8][3][9][8] = hrr_order_lfml;
  build_eri[8][3][10][8] = hrr_order_lfnl;
  build_eri[8][3][9][9] = hrr_order_lfmm;
  build_eri[8][3][10][9] = hrr_order_lfnm;
  build_eri[8][3][10][10] = hrr_order_lfnn;
  build_eri[7][4][10][1] = hrr_order_kgnp;
  build_eri[7][4][9][2] = hrr_order_kgmd;
  build_eri[7][4][8][3] = hrr_order_kglf;
  build_eri[7][4][7][4] = hrr_order_kgkg;
  build_eri[7][4][6][5] = hrr_order_kgih;
  build_eri[7][4][10][2] = hrr_order_kgnd;
  build_eri[7][4][9][3] = hrr_order_kgmf;
  build_eri[7][4][8][4] = hrr_order_kglg;
  build_eri[7][4][7][5] = hrr_order_kgkh;
  build_eri[7][4][6][6] = hrr_order_kgii;
  build_eri[7][4][10][3] = hrr_order_kgnf;
  build_eri[7][4][9][4] = hrr_order_kgmg;
  build_eri[7][4][8][5] = hrr_order_kglh;
  build_eri[7][4][7][6] = hrr_order_kgki;
  build_eri[7][4][10][4] = hrr_order_kgng;
  build_eri[7][4][9][5] = hrr_order_kgmh;
  build_eri[7][4][8][6] = hrr_order_kgli;
  build_eri[7][4][7][7] = hrr_order_kgkk;
  build_eri[7][4][10][5] = hrr_order_kgnh;
  build_eri[7][4][9][6] = hrr_order_kgmi;
  build_eri[7][4][8][7] = hrr_order_kglk;
  build_eri[7][4][10][6] = hrr_order_kgni;
  build_eri[7][4][9][7] = hrr_order_kgmk;
  build_eri[7][4][8][8] = hrr_order_kgll;
  build_eri[7][4][10][7] = hrr_order_kgnk;
  build_eri[7][4][9][8] = hrr_order_kgml;
  build_eri[7][4][10][8] = hrr_order_kgnl;
  build_eri[7][4][9][9] = hrr_order_kgmm;
  build_eri[7][4][10][9] = hrr_order_kgnm;
  build_eri[7][4][10][10] = hrr_order_kgnn;
  build_eri[6][5][10][1] = hrr_order_ihnp;
  build_eri[6][5][9][2] = hrr_order_ihmd;
  build_eri[6][5][8][3] = hrr_order_ihlf;
  build_eri[6][5][7][4] = hrr_order_ihkg;
  build_eri[6][5][6][5] = hrr_order_ihih;
  build_eri[6][5][10][2] = hrr_order_ihnd;
  build_eri[6][5][9][3] = hrr_order_ihmf;
  build_eri[6][5][8][4] = hrr_order_ihlg;
  build_eri[6][5][7][5] = hrr_order_ihkh;
  build_eri[6][5][6][6] = hrr_order_ihii;
  build_eri[6][5][10][3] = hrr_order_ihnf;
  build_eri[6][5][9][4] = hrr_order_ihmg;
  build_eri[6][5][8][5] = hrr_order_ihlh;
  build_eri[6][5][7][6] = hrr_order_ihki;
  build_eri[6][5][10][4] = hrr_order_ihng;
  build_eri[6][5][9][5] = hrr_order_ihmh;
  build_eri[6][5][8][6] = hrr_order_ihli;
  build_eri[6][5][7][7] = hrr_order_ihkk;
  build_eri[6][5][10][5] = hrr_order_ihnh;
  build_eri[6][5][9][6] = hrr_order_ihmi;
  build_eri[6][5][8][7] = hrr_order_ihlk;
  build_eri[6][5][10][6] = hrr_order_ihni;
  build_eri[6][5][9][7] = hrr_order_ihmk;
  build_eri[6][5][8][8] = hrr_order_ihll;
  build_eri[6][5][10][7] = hrr_order_ihnk;
  build_eri[6][5][9][8] = hrr_order_ihml;
  build_eri[6][5][10][8] = hrr_order_ihnl;
  build_eri[6][5][9][9] = hrr_order_ihmm;
  build_eri[6][5][10][9] = hrr_order_ihnm;
  build_eri[6][5][10][10] = hrr_order_ihnn;
  build_eri[10][2][10][2] = hrr_order_ndnd;
  build_eri[10][2][9][3] = hrr_order_ndmf;
  build_eri[10][2][8][4] = hrr_order_ndlg;
  build_eri[10][2][7][5] = hrr_order_ndkh;
  build_eri[10][2][6][6] = hrr_order_ndii;
  build_eri[10][2][10][3] = hrr_order_ndnf;
  build_eri[10][2][9][4] = hrr_order_ndmg;
  build_eri[10][2][8][5] = hrr_order_ndlh;
  build_eri[10][2][7][6] = hrr_order_ndki;
  build_eri[10][2][10][4] = hrr_order_ndng;
  build_eri[10][2][9][5] = hrr_order_ndmh;
  build_eri[10][2][8][6] = hrr_order_ndli;
  build_eri[10][2][7][7] = hrr_order_ndkk;
  build_eri[10][2][10][5] = hrr_order_ndnh;
  build_eri[10][2][9][6] = hrr_order_ndmi;
  build_eri[10][2][8][7] = hrr_order_ndlk;
  build_eri[10][2][10][6] = hrr_order_ndni;
  build_eri[10][2][9][7] = hrr_order_ndmk;
  build_eri[10][2][8][8] = hrr_order_ndll;
  build_eri[10][2][10][7] = hrr_order_ndnk;
  build_eri[10][2][9][8] = hrr_order_ndml;
  build_eri[10][2][10][8] = hrr_order_ndnl;
  build_eri[10][2][9][9] = hrr_order_ndmm;
  build_eri[10][2][10][9] = hrr_order_ndnm;
  build_eri[10][2][10][10] = hrr_order_ndnn;
  build_eri[9][3][10][2] = hrr_order_mfnd;
  build_eri[9][3][9][3] = hrr_order_mfmf;
  build_eri[9][3][8][4] = hrr_order_mflg;
  build_eri[9][3][7][5] = hrr_order_mfkh;
  build_eri[9][3][6][6] = hrr_order_mfii;
  build_eri[9][3][10][3] = hrr_order_mfnf;
  build_eri[9][3][9][4] = hrr_order_mfmg;
  build_eri[9][3][8][5] = hrr_order_mflh;
  build_eri[9][3][7][6] = hrr_order_mfki;
  build_eri[9][3][10][4] = hrr_order_mfng;
  build_eri[9][3][9][5] = hrr_order_mfmh;
  build_eri[9][3][8][6] = hrr_order_mfli;
  build_eri[9][3][7][7] = hrr_order_mfkk;
  build_eri[9][3][10][5] = hrr_order_mfnh;
  build_eri[9][3][9][6] = hrr_order_mfmi;
  build_eri[9][3][8][7] = hrr_order_mflk;
  build_eri[9][3][10][6] = hrr_order_mfni;
  build_eri[9][3][9][7] = hrr_order_mfmk;
  build_eri[9][3][8][8] = hrr_order_mfll;
  build_eri[9][3][10][7] = hrr_order_mfnk;
  build_eri[9][3][9][8] = hrr_order_mfml;
  build_eri[9][3][10][8] = hrr_order_mfnl;
  build_eri[9][3][9][9] = hrr_order_mfmm;
  build_eri[9][3][10][9] = hrr_order_mfnm;
  build_eri[9][3][10][10] = hrr_order_mfnn;
  build_eri[8][4][10][2] = hrr_order_lgnd;
  build_eri[8][4][9][3] = hrr_order_lgmf;
  build_eri[8][4][8][4] = hrr_order_lglg;
  build_eri[8][4][7][5] = hrr_order_lgkh;
  build_eri[8][4][6][6] = hrr_order_lgii;
  build_eri[8][4][10][3] = hrr_order_lgnf;
  build_eri[8][4][9][4] = hrr_order_lgmg;
  build_eri[8][4][8][5] = hrr_order_lglh;
  build_eri[8][4][7][6] = hrr_order_lgki;
  build_eri[8][4][10][4] = hrr_order_lgng;
  build_eri[8][4][9][5] = hrr_order_lgmh;
  build_eri[8][4][8][6] = hrr_order_lgli;
  build_eri[8][4][7][7] = hrr_order_lgkk;
  build_eri[8][4][10][5] = hrr_order_lgnh;
  build_eri[8][4][9][6] = hrr_order_lgmi;
  build_eri[8][4][8][7] = hrr_order_lglk;
  build_eri[8][4][10][6] = hrr_order_lgni;
  build_eri[8][4][9][7] = hrr_order_lgmk;
  build_eri[8][4][8][8] = hrr_order_lgll;
  build_eri[8][4][10][7] = hrr_order_lgnk;
  build_eri[8][4][9][8] = hrr_order_lgml;
  build_eri[8][4][10][8] = hrr_order_lgnl;
  build_eri[8][4][9][9] = hrr_order_lgmm;
  build_eri[8][4][10][9] = hrr_order_lgnm;
  build_eri[8][4][10][10] = hrr_order_lgnn;
  build_eri[7][5][10][2] = hrr_order_khnd;
  build_eri[7][5][9][3] = hrr_order_khmf;
  build_eri[7][5][8][4] = hrr_order_khlg;
  build_eri[7][5][7][5] = hrr_order_khkh;
  build_eri[7][5][6][6] = hrr_order_khii;
  build_eri[7][5][10][3] = hrr_order_khnf;
  build_eri[7][5][9][4] = hrr_order_khmg;
  build_eri[7][5][8][5] = hrr_order_khlh;
  build_eri[7][5][7][6] = hrr_order_khki;
  build_eri[7][5][10][4] = hrr_order_khng;
  build_eri[7][5][9][5] = hrr_order_khmh;
  build_eri[7][5][8][6] = hrr_order_khli;
  build_eri[7][5][7][7] = hrr_order_khkk;
  build_eri[7][5][10][5] = hrr_order_khnh;
  build_eri[7][5][9][6] = hrr_order_khmi;
  build_eri[7][5][8][7] = hrr_order_khlk;
  build_eri[7][5][10][6] = hrr_order_khni;
  build_eri[7][5][9][7] = hrr_order_khmk;
  build_eri[7][5][8][8] = hrr_order_khll;
  build_eri[7][5][10][7] = hrr_order_khnk;
  build_eri[7][5][9][8] = hrr_order_khml;
  build_eri[7][5][10][8] = hrr_order_khnl;
  build_eri[7][5][9][9] = hrr_order_khmm;
  build_eri[7][5][10][9] = hrr_order_khnm;
  build_eri[7][5][10][10] = hrr_order_khnn;
  build_eri[6][6][10][2] = hrr_order_iind;
  build_eri[6][6][9][3] = hrr_order_iimf;
  build_eri[6][6][8][4] = hrr_order_iilg;
  build_eri[6][6][7][5] = hrr_order_iikh;
  build_eri[6][6][6][6] = hrr_order_iiii;
  build_eri[6][6][10][3] = hrr_order_iinf;
  build_eri[6][6][9][4] = hrr_order_iimg;
  build_eri[6][6][8][5] = hrr_order_iilh;
  build_eri[6][6][7][6] = hrr_order_iiki;
  build_eri[6][6][10][4] = hrr_order_iing;
  build_eri[6][6][9][5] = hrr_order_iimh;
  build_eri[6][6][8][6] = hrr_order_iili;
  build_eri[6][6][7][7] = hrr_order_iikk;
  build_eri[6][6][10][5] = hrr_order_iinh;
  build_eri[6][6][9][6] = hrr_order_iimi;
  build_eri[6][6][8][7] = hrr_order_iilk;
  build_eri[6][6][10][6] = hrr_order_iini;
  build_eri[6][6][9][7] = hrr_order_iimk;
  build_eri[6][6][8][8] = hrr_order_iill;
  build_eri[6][6][10][7] = hrr_order_iink;
  build_eri[6][6][9][8] = hrr_order_iiml;
  build_eri[6][6][10][8] = hrr_order_iinl;
  build_eri[6][6][9][9] = hrr_order_iimm;
  build_eri[6][6][10][9] = hrr_order_iinm;
  build_eri[6][6][10][10] = hrr_order_iinn;
  build_eri[10][3][10][3] = hrr_order_nfnf;
  build_eri[10][3][9][4] = hrr_order_nfmg;
  build_eri[10][3][8][5] = hrr_order_nflh;
  build_eri[10][3][7][6] = hrr_order_nfki;
  build_eri[10][3][10][4] = hrr_order_nfng;
  build_eri[10][3][9][5] = hrr_order_nfmh;
  build_eri[10][3][8][6] = hrr_order_nfli;
  build_eri[10][3][7][7] = hrr_order_nfkk;
  build_eri[10][3][10][5] = hrr_order_nfnh;
  build_eri[10][3][9][6] = hrr_order_nfmi;
  build_eri[10][3][8][7] = hrr_order_nflk;
  build_eri[10][3][10][6] = hrr_order_nfni;
  build_eri[10][3][9][7] = hrr_order_nfmk;
  build_eri[10][3][8][8] = hrr_order_nfll;
  build_eri[10][3][10][7] = hrr_order_nfnk;
  build_eri[10][3][9][8] = hrr_order_nfml;
  build_eri[10][3][10][8] = hrr_order_nfnl;
  build_eri[10][3][9][9] = hrr_order_nfmm;
  build_eri[10][3][10][9] = hrr_order_nfnm;
  build_eri[10][3][10][10] = hrr_order_nfnn;
  build_eri[9][4][10][3] = hrr_order_mgnf;
  build_eri[9][4][9][4] = hrr_order_mgmg;
  build_eri[9][4][8][5] = hrr_order_mglh;
  build_eri[9][4][7][6] = hrr_order_mgki;
  build_eri[9][4][10][4] = hrr_order_mgng;
  build_eri[9][4][9][5] = hrr_order_mgmh;
  build_eri[9][4][8][6] = hrr_order_mgli;
  build_eri[9][4][7][7] = hrr_order_mgkk;
  build_eri[9][4][10][5] = hrr_order_mgnh;
  build_eri[9][4][9][6] = hrr_order_mgmi;
  build_eri[9][4][8][7] = hrr_order_mglk;
  build_eri[9][4][10][6] = hrr_order_mgni;
  build_eri[9][4][9][7] = hrr_order_mgmk;
  build_eri[9][4][8][8] = hrr_order_mgll;
  build_eri[9][4][10][7] = hrr_order_mgnk;
  build_eri[9][4][9][8] = hrr_order_mgml;
  build_eri[9][4][10][8] = hrr_order_mgnl;
  build_eri[9][4][9][9] = hrr_order_mgmm;
  build_eri[9][4][10][9] = hrr_order_mgnm;
  build_eri[9][4][10][10] = hrr_order_mgnn;
  build_eri[8][5][10][3] = hrr_order_lhnf;
  build_eri[8][5][9][4] = hrr_order_lhmg;
  build_eri[8][5][8][5] = hrr_order_lhlh;
  build_eri[8][5][7][6] = hrr_order_lhki;
  build_eri[8][5][10][4] = hrr_order_lhng;
  build_eri[8][5][9][5] = hrr_order_lhmh;
  build_eri[8][5][8][6] = hrr_order_lhli;
  build_eri[8][5][7][7] = hrr_order_lhkk;
  build_eri[8][5][10][5] = hrr_order_lhnh;
  build_eri[8][5][9][6] = hrr_order_lhmi;
  build_eri[8][5][8][7] = hrr_order_lhlk;
  build_eri[8][5][10][6] = hrr_order_lhni;
  build_eri[8][5][9][7] = hrr_order_lhmk;
  build_eri[8][5][8][8] = hrr_order_lhll;
  build_eri[8][5][10][7] = hrr_order_lhnk;
  build_eri[8][5][9][8] = hrr_order_lhml;
  build_eri[8][5][10][8] = hrr_order_lhnl;
  build_eri[8][5][9][9] = hrr_order_lhmm;
  build_eri[8][5][10][9] = hrr_order_lhnm;
  build_eri[8][5][10][10] = hrr_order_lhnn;
  build_eri[7][6][10][3] = hrr_order_kinf;
  build_eri[7][6][9][4] = hrr_order_kimg;
  build_eri[7][6][8][5] = hrr_order_kilh;
  build_eri[7][6][7][6] = hrr_order_kiki;
  build_eri[7][6][10][4] = hrr_order_king;
  build_eri[7][6][9][5] = hrr_order_kimh;
  build_eri[7][6][8][6] = hrr_order_kili;
  build_eri[7][6][7][7] = hrr_order_kikk;
  build_eri[7][6][10][5] = hrr_order_kinh;
  build_eri[7][6][9][6] = hrr_order_kimi;
  build_eri[7][6][8][7] = hrr_order_kilk;
  build_eri[7][6][10][6] = hrr_order_kini;
  build_eri[7][6][9][7] = hrr_order_kimk;
  build_eri[7][6][8][8] = hrr_order_kill;
  build_eri[7][6][10][7] = hrr_order_kink;
  build_eri[7][6][9][8] = hrr_order_kiml;
  build_eri[7][6][10][8] = hrr_order_kinl;
  build_eri[7][6][9][9] = hrr_order_kimm;
  build_eri[7][6][10][9] = hrr_order_kinm;
  build_eri[7][6][10][10] = hrr_order_kinn;
  build_eri[10][4][10][4] = hrr_order_ngng;
  build_eri[10][4][9][5] = hrr_order_ngmh;
  build_eri[10][4][8][6] = hrr_order_ngli;
  build_eri[10][4][7][7] = hrr_order_ngkk;
  build_eri[10][4][10][5] = hrr_order_ngnh;
  build_eri[10][4][9][6] = hrr_order_ngmi;
  build_eri[10][4][8][7] = hrr_order_nglk;
  build_eri[10][4][10][6] = hrr_order_ngni;
  build_eri[10][4][9][7] = hrr_order_ngmk;
  build_eri[10][4][8][8] = hrr_order_ngll;
  build_eri[10][4][10][7] = hrr_order_ngnk;
  build_eri[10][4][9][8] = hrr_order_ngml;
  build_eri[10][4][10][8] = hrr_order_ngnl;
  build_eri[10][4][9][9] = hrr_order_ngmm;
  build_eri[10][4][10][9] = hrr_order_ngnm;
  build_eri[10][4][10][10] = hrr_order_ngnn;
  build_eri[9][5][10][4] = hrr_order_mhng;
  build_eri[9][5][9][5] = hrr_order_mhmh;
  build_eri[9][5][8][6] = hrr_order_mhli;
  build_eri[9][5][7][7] = hrr_order_mhkk;
  build_eri[9][5][10][5] = hrr_order_mhnh;
  build_eri[9][5][9][6] = hrr_order_mhmi;
  build_eri[9][5][8][7] = hrr_order_mhlk;
  build_eri[9][5][10][6] = hrr_order_mhni;
  build_eri[9][5][9][7] = hrr_order_mhmk;
  build_eri[9][5][8][8] = hrr_order_mhll;
  build_eri[9][5][10][7] = hrr_order_mhnk;
  build_eri[9][5][9][8] = hrr_order_mhml;
  build_eri[9][5][10][8] = hrr_order_mhnl;
  build_eri[9][5][9][9] = hrr_order_mhmm;
  build_eri[9][5][10][9] = hrr_order_mhnm;
  build_eri[9][5][10][10] = hrr_order_mhnn;
  build_eri[8][6][10][4] = hrr_order_ling;
  build_eri[8][6][9][5] = hrr_order_limh;
  build_eri[8][6][8][6] = hrr_order_lili;
  build_eri[8][6][7][7] = hrr_order_likk;
  build_eri[8][6][10][5] = hrr_order_linh;
  build_eri[8][6][9][6] = hrr_order_limi;
  build_eri[8][6][8][7] = hrr_order_lilk;
  build_eri[8][6][10][6] = hrr_order_lini;
  build_eri[8][6][9][7] = hrr_order_limk;
  build_eri[8][6][8][8] = hrr_order_lill;
  build_eri[8][6][10][7] = hrr_order_link;
  build_eri[8][6][9][8] = hrr_order_liml;
  build_eri[8][6][10][8] = hrr_order_linl;
  build_eri[8][6][9][9] = hrr_order_limm;
  build_eri[8][6][10][9] = hrr_order_linm;
  build_eri[8][6][10][10] = hrr_order_linn;
  build_eri[7][7][10][4] = hrr_order_kkng;
  build_eri[7][7][9][5] = hrr_order_kkmh;
  build_eri[7][7][8][6] = hrr_order_kkli;
  build_eri[7][7][7][7] = hrr_order_kkkk;
  build_eri[7][7][10][5] = hrr_order_kknh;
  build_eri[7][7][9][6] = hrr_order_kkmi;
  build_eri[7][7][8][7] = hrr_order_kklk;
  build_eri[7][7][10][6] = hrr_order_kkni;
  build_eri[7][7][9][7] = hrr_order_kkmk;
  build_eri[7][7][8][8] = hrr_order_kkll;
  build_eri[7][7][10][7] = hrr_order_kknk;
  build_eri[7][7][9][8] = hrr_order_kkml;
  build_eri[7][7][10][8] = hrr_order_kknl;
  build_eri[7][7][9][9] = hrr_order_kkmm;
  build_eri[7][7][10][9] = hrr_order_kknm;
  build_eri[7][7][10][10] = hrr_order_kknn;
  build_eri[10][5][10][5] = hrr_order_nhnh;
  build_eri[10][5][9][6] = hrr_order_nhmi;
  build_eri[10][5][8][7] = hrr_order_nhlk;
  build_eri[10][5][10][6] = hrr_order_nhni;
  build_eri[10][5][9][7] = hrr_order_nhmk;
  build_eri[10][5][8][8] = hrr_order_nhll;
  build_eri[10][5][10][7] = hrr_order_nhnk;
  build_eri[10][5][9][8] = hrr_order_nhml;
  build_eri[10][5][10][8] = hrr_order_nhnl;
  build_eri[10][5][9][9] = hrr_order_nhmm;
  build_eri[10][5][10][9] = hrr_order_nhnm;
  build_eri[10][5][10][10] = hrr_order_nhnn;
  build_eri[9][6][10][5] = hrr_order_minh;
  build_eri[9][6][9][6] = hrr_order_mimi;
  build_eri[9][6][8][7] = hrr_order_milk;
  build_eri[9][6][10][6] = hrr_order_mini;
  build_eri[9][6][9][7] = hrr_order_mimk;
  build_eri[9][6][8][8] = hrr_order_mill;
  build_eri[9][6][10][7] = hrr_order_mink;
  build_eri[9][6][9][8] = hrr_order_miml;
  build_eri[9][6][10][8] = hrr_order_minl;
  build_eri[9][6][9][9] = hrr_order_mimm;
  build_eri[9][6][10][9] = hrr_order_minm;
  build_eri[9][6][10][10] = hrr_order_minn;
  build_eri[8][7][10][5] = hrr_order_lknh;
  build_eri[8][7][9][6] = hrr_order_lkmi;
  build_eri[8][7][8][7] = hrr_order_lklk;
  build_eri[8][7][10][6] = hrr_order_lkni;
  build_eri[8][7][9][7] = hrr_order_lkmk;
  build_eri[8][7][8][8] = hrr_order_lkll;
  build_eri[8][7][10][7] = hrr_order_lknk;
  build_eri[8][7][9][8] = hrr_order_lkml;
  build_eri[8][7][10][8] = hrr_order_lknl;
  build_eri[8][7][9][9] = hrr_order_lkmm;
  build_eri[8][7][10][9] = hrr_order_lknm;
  build_eri[8][7][10][10] = hrr_order_lknn;
  build_eri[10][6][10][6] = hrr_order_nini;
  build_eri[10][6][9][7] = hrr_order_nimk;
  build_eri[10][6][8][8] = hrr_order_nill;
  build_eri[10][6][10][7] = hrr_order_nink;
  build_eri[10][6][9][8] = hrr_order_niml;
  build_eri[10][6][10][8] = hrr_order_ninl;
  build_eri[10][6][9][9] = hrr_order_nimm;
  build_eri[10][6][10][9] = hrr_order_ninm;
  build_eri[10][6][10][10] = hrr_order_ninn;
  build_eri[9][7][10][6] = hrr_order_mkni;
  build_eri[9][7][9][7] = hrr_order_mkmk;
  build_eri[9][7][8][8] = hrr_order_mkll;
  build_eri[9][7][10][7] = hrr_order_mknk;
  build_eri[9][7][9][8] = hrr_order_mkml;
  build_eri[9][7][10][8] = hrr_order_mknl;
  build_eri[9][7][9][9] = hrr_order_mkmm;
  build_eri[9][7][10][9] = hrr_order_mknm;
  build_eri[9][7][10][10] = hrr_order_mknn;
  build_eri[8][8][10][6] = hrr_order_llni;
  build_eri[8][8][9][7] = hrr_order_llmk;
  build_eri[8][8][8][8] = hrr_order_llll;
  build_eri[8][8][10][7] = hrr_order_llnk;
  build_eri[8][8][9][8] = hrr_order_llml;
  build_eri[8][8][10][8] = hrr_order_llnl;
  build_eri[8][8][9][9] = hrr_order_llmm;
  build_eri[8][8][10][9] = hrr_order_llnm;
  build_eri[8][8][10][10] = hrr_order_llnn;
  build_eri[10][7][10][7] = hrr_order_nknk;
  build_eri[10][7][9][8] = hrr_order_nkml;
  build_eri[10][7][10][8] = hrr_order_nknl;
  build_eri[10][7][9][9] = hrr_order_nkmm;
  build_eri[10][7][10][9] = hrr_order_nknm;
  build_eri[10][7][10][10] = hrr_order_nknn;
  build_eri[9][8][10][7] = hrr_order_mlnk;
  build_eri[9][8][9][8] = hrr_order_mlml;
  build_eri[9][8][10][8] = hrr_order_mlnl;
  build_eri[9][8][9][9] = hrr_order_mlmm;
  build_eri[9][8][10][9] = hrr_order_mlnm;
  build_eri[9][8][10][10] = hrr_order_mlnn;
  build_eri[10][8][10][8] = hrr_order_nlnl;
  build_eri[10][8][9][9] = hrr_order_nlmm;
  build_eri[10][8][10][9] = hrr_order_nlnm;
  build_eri[10][8][10][10] = hrr_order_nlnn;
  build_eri[9][9][10][8] = hrr_order_mmnl;
  build_eri[9][9][9][9] = hrr_order_mmmm;
  build_eri[9][9][10][9] = hrr_order_mmnm;
  build_eri[9][9][10][10] = hrr_order_mmnn;
  build_eri[10][9][10][9] = hrr_order_nmnm;
  build_eri[10][9][10][10] = hrr_order_nmnn;
  build_eri[10][10][10][10] = hrr_order_nnnn;

  libint_stack_size[0] = 1;
  libint_stack_size[1] = 222;
  libint_stack_size[2] = 3193;
  libint_stack_size[3] = 34956;
  libint_stack_size[4] = 219445;
  libint_stack_size[5] = 759382;
  libint_stack_size[6] = 2984709;
  libint_stack_size[7] = 9731776;
  libint_stack_size[8] = 25249761;
  libint_stack_size[9] = 55370844;
  libint_stack_size[10] = 139284285;
}
/* These functions initialize library objects */
/* Library objects operate independently of each other */
int init_libint(Libint_t *libint, int max_am, int max_num_prim_quartets)
{
  int memory = 0;

  if (max_am >= LIBINT_MAX_AM) return -1;
  libint->int_stack = (REALTYPE *) malloc(libint_stack_size[max_am]*sizeof(REALTYPE));
  memory += libint_stack_size[max_am];
  libint->PrimQuartet = (prim_data *) malloc(max_num_prim_quartets*sizeof(prim_data));
  memory += max_num_prim_quartets*sizeof(prim_data)/sizeof(REALTYPE);
  return memory;
}

void free_libint(Libint_t *libint)
{
  if (libint->int_stack != NULL) {
    free(libint->int_stack);
    libint->int_stack = NULL;
  }
  if (libint->PrimQuartet != NULL) {
    free(libint->PrimQuartet);
    libint->PrimQuartet = NULL;
  }

  return;
}

int libint_storage_required(int max_am, int max_num_prim_quartets)
{
  int memory = 0;

  if (max_am >= LIBINT_MAX_AM) return -1;
  memory += libint_stack_size[max_am];
  memory += max_num_prim_quartets*sizeof(prim_data)/sizeof(REALTYPE);
  return memory;
}

}
