/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_fdff(Libr12_t *, prim_data *);

  /* Computes (fd|ff) integrals for linear R12-methods */

void hrr_grt_order_fdff(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[3][3] = int_stack + 0;
 Libr12->t2vrr_classes[3][4] = int_stack + 100;
 Libr12->t2vrr_classes[3][5] = int_stack + 250;
 Libr12->t2vrr_classes[3][6] = int_stack + 460;
 Libr12->t2vrr_classes[4][3] = int_stack + 740;
 Libr12->t2vrr_classes[4][4] = int_stack + 890;
 Libr12->t2vrr_classes[4][5] = int_stack + 1115;
 Libr12->t2vrr_classes[4][6] = int_stack + 1430;
 Libr12->gvrr_classes[6][3] = int_stack + 1850;
 Libr12->t2vrr_classes[5][3] = int_stack + 2130;
 Libr12->gvrr_classes[6][4] = int_stack + 2340;
 Libr12->t2vrr_classes[5][4] = int_stack + 2760;
 Libr12->gvrr_classes[6][5] = int_stack + 3075;
 Libr12->t2vrr_classes[5][5] = int_stack + 3663;
 Libr12->t2vrr_classes[5][6] = int_stack + 4104;
 Libr12->gvrr_classes[3][7] = int_stack + 4692;
 Libr12->t1vrr_classes[3][3] = int_stack + 5052;
 Libr12->t1vrr_classes[3][4] = int_stack + 5152;
 Libr12->t1vrr_classes[3][5] = int_stack + 5302;
 Libr12->t1vrr_classes[3][6] = int_stack + 5512;
 Libr12->gvrr_classes[4][7] = int_stack + 5792;
 Libr12->t1vrr_classes[4][3] = int_stack + 6332;
 Libr12->t1vrr_classes[4][4] = int_stack + 6482;
 Libr12->t1vrr_classes[4][5] = int_stack + 6707;
 Libr12->t1vrr_classes[4][6] = int_stack + 7022;
 Libr12->t1vrr_classes[5][3] = int_stack + 7442;
 Libr12->t1vrr_classes[5][4] = int_stack + 7652;
 Libr12->t1vrr_classes[5][5] = int_stack + 7967;
 Libr12->t1vrr_classes[5][6] = int_stack + 8408;
 Libr12->rvrr_classes[3][3] = int_stack + 8996;
 Libr12->rvrr_classes[3][4] = int_stack + 9096;
 Libr12->rvrr_classes[3][5] = int_stack + 9246;
 Libr12->rvrr_classes[3][6] = int_stack + 9456;
 Libr12->rvrr_classes[4][3] = int_stack + 9736;
 Libr12->rvrr_classes[4][4] = int_stack + 9886;
 Libr12->rvrr_classes[4][5] = int_stack + 10111;
 Libr12->rvrr_classes[4][6] = int_stack + 10426;
 Libr12->rvrr_classes[5][3] = int_stack + 10846;
 Libr12->rvrr_classes[5][4] = int_stack + 11056;
 Libr12->rvrr_classes[5][5] = int_stack + 11371;
 Libr12->rvrr_classes[5][6] = int_stack + 11812;
 Libr12->gvrr_classes[3][3] = int_stack + 12400;
 Libr12->gvrr_classes[3][4] = int_stack + 12500;
 Libr12->gvrr_classes[3][5] = int_stack + 12650;
 Libr12->gvrr_classes[3][6] = int_stack + 12860;
 Libr12->gvrr_classes[4][3] = int_stack + 13140;
 Libr12->gvrr_classes[4][4] = int_stack + 13290;
 Libr12->gvrr_classes[4][5] = int_stack + 13515;
 Libr12->gvrr_classes[4][6] = int_stack + 13830;
 Libr12->gvrr_classes[5][3] = int_stack + 14250;
 Libr12->gvrr_classes[5][4] = int_stack + 14460;
 Libr12->gvrr_classes[5][5] = int_stack + 14775;
 Libr12->gvrr_classes[5][6] = int_stack + 15216;
 memset(int_stack,0,15804*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 15804;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_fdff(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+15804, int_stack+12500, int_stack+12400, 10);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+16104, int_stack+12650, int_stack+12500, 10);
 /*--- compute (f0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+16554, int_stack+16104, int_stack+15804, 10);
 /*--- compute (g0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+17154, int_stack+13290, int_stack+13140, 15);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+17604, int_stack+13515, int_stack+13290, 15);
 /*--- compute (g0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+18279, int_stack+17604, int_stack+17154, 15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+19179, int_stack+12860, int_stack+12650, 10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+19809, int_stack+19179, int_stack+16104, 10);
 /*--- compute (f0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+20709, int_stack+100, int_stack+0, int_stack+12500, int_stack+13140, int_stack+12400, 3, 0);
 /*--- compute (f0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+21009, int_stack+250, int_stack+100, int_stack+12650, int_stack+13290, int_stack+12500, 3, 0);
 /*--- compute (f0|[r12,T2]|fd) ---*/
   t2hrr3_build_fd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+21459, int_stack+21009, int_stack+20709, int_stack+16104, int_stack+17154, int_stack+15804, 3, 0);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+22059, int_stack+460, int_stack+250, int_stack+12860, int_stack+13515, int_stack+12650, 3, 0);
 /*--- compute (f0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+22689, int_stack+22059, int_stack+21009, int_stack+19179, int_stack+17604, int_stack+16104, 3, 0);
 /*--- compute (f0|[r12,T2]|ff) ---*/
   t2hrr3_build_ff(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+23589, int_stack+22689, int_stack+21459, int_stack+19809, int_stack+18279, int_stack+16554, 3, 0);
 /*--- compute (h0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+15804, int_stack+14460, int_stack+14250, 21);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+20709, int_stack+14775, int_stack+14460, 21);
 /*--- compute (h0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+21654, int_stack+20709, int_stack+15804, 21);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+24589, int_stack+13830, int_stack+13515, 15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+25534, int_stack+24589, int_stack+17604, 15);
 /*--- compute (g0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+22914, int_stack+890, int_stack+740, int_stack+13290, int_stack+14250, int_stack+13140, 4, 0);
 /*--- compute (g0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+1115, int_stack+890, int_stack+13515, int_stack+14460, int_stack+13290, 4, 0);
 /*--- compute (g0|[r12,T2]|fd) ---*/
   t2hrr3_build_fd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+26884, int_stack+0, int_stack+22914, int_stack+17604, int_stack+15804, int_stack+17154, 4, 0);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+27784, int_stack+1430, int_stack+1115, int_stack+13830, int_stack+14775, int_stack+13515, 4, 0);
 /*--- compute (g0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+28729, int_stack+27784, int_stack+0, int_stack+24589, int_stack+20709, int_stack+17604, 4, 0);
 /*--- compute (g0|[r12,T2]|ff) ---*/
   t2hrr3_build_ff(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+28729, int_stack+26884, int_stack+25534, int_stack+21654, int_stack+18279, 4, 0);
 /*--- compute (fp|[r12,T2]|ff) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+26884, int_stack+0, int_stack+23589, 100);
 /*--- compute (i0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+29884, int_stack+2340, int_stack+1850, 28);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+22914, int_stack+3075, int_stack+2340, 28);
 /*--- compute (i0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+30724, int_stack+22914, int_stack+29884, 28);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+32404, int_stack+15216, int_stack+14775, 21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+33727, int_stack+32404, int_stack+20709, 21);
 /*--- compute (h0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+17154, int_stack+2760, int_stack+2130, int_stack+14460, int_stack+1850, int_stack+14250, 5, 0);
 /*--- compute (h0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+35617, int_stack+3663, int_stack+2760, int_stack+14775, int_stack+2340, int_stack+14460, 5, 0);
 /*--- compute (h0|[r12,T2]|fd) ---*/
   t2hrr3_build_fd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1500, int_stack+35617, int_stack+17154, int_stack+20709, int_stack+29884, int_stack+15804, 5, 0);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+36562, int_stack+4104, int_stack+3663, int_stack+15216, int_stack+3075, int_stack+14775, 5, 0);
 /*--- compute (h0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+14250, int_stack+36562, int_stack+35617, int_stack+32404, int_stack+22914, int_stack+20709, 5, 0);
 /*--- compute (h0|[r12,T2]|ff) ---*/
   t2hrr3_build_ff(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+35617, int_stack+14250, int_stack+1500, int_stack+33727, int_stack+30724, int_stack+21654, 5, 0);
 /*--- compute (gp|[r12,T2]|ff) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+37717, int_stack+35617, int_stack+0, 100);
 /*--- compute (f0|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+0, int_stack+19809, int_stack+16554, 10);
 /*--- compute (g0|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+1000, int_stack+25534, int_stack+18279, 15);
 /*--- compute (fp|ff) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+14250, int_stack+1000, int_stack+0, 100);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+2500, int_stack+4692, int_stack+12860, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+3340, int_stack+2500, int_stack+19179, 10);
 /*--- compute (f0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+35617, int_stack+3340, int_stack+19809, 10);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+2500, int_stack+5792, int_stack+13830, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+17250, int_stack+2500, int_stack+24589, 15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+2500, int_stack+17250, int_stack+25534, 15);
 /*--- compute (fp|gf) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+42217, int_stack+2500, int_stack+35617, 150);
 /*--- compute (h0|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+17250, int_stack+33727, int_stack+21654, 21);
 /*--- compute (gp|ff) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+19350, int_stack+17250, int_stack+1000, 100);
 /*--- compute (f0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+23850, int_stack+5152, int_stack+5052, 10);
 /*--- compute (f0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+24150, int_stack+5302, int_stack+5152, 10);
 /*--- compute (f0|[r12,T1]|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+37117, int_stack+24150, int_stack+23850, 10);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+24600, int_stack+5512, int_stack+5302, 10);
 /*--- compute (f0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+25230, int_stack+24600, int_stack+24150, 10);
 /*--- compute (f0|[r12,T1]|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+23850, int_stack+25230, int_stack+37117, 10);
 /*--- compute (g0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+37117, int_stack+6482, int_stack+6332, 15);
 /*--- compute (g0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+24850, int_stack+6707, int_stack+6482, 15);
 /*--- compute (g0|[r12,T1]|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+25525, int_stack+24850, int_stack+37117, 15);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+4750, int_stack+7022, int_stack+6707, 15);
 /*--- compute (g0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+5695, int_stack+4750, int_stack+24850, 15);
 /*--- compute (g0|[r12,T1]|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+29884, int_stack+5695, int_stack+25525, 15);
 /*--- compute (fp|[r12,T1]|ff) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+31384, int_stack+29884, int_stack+23850, int_stack+1000, int_stack+35617, int_stack+0, 3, 3);
 /*--- compute (h0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+7652, int_stack+7442, 21);
 /*--- compute (h0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+23850, int_stack+7967, int_stack+7652, 21);
 /*--- compute (h0|[r12,T1]|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+24795, int_stack+23850, int_stack+0, 21);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+4750, int_stack+8408, int_stack+7967, 21);
 /*--- compute (h0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+6073, int_stack+4750, int_stack+23850, 21);
 /*--- compute (h0|[r12,T1]|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+34384, int_stack+6073, int_stack+24795, 21);
 /*--- compute (gp|[r12,T1]|ff) ---*/
   t1hrr1_build_gp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+46717, int_stack+34384, int_stack+29884, int_stack+17250, int_stack+2500, int_stack+1000, 3, 3);
 /*--- compute (f0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+17250, int_stack+9096, int_stack+8996, 10);
 /*--- compute (f0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+17550, int_stack+9246, int_stack+9096, 10);
 /*--- compute (f0||fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+18000, int_stack+17550, int_stack+17250, 10);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+18600, int_stack+9456, int_stack+9246, 10);
 /*--- compute (f0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+29884, int_stack+18600, int_stack+17550, 10);
 /*--- compute (f0||ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+34384, int_stack+29884, int_stack+18000, 10);
 /*--- compute (g0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+29884, int_stack+9886, int_stack+9736, 15);
 /*--- compute (g0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+30334, int_stack+10111, int_stack+9886, 15);
 /*--- compute (g0||fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+17250, int_stack+30334, int_stack+29884, 15);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+18150, int_stack+10426, int_stack+10111, 15);
 /*--- compute (g0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+35384, int_stack+18150, int_stack+30334, 15);
 /*--- compute (g0||ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+29884, int_stack+35384, int_stack+17250, 15);
 /*--- compute (fp||ff) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+23850, int_stack+29884, int_stack+34384, 100);
 /*--- compute (h0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+34384, int_stack+11056, int_stack+10846, 21);
 /*--- compute (h0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+35014, int_stack+11371, int_stack+11056, 21);
 /*--- compute (h0||fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+35959, int_stack+35014, int_stack+34384, 21);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+17250, int_stack+11812, int_stack+11371, 21);
 /*--- compute (h0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+17250, int_stack+35014, 21);
 /*--- compute (h0||ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+17250, int_stack+0, int_stack+35959, 21);
 /*--- compute (gp||ff) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+17250, int_stack+29884, 100);
 /*--- compute (fd|[r12,T2]|ff) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+4500, int_stack+37717, int_stack+26884, 100);
     Libr12->te_ptr[3] = int_stack + 4500;
 /*--- compute (fd|[r12,T1]|ff) ---*/
   t1hrr1_build_fd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+34384, int_stack+46717, int_stack+31384, int_stack+19350, int_stack+42217, int_stack+14250, 3, 3);
     Libr12->te_ptr[2] = int_stack + 34384;
 /*--- compute (fd||ff) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+40384, int_stack+0, int_stack+23850, 100);
     Libr12->te_ptr[1] = int_stack + 40384;
 /*--- compute (fd|ff) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+23850, int_stack+19350, int_stack+14250, 100);
     Libr12->te_ptr[0] = int_stack + 23850;

}
