/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_ffgd(Libr12_t *, prim_data *);

  /* Computes (ff|gd) integrals for linear R12-methods */

void hrr_grt_order_ffgd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[3][4] = int_stack + 0;
 Libr12->t2vrr_classes[3][5] = int_stack + 150;
 Libr12->t2vrr_classes[3][6] = int_stack + 360;
 Libr12->t2vrr_classes[4][4] = int_stack + 640;
 Libr12->t2vrr_classes[4][5] = int_stack + 865;
 Libr12->t2vrr_classes[4][6] = int_stack + 1180;
 Libr12->t2vrr_classes[5][4] = int_stack + 1600;
 Libr12->t2vrr_classes[5][5] = int_stack + 1915;
 Libr12->t2vrr_classes[5][6] = int_stack + 2356;
 Libr12->gvrr_classes[7][4] = int_stack + 2944;
 Libr12->t2vrr_classes[6][4] = int_stack + 3484;
 Libr12->gvrr_classes[7][5] = int_stack + 3904;
 Libr12->t2vrr_classes[6][5] = int_stack + 4660;
 Libr12->t2vrr_classes[6][6] = int_stack + 5248;
 Libr12->gvrr_classes[3][7] = int_stack + 6032;
 Libr12->t1vrr_classes[3][4] = int_stack + 6392;
 Libr12->t1vrr_classes[3][5] = int_stack + 6542;
 Libr12->t1vrr_classes[3][6] = int_stack + 6752;
 Libr12->gvrr_classes[4][7] = int_stack + 7032;
 Libr12->t1vrr_classes[4][4] = int_stack + 7572;
 Libr12->t1vrr_classes[4][5] = int_stack + 7797;
 Libr12->t1vrr_classes[4][6] = int_stack + 8112;
 Libr12->gvrr_classes[5][7] = int_stack + 8532;
 Libr12->t1vrr_classes[5][4] = int_stack + 9288;
 Libr12->t1vrr_classes[5][5] = int_stack + 9603;
 Libr12->t1vrr_classes[5][6] = int_stack + 10044;
 Libr12->t1vrr_classes[6][4] = int_stack + 10632;
 Libr12->t1vrr_classes[6][5] = int_stack + 11052;
 Libr12->t1vrr_classes[6][6] = int_stack + 11640;
 Libr12->rvrr_classes[3][4] = int_stack + 12424;
 Libr12->rvrr_classes[3][5] = int_stack + 12574;
 Libr12->rvrr_classes[3][6] = int_stack + 12784;
 Libr12->rvrr_classes[4][4] = int_stack + 13064;
 Libr12->rvrr_classes[4][5] = int_stack + 13289;
 Libr12->rvrr_classes[4][6] = int_stack + 13604;
 Libr12->rvrr_classes[5][4] = int_stack + 14024;
 Libr12->rvrr_classes[5][5] = int_stack + 14339;
 Libr12->rvrr_classes[5][6] = int_stack + 14780;
 Libr12->rvrr_classes[6][4] = int_stack + 15368;
 Libr12->rvrr_classes[6][5] = int_stack + 15788;
 Libr12->rvrr_classes[6][6] = int_stack + 16376;
 Libr12->gvrr_classes[3][4] = int_stack + 17160;
 Libr12->gvrr_classes[3][5] = int_stack + 17310;
 Libr12->gvrr_classes[3][6] = int_stack + 17520;
 Libr12->gvrr_classes[4][4] = int_stack + 17800;
 Libr12->gvrr_classes[4][5] = int_stack + 18025;
 Libr12->gvrr_classes[4][6] = int_stack + 18340;
 Libr12->gvrr_classes[5][4] = int_stack + 18760;
 Libr12->gvrr_classes[5][5] = int_stack + 19075;
 Libr12->gvrr_classes[5][6] = int_stack + 19516;
 Libr12->gvrr_classes[6][4] = int_stack + 20104;
 Libr12->gvrr_classes[6][5] = int_stack + 20524;
 Libr12->gvrr_classes[6][6] = int_stack + 21112;
 memset(int_stack,0,21896*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 21896;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_ffgd(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+21896, int_stack+17310, int_stack+17160, 10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+22346, int_stack+18025, int_stack+17800, 15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+23021, int_stack+17520, int_stack+17310, 10);
 /*--- compute (f0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+23651, int_stack+150, int_stack+0, int_stack+17310, int_stack+17800, int_stack+17160, 3, 0);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+24101, int_stack+360, int_stack+150, int_stack+17520, int_stack+18025, int_stack+17310, 3, 0);
 /*--- compute (f0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+24731, int_stack+24101, int_stack+23651, int_stack+23021, int_stack+22346, int_stack+21896, 3, 0);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+23651, int_stack+19075, int_stack+18760, 21);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+25631, int_stack+18340, int_stack+18025, 15);
 /*--- compute (g0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+26576, int_stack+865, int_stack+640, int_stack+18025, int_stack+18760, int_stack+17800, 4, 0);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+27251, int_stack+1180, int_stack+865, int_stack+18340, int_stack+19075, int_stack+18025, 4, 0);
 /*--- compute (g0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+27251, int_stack+26576, int_stack+25631, int_stack+23651, int_stack+22346, 4, 0);
 /*--- compute (fp|[r12,T2]|gd) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+26576, int_stack+0, int_stack+24731, 90);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+29276, int_stack+20524, int_stack+20104, 28);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+30536, int_stack+19516, int_stack+19075, 21);
 /*--- compute (h0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+24596, int_stack+1915, int_stack+1600, int_stack+19075, int_stack+20104, int_stack+18760, 5, 0);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+31859, int_stack+2356, int_stack+1915, int_stack+19516, int_stack+20524, int_stack+19075, 5, 0);
 /*--- compute (h0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+33182, int_stack+31859, int_stack+24596, int_stack+30536, int_stack+29276, int_stack+23651, 5, 0);
 /*--- compute (gp|[r12,T2]|gd) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+35072, int_stack+33182, int_stack+0, 90);
 /*--- compute (fd|[r12,T2]|gd) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+39122, int_stack+35072, int_stack+26576, 90);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+26576, int_stack+3904, int_stack+2944, 36);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+21112, int_stack+20524, 28);
 /*--- compute (i0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+31859, int_stack+4660, int_stack+3484, int_stack+20524, int_stack+2944, int_stack+20104, 6, 0);
 /*--- compute (i0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1764, int_stack+5248, int_stack+4660, int_stack+21112, int_stack+3904, int_stack+20524, 6, 0);
 /*--- compute (i0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+44522, int_stack+1764, int_stack+31859, int_stack+0, int_stack+26576, int_stack+29276, 6, 0);
 /*--- compute (hp|[r12,T2]|gd) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+47042, int_stack+44522, int_stack+33182, 90);
 /*--- compute (gd|[r12,T2]|gd) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+52712, int_stack+47042, int_stack+35072, 90);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+44522, int_stack+23021, int_stack+21896, 10);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+45422, int_stack+25631, int_stack+22346, 15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+26576, int_stack+45422, int_stack+44522, 90);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+46772, int_stack+30536, int_stack+23651, 21);
 /*--- compute (gp|gd) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+48662, int_stack+46772, int_stack+45422, 90);
 /*--- compute (fd|gd) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+31859, int_stack+48662, int_stack+26576, 90);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+23651, int_stack+6032, int_stack+17520, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+37259, int_stack+23651, int_stack+23021, 10);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+1764, int_stack+7032, int_stack+18340, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+3024, int_stack+1764, int_stack+25631, 15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+20104, int_stack+3024, int_stack+37259, 126);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+23884, int_stack+8532, int_stack+19516, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+17160, int_stack+23884, int_stack+30536, 21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+60812, int_stack+17160, int_stack+3024, 126);
 /*--- compute (fd|hd) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+66482, int_stack+60812, int_stack+20104, 126);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+23884, int_stack+0, int_stack+29276, 28);
 /*--- compute (hp|gd) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+74042, int_stack+23884, int_stack+46772, 90);
 /*--- compute (gd|gd) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+79712, int_stack+74042, int_stack+48662, 90);
 /*--- compute (f0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+29276, int_stack+6542, int_stack+6392, 10);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+29726, int_stack+6752, int_stack+6542, 10);
 /*--- compute (f0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+30356, int_stack+29726, int_stack+29276, 10);
 /*--- compute (g0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+29276, int_stack+7797, int_stack+7572, 15);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+8112, int_stack+7797, 15);
 /*--- compute (g0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+945, int_stack+0, int_stack+29276, 15);
 /*--- compute (fp|[r12,T1]|gd) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+4914, int_stack+945, int_stack+30356, int_stack+45422, int_stack+37259, int_stack+44522, 4, 2);
 /*--- compute (h0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+9603, int_stack+9288, 21);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+37259, int_stack+10044, int_stack+9603, 21);
 /*--- compute (h0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+29276, int_stack+37259, int_stack+0, 21);
 /*--- compute (gp|[r12,T1]|gd) ---*/
   t1hrr1_build_gp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+87812, int_stack+29276, int_stack+945, int_stack+46772, int_stack+3024, int_stack+45422, 4, 2);
 /*--- compute (fd|[r12,T1]|gd) ---*/
   t1hrr1_build_fd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+91862, int_stack+87812, int_stack+4914, int_stack+48662, int_stack+20104, int_stack+26576, 4, 2);
 /*--- compute (i0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+11052, int_stack+10632, 28);
 /*--- compute (i0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+1260, int_stack+11640, int_stack+11052, 28);
 /*--- compute (i0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+3024, int_stack+1260, int_stack+0, 28);
 /*--- compute (hp|[r12,T1]|gd) ---*/
   t1hrr1_build_hp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+5544, int_stack+3024, int_stack+29276, int_stack+23884, int_stack+17160, int_stack+46772, 4, 2);
 /*--- compute (gd|[r12,T1]|gd) ---*/
   t1hrr1_build_gd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+17160, int_stack+5544, int_stack+87812, int_stack+74042, int_stack+60812, int_stack+48662, 4, 2);
 /*--- compute (f0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+60812, int_stack+12574, int_stack+12424, 10);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+61262, int_stack+12784, int_stack+12574, 10);
 /*--- compute (f0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+61892, int_stack+61262, int_stack+60812, 10);
 /*--- compute (g0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+60812, int_stack+13289, int_stack+13064, 15);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+62792, int_stack+13604, int_stack+13289, 15);
 /*--- compute (g0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+63737, int_stack+62792, int_stack+60812, 15);
 /*--- compute (fp||gd) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+74042, int_stack+63737, int_stack+61892, 90);
 /*--- compute (h0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+60812, int_stack+14339, int_stack+14024, 21);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+61757, int_stack+14780, int_stack+14339, 21);
 /*--- compute (h0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+76742, int_stack+61757, int_stack+60812, 21);
 /*--- compute (gp||gd) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+87812, int_stack+76742, int_stack+63737, 90);
 /*--- compute (fd||gd) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+60812, int_stack+87812, int_stack+74042, 90);
 /*--- compute (i0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+74042, int_stack+15788, int_stack+15368, 28);
 /*--- compute (i0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+25260, int_stack+16376, int_stack+15788, 28);
 /*--- compute (i0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+27024, int_stack+25260, int_stack+74042, 28);
 /*--- compute (hp||gd) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+27024, int_stack+76742, 90);
 /*--- compute (gd||gd) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+5670, int_stack+0, int_stack+87812, 90);
 /*--- compute (ff|[r12,T2]|gd) ---*/
   hrr1_build_ff(Libr12->ShellQuartet.AB,int_stack+97262, int_stack+52712, int_stack+39122, 90);
     Libr12->te_ptr[3] = int_stack + 97262;
 /*--- compute (ff|[r12,T1]|gd) ---*/
   t1hrr1_build_ff(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+37259, int_stack+17160, int_stack+91862, int_stack+79712, int_stack+66482, int_stack+31859, 4, 2);
     Libr12->te_ptr[2] = int_stack + 37259;
 /*--- compute (ff||gd) ---*/
   hrr1_build_ff(Libr12->ShellQuartet.AB,int_stack+87812, int_stack+5670, int_stack+60812, 90);
     Libr12->te_ptr[1] = int_stack + 87812;
 /*--- compute (ff|gd) ---*/
   hrr1_build_ff(Libr12->ShellQuartet.AB,int_stack+0, int_stack+79712, int_stack+31859, 90);
     Libr12->te_ptr[0] = int_stack + 0;

}
