/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_fpgp(Libr12_t *, prim_data *);

  /* Computes (fp|gp) integrals for linear R12-methods */

void hrr_grt_order_fpgp(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[3][4] = int_stack + 0;
 Libr12->t2vrr_classes[3][5] = int_stack + 150;
 Libr12->gvrr_classes[5][4] = int_stack + 360;
 Libr12->t2vrr_classes[4][4] = int_stack + 675;
 Libr12->t2vrr_classes[4][5] = int_stack + 900;
 Libr12->gvrr_classes[3][6] = int_stack + 1215;
 Libr12->t1vrr_classes[3][4] = int_stack + 1495;
 Libr12->t1vrr_classes[3][5] = int_stack + 1645;
 Libr12->t1vrr_classes[4][4] = int_stack + 1855;
 Libr12->t1vrr_classes[4][5] = int_stack + 2080;
 Libr12->rvrr_classes[3][4] = int_stack + 2395;
 Libr12->rvrr_classes[3][5] = int_stack + 2545;
 Libr12->rvrr_classes[4][4] = int_stack + 2755;
 Libr12->rvrr_classes[4][5] = int_stack + 2980;
 Libr12->gvrr_classes[3][4] = int_stack + 3295;
 Libr12->gvrr_classes[3][5] = int_stack + 3445;
 Libr12->gvrr_classes[4][4] = int_stack + 3655;
 Libr12->gvrr_classes[4][5] = int_stack + 3880;
 memset(int_stack,0,4195*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 4195;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_fpgp(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+4195, int_stack+150, int_stack+0, int_stack+3445, int_stack+3655, int_stack+3295, 3, 0);
 /*--- compute (g0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+4645, int_stack+900, int_stack+675, int_stack+3880, int_stack+360, int_stack+3655, 4, 0);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+3445, int_stack+3295, 10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+450, int_stack+1215, int_stack+3445, 10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+5320, int_stack+3880, int_stack+3655, 15);
 /*--- compute (f0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+3295, int_stack+1645, int_stack+1495, 10);
 /*--- compute (g0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+1080, int_stack+2080, int_stack+1855, 15);
 /*--- compute (f0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+3745, int_stack+2545, int_stack+2395, 10);
 /*--- compute (g0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+1755, int_stack+2980, int_stack+2755, 15);
 /*--- compute (fp|[r12,T2]|gp) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+5995, int_stack+4645, int_stack+4195, 45);
     Libr12->te_ptr[3] = int_stack + 5995;
 /*--- compute (fp|[r12,T1]|gp) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+7345, int_stack+1080, int_stack+3295, int_stack+5320, int_stack+450, int_stack+0, 4, 1);
     Libr12->te_ptr[2] = int_stack + 7345;
 /*--- compute (fp||gp) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+8695, int_stack+1755, int_stack+3745, 45);
     Libr12->te_ptr[1] = int_stack + 8695;
 /*--- compute (fp|gp) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+450, int_stack+5320, int_stack+0, 45);
     Libr12->te_ptr[0] = int_stack + 450;

}
