/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_g0gf(Libr12_t *, prim_data *);

  /* Computes (g0|gf) integrals for linear R12-methods */

void hrr_grt_order_g0gf(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[5][4] = int_stack + 0;
 Libr12->t2vrr_classes[4][4] = int_stack + 315;
 Libr12->gvrr_classes[5][5] = int_stack + 540;
 Libr12->t2vrr_classes[4][5] = int_stack + 981;
 Libr12->gvrr_classes[5][6] = int_stack + 1296;
 Libr12->t2vrr_classes[4][6] = int_stack + 1884;
 Libr12->t2vrr_classes[4][7] = int_stack + 2304;
 Libr12->t1vrr_classes[4][4] = int_stack + 2844;
 Libr12->t1vrr_classes[4][5] = int_stack + 3069;
 Libr12->t1vrr_classes[4][6] = int_stack + 3384;
 Libr12->t1vrr_classes[4][7] = int_stack + 3804;
 Libr12->rvrr_classes[4][4] = int_stack + 4344;
 Libr12->rvrr_classes[4][5] = int_stack + 4569;
 Libr12->rvrr_classes[4][6] = int_stack + 4884;
 Libr12->rvrr_classes[4][7] = int_stack + 5304;
 Libr12->gvrr_classes[4][4] = int_stack + 5844;
 Libr12->gvrr_classes[4][5] = int_stack + 6069;
 Libr12->gvrr_classes[4][6] = int_stack + 6384;
 Libr12->gvrr_classes[4][7] = int_stack + 6804;
 memset(int_stack,0,7344*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 7344;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_g0gf(Libr12, Data);
   Data++;
 }

 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+7344, int_stack+6069, int_stack+5844, 15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+8019, int_stack+6384, int_stack+6069, 15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+8964, int_stack+8019, int_stack+7344, 15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+10314, int_stack+540, int_stack+0, 21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+11259, int_stack+1296, int_stack+540, 21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+12582, int_stack+11259, int_stack+10314, 21);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+14472, int_stack+6804, int_stack+6384, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+15732, int_stack+14472, int_stack+8019, 15);
 /*--- compute (g0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+17622, int_stack+981, int_stack+315, int_stack+6069, int_stack+0, int_stack+5844, 4, 0);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+18297, int_stack+1884, int_stack+981, int_stack+6384, int_stack+540, int_stack+6069, 4, 0);
 /*--- compute (g0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+19242, int_stack+18297, int_stack+17622, int_stack+8019, int_stack+10314, int_stack+7344, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+2304, int_stack+1884, int_stack+6804, int_stack+1296, int_stack+6384, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+5844, int_stack+0, int_stack+18297, int_stack+14472, int_stack+11259, int_stack+8019, 4, 0);
 /*--- compute (g0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+14472, int_stack+3069, int_stack+2844, 15);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+3384, int_stack+3069, 15);
 /*--- compute (g0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+945, int_stack+0, int_stack+14472, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+14472, int_stack+3804, int_stack+3384, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+2295, int_stack+14472, int_stack+0, 15);
 /*--- compute (g0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+4569, int_stack+4344, 15);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+14472, int_stack+4884, int_stack+4569, 15);
 /*--- compute (g0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+10314, int_stack+14472, int_stack+0, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+17622, int_stack+5304, int_stack+4884, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+20592, int_stack+17622, int_stack+14472, 15);
 /*--- compute (g0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+22482, int_stack+5844, int_stack+19242, int_stack+15732, int_stack+12582, int_stack+8964, 4, 0);
     Libr12->te_ptr[3] = int_stack + 22482;
 /*--- compute (g0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+17622, int_stack+2295, int_stack+945, 15);
     Libr12->te_ptr[2] = int_stack + 17622;
 /*--- compute (g0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+20592, int_stack+10314, 15);
     Libr12->te_ptr[1] = int_stack + 0;
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+10314, int_stack+15732, int_stack+8964, 15);
     Libr12->te_ptr[0] = int_stack + 10314;

}
