/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_g0hf(Libr12_t *, prim_data *);

  /* Computes (g0|hf) integrals for linear R12-methods */

void hrr_grt_order_g0hf(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[5][5] = int_stack + 0;
 Libr12->t2vrr_classes[4][5] = int_stack + 441;
 Libr12->gvrr_classes[5][6] = int_stack + 756;
 Libr12->t2vrr_classes[4][6] = int_stack + 1344;
 Libr12->gvrr_classes[5][7] = int_stack + 1764;
 Libr12->t2vrr_classes[4][7] = int_stack + 2520;
 Libr12->t2vrr_classes[4][8] = int_stack + 3060;
 Libr12->t1vrr_classes[4][5] = int_stack + 3735;
 Libr12->t1vrr_classes[4][6] = int_stack + 4050;
 Libr12->t1vrr_classes[4][7] = int_stack + 4470;
 Libr12->t1vrr_classes[4][8] = int_stack + 5010;
 Libr12->rvrr_classes[4][5] = int_stack + 5685;
 Libr12->rvrr_classes[4][6] = int_stack + 6000;
 Libr12->rvrr_classes[4][7] = int_stack + 6420;
 Libr12->rvrr_classes[4][8] = int_stack + 6960;
 Libr12->gvrr_classes[4][5] = int_stack + 7635;
 Libr12->gvrr_classes[4][6] = int_stack + 7950;
 Libr12->gvrr_classes[4][7] = int_stack + 8370;
 Libr12->gvrr_classes[4][8] = int_stack + 8910;
 memset(int_stack,0,9585*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 9585;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_g0hf(Libr12, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+9585, int_stack+7950, int_stack+7635, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+10530, int_stack+8370, int_stack+7950, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+11790, int_stack+10530, int_stack+9585, 15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+13680, int_stack+756, int_stack+0, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+15003, int_stack+1764, int_stack+756, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+16767, int_stack+15003, int_stack+13680, 21);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+19413, int_stack+8910, int_stack+8370, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+21033, int_stack+19413, int_stack+10530, 15);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+23553, int_stack+1344, int_stack+441, int_stack+7950, int_stack+0, int_stack+7635, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+24498, int_stack+2520, int_stack+1344, int_stack+8370, int_stack+756, int_stack+7950, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+25758, int_stack+24498, int_stack+23553, int_stack+10530, int_stack+13680, int_stack+9585, 4, 0);
 /*--- compute (g0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+3060, int_stack+2520, int_stack+8910, int_stack+1764, int_stack+8370, 4, 0);
 /*--- compute (g0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+7635, int_stack+0, int_stack+24498, int_stack+19413, int_stack+15003, int_stack+10530, 4, 0);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+19413, int_stack+4050, int_stack+3735, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+0, int_stack+4470, int_stack+4050, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+1260, int_stack+0, int_stack+19413, 15);
 /*--- compute (g0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+19413, int_stack+5010, int_stack+4470, 15);
 /*--- compute (g0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+3150, int_stack+19413, int_stack+0, 15);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+6000, int_stack+5685, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+19413, int_stack+6420, int_stack+6000, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+13680, int_stack+19413, int_stack+0, 15);
 /*--- compute (g0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+23553, int_stack+6960, int_stack+6420, 15);
 /*--- compute (g0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+27648, int_stack+23553, int_stack+19413, 15);
 /*--- compute (g0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+30168, int_stack+7635, int_stack+25758, int_stack+21033, int_stack+16767, int_stack+11790, 4, 0);
     Libr12->te_ptr[3] = int_stack + 30168;
 /*--- compute (g0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+23553, int_stack+3150, int_stack+1260, 15);
     Libr12->te_ptr[2] = int_stack + 23553;
 /*--- compute (g0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+27648, int_stack+13680, 15);
     Libr12->te_ptr[1] = int_stack + 0;
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+13680, int_stack+21033, int_stack+11790, 15);
     Libr12->te_ptr[0] = int_stack + 13680;

}
