/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_gpgp(Libr12_t *, prim_data *);

  /* Computes (gp|gp) integrals for linear R12-methods */

void hrr_grt_order_gpgp(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[4][4] = int_stack + 0;
 Libr12->t2vrr_classes[4][5] = int_stack + 225;
 Libr12->gvrr_classes[6][4] = int_stack + 540;
 Libr12->t2vrr_classes[5][4] = int_stack + 960;
 Libr12->t2vrr_classes[5][5] = int_stack + 1275;
 Libr12->gvrr_classes[4][6] = int_stack + 1716;
 Libr12->t1vrr_classes[4][4] = int_stack + 2136;
 Libr12->t1vrr_classes[4][5] = int_stack + 2361;
 Libr12->t1vrr_classes[5][4] = int_stack + 2676;
 Libr12->t1vrr_classes[5][5] = int_stack + 2991;
 Libr12->rvrr_classes[4][4] = int_stack + 3432;
 Libr12->rvrr_classes[4][5] = int_stack + 3657;
 Libr12->rvrr_classes[5][4] = int_stack + 3972;
 Libr12->rvrr_classes[5][5] = int_stack + 4287;
 Libr12->gvrr_classes[4][4] = int_stack + 4728;
 Libr12->gvrr_classes[4][5] = int_stack + 4953;
 Libr12->gvrr_classes[5][4] = int_stack + 5268;
 Libr12->gvrr_classes[5][5] = int_stack + 5583;
 memset(int_stack,0,6024*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 6024;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_gpgp(Libr12, Data);
   Data++;
 }

 /*--- compute (g0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+6024, int_stack+225, int_stack+0, int_stack+4953, int_stack+5268, int_stack+4728, 4, 0);
 /*--- compute (h0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+6699, int_stack+1275, int_stack+960, int_stack+5583, int_stack+540, int_stack+5268, 5, 0);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+4953, int_stack+4728, 15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+675, int_stack+1716, int_stack+4953, 15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+7644, int_stack+5583, int_stack+5268, 21);
 /*--- compute (g0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+4728, int_stack+2361, int_stack+2136, 15);
 /*--- compute (h0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+1620, int_stack+2991, int_stack+2676, 21);
 /*--- compute (g0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+2565, int_stack+3657, int_stack+3432, 15);
 /*--- compute (h0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+8589, int_stack+4287, int_stack+3972, 21);
 /*--- compute (gp|[r12,T2]|gp) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+9534, int_stack+6699, int_stack+6024, 45);
     Libr12->te_ptr[3] = int_stack + 9534;
 /*--- compute (gp|[r12,T1]|gp) ---*/
   t1hrr1_build_gp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+5403, int_stack+1620, int_stack+4728, int_stack+7644, int_stack+675, int_stack+0, 4, 1);
     Libr12->te_ptr[2] = int_stack + 5403;
 /*--- compute (gp||gp) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+3240, int_stack+8589, int_stack+2565, 45);
     Libr12->te_ptr[1] = int_stack + 3240;
 /*--- compute (gp|gp) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+675, int_stack+7644, int_stack+0, 45);
     Libr12->te_ptr[0] = int_stack + 675;

}
