/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_p0dd(Libr12_t *, prim_data *);

  /* Computes (p0|dd) integrals for linear R12-methods */

void hrr_grt_order_p0dd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[2][2] = int_stack + 0;
 Libr12->t2vrr_classes[1][2] = int_stack + 36;
 Libr12->gvrr_classes[2][3] = int_stack + 54;
 Libr12->t2vrr_classes[1][3] = int_stack + 114;
 Libr12->t2vrr_classes[1][4] = int_stack + 144;
 Libr12->t1vrr_classes[1][2] = int_stack + 189;
 Libr12->t1vrr_classes[1][3] = int_stack + 207;
 Libr12->t1vrr_classes[1][4] = int_stack + 237;
 Libr12->rvrr_classes[1][2] = int_stack + 282;
 Libr12->rvrr_classes[1][3] = int_stack + 300;
 Libr12->rvrr_classes[1][4] = int_stack + 330;
 Libr12->gvrr_classes[1][2] = int_stack + 375;
 Libr12->gvrr_classes[1][3] = int_stack + 393;
 Libr12->gvrr_classes[1][4] = int_stack + 423;
 memset(int_stack,0,468*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 468;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_p0dd(Libr12, Data);
   Data++;
 }

 /*--- compute (p0|dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+468, int_stack+393, int_stack+375, 3);
 /*--- compute (d0|dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+522, int_stack+54, int_stack+0, 6);
 /*--- compute (p0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+630, int_stack+423, int_stack+393, 3);
 /*--- compute (p0|[r12,T2]|dp) ---*/
   t2hrr3_build_dp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+720, int_stack+114, int_stack+36, int_stack+393, int_stack+0, int_stack+375, 1, 0);
 /*--- compute (p0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+774, int_stack+144, int_stack+114, int_stack+423, int_stack+54, int_stack+393, 1, 0);
 /*--- compute (p0|[r12,T1]|dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+375, int_stack+207, int_stack+189, 3);
 /*--- compute (p0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+237, int_stack+207, 3);
 /*--- compute (p0||dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+90, int_stack+300, int_stack+282, 3);
 /*--- compute (p0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+144, int_stack+330, int_stack+300, 3);
 /*--- compute (p0|[r12,T2]|dd) ---*/
   t2hrr3_build_dd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+234, int_stack+774, int_stack+720, int_stack+630, int_stack+522, int_stack+468, 1, 0);
     Libr12->te_ptr[3] = int_stack + 234;
 /*--- compute (p0|[r12,T1]|dd) ---*/
   hrr3_build_dd(Libr12->ShellQuartet.CD,int_stack+522, int_stack+0, int_stack+375, 3);
     Libr12->te_ptr[2] = int_stack + 522;
 /*--- compute (p0||dd) ---*/
   hrr3_build_dd(Libr12->ShellQuartet.CD,int_stack+720, int_stack+144, int_stack+90, 3);
     Libr12->te_ptr[1] = int_stack + 720;
 /*--- compute (p0|dd) ---*/
   hrr3_build_dd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+630, int_stack+468, 3);
     Libr12->te_ptr[0] = int_stack + 0;

}
