/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_p0hg(Libr12_t *, prim_data *);

  /* Computes (p0|hg) integrals for linear R12-methods */

void hrr_grt_order_p0hg(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[2][5] = int_stack + 0;
 Libr12->t2vrr_classes[1][5] = int_stack + 126;
 Libr12->gvrr_classes[2][6] = int_stack + 189;
 Libr12->t2vrr_classes[1][6] = int_stack + 357;
 Libr12->gvrr_classes[2][7] = int_stack + 441;
 Libr12->t2vrr_classes[1][7] = int_stack + 657;
 Libr12->gvrr_classes[2][8] = int_stack + 765;
 Libr12->t2vrr_classes[1][8] = int_stack + 1035;
 Libr12->t2vrr_classes[1][9] = int_stack + 1170;
 Libr12->t1vrr_classes[1][5] = int_stack + 1335;
 Libr12->t1vrr_classes[1][6] = int_stack + 1398;
 Libr12->t1vrr_classes[1][7] = int_stack + 1482;
 Libr12->t1vrr_classes[1][8] = int_stack + 1590;
 Libr12->t1vrr_classes[1][9] = int_stack + 1725;
 Libr12->rvrr_classes[1][5] = int_stack + 1890;
 Libr12->rvrr_classes[1][6] = int_stack + 1953;
 Libr12->rvrr_classes[1][7] = int_stack + 2037;
 Libr12->rvrr_classes[1][8] = int_stack + 2145;
 Libr12->rvrr_classes[1][9] = int_stack + 2280;
 Libr12->gvrr_classes[1][5] = int_stack + 2445;
 Libr12->gvrr_classes[1][6] = int_stack + 2508;
 Libr12->gvrr_classes[1][7] = int_stack + 2592;
 Libr12->gvrr_classes[1][8] = int_stack + 2700;
 Libr12->gvrr_classes[1][9] = int_stack + 2835;
 memset(int_stack,0,3000*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 3000;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_p0hg(Libr12, Data);
   Data++;
 }

 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+3000, int_stack+2508, int_stack+2445, 3);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+3189, int_stack+2592, int_stack+2508, 3);
 /*--- compute (p0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+3441, int_stack+3189, int_stack+3000, 3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+3819, int_stack+2700, int_stack+2592, 3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+4143, int_stack+3819, int_stack+3189, 3);
 /*--- compute (p0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+4647, int_stack+4143, int_stack+3441, 3);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+5277, int_stack+189, int_stack+0, 6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+5655, int_stack+441, int_stack+189, 6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+6159, int_stack+5655, int_stack+5277, 6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+6915, int_stack+765, int_stack+441, 6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+7563, int_stack+6915, int_stack+5655, 6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+8571, int_stack+7563, int_stack+6159, 6);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+9831, int_stack+2835, int_stack+2700, 3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+10236, int_stack+9831, int_stack+3819, 3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+10884, int_stack+10236, int_stack+4143, 3);
 /*--- compute (p0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+11724, int_stack+357, int_stack+126, int_stack+2508, int_stack+0, int_stack+2445, 1, 0);
 /*--- compute (p0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+11913, int_stack+657, int_stack+357, int_stack+2592, int_stack+189, int_stack+2508, 1, 0);
 /*--- compute (p0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+11913, int_stack+11724, int_stack+3189, int_stack+5277, int_stack+3000, 1, 0);
 /*--- compute (p0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+5277, int_stack+1035, int_stack+657, int_stack+2700, int_stack+441, int_stack+2592, 1, 0);
 /*--- compute (p0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+12165, int_stack+5277, int_stack+11913, int_stack+3819, int_stack+5655, int_stack+3189, 1, 0);
 /*--- compute (p0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+12669, int_stack+12165, int_stack+0, int_stack+4143, int_stack+6159, int_stack+3441, 1, 0);
 /*--- compute (p0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+1170, int_stack+1035, int_stack+2835, int_stack+765, int_stack+2700, 1, 0);
 /*--- compute (p0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+405, int_stack+0, int_stack+5277, int_stack+9831, int_stack+6915, int_stack+3819, 1, 0);
 /*--- compute (p0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+5277, int_stack+405, int_stack+12165, int_stack+10236, int_stack+7563, int_stack+4143, 1, 0);
 /*--- compute (p0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+9831, int_stack+1398, int_stack+1335, 3);
 /*--- compute (p0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+10020, int_stack+1482, int_stack+1398, 3);
 /*--- compute (p0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+10272, int_stack+10020, int_stack+9831, 3);
 /*--- compute (p0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+6117, int_stack+1590, int_stack+1482, 3);
 /*--- compute (p0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+6441, int_stack+6117, int_stack+10020, 3);
 /*--- compute (p0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+6945, int_stack+6441, int_stack+10272, 3);
 /*--- compute (p0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+9831, int_stack+1725, int_stack+1590, 3);
 /*--- compute (p0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+10236, int_stack+9831, int_stack+6117, 3);
 /*--- compute (p0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+7575, int_stack+10236, int_stack+6441, 3);
 /*--- compute (p0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+6117, int_stack+1953, int_stack+1890, 3);
 /*--- compute (p0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+6306, int_stack+2037, int_stack+1953, 3);
 /*--- compute (p0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+6558, int_stack+6306, int_stack+6117, 3);
 /*--- compute (p0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+9831, int_stack+2145, int_stack+2037, 3);
 /*--- compute (p0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+10155, int_stack+9831, int_stack+6306, 3);
 /*--- compute (p0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+10155, int_stack+6558, 3);
 /*--- compute (p0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+6117, int_stack+2280, int_stack+2145, 3);
 /*--- compute (p0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+630, int_stack+6117, int_stack+9831, 3);
 /*--- compute (p0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+1278, int_stack+630, int_stack+10155, 3);
 /*--- compute (p0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+11724, int_stack+5277, int_stack+12669, int_stack+10884, int_stack+8571, int_stack+4647, 1, 0);
     Libr12->te_ptr[3] = int_stack + 11724;
 /*--- compute (p0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+12669, int_stack+7575, int_stack+6945, 3);
     Libr12->te_ptr[2] = int_stack + 12669;
 /*--- compute (p0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+5277, int_stack+1278, int_stack+0, 3);
     Libr12->te_ptr[1] = int_stack + 5277;
 /*--- compute (p0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+0, int_stack+10884, int_stack+4647, 3);
     Libr12->te_ptr[0] = int_stack + 0;

}
