/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdlib.h>
#include <libint/libint.h>
#include "libr12.h"
#include "r12_hrr_header.h"

extern "C" {
void (*build_r12_gr[6][6][6][6])(Libr12_t *, int);
void (*build_r12_grt[6][6][6][6])(Libr12_t *, int);
int libr12_stack_size[6];
/* This function initializes a matrix of pointers to routines */
/* for computing integral classes up to (hh|hh) */

void init_libr12_base()
{
  build_r12_grt[0][0][0][0] = hrr_grt_order_0000;
  build_r12_grt[0][0][1][0] = hrr_grt_order_00p0;
  build_r12_grt[0][0][2][0] = hrr_grt_order_00d0;
  build_r12_grt[0][0][1][1] = hrr_grt_order_00pp;
  build_r12_grt[0][0][3][0] = hrr_grt_order_00f0;
  build_r12_grt[0][0][2][1] = hrr_grt_order_00dp;
  build_r12_grt[0][0][4][0] = hrr_grt_order_00g0;
  build_r12_grt[0][0][3][1] = hrr_grt_order_00fp;
  build_r12_grt[0][0][2][2] = hrr_grt_order_00dd;
  build_r12_grt[0][0][5][0] = hrr_grt_order_00h0;
  build_r12_grt[0][0][4][1] = hrr_grt_order_00gp;
  build_r12_grt[0][0][3][2] = hrr_grt_order_00fd;
  build_r12_grt[0][0][5][1] = hrr_grt_order_00hp;
  build_r12_grt[0][0][4][2] = hrr_grt_order_00gd;
  build_r12_grt[0][0][3][3] = hrr_grt_order_00ff;
  build_r12_grt[0][0][5][2] = hrr_grt_order_00hd;
  build_r12_grt[0][0][4][3] = hrr_grt_order_00gf;
  build_r12_grt[0][0][5][3] = hrr_grt_order_00hf;
  build_r12_grt[0][0][4][4] = hrr_grt_order_00gg;
  build_r12_grt[0][0][5][4] = hrr_grt_order_00hg;
  build_r12_grt[0][0][5][5] = hrr_grt_order_00hh;
  build_r12_grt[1][0][1][0] = hrr_grt_order_p0p0;
  build_r12_grt[1][0][2][0] = hrr_grt_order_p0d0;
  build_r12_grt[1][0][1][1] = hrr_grt_order_p0pp;
  build_r12_grt[1][0][3][0] = hrr_grt_order_p0f0;
  build_r12_grt[1][0][2][1] = hrr_grt_order_p0dp;
  build_r12_grt[1][0][4][0] = hrr_grt_order_p0g0;
  build_r12_grt[1][0][3][1] = hrr_grt_order_p0fp;
  build_r12_grt[1][0][2][2] = hrr_grt_order_p0dd;
  build_r12_grt[1][0][5][0] = hrr_grt_order_p0h0;
  build_r12_grt[1][0][4][1] = hrr_grt_order_p0gp;
  build_r12_grt[1][0][3][2] = hrr_grt_order_p0fd;
  build_r12_grt[1][0][5][1] = hrr_grt_order_p0hp;
  build_r12_grt[1][0][4][2] = hrr_grt_order_p0gd;
  build_r12_grt[1][0][3][3] = hrr_grt_order_p0ff;
  build_r12_grt[1][0][5][2] = hrr_grt_order_p0hd;
  build_r12_grt[1][0][4][3] = hrr_grt_order_p0gf;
  build_r12_grt[1][0][5][3] = hrr_grt_order_p0hf;
  build_r12_grt[1][0][4][4] = hrr_grt_order_p0gg;
  build_r12_grt[1][0][5][4] = hrr_grt_order_p0hg;
  build_r12_grt[1][0][5][5] = hrr_grt_order_p0hh;
  build_r12_grt[2][0][2][0] = hrr_grt_order_d0d0;
  build_r12_grt[2][0][1][1] = hrr_grt_order_d0pp;
  build_r12_grt[2][0][3][0] = hrr_grt_order_d0f0;
  build_r12_grt[2][0][2][1] = hrr_grt_order_d0dp;
  build_r12_grt[2][0][4][0] = hrr_grt_order_d0g0;
  build_r12_grt[2][0][3][1] = hrr_grt_order_d0fp;
  build_r12_grt[2][0][2][2] = hrr_grt_order_d0dd;
  build_r12_grt[2][0][5][0] = hrr_grt_order_d0h0;
  build_r12_grt[2][0][4][1] = hrr_grt_order_d0gp;
  build_r12_grt[2][0][3][2] = hrr_grt_order_d0fd;
  build_r12_grt[2][0][5][1] = hrr_grt_order_d0hp;
  build_r12_grt[2][0][4][2] = hrr_grt_order_d0gd;
  build_r12_grt[2][0][3][3] = hrr_grt_order_d0ff;
  build_r12_grt[2][0][5][2] = hrr_grt_order_d0hd;
  build_r12_grt[2][0][4][3] = hrr_grt_order_d0gf;
  build_r12_grt[2][0][5][3] = hrr_grt_order_d0hf;
  build_r12_grt[2][0][4][4] = hrr_grt_order_d0gg;
  build_r12_grt[2][0][5][4] = hrr_grt_order_d0hg;
  build_r12_grt[2][0][5][5] = hrr_grt_order_d0hh;
  build_r12_grt[1][1][2][0] = hrr_grt_order_ppd0;
  build_r12_grt[1][1][1][1] = hrr_grt_order_pppp;
  build_r12_grt[1][1][3][0] = hrr_grt_order_ppf0;
  build_r12_grt[1][1][2][1] = hrr_grt_order_ppdp;
  build_r12_grt[1][1][4][0] = hrr_grt_order_ppg0;
  build_r12_grt[1][1][3][1] = hrr_grt_order_ppfp;
  build_r12_grt[1][1][2][2] = hrr_grt_order_ppdd;
  build_r12_grt[1][1][5][0] = hrr_grt_order_pph0;
  build_r12_grt[1][1][4][1] = hrr_grt_order_ppgp;
  build_r12_grt[1][1][3][2] = hrr_grt_order_ppfd;
  build_r12_grt[1][1][5][1] = hrr_grt_order_pphp;
  build_r12_grt[1][1][4][2] = hrr_grt_order_ppgd;
  build_r12_grt[1][1][3][3] = hrr_grt_order_ppff;
  build_r12_grt[1][1][5][2] = hrr_grt_order_pphd;
  build_r12_grt[1][1][4][3] = hrr_grt_order_ppgf;
  build_r12_grt[1][1][5][3] = hrr_grt_order_pphf;
  build_r12_grt[1][1][4][4] = hrr_grt_order_ppgg;
  build_r12_grt[1][1][5][4] = hrr_grt_order_pphg;
  build_r12_grt[1][1][5][5] = hrr_grt_order_pphh;
  build_r12_grt[3][0][3][0] = hrr_grt_order_f0f0;
  build_r12_grt[3][0][2][1] = hrr_grt_order_f0dp;
  build_r12_grt[3][0][4][0] = hrr_grt_order_f0g0;
  build_r12_grt[3][0][3][1] = hrr_grt_order_f0fp;
  build_r12_grt[3][0][2][2] = hrr_grt_order_f0dd;
  build_r12_grt[3][0][5][0] = hrr_grt_order_f0h0;
  build_r12_grt[3][0][4][1] = hrr_grt_order_f0gp;
  build_r12_grt[3][0][3][2] = hrr_grt_order_f0fd;
  build_r12_grt[3][0][5][1] = hrr_grt_order_f0hp;
  build_r12_grt[3][0][4][2] = hrr_grt_order_f0gd;
  build_r12_grt[3][0][3][3] = hrr_grt_order_f0ff;
  build_r12_grt[3][0][5][2] = hrr_grt_order_f0hd;
  build_r12_grt[3][0][4][3] = hrr_grt_order_f0gf;
  build_r12_grt[3][0][5][3] = hrr_grt_order_f0hf;
  build_r12_grt[3][0][4][4] = hrr_grt_order_f0gg;
  build_r12_grt[3][0][5][4] = hrr_grt_order_f0hg;
  build_r12_grt[3][0][5][5] = hrr_grt_order_f0hh;
  build_r12_grt[2][1][3][0] = hrr_grt_order_dpf0;
  build_r12_grt[2][1][2][1] = hrr_grt_order_dpdp;
  build_r12_grt[2][1][4][0] = hrr_grt_order_dpg0;
  build_r12_grt[2][1][3][1] = hrr_grt_order_dpfp;
  build_r12_grt[2][1][2][2] = hrr_grt_order_dpdd;
  build_r12_grt[2][1][5][0] = hrr_grt_order_dph0;
  build_r12_grt[2][1][4][1] = hrr_grt_order_dpgp;
  build_r12_grt[2][1][3][2] = hrr_grt_order_dpfd;
  build_r12_grt[2][1][5][1] = hrr_grt_order_dphp;
  build_r12_grt[2][1][4][2] = hrr_grt_order_dpgd;
  build_r12_grt[2][1][3][3] = hrr_grt_order_dpff;
  build_r12_grt[2][1][5][2] = hrr_grt_order_dphd;
  build_r12_grt[2][1][4][3] = hrr_grt_order_dpgf;
  build_r12_grt[2][1][5][3] = hrr_grt_order_dphf;
  build_r12_grt[2][1][4][4] = hrr_grt_order_dpgg;
  build_r12_grt[2][1][5][4] = hrr_grt_order_dphg;
  build_r12_grt[2][1][5][5] = hrr_grt_order_dphh;
  build_r12_grt[4][0][4][0] = hrr_grt_order_g0g0;
  build_r12_grt[4][0][3][1] = hrr_grt_order_g0fp;
  build_r12_grt[4][0][2][2] = hrr_grt_order_g0dd;
  build_r12_grt[4][0][5][0] = hrr_grt_order_g0h0;
  build_r12_grt[4][0][4][1] = hrr_grt_order_g0gp;
  build_r12_grt[4][0][3][2] = hrr_grt_order_g0fd;
  build_r12_grt[4][0][5][1] = hrr_grt_order_g0hp;
  build_r12_grt[4][0][4][2] = hrr_grt_order_g0gd;
  build_r12_grt[4][0][3][3] = hrr_grt_order_g0ff;
  build_r12_grt[4][0][5][2] = hrr_grt_order_g0hd;
  build_r12_grt[4][0][4][3] = hrr_grt_order_g0gf;
  build_r12_grt[4][0][5][3] = hrr_grt_order_g0hf;
  build_r12_grt[4][0][4][4] = hrr_grt_order_g0gg;
  build_r12_grt[4][0][5][4] = hrr_grt_order_g0hg;
  build_r12_grt[4][0][5][5] = hrr_grt_order_g0hh;
  build_r12_grt[3][1][4][0] = hrr_grt_order_fpg0;
  build_r12_grt[3][1][3][1] = hrr_grt_order_fpfp;
  build_r12_grt[3][1][2][2] = hrr_grt_order_fpdd;
  build_r12_grt[3][1][5][0] = hrr_grt_order_fph0;
  build_r12_grt[3][1][4][1] = hrr_grt_order_fpgp;
  build_r12_grt[3][1][3][2] = hrr_grt_order_fpfd;
  build_r12_grt[3][1][5][1] = hrr_grt_order_fphp;
  build_r12_grt[3][1][4][2] = hrr_grt_order_fpgd;
  build_r12_grt[3][1][3][3] = hrr_grt_order_fpff;
  build_r12_grt[3][1][5][2] = hrr_grt_order_fphd;
  build_r12_grt[3][1][4][3] = hrr_grt_order_fpgf;
  build_r12_grt[3][1][5][3] = hrr_grt_order_fphf;
  build_r12_grt[3][1][4][4] = hrr_grt_order_fpgg;
  build_r12_grt[3][1][5][4] = hrr_grt_order_fphg;
  build_r12_grt[3][1][5][5] = hrr_grt_order_fphh;
  build_r12_grt[2][2][4][0] = hrr_grt_order_ddg0;
  build_r12_grt[2][2][3][1] = hrr_grt_order_ddfp;
  build_r12_grt[2][2][2][2] = hrr_grt_order_dddd;
  build_r12_grt[2][2][5][0] = hrr_grt_order_ddh0;
  build_r12_grt[2][2][4][1] = hrr_grt_order_ddgp;
  build_r12_grt[2][2][3][2] = hrr_grt_order_ddfd;
  build_r12_grt[2][2][5][1] = hrr_grt_order_ddhp;
  build_r12_grt[2][2][4][2] = hrr_grt_order_ddgd;
  build_r12_grt[2][2][3][3] = hrr_grt_order_ddff;
  build_r12_grt[2][2][5][2] = hrr_grt_order_ddhd;
  build_r12_grt[2][2][4][3] = hrr_grt_order_ddgf;
  build_r12_grt[2][2][5][3] = hrr_grt_order_ddhf;
  build_r12_grt[2][2][4][4] = hrr_grt_order_ddgg;
  build_r12_grt[2][2][5][4] = hrr_grt_order_ddhg;
  build_r12_grt[2][2][5][5] = hrr_grt_order_ddhh;
  build_r12_grt[5][0][5][0] = hrr_grt_order_h0h0;
  build_r12_grt[5][0][4][1] = hrr_grt_order_h0gp;
  build_r12_grt[5][0][3][2] = hrr_grt_order_h0fd;
  build_r12_grt[5][0][5][1] = hrr_grt_order_h0hp;
  build_r12_grt[5][0][4][2] = hrr_grt_order_h0gd;
  build_r12_grt[5][0][3][3] = hrr_grt_order_h0ff;
  build_r12_grt[5][0][5][2] = hrr_grt_order_h0hd;
  build_r12_grt[5][0][4][3] = hrr_grt_order_h0gf;
  build_r12_grt[5][0][5][3] = hrr_grt_order_h0hf;
  build_r12_grt[5][0][4][4] = hrr_grt_order_h0gg;
  build_r12_grt[5][0][5][4] = hrr_grt_order_h0hg;
  build_r12_grt[5][0][5][5] = hrr_grt_order_h0hh;
  build_r12_grt[4][1][5][0] = hrr_grt_order_gph0;
  build_r12_grt[4][1][4][1] = hrr_grt_order_gpgp;
  build_r12_grt[4][1][3][2] = hrr_grt_order_gpfd;
  build_r12_grt[4][1][5][1] = hrr_grt_order_gphp;
  build_r12_grt[4][1][4][2] = hrr_grt_order_gpgd;
  build_r12_grt[4][1][3][3] = hrr_grt_order_gpff;
  build_r12_grt[4][1][5][2] = hrr_grt_order_gphd;
  build_r12_grt[4][1][4][3] = hrr_grt_order_gpgf;
  build_r12_grt[4][1][5][3] = hrr_grt_order_gphf;
  build_r12_grt[4][1][4][4] = hrr_grt_order_gpgg;
  build_r12_grt[4][1][5][4] = hrr_grt_order_gphg;
  build_r12_grt[4][1][5][5] = hrr_grt_order_gphh;
  build_r12_grt[3][2][5][0] = hrr_grt_order_fdh0;
  build_r12_grt[3][2][4][1] = hrr_grt_order_fdgp;
  build_r12_grt[3][2][3][2] = hrr_grt_order_fdfd;
  build_r12_grt[3][2][5][1] = hrr_grt_order_fdhp;
  build_r12_grt[3][2][4][2] = hrr_grt_order_fdgd;
  build_r12_grt[3][2][3][3] = hrr_grt_order_fdff;
  build_r12_grt[3][2][5][2] = hrr_grt_order_fdhd;
  build_r12_grt[3][2][4][3] = hrr_grt_order_fdgf;
  build_r12_grt[3][2][5][3] = hrr_grt_order_fdhf;
  build_r12_grt[3][2][4][4] = hrr_grt_order_fdgg;
  build_r12_grt[3][2][5][4] = hrr_grt_order_fdhg;
  build_r12_grt[3][2][5][5] = hrr_grt_order_fdhh;
  build_r12_grt[5][1][5][1] = hrr_grt_order_hphp;
  build_r12_grt[5][1][4][2] = hrr_grt_order_hpgd;
  build_r12_grt[5][1][3][3] = hrr_grt_order_hpff;
  build_r12_grt[5][1][5][2] = hrr_grt_order_hphd;
  build_r12_grt[5][1][4][3] = hrr_grt_order_hpgf;
  build_r12_grt[5][1][5][3] = hrr_grt_order_hphf;
  build_r12_grt[5][1][4][4] = hrr_grt_order_hpgg;
  build_r12_grt[5][1][5][4] = hrr_grt_order_hphg;
  build_r12_grt[5][1][5][5] = hrr_grt_order_hphh;
  build_r12_grt[4][2][5][1] = hrr_grt_order_gdhp;
  build_r12_grt[4][2][4][2] = hrr_grt_order_gdgd;
  build_r12_grt[4][2][3][3] = hrr_grt_order_gdff;
  build_r12_grt[4][2][5][2] = hrr_grt_order_gdhd;
  build_r12_grt[4][2][4][3] = hrr_grt_order_gdgf;
  build_r12_grt[4][2][5][3] = hrr_grt_order_gdhf;
  build_r12_grt[4][2][4][4] = hrr_grt_order_gdgg;
  build_r12_grt[4][2][5][4] = hrr_grt_order_gdhg;
  build_r12_grt[4][2][5][5] = hrr_grt_order_gdhh;
  build_r12_grt[3][3][5][1] = hrr_grt_order_ffhp;
  build_r12_grt[3][3][4][2] = hrr_grt_order_ffgd;
  build_r12_grt[3][3][3][3] = hrr_grt_order_ffff;
  build_r12_grt[3][3][5][2] = hrr_grt_order_ffhd;
  build_r12_grt[3][3][4][3] = hrr_grt_order_ffgf;
  build_r12_grt[3][3][5][3] = hrr_grt_order_ffhf;
  build_r12_grt[3][3][4][4] = hrr_grt_order_ffgg;
  build_r12_grt[3][3][5][4] = hrr_grt_order_ffhg;
  build_r12_grt[3][3][5][5] = hrr_grt_order_ffhh;
  build_r12_grt[5][2][5][2] = hrr_grt_order_hdhd;
  build_r12_grt[5][2][4][3] = hrr_grt_order_hdgf;
  build_r12_grt[5][2][5][3] = hrr_grt_order_hdhf;
  build_r12_grt[5][2][4][4] = hrr_grt_order_hdgg;
  build_r12_grt[5][2][5][4] = hrr_grt_order_hdhg;
  build_r12_grt[5][2][5][5] = hrr_grt_order_hdhh;
  build_r12_grt[4][3][5][2] = hrr_grt_order_gfhd;
  build_r12_grt[4][3][4][3] = hrr_grt_order_gfgf;
  build_r12_grt[4][3][5][3] = hrr_grt_order_gfhf;
  build_r12_grt[4][3][4][4] = hrr_grt_order_gfgg;
  build_r12_grt[4][3][5][4] = hrr_grt_order_gfhg;
  build_r12_grt[4][3][5][5] = hrr_grt_order_gfhh;
  build_r12_grt[5][3][5][3] = hrr_grt_order_hfhf;
  build_r12_grt[5][3][4][4] = hrr_grt_order_hfgg;
  build_r12_grt[5][3][5][4] = hrr_grt_order_hfhg;
  build_r12_grt[5][3][5][5] = hrr_grt_order_hfhh;
  build_r12_grt[4][4][5][3] = hrr_grt_order_gghf;
  build_r12_grt[4][4][4][4] = hrr_grt_order_gggg;
  build_r12_grt[4][4][5][4] = hrr_grt_order_gghg;
  build_r12_grt[4][4][5][5] = hrr_grt_order_gghh;
  build_r12_grt[5][4][5][4] = hrr_grt_order_hghg;
  build_r12_grt[5][4][5][5] = hrr_grt_order_hghh;
  build_r12_grt[5][5][5][5] = hrr_grt_order_hhhh;

  libr12_stack_size[0] = 10;
  libr12_stack_size[1] = 888;
  libr12_stack_size[2] = 13330;
  libr12_stack_size[3] = 107564;
  libr12_stack_size[4] = 737016;
  libr12_stack_size[5] = 3250005;
}

/* These functions initialize library objects */
/* Library objects operate independently of each other */
int init_libr12(Libr12_t *libr12, int max_am, int max_num_prim_quartets)
{
  int memory = 0;

  if (max_am >= LIBR12_MAX_AM) return -1;
  libr12->int_stack = (REALTYPE *) malloc(libr12_stack_size[max_am]*sizeof(REALTYPE));
  memory += libr12_stack_size[max_am];
  libr12->PrimQuartet = (prim_data *) malloc(max_num_prim_quartets*sizeof(prim_data));
  memory += max_num_prim_quartets*sizeof(prim_data)/sizeof(REALTYPE);
  return memory;
}

void free_libr12(Libr12_t *libr12)
{
  if (libr12->int_stack != NULL) {
    free(libr12->int_stack);
    libr12->int_stack = NULL;
  }
  if (libr12->PrimQuartet != NULL) {
    free(libr12->PrimQuartet);
    libr12->PrimQuartet = NULL;
  }

  return;
}

int libr12_storage_required(int max_am, int max_num_prim_quartets)
{
  int memory = 0;

  if (max_am >= LIBR12_MAX_AM) return -1;
  memory += libr12_stack_size[max_am];
  memory += max_num_prim_quartets*sizeof(prim_data)/sizeof(REALTYPE);
  return memory;
}
}
