/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_00hh(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+12, r12vrr_stack+3, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+21, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+24, r12vrr_stack+0, r12vrr_stack+21, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+30, r12vrr_stack+6, r12vrr_stack+24, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+40, r12vrr_stack+15, r12vrr_stack+6, r12vrr_stack+12, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+50, r12vrr_stack+40, r12vrr_stack+30, r12vrr_stack+15, r12vrr_stack+6, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+65, r12vrr_stack+21, r12vrr_stack+3, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+71, r12vrr_stack+24, r12vrr_stack+65, r12vrr_stack+0, r12vrr_stack+21, NULL);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+81, r12vrr_stack+30, r12vrr_stack+71, r12vrr_stack+6, r12vrr_stack+24, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+96, r12vrr_stack+50, r12vrr_stack+81, NULL, NULL, r12vrr_stack+30);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+141, r12vrr_stack+65, r12vrr_stack+6, r12vrr_stack+21, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+151, r12vrr_stack+71, r12vrr_stack+141, r12vrr_stack+24, r12vrr_stack+65, NULL);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+166, r12vrr_stack+81, r12vrr_stack+151, r12vrr_stack+30, r12vrr_stack+71, NULL);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+187, r12vrr_stack+50, r12vrr_stack+81, r12vrr_stack+40, r12vrr_stack+30, NULL);
 tmp = r12vrr_stack + 187;
 target_ptr = Libr12->gvrr_classes[0][5];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+208, r12vrr_stack+187, r12vrr_stack+166, NULL, NULL, r12vrr_stack+81);
 tmp = r12vrr_stack + 208;
 target_ptr = Libr12->gvrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+271, r12vrr_stack+187, r12vrr_stack+166, r12vrr_stack+50, r12vrr_stack+81, NULL);
 tmp = r12vrr_stack + 271;
 target_ptr = Libr12->gvrr_classes[0][6];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+21, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+24, r12vrr_stack+0, r12vrr_stack+21, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+30, r12vrr_stack+6, r12vrr_stack+24, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+299, r12vrr_stack+141, r12vrr_stack+30, r12vrr_stack+65, r12vrr_stack+6, NULL);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+314, r12vrr_stack+151, r12vrr_stack+299, r12vrr_stack+71, r12vrr_stack+141, NULL);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+335, r12vrr_stack+166, r12vrr_stack+314, r12vrr_stack+81, r12vrr_stack+151, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+363, r12vrr_stack+271, r12vrr_stack+335, NULL, NULL, r12vrr_stack+166);
 tmp = r12vrr_stack + 363;
 target_ptr = Libr12->gvrr_classes[1][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+447, r12vrr_stack+271, r12vrr_stack+335, r12vrr_stack+187, r12vrr_stack+166, NULL);
 tmp = r12vrr_stack + 447;
 target_ptr = Libr12->gvrr_classes[0][7];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+65, r12vrr_stack+21, r12vrr_stack+3, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+71, r12vrr_stack+24, r12vrr_stack+65, r12vrr_stack+0, r12vrr_stack+21, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+81, r12vrr_stack+30, r12vrr_stack+71, r12vrr_stack+6, r12vrr_stack+24, NULL);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+483, r12vrr_stack+299, r12vrr_stack+81, r12vrr_stack+141, r12vrr_stack+30, NULL);

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+504, r12vrr_stack+314, r12vrr_stack+483, r12vrr_stack+151, r12vrr_stack+299, NULL);

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+532, r12vrr_stack+335, r12vrr_stack+504, r12vrr_stack+166, r12vrr_stack+314, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+568, r12vrr_stack+447, r12vrr_stack+532, NULL, NULL, r12vrr_stack+335);
 tmp = r12vrr_stack + 568;
 target_ptr = Libr12->gvrr_classes[1][7];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|l0)^0 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+141, r12vrr_stack+447, r12vrr_stack+532, r12vrr_stack+271, r12vrr_stack+335, NULL);
 tmp = r12vrr_stack + 141;
 target_ptr = Libr12->gvrr_classes[0][8];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+676, r12vrr_stack+65, r12vrr_stack+6, r12vrr_stack+21, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+686, r12vrr_stack+71, r12vrr_stack+676, r12vrr_stack+24, r12vrr_stack+65, NULL);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+701, r12vrr_stack+81, r12vrr_stack+686, r12vrr_stack+30, r12vrr_stack+71, NULL);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+722, r12vrr_stack+483, r12vrr_stack+701, r12vrr_stack+299, r12vrr_stack+81, NULL);

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+750, r12vrr_stack+504, r12vrr_stack+722, r12vrr_stack+314, r12vrr_stack+483, NULL);

 /*--- compute (00|l0)^1 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+786, r12vrr_stack+532, r12vrr_stack+750, r12vrr_stack+335, r12vrr_stack+504, NULL);

 /*--- compute (p0|l0)^0 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+831, r12vrr_stack+141, r12vrr_stack+786, NULL, NULL, r12vrr_stack+532);
 tmp = r12vrr_stack + 831;
 target_ptr = Libr12->gvrr_classes[1][8];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+299, r12vrr_stack+141, r12vrr_stack+786, r12vrr_stack+447, r12vrr_stack+532, NULL);
 tmp = r12vrr_stack + 299;
 target_ptr = Libr12->gvrr_classes[0][9];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+354, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+357, r12vrr_stack+0, r12vrr_stack+354, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+21, r12vrr_stack+6, r12vrr_stack+357, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+966, r12vrr_stack+676, r12vrr_stack+21, r12vrr_stack+65, r12vrr_stack+6, NULL);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+981, r12vrr_stack+686, r12vrr_stack+966, r12vrr_stack+71, r12vrr_stack+676, NULL);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1002, r12vrr_stack+701, r12vrr_stack+981, r12vrr_stack+81, r12vrr_stack+686, NULL);

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1030, r12vrr_stack+722, r12vrr_stack+1002, r12vrr_stack+483, r12vrr_stack+701, NULL);

 /*--- compute (00|l0)^2 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1066, r12vrr_stack+750, r12vrr_stack+1030, r12vrr_stack+504, r12vrr_stack+722, NULL);

 /*--- compute (00|m0)^1 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+1111, r12vrr_stack+786, r12vrr_stack+1066, r12vrr_stack+532, r12vrr_stack+750, NULL);

 /*--- compute (p0|m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+1166, r12vrr_stack+299, r12vrr_stack+1111, NULL, NULL, r12vrr_stack+786);
 tmp = r12vrr_stack + 1166;
 target_ptr = Libr12->gvrr_classes[1][9];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|n0)^0 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+483, r12vrr_stack+299, r12vrr_stack+1111, r12vrr_stack+141, r12vrr_stack+786, NULL);
 tmp = r12vrr_stack + 483;
 target_ptr = Libr12->gvrr_classes[0][10];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+549, r12vrr_stack+354, r12vrr_stack+3, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+555, r12vrr_stack+357, r12vrr_stack+549, r12vrr_stack+0, r12vrr_stack+354, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+65, r12vrr_stack+21, r12vrr_stack+555, r12vrr_stack+6, r12vrr_stack+357, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1331, r12vrr_stack+966, r12vrr_stack+65, r12vrr_stack+676, r12vrr_stack+21, NULL);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+65, r12vrr_stack+981, r12vrr_stack+1331, r12vrr_stack+686, r12vrr_stack+966, NULL);

 /*--- compute (00|k0)^4 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1331, r12vrr_stack+1002, r12vrr_stack+65, r12vrr_stack+701, r12vrr_stack+981, NULL);

 /*--- compute (00|l0)^3 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1367, r12vrr_stack+1030, r12vrr_stack+1331, r12vrr_stack+722, r12vrr_stack+1002, NULL);

 /*--- compute (00|m0)^2 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+966, r12vrr_stack+1066, r12vrr_stack+1367, r12vrr_stack+750, r12vrr_stack+1030, NULL);

 /*--- compute (00|n0)^1 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+1331, r12vrr_stack+1111, r12vrr_stack+966, r12vrr_stack+786, r12vrr_stack+1066, NULL);

 /*--- compute (p0|n0)^0 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+1397, r12vrr_stack+483, r12vrr_stack+1331, NULL, NULL, r12vrr_stack+1111);

 /*--- compute (00|o0)^0 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+966, r12vrr_stack+483, r12vrr_stack+1331, r12vrr_stack+299, r12vrr_stack+1111, NULL);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+1331, &(Data->ss_r12_ss), NULL, r12vrr_stack+12, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+1334, r12vrr_stack+1331, &(Data->ss_r12_ss), r12vrr_stack+15, r12vrr_stack+12, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+1340, r12vrr_stack+1334, r12vrr_stack+1331, r12vrr_stack+40, r12vrr_stack+15, r12vrr_stack+12, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+0, r12vrr_stack+1340, r12vrr_stack+1334, r12vrr_stack+50, r12vrr_stack+40, r12vrr_stack+15, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+15, r12vrr_stack+0, r12vrr_stack+1340, r12vrr_stack+187, r12vrr_stack+50, r12vrr_stack+40, NULL);
 tmp = r12vrr_stack + 15;
 target_ptr = Libr12->rvrr_classes[0][5];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+1331, r12vrr_stack+15, r12vrr_stack+0, r12vrr_stack+271, r12vrr_stack+187, r12vrr_stack+50, NULL);
 tmp = r12vrr_stack + 1331;
 target_ptr = Libr12->rvrr_classes[0][6];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||k0)^0 ---*/
 _R_BUILD_00k0(Data,r12vrr_stack+1359, r12vrr_stack+1331, r12vrr_stack+15, r12vrr_stack+447, r12vrr_stack+271, r12vrr_stack+187, NULL);
 tmp = r12vrr_stack + 1359;
 target_ptr = Libr12->rvrr_classes[0][7];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||l0)^0 ---*/
 _R_BUILD_00l0(Data,r12vrr_stack+0, r12vrr_stack+1359, r12vrr_stack+1331, r12vrr_stack+141, r12vrr_stack+447, r12vrr_stack+271, NULL);
 tmp = r12vrr_stack + 0;
 target_ptr = Libr12->rvrr_classes[0][8];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+1044, r12vrr_stack+0, r12vrr_stack+1359, r12vrr_stack+299, r12vrr_stack+141, r12vrr_stack+447, NULL);
 tmp = r12vrr_stack + 1044;
 target_ptr = Libr12->rvrr_classes[0][9];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_00h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1331, r12vrr_stack+187, r12vrr_stack+271, r12vrr_stack+208, r12vrr_stack+96, r12vrr_stack+50);
 tmp = r12vrr_stack + 1331;
 target_ptr = Libr12->t2vrr_classes[0][5];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_00i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1352, r12vrr_stack+271, r12vrr_stack+447, r12vrr_stack+363, r12vrr_stack+208, r12vrr_stack+187);
 tmp = r12vrr_stack + 1352;
 target_ptr = Libr12->t2vrr_classes[0][6];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_00k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+45, r12vrr_stack+447, r12vrr_stack+141, r12vrr_stack+568, r12vrr_stack+363, r12vrr_stack+271);
 tmp = r12vrr_stack + 45;
 target_ptr = Libr12->t2vrr_classes[0][7];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_00l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+81, r12vrr_stack+141, r12vrr_stack+299, r12vrr_stack+831, r12vrr_stack+568, r12vrr_stack+447);
 tmp = r12vrr_stack + 81;
 target_ptr = Libr12->t2vrr_classes[0][8];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|[r12,T2]|m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+1099, r12vrr_stack+299, r12vrr_stack+483, r12vrr_stack+1166, r12vrr_stack+831, r12vrr_stack+141);
 tmp = r12vrr_stack + 1099;
 target_ptr = Libr12->t2vrr_classes[0][9];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|[r12,T2]|n0)^0 ---*/
 am[0] = 0;  am[1] = 10;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+1595, r12vrr_stack+483, r12vrr_stack+966, r12vrr_stack+1397, r12vrr_stack+1166, r12vrr_stack+299);
 tmp = r12vrr_stack + 1595;
 target_ptr = Libr12->t2vrr_classes[0][10];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_00h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1661, r12vrr_stack+187, r12vrr_stack+208, r12vrr_stack+271, NULL, NULL);
 tmp = r12vrr_stack + 1661;
 target_ptr = Libr12->t1vrr_classes[0][5];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_00i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1682, r12vrr_stack+271, r12vrr_stack+363, r12vrr_stack+447, NULL, NULL);
 tmp = r12vrr_stack + 1682;
 target_ptr = Libr12->t1vrr_classes[0][6];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_00k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1710, r12vrr_stack+447, r12vrr_stack+568, r12vrr_stack+141, NULL, NULL);
 tmp = r12vrr_stack + 1710;
 target_ptr = Libr12->t1vrr_classes[0][7];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_00l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1746, r12vrr_stack+141, r12vrr_stack+831, r12vrr_stack+299, NULL, NULL);
 tmp = r12vrr_stack + 1746;
 target_ptr = Libr12->t1vrr_classes[0][8];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|[r12,T1]|m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+1791, r12vrr_stack+299, r12vrr_stack+1166, r12vrr_stack+483, NULL, NULL);
 tmp = r12vrr_stack + 1791;
 target_ptr = Libr12->t1vrr_classes[0][9];
 for(i=0;i<55;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|[r12,T1]|n0)^0 ---*/
 am[0] = 0;  am[1] = 10;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+1154, r12vrr_stack+483, r12vrr_stack+1397, r12vrr_stack+966, NULL, NULL);
 tmp = r12vrr_stack + 1154;
 target_ptr = Libr12->t1vrr_classes[0][10];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||n0)^0 ---*/
 am[0] = 0;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+1380, r12vrr_stack+1044, r12vrr_stack+0, r12vrr_stack+483, r12vrr_stack+299, r12vrr_stack+141, NULL);
 tmp = r12vrr_stack + 1380;
 target_ptr = Libr12->rvrr_classes[0][10];
 for(i=0;i<66;i++)
   target_ptr[i] += tmp[i];


}

