/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_gdhh(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0, NULL, NULL, Data->F+4);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+3, r12vrr_stack+0, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+21, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+24, r12vrr_stack+21, r12vrr_stack+3, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+30, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+33, r12vrr_stack+0, r12vrr_stack+30, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+39, r12vrr_stack+15, r12vrr_stack+33, NULL, NULL, r12vrr_stack+0);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+57, r12vrr_stack+24, r12vrr_stack+15, NULL, NULL, r12vrr_stack+3);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+75, r12vrr_stack+57, r12vrr_stack+39, r12vrr_stack+24, r12vrr_stack+15, r12vrr_stack+6);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+111, r12vrr_stack+15, r12vrr_stack+33, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+121, r12vrr_stack+24, r12vrr_stack+15, r12vrr_stack+21, r12vrr_stack+3, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+131, r12vrr_stack+121, r12vrr_stack+111, NULL, NULL, r12vrr_stack+15);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+161, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+164, r12vrr_stack+161, r12vrr_stack+21, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+170, r12vrr_stack+164, r12vrr_stack+24, r12vrr_stack+161, r12vrr_stack+21, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+180, r12vrr_stack+170, r12vrr_stack+121, NULL, NULL, r12vrr_stack+24);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+21, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+210, r12vrr_stack+30, r12vrr_stack+21, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+216, r12vrr_stack+33, r12vrr_stack+210, r12vrr_stack+0, r12vrr_stack+30, NULL);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+226, r12vrr_stack+111, r12vrr_stack+216, NULL, NULL, r12vrr_stack+33);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+256, r12vrr_stack+131, r12vrr_stack+226, r12vrr_stack+121, r12vrr_stack+111, r12vrr_stack+39);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+316, r12vrr_stack+180, r12vrr_stack+131, r12vrr_stack+170, r12vrr_stack+121, r12vrr_stack+57);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+376, r12vrr_stack+316, r12vrr_stack+256, r12vrr_stack+180, r12vrr_stack+131, r12vrr_stack+75);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+476, r12vrr_stack+121, r12vrr_stack+111, r12vrr_stack+24, r12vrr_stack+15, NULL);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+491, r12vrr_stack+170, r12vrr_stack+121, r12vrr_stack+164, r12vrr_stack+24, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+506, r12vrr_stack+111, r12vrr_stack+216, r12vrr_stack+15, r12vrr_stack+33, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+521, r12vrr_stack+476, r12vrr_stack+506, NULL, NULL, r12vrr_stack+111);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+566, r12vrr_stack+491, r12vrr_stack+476, NULL, NULL, r12vrr_stack+121);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+611, r12vrr_stack+566, r12vrr_stack+521, r12vrr_stack+491, r12vrr_stack+476, r12vrr_stack+131);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+24, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+701, r12vrr_stack+24, r12vrr_stack+161, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+707, r12vrr_stack+701, r12vrr_stack+164, r12vrr_stack+24, r12vrr_stack+161, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+717, r12vrr_stack+707, r12vrr_stack+170, r12vrr_stack+701, r12vrr_stack+164, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+732, r12vrr_stack+717, r12vrr_stack+491, NULL, NULL, r12vrr_stack+170);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+777, r12vrr_stack+732, r12vrr_stack+566, r12vrr_stack+717, r12vrr_stack+491, r12vrr_stack+180);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+27, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+180, r12vrr_stack+21, r12vrr_stack+27, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+186, r12vrr_stack+210, r12vrr_stack+180, r12vrr_stack+30, r12vrr_stack+21, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+867, r12vrr_stack+216, r12vrr_stack+186, r12vrr_stack+33, r12vrr_stack+210, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+882, r12vrr_stack+506, r12vrr_stack+867, NULL, NULL, r12vrr_stack+216);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+927, r12vrr_stack+521, r12vrr_stack+882, r12vrr_stack+476, r12vrr_stack+506, r12vrr_stack+226);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1017, r12vrr_stack+611, r12vrr_stack+927, r12vrr_stack+566, r12vrr_stack+521, r12vrr_stack+256);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1167, r12vrr_stack+777, r12vrr_stack+611, r12vrr_stack+732, r12vrr_stack+566, r12vrr_stack+316);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+1317, r12vrr_stack+1167, r12vrr_stack+1017, r12vrr_stack+777, r12vrr_stack+611, r12vrr_stack+376);

 /*--- compute (p0|00)^4 ---*/
 _BUILD_p000(Data,r12vrr_stack+196, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (p0|p0)^4 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+161, r12vrr_stack+0, r12vrr_stack+30, NULL, NULL, Data->F+5);

 /*--- compute (d0|p0)^3 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+1542, r12vrr_stack+6, r12vrr_stack+161, r12vrr_stack+3, r12vrr_stack+0, r12vrr_stack+196);

 /*--- compute (p0|d0)^4 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+1560, r12vrr_stack+33, r12vrr_stack+210, NULL, NULL, r12vrr_stack+30);

 /*--- compute (d0|d0)^3 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+1578, r12vrr_stack+39, r12vrr_stack+1560, r12vrr_stack+15, r12vrr_stack+33, r12vrr_stack+161);

 /*--- compute (f0|d0)^2 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+1614, r12vrr_stack+75, r12vrr_stack+1578, r12vrr_stack+57, r12vrr_stack+39, r12vrr_stack+1542);

 /*--- compute (p0|f0)^4 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+1674, r12vrr_stack+216, r12vrr_stack+186, NULL, NULL, r12vrr_stack+210);

 /*--- compute (d0|f0)^3 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+1704, r12vrr_stack+226, r12vrr_stack+1674, r12vrr_stack+111, r12vrr_stack+216, r12vrr_stack+1560);

 /*--- compute (f0|f0)^2 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+1764, r12vrr_stack+256, r12vrr_stack+1704, r12vrr_stack+131, r12vrr_stack+226, r12vrr_stack+1578);

 /*--- compute (g0|f0)^1 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+1864, r12vrr_stack+376, r12vrr_stack+1764, r12vrr_stack+316, r12vrr_stack+256, r12vrr_stack+1614);

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+27, r12vrr_stack+3, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+316, r12vrr_stack+180, r12vrr_stack+15, r12vrr_stack+21, r12vrr_stack+27, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+326, r12vrr_stack+186, r12vrr_stack+316, r12vrr_stack+210, r12vrr_stack+180, NULL);

 /*--- compute (p0|g0)^4 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+2014, r12vrr_stack+867, r12vrr_stack+326, NULL, NULL, r12vrr_stack+186);

 /*--- compute (d0|g0)^3 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+2059, r12vrr_stack+882, r12vrr_stack+2014, r12vrr_stack+506, r12vrr_stack+867, r12vrr_stack+1674);

 /*--- compute (f0|g0)^2 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+2149, r12vrr_stack+927, r12vrr_stack+2059, r12vrr_stack+521, r12vrr_stack+882, r12vrr_stack+1704);

 /*--- compute (g0|g0)^1 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2299, r12vrr_stack+1017, r12vrr_stack+2149, r12vrr_stack+611, r12vrr_stack+927, r12vrr_stack+1764);

 /*--- compute (h0|g0)^0 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+2524, r12vrr_stack+1317, r12vrr_stack+2299, r12vrr_stack+1167, r12vrr_stack+1017, r12vrr_stack+1864);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+341, r12vrr_stack+506, r12vrr_stack+867, r12vrr_stack+111, r12vrr_stack+216, NULL);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+131, r12vrr_stack+476, r12vrr_stack+506, r12vrr_stack+121, r12vrr_stack+111, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2839, r12vrr_stack+131, r12vrr_stack+341, NULL, NULL, r12vrr_stack+506);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2902, r12vrr_stack+491, r12vrr_stack+476, r12vrr_stack+170, r12vrr_stack+121, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2923, r12vrr_stack+2902, r12vrr_stack+131, NULL, NULL, r12vrr_stack+476);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2986, r12vrr_stack+867, r12vrr_stack+326, r12vrr_stack+216, r12vrr_stack+186, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+3007, r12vrr_stack+341, r12vrr_stack+2986, NULL, NULL, r12vrr_stack+867);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3070, r12vrr_stack+2839, r12vrr_stack+3007, r12vrr_stack+131, r12vrr_stack+341, r12vrr_stack+882);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3196, r12vrr_stack+2923, r12vrr_stack+2839, r12vrr_stack+2902, r12vrr_stack+131, r12vrr_stack+521);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+3322, r12vrr_stack+3196, r12vrr_stack+3070, r12vrr_stack+2923, r12vrr_stack+2839, r12vrr_stack+927);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+521, r12vrr_stack+717, r12vrr_stack+491, r12vrr_stack+707, r12vrr_stack+170, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+3532, r12vrr_stack+521, r12vrr_stack+2902, NULL, NULL, r12vrr_stack+491);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3595, r12vrr_stack+3532, r12vrr_stack+2923, r12vrr_stack+521, r12vrr_stack+2902, r12vrr_stack+566);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+3721, r12vrr_stack+3595, r12vrr_stack+3196, r12vrr_stack+3532, r12vrr_stack+2923, r12vrr_stack+611);

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+170, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+173, r12vrr_stack+3, r12vrr_stack+170, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+542, r12vrr_stack+15, r12vrr_stack+173, r12vrr_stack+27, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+552, r12vrr_stack+316, r12vrr_stack+542, r12vrr_stack+180, r12vrr_stack+15, NULL);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+567, r12vrr_stack+326, r12vrr_stack+552, r12vrr_stack+186, r12vrr_stack+316, NULL);

 /*--- compute (p0|h0)^4 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+588, r12vrr_stack+2986, r12vrr_stack+567, NULL, NULL, r12vrr_stack+326);

 /*--- compute (d0|h0)^3 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3931, r12vrr_stack+3007, r12vrr_stack+588, r12vrr_stack+341, r12vrr_stack+2986, r12vrr_stack+2014);

 /*--- compute (f0|h0)^2 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+4057, r12vrr_stack+3070, r12vrr_stack+3931, r12vrr_stack+2839, r12vrr_stack+3007, r12vrr_stack+2059);

 /*--- compute (g0|h0)^1 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+4267, r12vrr_stack+3322, r12vrr_stack+4057, r12vrr_stack+3196, r12vrr_stack+3070, r12vrr_stack+2149);

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+4582, r12vrr_stack+3721, r12vrr_stack+3322, r12vrr_stack+3595, r12vrr_stack+3196, r12vrr_stack+1017);
 tmp = r12vrr_stack + 4582;
 target_ptr = Libr12->gvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|h0)^0 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+4897, r12vrr_stack+4582, r12vrr_stack+4267, r12vrr_stack+3721, r12vrr_stack+3322, r12vrr_stack+2299);
 tmp = r12vrr_stack + 4897;
 target_ptr = Libr12->gvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+651, r12vrr_stack+131, r12vrr_stack+341, r12vrr_stack+476, r12vrr_stack+506, NULL);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5338, r12vrr_stack+2902, r12vrr_stack+131, r12vrr_stack+491, r12vrr_stack+476, NULL);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5366, r12vrr_stack+341, r12vrr_stack+2986, r12vrr_stack+506, r12vrr_stack+867, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5394, r12vrr_stack+651, r12vrr_stack+5366, NULL, NULL, r12vrr_stack+341);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5478, r12vrr_stack+5338, r12vrr_stack+651, NULL, NULL, r12vrr_stack+131);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+5562, r12vrr_stack+5478, r12vrr_stack+5394, r12vrr_stack+5338, r12vrr_stack+651, r12vrr_stack+2839);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2839, r12vrr_stack+521, r12vrr_stack+2902, r12vrr_stack+717, r12vrr_stack+491, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5730, r12vrr_stack+2839, r12vrr_stack+5338, NULL, NULL, r12vrr_stack+2902);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+5814, r12vrr_stack+5730, r12vrr_stack+5478, r12vrr_stack+2839, r12vrr_stack+5338, r12vrr_stack+2923);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2923, r12vrr_stack+2986, r12vrr_stack+567, r12vrr_stack+867, r12vrr_stack+326, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5982, r12vrr_stack+5366, r12vrr_stack+2923, NULL, NULL, r12vrr_stack+2986);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+6066, r12vrr_stack+5394, r12vrr_stack+5982, r12vrr_stack+651, r12vrr_stack+5366, r12vrr_stack+3007);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+6234, r12vrr_stack+5562, r12vrr_stack+6066, r12vrr_stack+5478, r12vrr_stack+5394, r12vrr_stack+3070);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+6514, r12vrr_stack+5814, r12vrr_stack+5562, r12vrr_stack+5730, r12vrr_stack+5478, r12vrr_stack+3196);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+6794, r12vrr_stack+6514, r12vrr_stack+6234, r12vrr_stack+5814, r12vrr_stack+5562, r12vrr_stack+3322);
 tmp = r12vrr_stack + 6794;
 target_ptr = Libr12->gvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3196, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+3199, r12vrr_stack+170, r12vrr_stack+3196, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+3205, r12vrr_stack+173, r12vrr_stack+3199, r12vrr_stack+3, r12vrr_stack+170, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+3215, r12vrr_stack+542, r12vrr_stack+3205, r12vrr_stack+15, r12vrr_stack+173, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+3230, r12vrr_stack+552, r12vrr_stack+3215, r12vrr_stack+316, r12vrr_stack+542, NULL);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3251, r12vrr_stack+567, r12vrr_stack+3230, r12vrr_stack+326, r12vrr_stack+552, NULL);

 /*--- compute (p0|i0)^4 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+7214, r12vrr_stack+2923, r12vrr_stack+3251, NULL, NULL, r12vrr_stack+567);

 /*--- compute (d0|i0)^3 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+7298, r12vrr_stack+5982, r12vrr_stack+7214, r12vrr_stack+5366, r12vrr_stack+2923, r12vrr_stack+588);

 /*--- compute (f0|i0)^2 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+7466, r12vrr_stack+6066, r12vrr_stack+7298, r12vrr_stack+5394, r12vrr_stack+5982, r12vrr_stack+3931);

 /*--- compute (g0|i0)^1 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+7746, r12vrr_stack+6234, r12vrr_stack+7466, r12vrr_stack+5562, r12vrr_stack+6066, r12vrr_stack+4057);

 /*--- compute (h0|i0)^0 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+8166, r12vrr_stack+6794, r12vrr_stack+7746, r12vrr_stack+6514, r12vrr_stack+6234, r12vrr_stack+4267);
 tmp = r12vrr_stack + 8166;
 target_ptr = Libr12->gvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3279, r12vrr_stack+651, r12vrr_stack+5366, r12vrr_stack+131, r12vrr_stack+341, NULL);

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+476, r12vrr_stack+5338, r12vrr_stack+651, r12vrr_stack+2902, r12vrr_stack+131, NULL);

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+111, r12vrr_stack+5366, r12vrr_stack+2923, r12vrr_stack+341, r12vrr_stack+2986, NULL);

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8754, r12vrr_stack+3279, r12vrr_stack+111, NULL, NULL, r12vrr_stack+5366);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8862, r12vrr_stack+476, r12vrr_stack+3279, NULL, NULL, r12vrr_stack+651);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8970, r12vrr_stack+8862, r12vrr_stack+8754, r12vrr_stack+476, r12vrr_stack+3279, r12vrr_stack+5394);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5394, r12vrr_stack+2839, r12vrr_stack+5338, r12vrr_stack+521, r12vrr_stack+2902, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9186, r12vrr_stack+5394, r12vrr_stack+476, NULL, NULL, r12vrr_stack+5338);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9294, r12vrr_stack+9186, r12vrr_stack+8862, r12vrr_stack+5394, r12vrr_stack+476, r12vrr_stack+5478);

 /*--- compute (00|k0)^4 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5430, r12vrr_stack+2923, r12vrr_stack+3251, r12vrr_stack+2986, r12vrr_stack+567, NULL);

 /*--- compute (p0|k0)^3 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9510, r12vrr_stack+111, r12vrr_stack+5430, NULL, NULL, r12vrr_stack+2923);

 /*--- compute (d0|k0)^2 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9618, r12vrr_stack+8754, r12vrr_stack+9510, r12vrr_stack+3279, r12vrr_stack+111, r12vrr_stack+5982);

 /*--- compute (f0|k0)^1 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9834, r12vrr_stack+8970, r12vrr_stack+9618, r12vrr_stack+8862, r12vrr_stack+8754, r12vrr_stack+6066);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10194, r12vrr_stack+9294, r12vrr_stack+8970, r12vrr_stack+9186, r12vrr_stack+8862, r12vrr_stack+5562);

 /*--- compute (g0|k0)^0 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10554, r12vrr_stack+10194, r12vrr_stack+9834, r12vrr_stack+9294, r12vrr_stack+8970, r12vrr_stack+6234);
 tmp = r12vrr_stack + 10554;
 target_ptr = Libr12->gvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^11 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /*--- compute (00|d0)^10 ---*/
 _BUILD_00d0(Data,r12vrr_stack+5466, r12vrr_stack+3196, r12vrr_stack+3, Data->F+10, Data->F+11, NULL);

 /*--- compute (00|f0)^9 ---*/
 _BUILD_00f0(Data,r12vrr_stack+5472, r12vrr_stack+3199, r12vrr_stack+5466, r12vrr_stack+170, r12vrr_stack+3196, NULL);

 /*--- compute (00|g0)^8 ---*/
 _BUILD_00g0(Data,r12vrr_stack+5482, r12vrr_stack+3205, r12vrr_stack+5472, r12vrr_stack+173, r12vrr_stack+3199, NULL);

 /*--- compute (00|h0)^7 ---*/
 _BUILD_00h0(Data,r12vrr_stack+5497, r12vrr_stack+3215, r12vrr_stack+5482, r12vrr_stack+542, r12vrr_stack+3205, NULL);

 /*--- compute (00|i0)^6 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5518, r12vrr_stack+3230, r12vrr_stack+5497, r12vrr_stack+552, r12vrr_stack+3215, NULL);

 /*--- compute (00|k0)^5 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5546, r12vrr_stack+3251, r12vrr_stack+5518, r12vrr_stack+567, r12vrr_stack+3230, NULL);

 /*--- compute (p0|k0)^4 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5582, r12vrr_stack+5430, r12vrr_stack+5546, NULL, NULL, r12vrr_stack+3251);

 /*--- compute (d0|k0)^3 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+11094, r12vrr_stack+9510, r12vrr_stack+5582, r12vrr_stack+111, r12vrr_stack+5430, r12vrr_stack+7214);

 /*--- compute (f0|k0)^2 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+11310, r12vrr_stack+9618, r12vrr_stack+11094, r12vrr_stack+8754, r12vrr_stack+9510, r12vrr_stack+7298);

 /*--- compute (g0|k0)^1 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+11670, r12vrr_stack+9834, r12vrr_stack+11310, r12vrr_stack+8970, r12vrr_stack+9618, r12vrr_stack+7466);

 /*--- compute (h0|k0)^0 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+12210, r12vrr_stack+10554, r12vrr_stack+11670, r12vrr_stack+10194, r12vrr_stack+9834, r12vrr_stack+7746);
 tmp = r12vrr_stack + 12210;
 target_ptr = Libr12->gvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|l0)^2 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+2867, r12vrr_stack+3279, r12vrr_stack+111, r12vrr_stack+651, r12vrr_stack+5366, NULL);

 /*--- compute (00|l0)^1 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+12966, r12vrr_stack+476, r12vrr_stack+3279, r12vrr_stack+5338, r12vrr_stack+651, NULL);

 /*--- compute (00|l0)^3 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+651, r12vrr_stack+111, r12vrr_stack+5430, r12vrr_stack+5366, r12vrr_stack+2923, NULL);

 /*--- compute (p0|l0)^2 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13011, r12vrr_stack+2867, r12vrr_stack+651, NULL, NULL, r12vrr_stack+111);

 /*--- compute (p0|l0)^1 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13146, r12vrr_stack+12966, r12vrr_stack+2867, NULL, NULL, r12vrr_stack+3279);

 /*--- compute (d0|l0)^1 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13281, r12vrr_stack+13146, r12vrr_stack+13011, r12vrr_stack+12966, r12vrr_stack+2867, r12vrr_stack+8754);

 /*--- compute (00|l0)^0 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+8754, r12vrr_stack+5394, r12vrr_stack+476, r12vrr_stack+2839, r12vrr_stack+5338, NULL);

 /*--- compute (p0|l0)^0 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13551, r12vrr_stack+8754, r12vrr_stack+12966, NULL, NULL, r12vrr_stack+476);

 /*--- compute (d0|l0)^0 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13686, r12vrr_stack+13551, r12vrr_stack+13146, r12vrr_stack+8754, r12vrr_stack+12966, r12vrr_stack+8862);

 /*--- compute (00|l0)^4 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13956, r12vrr_stack+5430, r12vrr_stack+5546, r12vrr_stack+2923, r12vrr_stack+3251, NULL);

 /*--- compute (p0|l0)^3 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+8799, r12vrr_stack+651, r12vrr_stack+13956, NULL, NULL, r12vrr_stack+5430);

 /*--- compute (d0|l0)^2 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14001, r12vrr_stack+13011, r12vrr_stack+8799, r12vrr_stack+2867, r12vrr_stack+651, r12vrr_stack+9510);

 /*--- compute (f0|l0)^1 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14271, r12vrr_stack+13281, r12vrr_stack+14001, r12vrr_stack+13146, r12vrr_stack+13011, r12vrr_stack+9618);

 /*--- compute (f0|l0)^0 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+14721, r12vrr_stack+13686, r12vrr_stack+13281, r12vrr_stack+13551, r12vrr_stack+13146, r12vrr_stack+8970);

 /*--- compute (g0|l0)^0 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+15171, r12vrr_stack+14721, r12vrr_stack+14271, r12vrr_stack+13686, r12vrr_stack+13281, r12vrr_stack+9834);
 tmp = r12vrr_stack + 15171;
 target_ptr = Libr12->gvrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^12 ---*/
 _BUILD_00p0(Data,r12vrr_stack+5338, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /*--- compute (00|d0)^11 ---*/
 _BUILD_00d0(Data,r12vrr_stack+5341, r12vrr_stack+3, r12vrr_stack+5338, Data->F+11, Data->F+12, NULL);

 /*--- compute (00|f0)^10 ---*/
 _BUILD_00f0(Data,r12vrr_stack+170, r12vrr_stack+5466, r12vrr_stack+5341, r12vrr_stack+3196, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^9 ---*/
 _BUILD_00g0(Data,r12vrr_stack+5347, r12vrr_stack+5472, r12vrr_stack+170, r12vrr_stack+3199, r12vrr_stack+5466, NULL);

 /*--- compute (00|h0)^8 ---*/
 _BUILD_00h0(Data,r12vrr_stack+5362, r12vrr_stack+5482, r12vrr_stack+5347, r12vrr_stack+3205, r12vrr_stack+5472, NULL);

 /*--- compute (00|i0)^7 ---*/
 _BUILD_00i0(Data,r12vrr_stack+8934, r12vrr_stack+5497, r12vrr_stack+5362, r12vrr_stack+3215, r12vrr_stack+5482, NULL);

 /*--- compute (00|k0)^6 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8962, r12vrr_stack+5518, r12vrr_stack+8934, r12vrr_stack+3230, r12vrr_stack+5497, NULL);

 /*--- compute (00|l0)^5 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+8998, r12vrr_stack+5546, r12vrr_stack+8962, r12vrr_stack+3251, r12vrr_stack+5518, NULL);

 /*--- compute (p0|l0)^4 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9043, r12vrr_stack+13956, r12vrr_stack+8998, NULL, NULL, r12vrr_stack+5546);

 /*--- compute (d0|l0)^3 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+15846, r12vrr_stack+8799, r12vrr_stack+9043, r12vrr_stack+651, r12vrr_stack+13956, r12vrr_stack+5582);

 /*--- compute (f0|l0)^2 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+16116, r12vrr_stack+14001, r12vrr_stack+15846, r12vrr_stack+13011, r12vrr_stack+8799, r12vrr_stack+11094);

 /*--- compute (g0|l0)^1 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+16566, r12vrr_stack+14271, r12vrr_stack+16116, r12vrr_stack+13281, r12vrr_stack+14001, r12vrr_stack+11310);

 /*--- compute (h0|l0)^0 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+17241, r12vrr_stack+15171, r12vrr_stack+16566, r12vrr_stack+14721, r12vrr_stack+14271, r12vrr_stack+11670);
 tmp = r12vrr_stack + 17241;
 target_ptr = Libr12->gvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|m0)^2 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18186, r12vrr_stack+2867, r12vrr_stack+651, r12vrr_stack+3279, r12vrr_stack+111, NULL);

 /*--- compute (00|m0)^1 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18241, r12vrr_stack+12966, r12vrr_stack+2867, r12vrr_stack+476, r12vrr_stack+3279, NULL);

 /*--- compute (00|m0)^3 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18296, r12vrr_stack+651, r12vrr_stack+13956, r12vrr_stack+111, r12vrr_stack+5430, NULL);

 /*--- compute (p0|m0)^2 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18351, r12vrr_stack+18186, r12vrr_stack+18296, NULL, NULL, r12vrr_stack+651);

 /*--- compute (p0|m0)^1 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18516, r12vrr_stack+18241, r12vrr_stack+18186, NULL, NULL, r12vrr_stack+2867);

 /*--- compute (d0|m0)^1 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18681, r12vrr_stack+18516, r12vrr_stack+18351, r12vrr_stack+18241, r12vrr_stack+18186, r12vrr_stack+13011);

 /*--- compute (00|m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+13011, r12vrr_stack+8754, r12vrr_stack+12966, r12vrr_stack+5394, r12vrr_stack+476, NULL);

 /*--- compute (p0|m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+19011, r12vrr_stack+13011, r12vrr_stack+18241, NULL, NULL, r12vrr_stack+12966);

 /*--- compute (d0|m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+19176, r12vrr_stack+19011, r12vrr_stack+18516, r12vrr_stack+13011, r12vrr_stack+18241, r12vrr_stack+13146);

 /*--- compute (00|m0)^4 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+13066, r12vrr_stack+13956, r12vrr_stack+8998, r12vrr_stack+5430, r12vrr_stack+5546, NULL);

 /*--- compute (p0|m0)^3 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+19506, r12vrr_stack+18296, r12vrr_stack+13066, NULL, NULL, r12vrr_stack+13956);

 /*--- compute (d0|m0)^2 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+19671, r12vrr_stack+18351, r12vrr_stack+19506, r12vrr_stack+18186, r12vrr_stack+18296, r12vrr_stack+8799);

 /*--- compute (f0|m0)^1 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+20001, r12vrr_stack+18681, r12vrr_stack+19671, r12vrr_stack+18516, r12vrr_stack+18351, r12vrr_stack+14001);

 /*--- compute (f0|m0)^0 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+20551, r12vrr_stack+19176, r12vrr_stack+18681, r12vrr_stack+19011, r12vrr_stack+18516, r12vrr_stack+13281);

 /*--- compute (g0|m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21101, r12vrr_stack+20551, r12vrr_stack+20001, r12vrr_stack+19176, r12vrr_stack+18681, r12vrr_stack+14271);
 tmp = r12vrr_stack + 21101;
 target_ptr = Libr12->gvrr_classes[4][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^13 ---*/
 _BUILD_00p0(Data,r12vrr_stack+476, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /*--- compute (00|d0)^12 ---*/
 _BUILD_00d0(Data,r12vrr_stack+479, r12vrr_stack+5338, r12vrr_stack+476, Data->F+12, Data->F+13, NULL);

 /*--- compute (00|f0)^11 ---*/
 _BUILD_00f0(Data,r12vrr_stack+485, r12vrr_stack+5341, r12vrr_stack+479, r12vrr_stack+3, r12vrr_stack+5338, NULL);

 /*--- compute (00|g0)^10 ---*/
 _BUILD_00g0(Data,r12vrr_stack+495, r12vrr_stack+170, r12vrr_stack+485, r12vrr_stack+5466, r12vrr_stack+5341, NULL);

 /*--- compute (00|h0)^9 ---*/
 _BUILD_00h0(Data,r12vrr_stack+13121, r12vrr_stack+5347, r12vrr_stack+495, r12vrr_stack+5472, r12vrr_stack+170, NULL);

 /*--- compute (00|i0)^8 ---*/
 _BUILD_00i0(Data,r12vrr_stack+13142, r12vrr_stack+5362, r12vrr_stack+13121, r12vrr_stack+5482, r12vrr_stack+5347, NULL);

 /*--- compute (00|k0)^7 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+13170, r12vrr_stack+8934, r12vrr_stack+13142, r12vrr_stack+5497, r12vrr_stack+5362, NULL);

 /*--- compute (00|l0)^6 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13206, r12vrr_stack+8962, r12vrr_stack+13170, r12vrr_stack+5518, r12vrr_stack+8934, NULL);

 /*--- compute (00|m0)^5 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+13251, r12vrr_stack+8998, r12vrr_stack+13206, r12vrr_stack+5546, r12vrr_stack+8962, NULL);

 /*--- compute (p0|m0)^4 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+13306, r12vrr_stack+13066, r12vrr_stack+13251, NULL, NULL, r12vrr_stack+8998);

 /*--- compute (d0|m0)^3 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+21926, r12vrr_stack+19506, r12vrr_stack+13306, r12vrr_stack+18296, r12vrr_stack+13066, r12vrr_stack+9043);

 /*--- compute (f0|m0)^2 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+22256, r12vrr_stack+19671, r12vrr_stack+21926, r12vrr_stack+18351, r12vrr_stack+19506, r12vrr_stack+15846);

 /*--- compute (g0|m0)^1 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+22806, r12vrr_stack+20001, r12vrr_stack+22256, r12vrr_stack+18681, r12vrr_stack+19671, r12vrr_stack+16116);

 /*--- compute (h0|m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+23631, r12vrr_stack+21101, r12vrr_stack+22806, r12vrr_stack+20551, r12vrr_stack+20001, r12vrr_stack+16566);
 tmp = r12vrr_stack + 23631;
 target_ptr = Libr12->gvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|n0)^2 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+13471, r12vrr_stack+18186, r12vrr_stack+18296, r12vrr_stack+2867, r12vrr_stack+651, NULL);

 /*--- compute (00|n0)^1 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+24786, r12vrr_stack+18241, r12vrr_stack+18186, r12vrr_stack+12966, r12vrr_stack+2867, NULL);

 /*--- compute (00|n0)^3 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+24852, r12vrr_stack+18296, r12vrr_stack+13066, r12vrr_stack+651, r12vrr_stack+13956, NULL);

 /*--- compute (p0|n0)^2 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+24918, r12vrr_stack+13471, r12vrr_stack+24852, NULL, NULL, r12vrr_stack+18296);

 /*--- compute (p0|n0)^1 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+25116, r12vrr_stack+24786, r12vrr_stack+13471, NULL, NULL, r12vrr_stack+18186);

 /*--- compute (d0|n0)^1 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+25314, r12vrr_stack+25116, r12vrr_stack+24918, r12vrr_stack+24786, r12vrr_stack+13471, r12vrr_stack+18351);

 /*--- compute (00|n0)^0 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+18351, r12vrr_stack+13011, r12vrr_stack+18241, r12vrr_stack+8754, r12vrr_stack+12966, NULL);

 /*--- compute (p0|n0)^0 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+25710, r12vrr_stack+18351, r12vrr_stack+24786, NULL, NULL, r12vrr_stack+18241);

 /*--- compute (d0|n0)^0 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+25908, r12vrr_stack+25710, r12vrr_stack+25116, r12vrr_stack+18351, r12vrr_stack+24786, r12vrr_stack+18516);

 /*--- compute (00|n0)^4 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+18417, r12vrr_stack+13066, r12vrr_stack+13251, r12vrr_stack+13956, r12vrr_stack+8998, NULL);

 /*--- compute (p0|n0)^3 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+18483, r12vrr_stack+24852, r12vrr_stack+18417, NULL, NULL, r12vrr_stack+13066);

 /*--- compute (d0|n0)^2 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+26304, r12vrr_stack+24918, r12vrr_stack+18483, r12vrr_stack+13471, r12vrr_stack+24852, r12vrr_stack+19506);

 /*--- compute (f0|n0)^1 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+26700, r12vrr_stack+25314, r12vrr_stack+26304, r12vrr_stack+25116, r12vrr_stack+24918, r12vrr_stack+19671);

 /*--- compute (f0|n0)^0 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+27360, r12vrr_stack+25908, r12vrr_stack+25314, r12vrr_stack+25710, r12vrr_stack+25116, r12vrr_stack+18681);

 /*--- compute (g0|n0)^0 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+28020, r12vrr_stack+27360, r12vrr_stack+26700, r12vrr_stack+25908, r12vrr_stack+25314, r12vrr_stack+20001);
 tmp = r12vrr_stack + 28020;
 target_ptr = Libr12->gvrr_classes[4][10];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^14 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /*--- compute (00|d0)^13 ---*/
 _BUILD_00d0(Data,r12vrr_stack+18681, r12vrr_stack+476, r12vrr_stack+3, Data->F+13, Data->F+14, NULL);

 /*--- compute (00|f0)^12 ---*/
 _BUILD_00f0(Data,r12vrr_stack+18687, r12vrr_stack+479, r12vrr_stack+18681, r12vrr_stack+5338, r12vrr_stack+476, NULL);

 /*--- compute (00|g0)^11 ---*/
 _BUILD_00g0(Data,r12vrr_stack+18697, r12vrr_stack+485, r12vrr_stack+18687, r12vrr_stack+5341, r12vrr_stack+479, NULL);

 /*--- compute (00|h0)^10 ---*/
 _BUILD_00h0(Data,r12vrr_stack+18712, r12vrr_stack+495, r12vrr_stack+18697, r12vrr_stack+170, r12vrr_stack+485, NULL);

 /*--- compute (00|i0)^9 ---*/
 _BUILD_00i0(Data,r12vrr_stack+18733, r12vrr_stack+13121, r12vrr_stack+18712, r12vrr_stack+5347, r12vrr_stack+495, NULL);

 /*--- compute (00|k0)^8 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+18761, r12vrr_stack+13142, r12vrr_stack+18733, r12vrr_stack+5362, r12vrr_stack+13121, NULL);

 /*--- compute (00|l0)^7 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+12966, r12vrr_stack+13170, r12vrr_stack+18761, r12vrr_stack+8934, r12vrr_stack+13142, NULL);

 /*--- compute (00|m0)^6 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+5338, r12vrr_stack+13206, r12vrr_stack+12966, r12vrr_stack+8962, r12vrr_stack+13170, NULL);

 /*--- compute (00|n0)^5 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+18797, r12vrr_stack+13251, r12vrr_stack+5338, r12vrr_stack+8998, r12vrr_stack+13206, NULL);

 /*--- compute (p0|n0)^4 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+29010, r12vrr_stack+18417, r12vrr_stack+18797, NULL, NULL, r12vrr_stack+13251);

 /*--- compute (d0|n0)^3 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+29208, r12vrr_stack+18483, r12vrr_stack+29010, r12vrr_stack+24852, r12vrr_stack+18417, r12vrr_stack+13306);

 /*--- compute (f0|n0)^2 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+29604, r12vrr_stack+26304, r12vrr_stack+29208, r12vrr_stack+24918, r12vrr_stack+18483, r12vrr_stack+21926);

 /*--- compute (g0|n0)^1 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+30264, r12vrr_stack+26700, r12vrr_stack+29604, r12vrr_stack+25314, r12vrr_stack+26304, r12vrr_stack+22256);

 /*--- compute (h0|n0)^0 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+31254, r12vrr_stack+28020, r12vrr_stack+30264, r12vrr_stack+27360, r12vrr_stack+26700, r12vrr_stack+22806);
 tmp = r12vrr_stack + 31254;
 target_ptr = Libr12->gvrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|o0)^2 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+18863, r12vrr_stack+13471, r12vrr_stack+24852, r12vrr_stack+18186, r12vrr_stack+18296, NULL);

 /*--- compute (00|o0)^1 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+32640, r12vrr_stack+24786, r12vrr_stack+13471, r12vrr_stack+18241, r12vrr_stack+18186, NULL);

 /*--- compute (00|o0)^3 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+32718, r12vrr_stack+24852, r12vrr_stack+18417, r12vrr_stack+18296, r12vrr_stack+13066, NULL);

 /*--- compute (p0|o0)^2 ---*/
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+32796, r12vrr_stack+18863, r12vrr_stack+32718, NULL, NULL, r12vrr_stack+24852);

 /*--- compute (p0|o0)^1 ---*/
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+33030, r12vrr_stack+32640, r12vrr_stack+18863, NULL, NULL, r12vrr_stack+13471);

 /*--- compute (d0|o0)^1 ---*/
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+33264, r12vrr_stack+33030, r12vrr_stack+32796, r12vrr_stack+32640, r12vrr_stack+18863, r12vrr_stack+24918);

 /*--- compute (00|o0)^0 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+13471, r12vrr_stack+18351, r12vrr_stack+24786, r12vrr_stack+13011, r12vrr_stack+18241, NULL);

 /*--- compute (p0|o0)^0 ---*/
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+24852, r12vrr_stack+13471, r12vrr_stack+32640, NULL, NULL, r12vrr_stack+24786);

 /*--- compute (d0|o0)^0 ---*/
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+33732, r12vrr_stack+24852, r12vrr_stack+33030, r12vrr_stack+13471, r12vrr_stack+32640, r12vrr_stack+25116);

 /*--- compute (00|o0)^4 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+32640, r12vrr_stack+18417, r12vrr_stack+18797, r12vrr_stack+13066, r12vrr_stack+13251, NULL);

 /*--- compute (p0|o0)^3 ---*/
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+34200, r12vrr_stack+32718, r12vrr_stack+32640, NULL, NULL, r12vrr_stack+18417);

 /*--- compute (d0|o0)^2 ---*/
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+34434, r12vrr_stack+32796, r12vrr_stack+34200, r12vrr_stack+18863, r12vrr_stack+32718, r12vrr_stack+18483);

 /*--- compute (f0|o0)^1 ---*/
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+34902, r12vrr_stack+33264, r12vrr_stack+34434, r12vrr_stack+33030, r12vrr_stack+32796, r12vrr_stack+26304);

 /*--- compute (f0|o0)^0 ---*/
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+35682, r12vrr_stack+33732, r12vrr_stack+33264, r12vrr_stack+24852, r12vrr_stack+33030, r12vrr_stack+25314);

 /*--- compute (g0|o0)^0 ---*/
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+36462, r12vrr_stack+35682, r12vrr_stack+34902, r12vrr_stack+33732, r12vrr_stack+33264, r12vrr_stack+26700);
 tmp = r12vrr_stack + 36462;
 target_ptr = Libr12->gvrr_classes[4][11];
 for(i=0;i<1170;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^5 ---*/
 _BUILD_p000(Data,r12vrr_stack+33732, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (d0|00)^4 ---*/
 _BUILD_d000(Data,r12vrr_stack+33735, r12vrr_stack+196, r12vrr_stack+33732, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|p0)^5 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+33741, r12vrr_stack+30, r12vrr_stack+21, NULL, NULL, Data->F+6);

 /*--- compute (d0|p0)^4 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+57, r12vrr_stack+161, r12vrr_stack+33741, r12vrr_stack+0, r12vrr_stack+30, r12vrr_stack+33732);

 /*--- compute (f0|p0)^3 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+33750, r12vrr_stack+1542, r12vrr_stack+57, r12vrr_stack+6, r12vrr_stack+161, r12vrr_stack+33735);

 /*--- compute (p0|d0)^5 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+33780, r12vrr_stack+210, r12vrr_stack+180, NULL, NULL, r12vrr_stack+21);

 /*--- compute (d0|d0)^4 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+33798, r12vrr_stack+1560, r12vrr_stack+33780, r12vrr_stack+33, r12vrr_stack+210, r12vrr_stack+33741);

 /*--- compute (f0|d0)^3 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+33834, r12vrr_stack+1578, r12vrr_stack+33798, r12vrr_stack+39, r12vrr_stack+1560, r12vrr_stack+57);

 /*--- compute (g0|d0)^2 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+33894, r12vrr_stack+1614, r12vrr_stack+33834, r12vrr_stack+75, r12vrr_stack+1578, r12vrr_stack+33750);

 /*--- compute (p0|f0)^5 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+75, r12vrr_stack+186, r12vrr_stack+316, NULL, NULL, r12vrr_stack+180);

 /*--- compute (d0|f0)^4 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+33984, r12vrr_stack+1674, r12vrr_stack+75, r12vrr_stack+216, r12vrr_stack+186, r12vrr_stack+33780);

 /*--- compute (f0|f0)^3 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+34044, r12vrr_stack+1704, r12vrr_stack+33984, r12vrr_stack+226, r12vrr_stack+1674, r12vrr_stack+33798);

 /*--- compute (g0|f0)^2 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+33030, r12vrr_stack+1764, r12vrr_stack+34044, r12vrr_stack+256, r12vrr_stack+1704, r12vrr_stack+33834);

 /*--- compute (h0|f0)^1 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+24786, r12vrr_stack+1864, r12vrr_stack+33030, r12vrr_stack+376, r12vrr_stack+1764, r12vrr_stack+33894);

 /*--- compute (p0|g0)^5 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+216, r12vrr_stack+326, r12vrr_stack+552, NULL, NULL, r12vrr_stack+316);

 /*--- compute (d0|g0)^4 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+18863, r12vrr_stack+2014, r12vrr_stack+216, r12vrr_stack+867, r12vrr_stack+326, r12vrr_stack+75);

 /*--- compute (f0|g0)^3 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+24996, r12vrr_stack+2059, r12vrr_stack+18863, r12vrr_stack+882, r12vrr_stack+2014, r12vrr_stack+33984);

 /*--- compute (g0|g0)^2 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+25146, r12vrr_stack+2149, r12vrr_stack+24996, r12vrr_stack+927, r12vrr_stack+2059, r12vrr_stack+34044);

 /*--- compute (h0|g0)^1 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+25371, r12vrr_stack+2299, r12vrr_stack+25146, r12vrr_stack+1017, r12vrr_stack+2149, r12vrr_stack+33030);

 /*--- compute (i0|g0)^0 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+37632, r12vrr_stack+2524, r12vrr_stack+25371, r12vrr_stack+1317, r12vrr_stack+2299, r12vrr_stack+24786);

 /*--- compute (p0|h0)^5 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+867, r12vrr_stack+567, r12vrr_stack+3230, NULL, NULL, r12vrr_stack+552);

 /*--- compute (d0|h0)^4 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+930, r12vrr_stack+588, r12vrr_stack+867, r12vrr_stack+2986, r12vrr_stack+567, r12vrr_stack+216);

 /*--- compute (f0|h0)^3 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+38052, r12vrr_stack+3931, r12vrr_stack+930, r12vrr_stack+3007, r12vrr_stack+588, r12vrr_stack+18863);

 /*--- compute (g0|h0)^2 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+38262, r12vrr_stack+4057, r12vrr_stack+38052, r12vrr_stack+3070, r12vrr_stack+3931, r12vrr_stack+24996);

 /*--- compute (h0|h0)^1 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+38577, r12vrr_stack+4267, r12vrr_stack+38262, r12vrr_stack+3322, r12vrr_stack+4057, r12vrr_stack+25146);

 /*--- compute (i0|h0)^0 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+39018, r12vrr_stack+4897, r12vrr_stack+38577, r12vrr_stack+4582, r12vrr_stack+4267, r12vrr_stack+25371);
 tmp = r12vrr_stack + 39018;
 target_ptr = Libr12->gvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^5 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+33180, r12vrr_stack+3251, r12vrr_stack+5518, NULL, NULL, r12vrr_stack+3230);

 /*--- compute (d0|i0)^4 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+3279, r12vrr_stack+7214, r12vrr_stack+33180, r12vrr_stack+2923, r12vrr_stack+3251, r12vrr_stack+867);

 /*--- compute (f0|i0)^3 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+2867, r12vrr_stack+7298, r12vrr_stack+3279, r12vrr_stack+5982, r12vrr_stack+7214, r12vrr_stack+930);

 /*--- compute (g0|i0)^2 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+39606, r12vrr_stack+7466, r12vrr_stack+2867, r12vrr_stack+6066, r12vrr_stack+7298, r12vrr_stack+38052);

 /*--- compute (h0|i0)^1 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+40026, r12vrr_stack+7746, r12vrr_stack+39606, r12vrr_stack+6234, r12vrr_stack+7466, r12vrr_stack+38262);

 /*--- compute (i0|i0)^0 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+40614, r12vrr_stack+8166, r12vrr_stack+40026, r12vrr_stack+6794, r12vrr_stack+7746, r12vrr_stack+38577);
 tmp = r12vrr_stack + 40614;
 target_ptr = Libr12->gvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^5 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5982, r12vrr_stack+5546, r12vrr_stack+8962, NULL, NULL, r12vrr_stack+5518);

 /*--- compute (d0|k0)^4 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6090, r12vrr_stack+5582, r12vrr_stack+5982, r12vrr_stack+5430, r12vrr_stack+5546, r12vrr_stack+33180);

 /*--- compute (f0|k0)^3 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+41398, r12vrr_stack+11094, r12vrr_stack+6090, r12vrr_stack+9510, r12vrr_stack+5582, r12vrr_stack+3279);

 /*--- compute (g0|k0)^2 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+41758, r12vrr_stack+11310, r12vrr_stack+41398, r12vrr_stack+9618, r12vrr_stack+11094, r12vrr_stack+2867);

 /*--- compute (h0|k0)^1 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+42298, r12vrr_stack+11670, r12vrr_stack+41758, r12vrr_stack+9834, r12vrr_stack+11310, r12vrr_stack+39606);

 /*--- compute (i0|k0)^0 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+43054, r12vrr_stack+12210, r12vrr_stack+42298, r12vrr_stack+10554, r12vrr_stack+11670, r12vrr_stack+40026);
 tmp = r12vrr_stack + 43054;
 target_ptr = Libr12->gvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|l0)^5 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+341, r12vrr_stack+8998, r12vrr_stack+13206, NULL, NULL, r12vrr_stack+8962);

 /*--- compute (d0|l0)^4 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9510, r12vrr_stack+9043, r12vrr_stack+341, r12vrr_stack+13956, r12vrr_stack+8998, r12vrr_stack+5982);

 /*--- compute (f0|l0)^3 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+44062, r12vrr_stack+15846, r12vrr_stack+9510, r12vrr_stack+8799, r12vrr_stack+9043, r12vrr_stack+6090);

 /*--- compute (g0|l0)^2 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+44512, r12vrr_stack+16116, r12vrr_stack+44062, r12vrr_stack+14001, r12vrr_stack+15846, r12vrr_stack+41398);

 /*--- compute (h0|l0)^1 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+45187, r12vrr_stack+16566, r12vrr_stack+44512, r12vrr_stack+14271, r12vrr_stack+16116, r12vrr_stack+41758);

 /*--- compute (i0|l0)^0 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+46132, r12vrr_stack+17241, r12vrr_stack+45187, r12vrr_stack+15171, r12vrr_stack+16566, r12vrr_stack+42298);
 tmp = r12vrr_stack + 46132;
 target_ptr = Libr12->gvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|m0)^5 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+18186, r12vrr_stack+13251, r12vrr_stack+5338, NULL, NULL, r12vrr_stack+13206);

 /*--- compute (d0|m0)^4 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+13956, r12vrr_stack+13306, r12vrr_stack+18186, r12vrr_stack+13066, r12vrr_stack+13251, r12vrr_stack+341);

 /*--- compute (f0|m0)^3 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+47392, r12vrr_stack+21926, r12vrr_stack+13956, r12vrr_stack+19506, r12vrr_stack+13306, r12vrr_stack+9510);

 /*--- compute (g0|m0)^2 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+47942, r12vrr_stack+22256, r12vrr_stack+47392, r12vrr_stack+19671, r12vrr_stack+21926, r12vrr_stack+44062);

 /*--- compute (h0|m0)^1 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+48767, r12vrr_stack+22806, r12vrr_stack+47942, r12vrr_stack+20001, r12vrr_stack+22256, r12vrr_stack+44512);

 /*--- compute (i0|m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+49922, r12vrr_stack+23631, r12vrr_stack+48767, r12vrr_stack+21101, r12vrr_stack+22806, r12vrr_stack+45187);
 tmp = r12vrr_stack + 49922;
 target_ptr = Libr12->gvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^15 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /*--- compute (00|d0)^14 ---*/
 _BUILD_00d0(Data,r12vrr_stack+19506, r12vrr_stack+3, r12vrr_stack+0, Data->F+14, Data->F+15, NULL);

 /*--- compute (00|f0)^13 ---*/
 _BUILD_00f0(Data,r12vrr_stack+170, r12vrr_stack+18681, r12vrr_stack+19506, r12vrr_stack+476, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^12 ---*/
 _BUILD_00g0(Data,r12vrr_stack+19512, r12vrr_stack+18687, r12vrr_stack+170, r12vrr_stack+479, r12vrr_stack+18681, NULL);

 /*--- compute (00|h0)^11 ---*/
 _BUILD_00h0(Data,r12vrr_stack+19527, r12vrr_stack+18697, r12vrr_stack+19512, r12vrr_stack+485, r12vrr_stack+18687, NULL);

 /*--- compute (00|i0)^10 ---*/
 _BUILD_00i0(Data,r12vrr_stack+19548, r12vrr_stack+18712, r12vrr_stack+19527, r12vrr_stack+495, r12vrr_stack+18697, NULL);

 /*--- compute (00|k0)^9 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+476, r12vrr_stack+18733, r12vrr_stack+19548, r12vrr_stack+13121, r12vrr_stack+18712, NULL);

 /*--- compute (00|l0)^8 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+19576, r12vrr_stack+18761, r12vrr_stack+476, r12vrr_stack+13142, r12vrr_stack+18733, NULL);

 /*--- compute (00|m0)^7 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+261, r12vrr_stack+12966, r12vrr_stack+19576, r12vrr_stack+13170, r12vrr_stack+18761, NULL);

 /*--- compute (00|n0)^6 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+19621, r12vrr_stack+5338, r12vrr_stack+261, r12vrr_stack+13206, r12vrr_stack+12966, NULL);

 /*--- compute (p0|n0)^5 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+19687, r12vrr_stack+18797, r12vrr_stack+19621, NULL, NULL, r12vrr_stack+5338);

 /*--- compute (d0|n0)^4 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+19885, r12vrr_stack+29010, r12vrr_stack+19687, r12vrr_stack+18417, r12vrr_stack+18797, r12vrr_stack+18186);

 /*--- compute (f0|n0)^3 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+51462, r12vrr_stack+29208, r12vrr_stack+19885, r12vrr_stack+18483, r12vrr_stack+29010, r12vrr_stack+13956);

 /*--- compute (g0|n0)^2 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+52122, r12vrr_stack+29604, r12vrr_stack+51462, r12vrr_stack+26304, r12vrr_stack+29208, r12vrr_stack+47392);

 /*--- compute (h0|n0)^1 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+53112, r12vrr_stack+30264, r12vrr_stack+52122, r12vrr_stack+26700, r12vrr_stack+29604, r12vrr_stack+47942);

 /*--- compute (i0|n0)^0 ---*/
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+54498, r12vrr_stack+31254, r12vrr_stack+53112, r12vrr_stack+28020, r12vrr_stack+30264, r12vrr_stack+48767);
 tmp = r12vrr_stack + 54498;
 target_ptr = Libr12->gvrr_classes[6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|o0)^5 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+26304, r12vrr_stack+18797, r12vrr_stack+19621, r12vrr_stack+13251, r12vrr_stack+5338, NULL);

 /*--- compute (p0|o0)^4 ---*/
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+26382, r12vrr_stack+32640, r12vrr_stack+26304, NULL, NULL, r12vrr_stack+18797);

 /*--- compute (d0|o0)^3 ---*/
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+26616, r12vrr_stack+34200, r12vrr_stack+26382, r12vrr_stack+32718, r12vrr_stack+32640, r12vrr_stack+29010);

 /*--- compute (f0|o0)^2 ---*/
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+56346, r12vrr_stack+34434, r12vrr_stack+26616, r12vrr_stack+32796, r12vrr_stack+34200, r12vrr_stack+29208);

 /*--- compute (g0|o0)^1 ---*/
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+57126, r12vrr_stack+34902, r12vrr_stack+56346, r12vrr_stack+33264, r12vrr_stack+34434, r12vrr_stack+29604);

 /*--- compute (h0|o0)^0 ---*/
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+58296, r12vrr_stack+36462, r12vrr_stack+57126, r12vrr_stack+35682, r12vrr_stack+34902, r12vrr_stack+30264);
 tmp = r12vrr_stack + 58296;
 target_ptr = Libr12->gvrr_classes[5][11];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^6 ---*/
 _BUILD_p000(Data,r12vrr_stack+33264, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (d0|00)^5 ---*/
 _BUILD_d000(Data,r12vrr_stack+33267, r12vrr_stack+33732, r12vrr_stack+33264, Data->F+5, Data->F+6, NULL);

 /*--- compute (f0|00)^4 ---*/
 _BUILD_f000(Data,r12vrr_stack+33273, r12vrr_stack+33735, r12vrr_stack+33267, r12vrr_stack+196, r12vrr_stack+33732, NULL);

 /*--- compute (p0|p0)^6 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+512, r12vrr_stack+21, r12vrr_stack+27, NULL, NULL, Data->F+7);

 /*--- compute (d0|p0)^5 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+33283, r12vrr_stack+33741, r12vrr_stack+512, r12vrr_stack+30, r12vrr_stack+21, r12vrr_stack+33264);

 /*--- compute (f0|p0)^4 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+33301, r12vrr_stack+57, r12vrr_stack+33283, r12vrr_stack+161, r12vrr_stack+33741, r12vrr_stack+33267);

 /*--- compute (g0|p0)^3 ---*/
 _BUILD_g0p0(Data,r12vrr_stack+33331, r12vrr_stack+33750, r12vrr_stack+33301, r12vrr_stack+1542, r12vrr_stack+57, r12vrr_stack+33273);

 /*--- compute (p0|d0)^6 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+1542, r12vrr_stack+180, r12vrr_stack+15, NULL, NULL, r12vrr_stack+27);

 /*--- compute (d0|d0)^5 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+27, r12vrr_stack+33780, r12vrr_stack+1542, r12vrr_stack+210, r12vrr_stack+180, r12vrr_stack+512);

 /*--- compute (f0|d0)^4 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+33376, r12vrr_stack+33798, r12vrr_stack+27, r12vrr_stack+1560, r12vrr_stack+33780, r12vrr_stack+33283);

 /*--- compute (g0|d0)^3 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+33436, r12vrr_stack+33834, r12vrr_stack+33376, r12vrr_stack+1578, r12vrr_stack+33798, r12vrr_stack+33301);

 /*--- compute (h0|d0)^2 ---*/
 _BUILD_h0d0(Data,r12vrr_stack+33526, r12vrr_stack+33894, r12vrr_stack+33436, r12vrr_stack+1614, r12vrr_stack+33834, r12vrr_stack+33331);

 /*--- compute (p0|f0)^6 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+1560, r12vrr_stack+316, r12vrr_stack+542, NULL, NULL, r12vrr_stack+15);

 /*--- compute (d0|f0)^5 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+1590, r12vrr_stack+75, r12vrr_stack+1560, r12vrr_stack+186, r12vrr_stack+316, r12vrr_stack+1542);

 /*--- compute (f0|f0)^4 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+33264, r12vrr_stack+33984, r12vrr_stack+1590, r12vrr_stack+1674, r12vrr_stack+75, r12vrr_stack+27);

 /*--- compute (g0|f0)^3 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+33652, r12vrr_stack+34044, r12vrr_stack+33264, r12vrr_stack+1704, r12vrr_stack+33984, r12vrr_stack+33376);

 /*--- compute (h0|f0)^2 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+33802, r12vrr_stack+33030, r12vrr_stack+33652, r12vrr_stack+1764, r12vrr_stack+34044, r12vrr_stack+33436);

 /*--- compute (i0|f0)^1 ---*/
 _BUILD_i0f0(Data,r12vrr_stack+32718, r12vrr_stack+24786, r12vrr_stack+33802, r12vrr_stack+1864, r12vrr_stack+33030, r12vrr_stack+33526);

 /*--- compute (p0|g0)^6 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+24786, r12vrr_stack+552, r12vrr_stack+3215, NULL, NULL, r12vrr_stack+542);

 /*--- compute (d0|g0)^5 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+24831, r12vrr_stack+216, r12vrr_stack+24786, r12vrr_stack+326, r12vrr_stack+552, r12vrr_stack+1560);

 /*--- compute (f0|g0)^4 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1650, r12vrr_stack+18863, r12vrr_stack+24831, r12vrr_stack+2014, r12vrr_stack+216, r12vrr_stack+1590);

 /*--- compute (g0|g0)^3 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+1800, r12vrr_stack+24996, r12vrr_stack+1650, r12vrr_stack+2059, r12vrr_stack+18863, r12vrr_stack+33264);

 /*--- compute (h0|g0)^2 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+33264, r12vrr_stack+25146, r12vrr_stack+1800, r12vrr_stack+2149, r12vrr_stack+24996, r12vrr_stack+33652);

 /*--- compute (i0|g0)^1 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+14286, r12vrr_stack+25371, r12vrr_stack+33264, r12vrr_stack+2299, r12vrr_stack+25146, r12vrr_stack+33802);

 /*--- compute (k0|g0)^0 ---*/
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,r12vrr_stack+33579, r12vrr_stack+37632, r12vrr_stack+14286, r12vrr_stack+2524, r12vrr_stack+25371, r12vrr_stack+32718);

 /*--- compute (p0|h0)^6 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+32718, r12vrr_stack+3230, r12vrr_stack+5497, NULL, NULL, r12vrr_stack+3215);

 /*--- compute (d0|h0)^5 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+32781, r12vrr_stack+867, r12vrr_stack+32718, r12vrr_stack+567, r12vrr_stack+3230, r12vrr_stack+24786);

 /*--- compute (f0|h0)^4 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+32907, r12vrr_stack+930, r12vrr_stack+32781, r12vrr_stack+588, r12vrr_stack+867, r12vrr_stack+24831);

 /*--- compute (g0|h0)^3 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+24786, r12vrr_stack+38052, r12vrr_stack+32907, r12vrr_stack+3931, r12vrr_stack+930, r12vrr_stack+1650);

 /*--- compute (h0|h0)^2 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+25101, r12vrr_stack+38262, r12vrr_stack+24786, r12vrr_stack+4057, r12vrr_stack+38052, r12vrr_stack+1800);

 /*--- compute (i0|h0)^1 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+1542, r12vrr_stack+38577, r12vrr_stack+25101, r12vrr_stack+4267, r12vrr_stack+38262, r12vrr_stack+33264);

 /*--- compute (k0|h0)^0 ---*/
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,r12vrr_stack+59934, r12vrr_stack+39018, r12vrr_stack+1542, r12vrr_stack+4897, r12vrr_stack+38577, r12vrr_stack+14286);
 tmp = r12vrr_stack + 59934;
 target_ptr = Libr12->gvrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^6 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+14286, r12vrr_stack+5518, r12vrr_stack+8934, NULL, NULL, r12vrr_stack+5497);

 /*--- compute (d0|i0)^5 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+25542, r12vrr_stack+33180, r12vrr_stack+14286, r12vrr_stack+3251, r12vrr_stack+5518, r12vrr_stack+32718);

 /*--- compute (f0|i0)^4 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+14370, r12vrr_stack+3279, r12vrr_stack+25542, r12vrr_stack+7214, r12vrr_stack+33180, r12vrr_stack+32781);

 /*--- compute (g0|i0)^3 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+38052, r12vrr_stack+2867, r12vrr_stack+14370, r12vrr_stack+7298, r12vrr_stack+3279, r12vrr_stack+32907);

 /*--- compute (h0|i0)^2 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+32718, r12vrr_stack+39606, r12vrr_stack+38052, r12vrr_stack+7466, r12vrr_stack+2867, r12vrr_stack+24786);

 /*--- compute (i0|i0)^1 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+60690, r12vrr_stack+40026, r12vrr_stack+32718, r12vrr_stack+7746, r12vrr_stack+39606, r12vrr_stack+25101);

 /*--- compute (k0|i0)^0 ---*/
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,r12vrr_stack+61474, r12vrr_stack+40614, r12vrr_stack+60690, r12vrr_stack+8166, r12vrr_stack+40026, r12vrr_stack+1542);
 tmp = r12vrr_stack + 61474;
 target_ptr = Libr12->gvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^6 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1542, r12vrr_stack+8962, r12vrr_stack+13170, NULL, NULL, r12vrr_stack+8934);

 /*--- compute (d0|k0)^5 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1650, r12vrr_stack+5982, r12vrr_stack+1542, r12vrr_stack+5546, r12vrr_stack+8962, r12vrr_stack+14286);

 /*--- compute (f0|k0)^4 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1866, r12vrr_stack+6090, r12vrr_stack+1650, r12vrr_stack+5582, r12vrr_stack+5982, r12vrr_stack+25542);

 /*--- compute (g0|k0)^3 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+39606, r12vrr_stack+41398, r12vrr_stack+1866, r12vrr_stack+11094, r12vrr_stack+6090, r12vrr_stack+14370);

 /*--- compute (h0|k0)^2 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+24786, r12vrr_stack+41758, r12vrr_stack+39606, r12vrr_stack+11310, r12vrr_stack+41398, r12vrr_stack+38052);

 /*--- compute (i0|k0)^1 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+62482, r12vrr_stack+42298, r12vrr_stack+24786, r12vrr_stack+11670, r12vrr_stack+41758, r12vrr_stack+32718);

 /*--- compute (k0|k0)^0 ---*/
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+63490, r12vrr_stack+43054, r12vrr_stack+62482, r12vrr_stack+12210, r12vrr_stack+42298, r12vrr_stack+60690);
 tmp = r12vrr_stack + 63490;
 target_ptr = Libr12->gvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|l0)^6 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+60690, r12vrr_stack+13206, r12vrr_stack+12966, NULL, NULL, r12vrr_stack+13170);

 /*--- compute (d0|l0)^5 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+20281, r12vrr_stack+341, r12vrr_stack+60690, r12vrr_stack+8998, r12vrr_stack+13206, r12vrr_stack+1542);

 /*--- compute (f0|l0)^4 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+60825, r12vrr_stack+9510, r12vrr_stack+20281, r12vrr_stack+9043, r12vrr_stack+341, r12vrr_stack+1650);

 /*--- compute (g0|l0)^3 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+32718, r12vrr_stack+44062, r12vrr_stack+60825, r12vrr_stack+15846, r12vrr_stack+9510, r12vrr_stack+1866);

 /*--- compute (h0|l0)^2 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1542, r12vrr_stack+44512, r12vrr_stack+32718, r12vrr_stack+16116, r12vrr_stack+44062, r12vrr_stack+39606);

 /*--- compute (i0|l0)^1 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+41398, r12vrr_stack+45187, r12vrr_stack+1542, r12vrr_stack+16566, r12vrr_stack+44512, r12vrr_stack+24786);

 /*--- compute (k0|l0)^0 ---*/
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+64786, r12vrr_stack+46132, r12vrr_stack+41398, r12vrr_stack+17241, r12vrr_stack+45187, r12vrr_stack+62482);
 tmp = r12vrr_stack + 64786;
 target_ptr = Libr12->gvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|m0)^6 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+62482, r12vrr_stack+5338, r12vrr_stack+261, NULL, NULL, r12vrr_stack+12966);

 /*--- compute (d0|m0)^5 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+62647, r12vrr_stack+18186, r12vrr_stack+62482, r12vrr_stack+13251, r12vrr_stack+5338, r12vrr_stack+60690);

 /*--- compute (f0|m0)^4 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+24786, r12vrr_stack+13956, r12vrr_stack+62647, r12vrr_stack+13306, r12vrr_stack+18186, r12vrr_stack+20281);

 /*--- compute (g0|m0)^3 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+39606, r12vrr_stack+47392, r12vrr_stack+24786, r12vrr_stack+21926, r12vrr_stack+13956, r12vrr_stack+60825);

 /*--- compute (h0|m0)^2 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+44062, r12vrr_stack+47942, r12vrr_stack+39606, r12vrr_stack+22256, r12vrr_stack+47392, r12vrr_stack+32718);

 /*--- compute (i0|m0)^1 ---*/
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+66406, r12vrr_stack+48767, r12vrr_stack+44062, r12vrr_stack+22806, r12vrr_stack+47942, r12vrr_stack+1542);

 /*--- compute (k0|m0)^0 ---*/
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+67946, r12vrr_stack+49922, r12vrr_stack+66406, r12vrr_stack+23631, r12vrr_stack+48767, r12vrr_stack+41398);
 tmp = r12vrr_stack + 67946;
 target_ptr = Libr12->gvrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^16 ---*/
 _BUILD_00p0(Data,r12vrr_stack+41398, Data->F+16, Data->F+17, NULL, NULL, NULL);

 /*--- compute (00|d0)^15 ---*/
 _BUILD_00d0(Data,r12vrr_stack+41401, r12vrr_stack+0, r12vrr_stack+41398, Data->F+15, Data->F+16, NULL);

 /*--- compute (00|f0)^14 ---*/
 _BUILD_00f0(Data,r12vrr_stack+41407, r12vrr_stack+19506, r12vrr_stack+41401, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (00|g0)^13 ---*/
 _BUILD_00g0(Data,r12vrr_stack+0, r12vrr_stack+170, r12vrr_stack+41407, r12vrr_stack+18681, r12vrr_stack+19506, NULL);

 /*--- compute (00|h0)^12 ---*/
 _BUILD_00h0(Data,r12vrr_stack+41398, r12vrr_stack+19512, r12vrr_stack+0, r12vrr_stack+18687, r12vrr_stack+170, NULL);

 /*--- compute (00|i0)^11 ---*/
 _BUILD_00i0(Data,r12vrr_stack+41419, r12vrr_stack+19527, r12vrr_stack+41398, r12vrr_stack+18697, r12vrr_stack+19512, NULL);

 /*--- compute (00|k0)^10 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+41447, r12vrr_stack+19548, r12vrr_stack+41419, r12vrr_stack+18712, r12vrr_stack+19527, NULL);

 /*--- compute (00|l0)^9 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+41398, r12vrr_stack+476, r12vrr_stack+41447, r12vrr_stack+18733, r12vrr_stack+19548, NULL);

 /*--- compute (00|m0)^8 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+41443, r12vrr_stack+19576, r12vrr_stack+41398, r12vrr_stack+18761, r12vrr_stack+476, NULL);

 /*--- compute (00|n0)^7 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+41498, r12vrr_stack+261, r12vrr_stack+41443, r12vrr_stack+12966, r12vrr_stack+19576, NULL);

 /*--- compute (p0|n0)^6 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+41564, r12vrr_stack+19621, r12vrr_stack+41498, NULL, NULL, r12vrr_stack+261);

 /*--- compute (d0|n0)^5 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+41762, r12vrr_stack+19687, r12vrr_stack+41564, r12vrr_stack+18797, r12vrr_stack+19621, r12vrr_stack+62482);

 /*--- compute (f0|n0)^4 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+42158, r12vrr_stack+19885, r12vrr_stack+41762, r12vrr_stack+29010, r12vrr_stack+19687, r12vrr_stack+62647);

 /*--- compute (g0|n0)^3 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+62482, r12vrr_stack+51462, r12vrr_stack+42158, r12vrr_stack+29208, r12vrr_stack+19885, r12vrr_stack+24786);

 /*--- compute (h0|n0)^2 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+41564, r12vrr_stack+52122, r12vrr_stack+62482, r12vrr_stack+29604, r12vrr_stack+51462, r12vrr_stack+39606);

 /*--- compute (i0|n0)^1 ---*/
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+47392, r12vrr_stack+53112, r12vrr_stack+41564, r12vrr_stack+30264, r12vrr_stack+52122, r12vrr_stack+44062);

 /*--- compute (k0|n0)^0 ---*/
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+69926, r12vrr_stack+54498, r12vrr_stack+47392, r12vrr_stack+31254, r12vrr_stack+53112, r12vrr_stack+66406);

 /*--- compute (00|o0)^6 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+66406, r12vrr_stack+19621, r12vrr_stack+41498, r12vrr_stack+5338, r12vrr_stack+261, NULL);

 /*--- compute (p0|o0)^5 ---*/
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+66484, r12vrr_stack+26304, r12vrr_stack+66406, NULL, NULL, r12vrr_stack+19621);

 /*--- compute (d0|o0)^4 ---*/
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+66718, r12vrr_stack+26382, r12vrr_stack+66484, r12vrr_stack+32640, r12vrr_stack+26304, r12vrr_stack+19687);

 /*--- compute (f0|o0)^3 ---*/
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+32640, r12vrr_stack+26616, r12vrr_stack+66718, r12vrr_stack+34200, r12vrr_stack+26382, r12vrr_stack+19885);

 /*--- compute (g0|o0)^2 ---*/
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+66406, r12vrr_stack+56346, r12vrr_stack+32640, r12vrr_stack+34434, r12vrr_stack+26616, r12vrr_stack+51462);

 /*--- compute (h0|o0)^1 ---*/
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+47392, r12vrr_stack+57126, r12vrr_stack+66406, r12vrr_stack+34902, r12vrr_stack+56346, r12vrr_stack+52122);

 /*--- compute (i0|o0)^0 ---*/
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+29010, r12vrr_stack+58296, r12vrr_stack+47392, r12vrr_stack+36462, r12vrr_stack+57126, r12vrr_stack+53112);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+47392, &(Data->ss_r12_ss), NULL, r12vrr_stack+24, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+47395, r12vrr_stack+47392, &(Data->ss_r12_ss), r12vrr_stack+701, r12vrr_stack+24, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+47401, r12vrr_stack+47395, r12vrr_stack+47392, r12vrr_stack+707, r12vrr_stack+701, r12vrr_stack+24, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+47411, r12vrr_stack+47401, r12vrr_stack+47395, r12vrr_stack+717, r12vrr_stack+707, r12vrr_stack+701, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+47426, r12vrr_stack+47411, r12vrr_stack+47401, r12vrr_stack+521, r12vrr_stack+717, r12vrr_stack+707, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+47447, r12vrr_stack+47426, NULL, r12vrr_stack+3532, r12vrr_stack+521, NULL, r12vrr_stack+717);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+47510, r12vrr_stack+47447, r12vrr_stack+47426, r12vrr_stack+3595, r12vrr_stack+3532, r12vrr_stack+521, r12vrr_stack+732);

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+47636, r12vrr_stack+47510, r12vrr_stack+47447, r12vrr_stack+3721, r12vrr_stack+3595, r12vrr_stack+3532, r12vrr_stack+777);

 /*--- compute (g0||h0)^0 ---*/
 _R_BUILD_g0h0(Data,r12vrr_stack+732, r12vrr_stack+47636, r12vrr_stack+47510, r12vrr_stack+4582, r12vrr_stack+3721, r12vrr_stack+3595, r12vrr_stack+1167);
 tmp = r12vrr_stack + 732;
 target_ptr = Libr12->rvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||h0)^0 ---*/
 _R_BUILD_h0h0(Data,r12vrr_stack+47846, r12vrr_stack+732, r12vrr_stack+47636, r12vrr_stack+4897, r12vrr_stack+4582, r12vrr_stack+3721, r12vrr_stack+1317);
 tmp = r12vrr_stack + 47846;
 target_ptr = Libr12->rvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+47447, r12vrr_stack+47426, r12vrr_stack+47411, r12vrr_stack+2839, r12vrr_stack+521, r12vrr_stack+717, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+47475, r12vrr_stack+47447, NULL, r12vrr_stack+5730, r12vrr_stack+2839, NULL, r12vrr_stack+521);

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+47559, r12vrr_stack+47475, r12vrr_stack+47447, r12vrr_stack+5814, r12vrr_stack+5730, r12vrr_stack+2839, r12vrr_stack+3532);

 /*--- compute (f0||i0)^0 ---*/
 _R_BUILD_f0i0(Data,r12vrr_stack+48287, r12vrr_stack+47559, r12vrr_stack+47475, r12vrr_stack+6514, r12vrr_stack+5814, r12vrr_stack+5730, r12vrr_stack+3595);

 /*--- compute (g0||i0)^0 ---*/
 _R_BUILD_g0i0(Data,r12vrr_stack+48567, r12vrr_stack+48287, r12vrr_stack+47559, r12vrr_stack+6794, r12vrr_stack+6514, r12vrr_stack+5814, r12vrr_stack+3721);
 tmp = r12vrr_stack + 48567;
 target_ptr = Libr12->rvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||i0)^0 ---*/
 _R_BUILD_h0i0(Data,r12vrr_stack+48987, r12vrr_stack+48567, r12vrr_stack+48287, r12vrr_stack+8166, r12vrr_stack+6794, r12vrr_stack+6514, r12vrr_stack+4582);
 tmp = r12vrr_stack + 48987;
 target_ptr = Libr12->rvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||k0)^0 ---*/
 _R_BUILD_00k0(Data,r12vrr_stack+48287, r12vrr_stack+47447, r12vrr_stack+47426, r12vrr_stack+5394, r12vrr_stack+2839, r12vrr_stack+521, NULL);

 /*--- compute (p0||k0)^0 ---*/
 _R_BUILD_p0k0(Data,r12vrr_stack+48323, r12vrr_stack+48287, NULL, r12vrr_stack+9186, r12vrr_stack+5394, NULL, r12vrr_stack+2839);

 /*--- compute (d0||k0)^0 ---*/
 _R_BUILD_d0k0(Data,r12vrr_stack+47475, r12vrr_stack+48323, r12vrr_stack+48287, r12vrr_stack+9294, r12vrr_stack+9186, r12vrr_stack+5394, r12vrr_stack+5730);

 /*--- compute (f0||k0)^0 ---*/
 _R_BUILD_f0k0(Data,r12vrr_stack+56346, r12vrr_stack+47475, r12vrr_stack+48323, r12vrr_stack+10194, r12vrr_stack+9294, r12vrr_stack+9186, r12vrr_stack+5814);

 /*--- compute (g0||k0)^0 ---*/
 _R_BUILD_g0k0(Data,r12vrr_stack+56706, r12vrr_stack+56346, r12vrr_stack+47475, r12vrr_stack+10554, r12vrr_stack+10194, r12vrr_stack+9294, r12vrr_stack+6514);
 tmp = r12vrr_stack + 56706;
 target_ptr = Libr12->rvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||k0)^0 ---*/
 _R_BUILD_h0k0(Data,r12vrr_stack+57246, r12vrr_stack+56706, r12vrr_stack+56346, r12vrr_stack+12210, r12vrr_stack+10554, r12vrr_stack+10194, r12vrr_stack+6794);
 tmp = r12vrr_stack + 57246;
 target_ptr = Libr12->rvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||l0)^0 ---*/
 _R_BUILD_00l0(Data,r12vrr_stack+12966, r12vrr_stack+48287, r12vrr_stack+47447, r12vrr_stack+8754, r12vrr_stack+5394, r12vrr_stack+2839, NULL);

 /*--- compute (p0||l0)^0 ---*/
 _R_BUILD_p0l0(Data,r12vrr_stack+2839, r12vrr_stack+12966, NULL, r12vrr_stack+13551, r12vrr_stack+8754, NULL, r12vrr_stack+5394);

 /*--- compute (d0||l0)^0 ---*/
 _R_BUILD_d0l0(Data,r12vrr_stack+1047, r12vrr_stack+2839, r12vrr_stack+12966, r12vrr_stack+13686, r12vrr_stack+13551, r12vrr_stack+8754, r12vrr_stack+9186);

 /*--- compute (f0||l0)^0 ---*/
 _R_BUILD_f0l0(Data,r12vrr_stack+2974, r12vrr_stack+1047, r12vrr_stack+2839, r12vrr_stack+14721, r12vrr_stack+13686, r12vrr_stack+13551, r12vrr_stack+9294);

 /*--- compute (g0||l0)^0 ---*/
 _R_BUILD_g0l0(Data,r12vrr_stack+66406, r12vrr_stack+2974, r12vrr_stack+1047, r12vrr_stack+15171, r12vrr_stack+14721, r12vrr_stack+13686, r12vrr_stack+10194);
 tmp = r12vrr_stack + 66406;
 target_ptr = Libr12->rvrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||l0)^0 ---*/
 _R_BUILD_h0l0(Data,r12vrr_stack+51462, r12vrr_stack+66406, r12vrr_stack+2974, r12vrr_stack+17241, r12vrr_stack+15171, r12vrr_stack+14721, r12vrr_stack+10554);
 tmp = r12vrr_stack + 51462;
 target_ptr = Libr12->rvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+1047, r12vrr_stack+12966, r12vrr_stack+48287, r12vrr_stack+13011, r12vrr_stack+8754, r12vrr_stack+5394, NULL);

 /*--- compute (p0||m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+18186, r12vrr_stack+1047, NULL, r12vrr_stack+19011, r12vrr_stack+13011, NULL, r12vrr_stack+8754);

 /*--- compute (d0||m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+2839, r12vrr_stack+18186, r12vrr_stack+1047, r12vrr_stack+19176, r12vrr_stack+19011, r12vrr_stack+13011, r12vrr_stack+13551);

 /*--- compute (f0||m0)^0 ---*/
 am[0] = 3;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+3169, r12vrr_stack+2839, r12vrr_stack+18186, r12vrr_stack+20551, r12vrr_stack+19176, r12vrr_stack+19011, r12vrr_stack+13686);

 /*--- compute (g0||m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+67081, r12vrr_stack+3169, r12vrr_stack+2839, r12vrr_stack+21101, r12vrr_stack+20551, r12vrr_stack+19176, r12vrr_stack+14721);
 tmp = r12vrr_stack + 67081;
 target_ptr = Libr12->rvrr_classes[4][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+52407, r12vrr_stack+67081, r12vrr_stack+3169, r12vrr_stack+23631, r12vrr_stack+21101, r12vrr_stack+20551, r12vrr_stack+15171);
 tmp = r12vrr_stack + 52407;
 target_ptr = Libr12->rvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||n0)^0 ---*/
 am[0] = 0;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+2839, r12vrr_stack+1047, r12vrr_stack+12966, r12vrr_stack+18351, r12vrr_stack+13011, r12vrr_stack+8754, NULL);

 /*--- compute (p0||n0)^0 ---*/
 am[0] = 1;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+8754, r12vrr_stack+2839, NULL, r12vrr_stack+25710, r12vrr_stack+18351, NULL, r12vrr_stack+13011);

 /*--- compute (d0||n0)^0 ---*/
 am[0] = 2;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+8952, r12vrr_stack+8754, r12vrr_stack+2839, r12vrr_stack+25908, r12vrr_stack+25710, r12vrr_stack+18351, r12vrr_stack+19011);

 /*--- compute (f0||n0)^0 ---*/
 am[0] = 3;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+2839, r12vrr_stack+8952, r12vrr_stack+8754, r12vrr_stack+27360, r12vrr_stack+25908, r12vrr_stack+25710, r12vrr_stack+19176);

 /*--- compute (g0||n0)^0 ---*/
 am[0] = 4;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+12966, r12vrr_stack+2839, r12vrr_stack+8952, r12vrr_stack+28020, r12vrr_stack+27360, r12vrr_stack+25908, r12vrr_stack+20551);
 tmp = r12vrr_stack + 12966;
 target_ptr = Libr12->rvrr_classes[4][10];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||n0)^0 ---*/
 am[0] = 5;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+8754, r12vrr_stack+12966, r12vrr_stack+2839, r12vrr_stack+31254, r12vrr_stack+28020, r12vrr_stack+27360, r12vrr_stack+21101);
 tmp = r12vrr_stack + 8754;
 target_ptr = Libr12->rvrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2839, r12vrr_stack+4582, r12vrr_stack+6794, r12vrr_stack+4897, r12vrr_stack+2524, r12vrr_stack+1317);
 tmp = r12vrr_stack + 2839;
 target_ptr = Libr12->t2vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3154, r12vrr_stack+6794, r12vrr_stack+10554, r12vrr_stack+8166, r12vrr_stack+4897, r12vrr_stack+4582);
 tmp = r12vrr_stack + 3154;
 target_ptr = Libr12->t2vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_g0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+13956, r12vrr_stack+10554, r12vrr_stack+15171, r12vrr_stack+12210, r12vrr_stack+8166, r12vrr_stack+6794);
 tmp = r12vrr_stack + 13956;
 target_ptr = Libr12->t2vrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_g0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1047, r12vrr_stack+15171, r12vrr_stack+21101, r12vrr_stack+17241, r12vrr_stack+12210, r12vrr_stack+10554);
 tmp = r12vrr_stack + 1047;
 target_ptr = Libr12->t2vrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+18186, r12vrr_stack+21101, r12vrr_stack+28020, r12vrr_stack+23631, r12vrr_stack+17241, r12vrr_stack+15171);
 tmp = r12vrr_stack + 18186;
 target_ptr = Libr12->t2vrr_classes[4][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|n0)^0 ---*/
 am[0] = 4;  am[1] = 10;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+19011, r12vrr_stack+28020, r12vrr_stack+36462, r12vrr_stack+31254, r12vrr_stack+23631, r12vrr_stack+21101);
 tmp = r12vrr_stack + 19011;
 target_ptr = Libr12->t2vrr_classes[4][10];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1722, r12vrr_stack+4897, r12vrr_stack+8166, r12vrr_stack+39018, r12vrr_stack+37632, r12vrr_stack+2524);
 tmp = r12vrr_stack + 1722;
 target_ptr = Libr12->t2vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+53562, r12vrr_stack+8166, r12vrr_stack+12210, r12vrr_stack+40614, r12vrr_stack+39018, r12vrr_stack+4897);
 tmp = r12vrr_stack + 53562;
 target_ptr = Libr12->t2vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_h0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+32640, r12vrr_stack+12210, r12vrr_stack+17241, r12vrr_stack+43054, r12vrr_stack+40614, r12vrr_stack+8166);
 tmp = r12vrr_stack + 32640;
 target_ptr = Libr12->t2vrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_h0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+5338, r12vrr_stack+17241, r12vrr_stack+23631, r12vrr_stack+46132, r12vrr_stack+43054, r12vrr_stack+12210);
 tmp = r12vrr_stack + 5338;
 target_ptr = Libr12->t2vrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+44062, r12vrr_stack+23631, r12vrr_stack+31254, r12vrr_stack+49922, r12vrr_stack+46132, r12vrr_stack+17241);
 tmp = r12vrr_stack + 44062;
 target_ptr = Libr12->t2vrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|n0)^0 ---*/
 am[0] = 5;  am[1] = 10;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+24786, r12vrr_stack+31254, r12vrr_stack+58296, r12vrr_stack+54498, r12vrr_stack+49922, r12vrr_stack+23631);
 tmp = r12vrr_stack + 24786;
 target_ptr = Libr12->t2vrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_i0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+45217, r12vrr_stack+39018, r12vrr_stack+40614, r12vrr_stack+59934, r12vrr_stack+33579, r12vrr_stack+37632);
 tmp = r12vrr_stack + 45217;
 target_ptr = Libr12->t2vrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_i0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+60690, r12vrr_stack+40614, r12vrr_stack+43054, r12vrr_stack+61474, r12vrr_stack+59934, r12vrr_stack+39018);
 tmp = r12vrr_stack + 60690;
 target_ptr = Libr12->t2vrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_i0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+39606, r12vrr_stack+43054, r12vrr_stack+46132, r12vrr_stack+63490, r12vrr_stack+61474, r12vrr_stack+40614);
 tmp = r12vrr_stack + 39606;
 target_ptr = Libr12->t2vrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_i0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+37632, r12vrr_stack+46132, r12vrr_stack+49922, r12vrr_stack+64786, r12vrr_stack+63490, r12vrr_stack+43054);
 tmp = r12vrr_stack + 37632;
 target_ptr = Libr12->t2vrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+33396, r12vrr_stack+49922, r12vrr_stack+54498, r12vrr_stack+67946, r12vrr_stack+64786, r12vrr_stack+46132);
 tmp = r12vrr_stack + 33396;
 target_ptr = Libr12->t2vrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T2]|n0)^0 ---*/
 am[0] = 6;  am[1] = 10;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+72302, r12vrr_stack+54498, r12vrr_stack+29010, r12vrr_stack+69926, r12vrr_stack+67946, r12vrr_stack+49922);
 tmp = r12vrr_stack + 72302;
 target_ptr = Libr12->t2vrr_classes[6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2163, r12vrr_stack+4582, r12vrr_stack+4897, r12vrr_stack+6794, r12vrr_stack+6514, r12vrr_stack+3721);
 tmp = r12vrr_stack + 2163;
 target_ptr = Libr12->t1vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3574, r12vrr_stack+6794, r12vrr_stack+8166, r12vrr_stack+10554, r12vrr_stack+10194, r12vrr_stack+6514);
 tmp = r12vrr_stack + 3574;
 target_ptr = Libr12->t1vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_g0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3994, r12vrr_stack+10554, r12vrr_stack+12210, r12vrr_stack+15171, r12vrr_stack+14721, r12vrr_stack+10194);
 tmp = r12vrr_stack + 3994;
 target_ptr = Libr12->t1vrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_g0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+34936, r12vrr_stack+15171, r12vrr_stack+17241, r12vrr_stack+21101, r12vrr_stack+20551, r12vrr_stack+14721);
 tmp = r12vrr_stack + 34936;
 target_ptr = Libr12->t1vrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+62482, r12vrr_stack+21101, r12vrr_stack+23631, r12vrr_stack+28020, r12vrr_stack+27360, r12vrr_stack+20551);
 tmp = r12vrr_stack + 62482;
 target_ptr = Libr12->t1vrr_classes[4][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|n0)^0 ---*/
 am[0] = 4;  am[1] = 10;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+20001, r12vrr_stack+28020, r12vrr_stack+31254, r12vrr_stack+36462, r12vrr_stack+35682, r12vrr_stack+27360);
 tmp = r12vrr_stack + 20001;
 target_ptr = Libr12->t1vrr_classes[4][10];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+14496, r12vrr_stack+4897, r12vrr_stack+39018, r12vrr_stack+8166, r12vrr_stack+6794, r12vrr_stack+4582);
 tmp = r12vrr_stack + 14496;
 target_ptr = Libr12->t1vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+35611, r12vrr_stack+8166, r12vrr_stack+40614, r12vrr_stack+12210, r12vrr_stack+10554, r12vrr_stack+6794);
 tmp = r12vrr_stack + 35611;
 target_ptr = Libr12->t1vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_h0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+26172, r12vrr_stack+12210, r12vrr_stack+43054, r12vrr_stack+17241, r12vrr_stack+15171, r12vrr_stack+10554);
 tmp = r12vrr_stack + 26172;
 target_ptr = Libr12->t1vrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_h0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+26928, r12vrr_stack+17241, r12vrr_stack+46132, r12vrr_stack+23631, r12vrr_stack+21101, r12vrr_stack+15171);
 tmp = r12vrr_stack + 26928;
 target_ptr = Libr12->t1vrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+41398, r12vrr_stack+23631, r12vrr_stack+49922, r12vrr_stack+31254, r12vrr_stack+28020, r12vrr_stack+21101);
 tmp = r12vrr_stack + 41398;
 target_ptr = Libr12->t1vrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|n0)^0 ---*/
 am[0] = 5;  am[1] = 10;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+21926, r12vrr_stack+31254, r12vrr_stack+54498, r12vrr_stack+58296, r12vrr_stack+36462, r12vrr_stack+28020);
 tmp = r12vrr_stack + 21926;
 target_ptr = Libr12->t1vrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_i0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+36199, r12vrr_stack+39018, r12vrr_stack+59934, r12vrr_stack+40614, r12vrr_stack+8166, r12vrr_stack+4897);
 tmp = r12vrr_stack + 36199;
 target_ptr = Libr12->t1vrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_i0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+36787, r12vrr_stack+40614, r12vrr_stack+61474, r12vrr_stack+43054, r12vrr_stack+12210, r12vrr_stack+8166);
 tmp = r12vrr_stack + 36787;
 target_ptr = Libr12->t1vrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_i0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+61474, r12vrr_stack+43054, r12vrr_stack+63490, r12vrr_stack+46132, r12vrr_stack+17241, r12vrr_stack+12210);
 tmp = r12vrr_stack + 61474;
 target_ptr = Libr12->t1vrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_i0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+63307, r12vrr_stack+46132, r12vrr_stack+64786, r12vrr_stack+49922, r12vrr_stack+23631, r12vrr_stack+17241);
 tmp = r12vrr_stack + 63307;
 target_ptr = Libr12->t1vrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+64567, r12vrr_stack+49922, r12vrr_stack+67946, r12vrr_stack+54498, r12vrr_stack+31254, r12vrr_stack+23631);
 tmp = r12vrr_stack + 64567;
 target_ptr = Libr12->t1vrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|[r12,T1]|n0)^0 ---*/
 am[0] = 6;  am[1] = 10;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+67906, r12vrr_stack+54498, r12vrr_stack+69926, r12vrr_stack+29010, r12vrr_stack+58296, r12vrr_stack+31254);
 tmp = r12vrr_stack + 67906;
 target_ptr = Libr12->t1vrr_classes[6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||h0)^0 ---*/
 _R_BUILD_i0h0(Data,r12vrr_stack+29010, r12vrr_stack+47846, r12vrr_stack+732, r12vrr_stack+39018, r12vrr_stack+4897, r12vrr_stack+4582, r12vrr_stack+2524);
 tmp = r12vrr_stack + 29010;
 target_ptr = Libr12->rvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||i0)^0 ---*/
 _R_BUILD_i0i0(Data,r12vrr_stack+29598, r12vrr_stack+48987, r12vrr_stack+48567, r12vrr_stack+40614, r12vrr_stack+8166, r12vrr_stack+6794, r12vrr_stack+4897);
 tmp = r12vrr_stack + 29598;
 target_ptr = Libr12->rvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||k0)^0 ---*/
 _R_BUILD_i0k0(Data,r12vrr_stack+47392, r12vrr_stack+57246, r12vrr_stack+56706, r12vrr_stack+43054, r12vrr_stack+12210, r12vrr_stack+10554, r12vrr_stack+8166);
 tmp = r12vrr_stack + 47392;
 target_ptr = Libr12->rvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||l0)^0 ---*/
 _R_BUILD_i0l0(Data,r12vrr_stack+10140, r12vrr_stack+51462, r12vrr_stack+66406, r12vrr_stack+46132, r12vrr_stack+17241, r12vrr_stack+15171, r12vrr_stack+12210);
 tmp = r12vrr_stack + 10140;
 target_ptr = Libr12->rvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+11400, r12vrr_stack+52407, r12vrr_stack+67081, r12vrr_stack+49922, r12vrr_stack+23631, r12vrr_stack+21101, r12vrr_stack+17241);
 tmp = r12vrr_stack + 11400;
 target_ptr = Libr12->rvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0||n0)^0 ---*/
 am[0] = 6;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+14937, r12vrr_stack+8754, r12vrr_stack+12966, r12vrr_stack+54498, r12vrr_stack+31254, r12vrr_stack+28020, r12vrr_stack+23631);
 tmp = r12vrr_stack + 14937;
 target_ptr = Libr12->rvrr_classes[6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];


}

