/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_h0h0(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (p0|00)^4 ---*/
 _BUILD_p000(Data,r12vrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+9, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (p0|p0)^4 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+12, r12vrr_stack+3, r12vrr_stack+9, NULL, NULL, Data->F+5);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+21, r12vrr_stack+6, r12vrr_stack+3, NULL, NULL, Data->F+4);

 /*--- compute (d0|p0)^3 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+30, r12vrr_stack+21, r12vrr_stack+12, r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+48, r12vrr_stack+3, r12vrr_stack+9, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+54, r12vrr_stack+6, r12vrr_stack+3, Data->F+3, Data->F+4, NULL);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+60, r12vrr_stack+54, r12vrr_stack+48, NULL, NULL, r12vrr_stack+3);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+78, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+81, r12vrr_stack+78, r12vrr_stack+6, Data->F+2, Data->F+3, NULL);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+87, r12vrr_stack+81, r12vrr_stack+54, NULL, NULL, r12vrr_stack+6);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+105, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+108, r12vrr_stack+9, r12vrr_stack+105, Data->F+5, Data->F+6, NULL);

 /*--- compute (p0|d0)^4 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+114, r12vrr_stack+48, r12vrr_stack+108, NULL, NULL, r12vrr_stack+9);

 /*--- compute (d0|d0)^3 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+132, r12vrr_stack+60, r12vrr_stack+114, r12vrr_stack+54, r12vrr_stack+48, r12vrr_stack+12);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+168, r12vrr_stack+87, r12vrr_stack+60, r12vrr_stack+81, r12vrr_stack+54, r12vrr_stack+21);

 /*--- compute (f0|d0)^2 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+204, r12vrr_stack+168, r12vrr_stack+132, r12vrr_stack+87, r12vrr_stack+60, r12vrr_stack+30);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+264, r12vrr_stack+54, r12vrr_stack+48, r12vrr_stack+6, r12vrr_stack+3, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+274, r12vrr_stack+81, r12vrr_stack+54, r12vrr_stack+78, r12vrr_stack+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+284, r12vrr_stack+48, r12vrr_stack+108, r12vrr_stack+3, r12vrr_stack+9, NULL);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+294, r12vrr_stack+264, r12vrr_stack+284, NULL, NULL, r12vrr_stack+48);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+324, r12vrr_stack+274, r12vrr_stack+264, NULL, NULL, r12vrr_stack+54);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+354, r12vrr_stack+324, r12vrr_stack+294, r12vrr_stack+274, r12vrr_stack+264, r12vrr_stack+60);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+414, r12vrr_stack+6, r12vrr_stack+78, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+420, r12vrr_stack+414, r12vrr_stack+81, r12vrr_stack+6, r12vrr_stack+78, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+430, r12vrr_stack+420, r12vrr_stack+274, NULL, NULL, r12vrr_stack+81);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+460, r12vrr_stack+430, r12vrr_stack+324, r12vrr_stack+420, r12vrr_stack+274, r12vrr_stack+87);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+78, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+87, r12vrr_stack+105, r12vrr_stack+78, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+93, r12vrr_stack+108, r12vrr_stack+87, r12vrr_stack+9, r12vrr_stack+105, NULL);

 /*--- compute (p0|f0)^4 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+520, r12vrr_stack+284, r12vrr_stack+93, NULL, NULL, r12vrr_stack+108);

 /*--- compute (d0|f0)^3 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+550, r12vrr_stack+294, r12vrr_stack+520, r12vrr_stack+264, r12vrr_stack+284, r12vrr_stack+114);

 /*--- compute (f0|f0)^2 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+610, r12vrr_stack+354, r12vrr_stack+550, r12vrr_stack+324, r12vrr_stack+294, r12vrr_stack+132);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+710, r12vrr_stack+460, r12vrr_stack+354, r12vrr_stack+430, r12vrr_stack+324, r12vrr_stack+168);

 /*--- compute (g0|f0)^1 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+810, r12vrr_stack+710, r12vrr_stack+610, r12vrr_stack+460, r12vrr_stack+354, r12vrr_stack+204);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+960, r12vrr_stack+264, r12vrr_stack+284, r12vrr_stack+54, r12vrr_stack+48, NULL);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+975, r12vrr_stack+274, r12vrr_stack+264, r12vrr_stack+81, r12vrr_stack+54, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+990, r12vrr_stack+975, r12vrr_stack+960, NULL, NULL, r12vrr_stack+264);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1035, r12vrr_stack+420, r12vrr_stack+274, r12vrr_stack+414, r12vrr_stack+81, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1050, r12vrr_stack+1035, r12vrr_stack+975, NULL, NULL, r12vrr_stack+274);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1095, r12vrr_stack+284, r12vrr_stack+93, r12vrr_stack+48, r12vrr_stack+108, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1110, r12vrr_stack+960, r12vrr_stack+1095, NULL, NULL, r12vrr_stack+284);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1155, r12vrr_stack+990, r12vrr_stack+1110, r12vrr_stack+975, r12vrr_stack+960, r12vrr_stack+294);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1245, r12vrr_stack+1050, r12vrr_stack+990, r12vrr_stack+1035, r12vrr_stack+975, r12vrr_stack+324);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1335, r12vrr_stack+1245, r12vrr_stack+1155, r12vrr_stack+1050, r12vrr_stack+990, r12vrr_stack+354);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+324, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+81, r12vrr_stack+324, r12vrr_stack+6, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+327, r12vrr_stack+81, r12vrr_stack+414, r12vrr_stack+324, r12vrr_stack+6, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+337, r12vrr_stack+327, r12vrr_stack+420, r12vrr_stack+81, r12vrr_stack+414, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1485, r12vrr_stack+337, r12vrr_stack+1035, NULL, NULL, r12vrr_stack+420);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1530, r12vrr_stack+1485, r12vrr_stack+1050, r12vrr_stack+337, r12vrr_stack+1035, r12vrr_stack+430);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1620, r12vrr_stack+1530, r12vrr_stack+1245, r12vrr_stack+1485, r12vrr_stack+1050, r12vrr_stack+460);

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+414, r12vrr_stack+78, r12vrr_stack+6, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+430, r12vrr_stack+87, r12vrr_stack+414, r12vrr_stack+105, r12vrr_stack+78, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+440, r12vrr_stack+93, r12vrr_stack+430, r12vrr_stack+108, r12vrr_stack+87, NULL);

 /*--- compute (p0|g0)^4 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+455, r12vrr_stack+1095, r12vrr_stack+440, NULL, NULL, r12vrr_stack+93);

 /*--- compute (d0|g0)^3 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1770, r12vrr_stack+1110, r12vrr_stack+455, r12vrr_stack+960, r12vrr_stack+1095, r12vrr_stack+520);

 /*--- compute (f0|g0)^2 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1860, r12vrr_stack+1155, r12vrr_stack+1770, r12vrr_stack+990, r12vrr_stack+1110, r12vrr_stack+550);

 /*--- compute (g0|g0)^1 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2010, r12vrr_stack+1335, r12vrr_stack+1860, r12vrr_stack+1245, r12vrr_stack+1155, r12vrr_stack+610);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2235, r12vrr_stack+1620, r12vrr_stack+1335, r12vrr_stack+1530, r12vrr_stack+1245, r12vrr_stack+710);

 /*--- compute (h0|g0)^0 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+2460, r12vrr_stack+2235, r12vrr_stack+2010, r12vrr_stack+1620, r12vrr_stack+1335, r12vrr_stack+810);

 /*--- compute (p0|00)^5 ---*/
 _BUILD_p000(Data,r12vrr_stack+500, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (d0|00)^4 ---*/
 _BUILD_d000(Data,r12vrr_stack+54, r12vrr_stack+0, r12vrr_stack+500, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|p0)^5 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+503, r12vrr_stack+9, r12vrr_stack+105, NULL, NULL, Data->F+6);

 /*--- compute (d0|p0)^4 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+2775, r12vrr_stack+12, r12vrr_stack+503, r12vrr_stack+3, r12vrr_stack+9, r12vrr_stack+500);

 /*--- compute (f0|p0)^3 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+2793, r12vrr_stack+30, r12vrr_stack+2775, r12vrr_stack+21, r12vrr_stack+12, r12vrr_stack+54);

 /*--- compute (p0|d0)^5 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+9, r12vrr_stack+108, r12vrr_stack+87, NULL, NULL, r12vrr_stack+105);

 /*--- compute (d0|d0)^4 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+2823, r12vrr_stack+114, r12vrr_stack+9, r12vrr_stack+48, r12vrr_stack+108, r12vrr_stack+503);

 /*--- compute (f0|d0)^3 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+2859, r12vrr_stack+132, r12vrr_stack+2823, r12vrr_stack+60, r12vrr_stack+114, r12vrr_stack+2775);

 /*--- compute (g0|d0)^2 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+2919, r12vrr_stack+204, r12vrr_stack+2859, r12vrr_stack+168, r12vrr_stack+132, r12vrr_stack+2793);

 /*--- compute (p0|f0)^5 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+2775, r12vrr_stack+93, r12vrr_stack+430, NULL, NULL, r12vrr_stack+87);

 /*--- compute (d0|f0)^4 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+103, r12vrr_stack+520, r12vrr_stack+2775, r12vrr_stack+284, r12vrr_stack+93, r12vrr_stack+9);

 /*--- compute (f0|f0)^3 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+163, r12vrr_stack+550, r12vrr_stack+103, r12vrr_stack+294, r12vrr_stack+520, r12vrr_stack+2823);

 /*--- compute (g0|f0)^2 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+3009, r12vrr_stack+610, r12vrr_stack+163, r12vrr_stack+354, r12vrr_stack+550, r12vrr_stack+2859);

 /*--- compute (h0|f0)^1 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+3159, r12vrr_stack+810, r12vrr_stack+3009, r12vrr_stack+710, r12vrr_stack+610, r12vrr_stack+2919);

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+294, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+0, r12vrr_stack+6, r12vrr_stack+294, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+297, r12vrr_stack+414, r12vrr_stack+0, r12vrr_stack+78, r12vrr_stack+6, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+307, r12vrr_stack+430, r12vrr_stack+297, r12vrr_stack+87, r12vrr_stack+414, NULL);

 /*--- compute (p0|g0)^5 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+9, r12vrr_stack+440, r12vrr_stack+307, NULL, NULL, r12vrr_stack+430);

 /*--- compute (d0|g0)^4 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+2805, r12vrr_stack+455, r12vrr_stack+9, r12vrr_stack+1095, r12vrr_stack+440, r12vrr_stack+2775);

 /*--- compute (f0|g0)^3 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+500, r12vrr_stack+1770, r12vrr_stack+2805, r12vrr_stack+1110, r12vrr_stack+455, r12vrr_stack+103);

 /*--- compute (g0|g0)^2 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+650, r12vrr_stack+1860, r12vrr_stack+500, r12vrr_stack+1155, r12vrr_stack+1770, r12vrr_stack+163);

 /*--- compute (h0|g0)^1 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+3369, r12vrr_stack+2010, r12vrr_stack+650, r12vrr_stack+1335, r12vrr_stack+1860, r12vrr_stack+3009);

 /*--- compute (i0|g0)^0 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+3684, r12vrr_stack+2460, r12vrr_stack+3369, r12vrr_stack+2235, r12vrr_stack+2010, r12vrr_stack+3159);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+103, r12vrr_stack+960, r12vrr_stack+1095, r12vrr_stack+264, r12vrr_stack+284, NULL);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+124, r12vrr_stack+975, r12vrr_stack+960, r12vrr_stack+274, r12vrr_stack+264, NULL);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+145, r12vrr_stack+1095, r12vrr_stack+440, r12vrr_stack+284, r12vrr_stack+93, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+166, r12vrr_stack+103, r12vrr_stack+145, NULL, NULL, r12vrr_stack+1095);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2895, r12vrr_stack+124, r12vrr_stack+103, NULL, NULL, r12vrr_stack+960);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+2958, r12vrr_stack+2895, r12vrr_stack+166, r12vrr_stack+124, r12vrr_stack+103, r12vrr_stack+1110);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1110, r12vrr_stack+1035, r12vrr_stack+975, r12vrr_stack+420, r12vrr_stack+274, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+229, r12vrr_stack+1110, r12vrr_stack+124, NULL, NULL, r12vrr_stack+975);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3084, r12vrr_stack+229, r12vrr_stack+2895, r12vrr_stack+1110, r12vrr_stack+124, r12vrr_stack+990);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+990, r12vrr_stack+440, r12vrr_stack+307, r12vrr_stack+93, r12vrr_stack+430, NULL);

 /*--- compute (p0|h0)^4 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+3210, r12vrr_stack+145, r12vrr_stack+990, NULL, NULL, r12vrr_stack+440);

 /*--- compute (d0|h0)^3 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+4104, r12vrr_stack+166, r12vrr_stack+3210, r12vrr_stack+103, r12vrr_stack+145, r12vrr_stack+455);

 /*--- compute (f0|h0)^2 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+4230, r12vrr_stack+2958, r12vrr_stack+4104, r12vrr_stack+2895, r12vrr_stack+166, r12vrr_stack+1770);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+4440, r12vrr_stack+3084, r12vrr_stack+2958, r12vrr_stack+229, r12vrr_stack+2895, r12vrr_stack+1155);

 /*--- compute (g0|h0)^1 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+4650, r12vrr_stack+4440, r12vrr_stack+4230, r12vrr_stack+3084, r12vrr_stack+2958, r12vrr_stack+1860);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1770, r12vrr_stack+337, r12vrr_stack+1035, r12vrr_stack+327, r12vrr_stack+420, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1791, r12vrr_stack+1770, r12vrr_stack+1110, NULL, NULL, r12vrr_stack+1035);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1854, r12vrr_stack+1791, r12vrr_stack+229, r12vrr_stack+1770, r12vrr_stack+1110, r12vrr_stack+1050);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+4965, r12vrr_stack+1854, r12vrr_stack+3084, r12vrr_stack+1791, r12vrr_stack+229, r12vrr_stack+1245);

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+5175, r12vrr_stack+4965, r12vrr_stack+4440, r12vrr_stack+1854, r12vrr_stack+3084, r12vrr_stack+1335);

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+1050, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+1053, r12vrr_stack+294, r12vrr_stack+1050, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+420, r12vrr_stack+0, r12vrr_stack+1053, r12vrr_stack+6, r12vrr_stack+294, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1050, r12vrr_stack+297, r12vrr_stack+420, r12vrr_stack+414, r12vrr_stack+0, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1065, r12vrr_stack+307, r12vrr_stack+1050, r12vrr_stack+430, r12vrr_stack+297, NULL);

 /*--- compute (p0|h0)^5 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1131, r12vrr_stack+990, r12vrr_stack+1065, NULL, NULL, r12vrr_stack+307);

 /*--- compute (d0|h0)^4 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1194, r12vrr_stack+3210, r12vrr_stack+1131, r12vrr_stack+145, r12vrr_stack+990, r12vrr_stack+9);

 /*--- compute (f0|h0)^3 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+5490, r12vrr_stack+4104, r12vrr_stack+1194, r12vrr_stack+166, r12vrr_stack+3210, r12vrr_stack+2805);

 /*--- compute (g0|h0)^2 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+1131, r12vrr_stack+4230, r12vrr_stack+5490, r12vrr_stack+2958, r12vrr_stack+4104, r12vrr_stack+500);

 /*--- compute (h0|h0)^1 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+5490, r12vrr_stack+4650, r12vrr_stack+1131, r12vrr_stack+4440, r12vrr_stack+4230, r12vrr_stack+650);

 /*--- compute (h0|h0)^0 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+455, r12vrr_stack+5175, r12vrr_stack+4650, r12vrr_stack+4965, r12vrr_stack+4440, r12vrr_stack+2010);
 tmp = r12vrr_stack + 455;
 target_ptr = Libr12->gvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|h0)^0 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+5931, r12vrr_stack+455, r12vrr_stack+5490, r12vrr_stack+5175, r12vrr_stack+4650, r12vrr_stack+3369);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5490, r12vrr_stack+103, r12vrr_stack+145, r12vrr_stack+960, r12vrr_stack+1095, NULL);

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5518, r12vrr_stack+124, r12vrr_stack+103, r12vrr_stack+975, r12vrr_stack+960, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5546, r12vrr_stack+5518, r12vrr_stack+5490, NULL, NULL, r12vrr_stack+103);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5630, r12vrr_stack+1110, r12vrr_stack+124, r12vrr_stack+1035, r12vrr_stack+975, NULL);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5658, r12vrr_stack+5630, r12vrr_stack+5518, NULL, NULL, r12vrr_stack+124);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5742, r12vrr_stack+145, r12vrr_stack+990, r12vrr_stack+1095, r12vrr_stack+440, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+5770, r12vrr_stack+5490, r12vrr_stack+5742, NULL, NULL, r12vrr_stack+145);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+1131, r12vrr_stack+5546, r12vrr_stack+5770, r12vrr_stack+5518, r12vrr_stack+5490, r12vrr_stack+166);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+1299, r12vrr_stack+5658, r12vrr_stack+5546, r12vrr_stack+5630, r12vrr_stack+5518, r12vrr_stack+2895);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+6519, r12vrr_stack+1299, r12vrr_stack+1131, r12vrr_stack+5658, r12vrr_stack+5546, r12vrr_stack+2958);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5518, r12vrr_stack+1770, r12vrr_stack+1110, r12vrr_stack+337, r12vrr_stack+1035, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+6799, r12vrr_stack+5518, r12vrr_stack+5630, NULL, NULL, r12vrr_stack+1110);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+1980, r12vrr_stack+6799, r12vrr_stack+5658, r12vrr_stack+5518, r12vrr_stack+5630, r12vrr_stack+229);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+2775, r12vrr_stack+1980, r12vrr_stack+1299, r12vrr_stack+6799, r12vrr_stack+5658, r12vrr_stack+3084);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5518, r12vrr_stack+990, r12vrr_stack+1065, r12vrr_stack+440, r12vrr_stack+307, NULL);

 /*--- compute (p0|i0)^4 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+6799, r12vrr_stack+5742, r12vrr_stack+5518, NULL, NULL, r12vrr_stack+990);

 /*--- compute (d0|i0)^3 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+896, r12vrr_stack+5770, r12vrr_stack+6799, r12vrr_stack+5490, r12vrr_stack+5742, r12vrr_stack+3210);

 /*--- compute (f0|i0)^2 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+3055, r12vrr_stack+1131, r12vrr_stack+896, r12vrr_stack+5546, r12vrr_stack+5770, r12vrr_stack+4104);

 /*--- compute (g0|i0)^1 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+5490, r12vrr_stack+6519, r12vrr_stack+3055, r12vrr_stack+1299, r12vrr_stack+1131, r12vrr_stack+4230);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+3055, r12vrr_stack+2775, r12vrr_stack+6519, r12vrr_stack+1980, r12vrr_stack+1299, r12vrr_stack+4440);

 /*--- compute (h0|i0)^0 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+896, r12vrr_stack+3055, r12vrr_stack+5490, r12vrr_stack+2775, r12vrr_stack+6519, r12vrr_stack+4650);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+6519, &(Data->ss_r12_ss), NULL, r12vrr_stack+324, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+6522, r12vrr_stack+6519, &(Data->ss_r12_ss), r12vrr_stack+81, r12vrr_stack+324, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+6528, r12vrr_stack+6522, r12vrr_stack+6519, r12vrr_stack+327, r12vrr_stack+81, r12vrr_stack+324, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+6538, r12vrr_stack+6528, r12vrr_stack+6522, r12vrr_stack+337, r12vrr_stack+327, r12vrr_stack+81, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+6553, r12vrr_stack+6538, r12vrr_stack+6528, r12vrr_stack+1770, r12vrr_stack+337, r12vrr_stack+327, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+6574, r12vrr_stack+6553, NULL, r12vrr_stack+1791, r12vrr_stack+1770, NULL, r12vrr_stack+337);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+6637, r12vrr_stack+6574, r12vrr_stack+6553, r12vrr_stack+1854, r12vrr_stack+1791, r12vrr_stack+1770, r12vrr_stack+1485);

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+6763, r12vrr_stack+6637, r12vrr_stack+6574, r12vrr_stack+4965, r12vrr_stack+1854, r12vrr_stack+1791, r12vrr_stack+1530);

 /*--- compute (g0||h0)^0 ---*/
 _R_BUILD_g0h0(Data,r12vrr_stack+5490, r12vrr_stack+6763, r12vrr_stack+6637, r12vrr_stack+5175, r12vrr_stack+4965, r12vrr_stack+1854, r12vrr_stack+1620);

 /*--- compute (h0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+4104, r12vrr_stack+455, r12vrr_stack+896, r12vrr_stack+5931, r12vrr_stack+3684, r12vrr_stack+2460);
 tmp = r12vrr_stack + 4104;
 target_ptr = Libr12->t2vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2460, r12vrr_stack+455, r12vrr_stack+5931, r12vrr_stack+896, r12vrr_stack+3055, r12vrr_stack+5175);
 tmp = r12vrr_stack + 2460;
 target_ptr = Libr12->t1vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||h0)^0 ---*/
 _R_BUILD_h0h0(Data,r12vrr_stack+896, r12vrr_stack+5490, r12vrr_stack+6763, r12vrr_stack+455, r12vrr_stack+5175, r12vrr_stack+4965, r12vrr_stack+2235);
 tmp = r12vrr_stack + 896;
 target_ptr = Libr12->rvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];


}

