/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_pphp(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+9, r12vrr_stack+0, r12vrr_stack+6, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+3, r12vrr_stack+0, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+21, r12vrr_stack+15, r12vrr_stack+9, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+31, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+34, r12vrr_stack+6, r12vrr_stack+31, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+40, r12vrr_stack+9, r12vrr_stack+34, r12vrr_stack+0, r12vrr_stack+6, NULL);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+50, r12vrr_stack+21, r12vrr_stack+40, r12vrr_stack+15, r12vrr_stack+9, NULL);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+65, r12vrr_stack+0, r12vrr_stack+3, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+71, r12vrr_stack+65, r12vrr_stack+15, r12vrr_stack+0, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+81, r12vrr_stack+71, r12vrr_stack+21, r12vrr_stack+65, r12vrr_stack+15, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+96, r12vrr_stack+81, r12vrr_stack+50, NULL, NULL, r12vrr_stack+21);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+141, r12vrr_stack+21, r12vrr_stack+40, NULL, NULL, r12vrr_stack+9);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+31, r12vrr_stack+3, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+171, r12vrr_stack+34, r12vrr_stack+15, r12vrr_stack+6, r12vrr_stack+31, NULL);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+181, r12vrr_stack+40, r12vrr_stack+171, r12vrr_stack+9, r12vrr_stack+34, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+196, r12vrr_stack+50, r12vrr_stack+181, NULL, NULL, r12vrr_stack+40);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+241, r12vrr_stack+96, r12vrr_stack+196, r12vrr_stack+81, r12vrr_stack+50, r12vrr_stack+141);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+331, r12vrr_stack+50, r12vrr_stack+181, r12vrr_stack+21, r12vrr_stack+40, NULL);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+352, r12vrr_stack+81, r12vrr_stack+50, r12vrr_stack+71, r12vrr_stack+21, NULL);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+373, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+376, r12vrr_stack+3, r12vrr_stack+373, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+382, r12vrr_stack+15, r12vrr_stack+376, r12vrr_stack+31, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+392, r12vrr_stack+171, r12vrr_stack+382, r12vrr_stack+34, r12vrr_stack+15, NULL);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+407, r12vrr_stack+181, r12vrr_stack+392, r12vrr_stack+40, r12vrr_stack+171, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+428, r12vrr_stack+331, r12vrr_stack+407, NULL, NULL, r12vrr_stack+181);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+491, r12vrr_stack+352, r12vrr_stack+331, NULL, NULL, r12vrr_stack+50);
 tmp = r12vrr_stack + 491;
 target_ptr = Libr12->gvrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+554, r12vrr_stack+491, r12vrr_stack+428, r12vrr_stack+352, r12vrr_stack+331, r12vrr_stack+196);
 tmp = r12vrr_stack + 554;
 target_ptr = Libr12->gvrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+680, r12vrr_stack+331, r12vrr_stack+407, r12vrr_stack+50, r12vrr_stack+181, NULL);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+708, r12vrr_stack+352, r12vrr_stack+331, r12vrr_stack+81, r12vrr_stack+50, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+736, r12vrr_stack+708, r12vrr_stack+680, NULL, NULL, r12vrr_stack+331);
 tmp = r12vrr_stack + 736;
 target_ptr = Libr12->gvrr_classes[1][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+31, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+820, r12vrr_stack+373, r12vrr_stack+31, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+826, r12vrr_stack+376, r12vrr_stack+820, r12vrr_stack+3, r12vrr_stack+373, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+836, r12vrr_stack+382, r12vrr_stack+826, r12vrr_stack+15, r12vrr_stack+376, NULL);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+851, r12vrr_stack+392, r12vrr_stack+836, r12vrr_stack+171, r12vrr_stack+382, NULL);

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+872, r12vrr_stack+407, r12vrr_stack+851, r12vrr_stack+181, r12vrr_stack+392, NULL);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+900, r12vrr_stack+680, r12vrr_stack+872, NULL, NULL, r12vrr_stack+407);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+984, r12vrr_stack+736, r12vrr_stack+900, r12vrr_stack+708, r12vrr_stack+680, r12vrr_stack+428);
 tmp = r12vrr_stack + 984;
 target_ptr = Libr12->gvrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1152, r12vrr_stack+680, r12vrr_stack+872, r12vrr_stack+331, r12vrr_stack+407, NULL);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1188, r12vrr_stack+708, r12vrr_stack+680, r12vrr_stack+352, r12vrr_stack+331, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1224, r12vrr_stack+1188, r12vrr_stack+1152, NULL, NULL, r12vrr_stack+680);
 tmp = r12vrr_stack + 1224;
 target_ptr = Libr12->gvrr_classes[1][7];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+1332, r12vrr_stack+9, r12vrr_stack+34, NULL, NULL, r12vrr_stack+6);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+1350, r12vrr_stack+40, r12vrr_stack+171, NULL, NULL, r12vrr_stack+34);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+1380, r12vrr_stack+141, r12vrr_stack+1350, r12vrr_stack+21, r12vrr_stack+40, r12vrr_stack+1332);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1440, r12vrr_stack+181, r12vrr_stack+392, NULL, NULL, r12vrr_stack+171);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1485, r12vrr_stack+196, r12vrr_stack+1440, r12vrr_stack+50, r12vrr_stack+181, r12vrr_stack+1350);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1575, r12vrr_stack+241, r12vrr_stack+1485, r12vrr_stack+96, r12vrr_stack+196, r12vrr_stack+1380);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1332, r12vrr_stack+407, r12vrr_stack+851, NULL, NULL, r12vrr_stack+392);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1725, r12vrr_stack+428, r12vrr_stack+1332, r12vrr_stack+331, r12vrr_stack+407, r12vrr_stack+1440);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+1851, r12vrr_stack+554, r12vrr_stack+1725, r12vrr_stack+491, r12vrr_stack+428, r12vrr_stack+1485);
 tmp = r12vrr_stack + 1851;
 target_ptr = Libr12->gvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+428, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+431, r12vrr_stack+31, r12vrr_stack+428, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+437, r12vrr_stack+820, r12vrr_stack+431, r12vrr_stack+373, r12vrr_stack+31, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+447, r12vrr_stack+826, r12vrr_stack+437, r12vrr_stack+376, r12vrr_stack+820, NULL);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+331, r12vrr_stack+836, r12vrr_stack+447, r12vrr_stack+382, r12vrr_stack+826, NULL);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+428, r12vrr_stack+851, r12vrr_stack+331, r12vrr_stack+392, r12vrr_stack+836, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+1395, r12vrr_stack+872, r12vrr_stack+428, NULL, NULL, r12vrr_stack+851);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+2061, r12vrr_stack+900, r12vrr_stack+1395, r12vrr_stack+680, r12vrr_stack+872, r12vrr_stack+1332);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+2229, r12vrr_stack+984, r12vrr_stack+2061, r12vrr_stack+736, r12vrr_stack+900, r12vrr_stack+1725);

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1725, r12vrr_stack+872, r12vrr_stack+428, r12vrr_stack+407, r12vrr_stack+851, NULL);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2061, r12vrr_stack+1152, r12vrr_stack+1725, NULL, NULL, r12vrr_stack+872);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1332, r12vrr_stack+1224, r12vrr_stack+2061, r12vrr_stack+1188, r12vrr_stack+1152, r12vrr_stack+900);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+1152, &(Data->ss_r12_ss), NULL, r12vrr_stack+0, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+1155, r12vrr_stack+1152, &(Data->ss_r12_ss), r12vrr_stack+65, r12vrr_stack+0, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+1161, r12vrr_stack+1155, r12vrr_stack+1152, r12vrr_stack+71, r12vrr_stack+65, r12vrr_stack+0, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+0, r12vrr_stack+1161, r12vrr_stack+1155, r12vrr_stack+81, r12vrr_stack+71, r12vrr_stack+65, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+331, r12vrr_stack+0, r12vrr_stack+1161, r12vrr_stack+352, r12vrr_stack+81, r12vrr_stack+71, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+15, r12vrr_stack+331, NULL, r12vrr_stack+491, r12vrr_stack+352, NULL, r12vrr_stack+81);
 tmp = r12vrr_stack + 15;
 target_ptr = Libr12->rvrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+680, r12vrr_stack+331, r12vrr_stack+0, r12vrr_stack+708, r12vrr_stack+352, r12vrr_stack+81, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+2061, r12vrr_stack+680, NULL, r12vrr_stack+736, r12vrr_stack+708, NULL, r12vrr_stack+352);
 tmp = r12vrr_stack + 2061;
 target_ptr = Libr12->rvrr_classes[1][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_p0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2145, r12vrr_stack+491, r12vrr_stack+736, r12vrr_stack+554, r12vrr_stack+241, r12vrr_stack+96);
 tmp = r12vrr_stack + 2145;
 target_ptr = Libr12->t2vrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_p0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1725, r12vrr_stack+736, r12vrr_stack+1224, r12vrr_stack+984, r12vrr_stack+554, r12vrr_stack+491);
 tmp = r12vrr_stack + 1725;
 target_ptr = Libr12->t2vrr_classes[1][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_d0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+820, r12vrr_stack+554, r12vrr_stack+984, r12vrr_stack+1851, r12vrr_stack+1575, r12vrr_stack+241);
 tmp = r12vrr_stack + 820;
 target_ptr = Libr12->t2vrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_d0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1548, r12vrr_stack+984, r12vrr_stack+1332, r12vrr_stack+2229, r12vrr_stack+1851, r12vrr_stack+554);
 tmp = r12vrr_stack + 1548;
 target_ptr = Libr12->t2vrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_p0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+373, r12vrr_stack+491, r12vrr_stack+554, r12vrr_stack+736, r12vrr_stack+708, r12vrr_stack+352);
 tmp = r12vrr_stack + 373;
 target_ptr = Libr12->t1vrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_p0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+141, r12vrr_stack+736, r12vrr_stack+984, r12vrr_stack+1224, r12vrr_stack+1188, r12vrr_stack+708);
 tmp = r12vrr_stack + 141;
 target_ptr = Libr12->t1vrr_classes[1][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_d0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2509, r12vrr_stack+554, r12vrr_stack+1851, r12vrr_stack+984, r12vrr_stack+736, r12vrr_stack+491);
 tmp = r12vrr_stack + 2509;
 target_ptr = Libr12->t1vrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_d0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1809, r12vrr_stack+984, r12vrr_stack+2229, r12vrr_stack+1332, r12vrr_stack+1224, r12vrr_stack+736);
 tmp = r12vrr_stack + 1809;
 target_ptr = Libr12->t1vrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+1152, r12vrr_stack+15, r12vrr_stack+331, r12vrr_stack+554, r12vrr_stack+491, r12vrr_stack+352, r12vrr_stack+96);
 tmp = r12vrr_stack + 1152;
 target_ptr = Libr12->rvrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+1278, r12vrr_stack+2061, r12vrr_stack+680, r12vrr_stack+984, r12vrr_stack+736, r12vrr_stack+708, r12vrr_stack+491);
 tmp = r12vrr_stack + 1278;
 target_ptr = Libr12->rvrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];


}

