/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (p0|hg) integrals */

void d12vrr_order_p0hg(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+6, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+9, dvrr_stack+0, dvrr_stack+6, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+3, dvrr_stack+0, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+21, dvrr_stack+15, dvrr_stack+9, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+31, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+34, dvrr_stack+31, dvrr_stack+3, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+40, dvrr_stack+34, dvrr_stack+15, dvrr_stack+31, dvrr_stack+3, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+50, dvrr_stack+6, dvrr_stack+3, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+56, dvrr_stack+9, dvrr_stack+50, dvrr_stack+0, dvrr_stack+6, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+66, dvrr_stack+21, dvrr_stack+56, dvrr_stack+15, dvrr_stack+9, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+81, dvrr_stack+40, dvrr_stack+21, dvrr_stack+34, dvrr_stack+15, NULL);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+96, dvrr_stack+81, dvrr_stack+66, dvrr_stack+40, dvrr_stack+21, NULL);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+117, dvrr_stack+0, dvrr_stack+31, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+123, dvrr_stack+117, dvrr_stack+34, dvrr_stack+0, dvrr_stack+31, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+133, dvrr_stack+123, dvrr_stack+40, dvrr_stack+117, dvrr_stack+34, NULL);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+148, dvrr_stack+133, dvrr_stack+81, dvrr_stack+123, dvrr_stack+40, NULL);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+31, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+169, dvrr_stack+3, dvrr_stack+31, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+175, dvrr_stack+50, dvrr_stack+169, dvrr_stack+6, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+185, dvrr_stack+56, dvrr_stack+175, dvrr_stack+9, dvrr_stack+50, NULL);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+200, dvrr_stack+66, dvrr_stack+185, dvrr_stack+21, dvrr_stack+56, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+221, dvrr_stack+96, dvrr_stack+200, dvrr_stack+81, dvrr_stack+66, NULL);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+249, dvrr_stack+148, dvrr_stack+96, dvrr_stack+133, dvrr_stack+81, NULL);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+277, dvrr_stack+249, dvrr_stack+221, dvrr_stack+148, dvrr_stack+96, NULL);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+6, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+9, dvrr_stack+6, dvrr_stack+0, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+313, dvrr_stack+9, dvrr_stack+117, dvrr_stack+6, dvrr_stack+0, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+323, dvrr_stack+313, dvrr_stack+123, dvrr_stack+9, dvrr_stack+117, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+338, dvrr_stack+323, dvrr_stack+133, dvrr_stack+313, dvrr_stack+123, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+359, dvrr_stack+338, dvrr_stack+148, dvrr_stack+323, dvrr_stack+133, NULL);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+387, dvrr_stack+359, dvrr_stack+249, dvrr_stack+338, dvrr_stack+148, NULL);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6, dvrr_stack+31, dvrr_stack+0, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+423, dvrr_stack+169, dvrr_stack+6, dvrr_stack+3, dvrr_stack+31, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+433, dvrr_stack+175, dvrr_stack+423, dvrr_stack+50, dvrr_stack+169, NULL);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+448, dvrr_stack+185, dvrr_stack+433, dvrr_stack+56, dvrr_stack+175, NULL);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+469, dvrr_stack+200, dvrr_stack+448, dvrr_stack+66, dvrr_stack+185, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+497, dvrr_stack+221, dvrr_stack+469, dvrr_stack+96, dvrr_stack+200, NULL);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+533, dvrr_stack+277, dvrr_stack+497, dvrr_stack+249, dvrr_stack+221, NULL);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+578, dvrr_stack+387, dvrr_stack+277, dvrr_stack+359, dvrr_stack+249, NULL);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+623, dvrr_stack+578, dvrr_stack+533, dvrr_stack+387, dvrr_stack+277, NULL);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+50, dvrr_stack+0, dvrr_stack+3, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+56, dvrr_stack+6, dvrr_stack+50, dvrr_stack+31, dvrr_stack+0, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+678, dvrr_stack+423, dvrr_stack+56, dvrr_stack+169, dvrr_stack+6, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+693, dvrr_stack+433, dvrr_stack+678, dvrr_stack+175, dvrr_stack+423, NULL);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+714, dvrr_stack+448, dvrr_stack+693, dvrr_stack+185, dvrr_stack+433, NULL);

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+742, dvrr_stack+469, dvrr_stack+714, dvrr_stack+200, dvrr_stack+448, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+778, dvrr_stack+497, dvrr_stack+742, dvrr_stack+221, dvrr_stack+469, NULL);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+823, dvrr_stack+533, dvrr_stack+778, NULL, NULL, dvrr_stack+497);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+958, dvrr_stack+533, dvrr_stack+778, dvrr_stack+277, dvrr_stack+497, NULL);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+31, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+169, dvrr_stack+3, dvrr_stack+31, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+175, dvrr_stack+50, dvrr_stack+169, dvrr_stack+0, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+185, dvrr_stack+56, dvrr_stack+175, dvrr_stack+6, dvrr_stack+50, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1013, dvrr_stack+678, dvrr_stack+185, dvrr_stack+423, dvrr_stack+56, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1034, dvrr_stack+693, dvrr_stack+1013, dvrr_stack+433, dvrr_stack+678, NULL);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1062, dvrr_stack+714, dvrr_stack+1034, dvrr_stack+448, dvrr_stack+693, NULL);

 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+423, dvrr_stack+742, dvrr_stack+1062, dvrr_stack+469, dvrr_stack+714, NULL);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1098, dvrr_stack+778, dvrr_stack+423, dvrr_stack+497, dvrr_stack+742, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1153, dvrr_stack+958, dvrr_stack+1098, NULL, NULL, dvrr_stack+778);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1318, dvrr_stack+623, dvrr_stack+958, NULL, NULL, dvrr_stack+533);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1483, dvrr_stack+1318, dvrr_stack+1153, dvrr_stack+623, dvrr_stack+958, dvrr_stack+823);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1813, dvrr_stack+338, dvrr_stack+148, NULL, NULL, dvrr_stack+133);
 tmp = dvrr_stack + 1813;
 target_ptr = Libderiv->dvrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+1876, dvrr_stack+359, dvrr_stack+249, NULL, NULL, dvrr_stack+148);
 tmp = dvrr_stack + 1876;
 target_ptr = Libderiv->dvrr_classes[1][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+1960,dvrr_stack+1876,dvrr_stack+1813,3);


 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2149, dvrr_stack+387, dvrr_stack+277, NULL, NULL, dvrr_stack+249);
 tmp = dvrr_stack + 2149;
 target_ptr = Libderiv->dvrr_classes[1][7];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+2257,dvrr_stack+2149,dvrr_stack+1876,3);


 /* compute (1 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+2509,dvrr_stack+2257,dvrr_stack+1960,3);


 /* compute (1 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,63,dvrr_stack+2887, dvrr_stack+2509, dvrr_stack+1813);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3076, dvrr_stack+578, dvrr_stack+533, NULL, NULL, dvrr_stack+277);
 tmp = dvrr_stack + 3076;
 target_ptr = Libderiv->dvrr_classes[1][8];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+3211,dvrr_stack+3076,dvrr_stack+2149,3);


 /* compute (1 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+3535,dvrr_stack+3211,dvrr_stack+2257,3);


 /* compute (1 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,84,dvrr_stack+4039, dvrr_stack+3535, dvrr_stack+1876);

 /* compute (1 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+4291,dvrr_stack+1318,dvrr_stack+3076,3);


 /* compute (1 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+4696,dvrr_stack+4291,dvrr_stack+3211,3);


 /* compute (1 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,108,dvrr_stack+5344, dvrr_stack+4696, dvrr_stack+2149);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+5668, dvrr_stack+958, dvrr_stack+1098, dvrr_stack+533, dvrr_stack+778, NULL);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+5734, dvrr_stack+623, dvrr_stack+958, dvrr_stack+578, dvrr_stack+533, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+5800, dvrr_stack+5734, dvrr_stack+5668, NULL, NULL, dvrr_stack+958);

 /* compute (1 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+5998,dvrr_stack+5800,dvrr_stack+1318,3);


 /* compute (1 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+6493,dvrr_stack+5998,dvrr_stack+4291,3);


 /* compute (1 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,135,dvrr_stack+7303, dvrr_stack+6493, dvrr_stack+3076);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6, dvrr_stack+31, dvrr_stack+0, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+7708, dvrr_stack+169, dvrr_stack+6, dvrr_stack+3, dvrr_stack+31, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+0, dvrr_stack+175, dvrr_stack+7708, dvrr_stack+50, dvrr_stack+169, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+7708, dvrr_stack+185, dvrr_stack+0, dvrr_stack+56, dvrr_stack+175, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+7729, dvrr_stack+1013, dvrr_stack+7708, dvrr_stack+678, dvrr_stack+185, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7757, dvrr_stack+1034, dvrr_stack+7729, dvrr_stack+693, dvrr_stack+1013, NULL);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7708, dvrr_stack+1062, dvrr_stack+7757, dvrr_stack+714, dvrr_stack+1034, NULL);

 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+678, dvrr_stack+423, dvrr_stack+7708, dvrr_stack+742, dvrr_stack+1062, NULL);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+7708, dvrr_stack+1098, dvrr_stack+678, dvrr_stack+778, dvrr_stack+423, NULL);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+7774, dvrr_stack+5668, dvrr_stack+7708, dvrr_stack+958, dvrr_stack+1098, NULL);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+7852, dvrr_stack+5734, dvrr_stack+5668, dvrr_stack+623, dvrr_stack+958, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+7930, dvrr_stack+7852, dvrr_stack+7774, NULL, NULL, dvrr_stack+5668);

 /* compute (1 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+8164,dvrr_stack+7930,dvrr_stack+5800,3);


 /* compute (1 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+8758,dvrr_stack+8164,dvrr_stack+5998,3);


 /* compute (1 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,165,dvrr_stack+9748, dvrr_stack+8758, dvrr_stack+1318);

 /* compute (1 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,63,dvrr_stack+10243, dvrr_stack+2509, dvrr_stack+1813);

 /* compute (1 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,84,dvrr_stack+10432, dvrr_stack+3535, dvrr_stack+1876);

 /* compute (1 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,108,dvrr_stack+10684, dvrr_stack+4696, dvrr_stack+2149);

 /* compute (1 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,135,dvrr_stack+11008, dvrr_stack+6493, dvrr_stack+3076);

 /* compute (1 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,165,dvrr_stack+11413, dvrr_stack+8758, dvrr_stack+1318);

 /* compute (1 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,63,dvrr_stack+11908, dvrr_stack+2509, dvrr_stack+1813);

 /* compute (1 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,84,dvrr_stack+2509, dvrr_stack+3535, dvrr_stack+1876);

 /* compute (1 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,108,dvrr_stack+3535, dvrr_stack+4696, dvrr_stack+2149);

 /* compute (1 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,135,dvrr_stack+4696, dvrr_stack+6493, dvrr_stack+3076);

 /* compute (1 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,165,dvrr_stack+6493, dvrr_stack+8758, dvrr_stack+1318);

 /* compute (1 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+8758, dvrr_stack+323, dvrr_stack+133, NULL, NULL, dvrr_stack+123);

 /* compute (1 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+8803,dvrr_stack+1813,dvrr_stack+8758,3);


 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,45,dvrr_stack+8938, dvrr_stack+8803, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,84,dvrr_stack+8983, dvrr_stack+2257, NULL);
 tmp = dvrr_stack + 8983;
 target_ptr = Libderiv->deriv_classes[1][6][11];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,63,dvrr_stack+9067, dvrr_stack+1960, NULL);
 tmp = dvrr_stack + 9067;
 target_ptr = Libderiv->deriv_classes[1][5][11];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,108,dvrr_stack+9130, dvrr_stack+3211, NULL);
 tmp = dvrr_stack + 9130;
 target_ptr = Libderiv->deriv_classes[1][7][11];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,135,dvrr_stack+9238, dvrr_stack+4291, NULL);
 tmp = dvrr_stack + 9238;
 target_ptr = Libderiv->deriv_classes[1][8][11];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,165,dvrr_stack+9373, dvrr_stack+5998, NULL);
 tmp = dvrr_stack + 9373;
 target_ptr = Libderiv->deriv_classes[1][9][11];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,198,dvrr_stack+9538, dvrr_stack+8164, NULL);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,45,dvrr_stack+6988, dvrr_stack+8803, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,84,dvrr_stack+7033, dvrr_stack+2257, NULL);
 tmp = dvrr_stack + 7033;
 target_ptr = Libderiv->deriv_classes[1][6][10];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,63,dvrr_stack+7117, dvrr_stack+1960, NULL);
 tmp = dvrr_stack + 7117;
 target_ptr = Libderiv->deriv_classes[1][5][10];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,108,dvrr_stack+7180, dvrr_stack+3211, NULL);
 tmp = dvrr_stack + 7180;
 target_ptr = Libderiv->deriv_classes[1][7][10];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,135,dvrr_stack+5101, dvrr_stack+4291, NULL);
 tmp = dvrr_stack + 5101;
 target_ptr = Libderiv->deriv_classes[1][8][10];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,165,dvrr_stack+3859, dvrr_stack+5998, NULL);
 tmp = dvrr_stack + 3859;
 target_ptr = Libderiv->deriv_classes[1][9][10];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,198,dvrr_stack+12097, dvrr_stack+8164, NULL);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,45,dvrr_stack+5236, dvrr_stack+8803, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,84,dvrr_stack+8803, dvrr_stack+2257, NULL);
 tmp = dvrr_stack + 8803;
 target_ptr = Libderiv->deriv_classes[1][6][9];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,63,dvrr_stack+5281, dvrr_stack+1960, NULL);
 tmp = dvrr_stack + 5281;
 target_ptr = Libderiv->deriv_classes[1][5][9];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,108,dvrr_stack+1960, dvrr_stack+3211, NULL);
 tmp = dvrr_stack + 1960;
 target_ptr = Libderiv->deriv_classes[1][7][9];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,135,dvrr_stack+3211, dvrr_stack+4291, NULL);
 tmp = dvrr_stack + 3211;
 target_ptr = Libderiv->deriv_classes[1][8][9];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,165,dvrr_stack+4291, dvrr_stack+5998, NULL);
 tmp = dvrr_stack + 4291;
 target_ptr = Libderiv->deriv_classes[1][9][9];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,198,dvrr_stack+5998, dvrr_stack+8164, NULL);

 /* compute (1 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+8164, dvrr_stack+313, dvrr_stack+123, NULL, NULL, dvrr_stack+117);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,3,1,dvrr_stack+8194, dvrr_stack+1813, dvrr_stack+8164);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+8239, dvrr_stack+2149, dvrr_stack+1813);
 tmp = dvrr_stack + 8239;
 target_ptr = Libderiv->deriv_classes[1][6][8];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+8323, dvrr_stack+1876, dvrr_stack+8758);
 tmp = dvrr_stack + 8323;
 target_ptr = Libderiv->deriv_classes[1][5][8];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+8386, dvrr_stack+3076, dvrr_stack+1876);
 tmp = dvrr_stack + 8386;
 target_ptr = Libderiv->deriv_classes[1][7][8];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+8494, dvrr_stack+1318, dvrr_stack+2149);
 tmp = dvrr_stack + 8494;
 target_ptr = Libderiv->deriv_classes[1][8][8];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+6196, dvrr_stack+5800, dvrr_stack+3076);
 tmp = dvrr_stack + 6196;
 target_ptr = Libderiv->deriv_classes[1][9][8];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,3,1,dvrr_stack+4456, dvrr_stack+7930, dvrr_stack+1318);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,3,1,dvrr_stack+8629, dvrr_stack+1813, dvrr_stack+8164);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+8674, dvrr_stack+2149, dvrr_stack+1813);
 tmp = dvrr_stack + 8674;
 target_ptr = Libderiv->deriv_classes[1][6][7];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+6361, dvrr_stack+1876, dvrr_stack+8758);
 tmp = dvrr_stack + 6361;
 target_ptr = Libderiv->deriv_classes[1][5][7];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+3346, dvrr_stack+3076, dvrr_stack+1876);
 tmp = dvrr_stack + 3346;
 target_ptr = Libderiv->deriv_classes[1][7][7];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+2257, dvrr_stack+1318, dvrr_stack+2149);
 tmp = dvrr_stack + 2257;
 target_ptr = Libderiv->deriv_classes[1][8][7];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+12295, dvrr_stack+5800, dvrr_stack+3076);
 tmp = dvrr_stack + 12295;
 target_ptr = Libderiv->deriv_classes[1][9][7];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,3,1,dvrr_stack+12460, dvrr_stack+7930, dvrr_stack+1318);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,3,1,dvrr_stack+6424, dvrr_stack+1813, dvrr_stack+8164);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+2392, dvrr_stack+2149, dvrr_stack+1813);
 tmp = dvrr_stack + 2392;
 target_ptr = Libderiv->deriv_classes[1][6][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+3454, dvrr_stack+1876, dvrr_stack+8758);
 tmp = dvrr_stack + 3454;
 target_ptr = Libderiv->deriv_classes[1][5][6];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+2761, dvrr_stack+3076, dvrr_stack+1876);
 tmp = dvrr_stack + 2761;
 target_ptr = Libderiv->deriv_classes[1][7][6];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+7774, dvrr_stack+1318, dvrr_stack+2149);
 tmp = dvrr_stack + 7774;
 target_ptr = Libderiv->deriv_classes[1][8][6];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+12658, dvrr_stack+5800, dvrr_stack+3076);
 tmp = dvrr_stack + 12658;
 target_ptr = Libderiv->deriv_classes[1][9][6];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,3,1,dvrr_stack+12823, dvrr_stack+7930, dvrr_stack+1318);

 /* compute (0 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+2068,dvrr_stack+359,dvrr_stack+338,1);


 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,21,dvrr_stack+6469, dvrr_stack+2068, NULL);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+8887, dvrr_stack+133, dvrr_stack+81, NULL, NULL, dvrr_stack+40);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+7909, dvrr_stack+148, dvrr_stack+96, NULL, NULL, dvrr_stack+81);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+7972, dvrr_stack+1813, dvrr_stack+7909, dvrr_stack+338, dvrr_stack+148, dvrr_stack+8887);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+8098, dvrr_stack+249, dvrr_stack+221, NULL, NULL, dvrr_stack+96);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+13021, dvrr_stack+1876, dvrr_stack+8098, dvrr_stack+359, dvrr_stack+249, dvrr_stack+7909);

 /* compute (2 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+13189,dvrr_stack+13021,dvrr_stack+7972,6);


 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,126,dvrr_stack+13567, dvrr_stack+13189, NULL);

 /* compute (0 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+13693,dvrr_stack+387,dvrr_stack+359,1);


 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,28,dvrr_stack+4654, dvrr_stack+13693, NULL);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+13777, dvrr_stack+277, dvrr_stack+497, NULL, NULL, dvrr_stack+221);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+13885, dvrr_stack+2149, dvrr_stack+13777, dvrr_stack+387, dvrr_stack+277, dvrr_stack+8098);

 /* compute (2 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+14101,dvrr_stack+13885,dvrr_stack+13021,6);


 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,168,dvrr_stack+14605, dvrr_stack+14101, NULL);

 /* compute (0 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+14773,dvrr_stack+578,dvrr_stack+387,1);


 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,36,dvrr_stack+14881, dvrr_stack+14773, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+14917, dvrr_stack+3076, dvrr_stack+823, dvrr_stack+578, dvrr_stack+533, dvrr_stack+13777);

 /* compute (2 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+15187,dvrr_stack+14917,dvrr_stack+13885,6);


 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,216,dvrr_stack+15835, dvrr_stack+15187, NULL);

 /* compute (0 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+16051,dvrr_stack+623,dvrr_stack+578,1);


 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,45,dvrr_stack+16186, dvrr_stack+16051, NULL);

 /* compute (2 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+16231,dvrr_stack+1483,dvrr_stack+14917,6);


 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,270,dvrr_stack+17041, dvrr_stack+16231, NULL);

 /* compute (0 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+17311,dvrr_stack+5734,dvrr_stack+623,1);


 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,55,dvrr_stack+17476, dvrr_stack+17311, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+17531, dvrr_stack+5668, dvrr_stack+7708, NULL, NULL, dvrr_stack+1098);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+17729, dvrr_stack+5800, dvrr_stack+17531, dvrr_stack+5734, dvrr_stack+5668, dvrr_stack+1153);

 /* compute (2 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+18125,dvrr_stack+17729,dvrr_stack+1483,6);


 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,330,dvrr_stack+19115, dvrr_stack+18125, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,21,dvrr_stack+5668, dvrr_stack+2068, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,126,dvrr_stack+17531, dvrr_stack+13189, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,28,dvrr_stack+5689, dvrr_stack+13693, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,168,dvrr_stack+5800, dvrr_stack+14101, NULL);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,36,dvrr_stack+17657, dvrr_stack+14773, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,216,dvrr_stack+19445, dvrr_stack+15187, NULL);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,45,dvrr_stack+7708, dvrr_stack+16051, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,270,dvrr_stack+19661, dvrr_stack+16231, NULL);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,55,dvrr_stack+19931, dvrr_stack+17311, NULL);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,330,dvrr_stack+19986, dvrr_stack+18125, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,21,dvrr_stack+7753, dvrr_stack+2068, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+20316, dvrr_stack+13189, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,28,dvrr_stack+13189, dvrr_stack+13693, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+13217, dvrr_stack+14101, NULL);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,36,dvrr_stack+17693, dvrr_stack+14773, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+14101, dvrr_stack+15187, NULL);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,45,dvrr_stack+15187, dvrr_stack+16051, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+15232, dvrr_stack+16231, NULL);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,55,dvrr_stack+16231, dvrr_stack+17311, NULL);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+16286, dvrr_stack+18125, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,1,1,dvrr_stack+18125, dvrr_stack+359, dvrr_stack+323);

 /* compute (1 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+5968, dvrr_stack+123, dvrr_stack+40, NULL, NULL, dvrr_stack+34);

 /* compute (2 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+18146, dvrr_stack+8758, dvrr_stack+8887, dvrr_stack+323, dvrr_stack+133, dvrr_stack+5968);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+18236, dvrr_stack+13021, dvrr_stack+18146);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,1,1,dvrr_stack+5968, dvrr_stack+387, dvrr_stack+338);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+18362, dvrr_stack+13885, dvrr_stack+7972);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,1,1,dvrr_stack+8758, dvrr_stack+578, dvrr_stack+359);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+18530, dvrr_stack+14917, dvrr_stack+13021);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,1,1,dvrr_stack+18746, dvrr_stack+623, dvrr_stack+387);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+18791, dvrr_stack+1483, dvrr_stack+13885);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,1,1,dvrr_stack+17311, dvrr_stack+5734, dvrr_stack+578);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+16616, dvrr_stack+17729, dvrr_stack+14917);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,1,1,dvrr_stack+19061, dvrr_stack+359, dvrr_stack+323);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+16051, dvrr_stack+13021, dvrr_stack+18146);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,1,1,dvrr_stack+19082, dvrr_stack+387, dvrr_stack+338);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+15502, dvrr_stack+13885, dvrr_stack+7972);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,1,1,dvrr_stack+17366, dvrr_stack+578, dvrr_stack+359);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+14317, dvrr_stack+14917, dvrr_stack+13021);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,1,1,dvrr_stack+17402, dvrr_stack+623, dvrr_stack+387);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+20442, dvrr_stack+1483, dvrr_stack+13885);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,1,1,dvrr_stack+16946, dvrr_stack+5734, dvrr_stack+578);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+20712, dvrr_stack+17729, dvrr_stack+14917);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,1,1,dvrr_stack+17447, dvrr_stack+359, dvrr_stack+323);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+15670, dvrr_stack+13021, dvrr_stack+18146);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,1,1,dvrr_stack+18146, dvrr_stack+387, dvrr_stack+338);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+13385, dvrr_stack+13885, dvrr_stack+7972);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,1,1,dvrr_stack+18174, dvrr_stack+578, dvrr_stack+359);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+21042, dvrr_stack+14917, dvrr_stack+13021);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,1,1,dvrr_stack+14773, dvrr_stack+623, dvrr_stack+387);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+21258, dvrr_stack+1483, dvrr_stack+13885);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,1,1,dvrr_stack+14818, dvrr_stack+5734, dvrr_stack+578);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+21528, dvrr_stack+17729, dvrr_stack+14917);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,21,dvrr_stack+17729, dvrr_stack+1813, NULL);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+17750, dvrr_stack+40, dvrr_stack+21, NULL, NULL, dvrr_stack+15);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+17780, dvrr_stack+81, dvrr_stack+66, NULL, NULL, dvrr_stack+21);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+17825, dvrr_stack+8887, dvrr_stack+17780, dvrr_stack+133, dvrr_stack+81, dvrr_stack+17750);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+17915, dvrr_stack+96, dvrr_stack+200, NULL, NULL, dvrr_stack+66);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+17978, dvrr_stack+7909, dvrr_stack+17915, dvrr_stack+148, dvrr_stack+96, dvrr_stack+17780);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+21858, dvrr_stack+7972, dvrr_stack+17978, dvrr_stack+1813, dvrr_stack+7909, dvrr_stack+17825);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+17750, dvrr_stack+21858, dvrr_stack+1813);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,28,dvrr_stack+7909, dvrr_stack+1876, NULL);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+13693, dvrr_stack+221, dvrr_stack+469, NULL, NULL, dvrr_stack+200);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+22068, dvrr_stack+8098, dvrr_stack+13693, dvrr_stack+249, dvrr_stack+221, dvrr_stack+17915);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+22236, dvrr_stack+13021, dvrr_stack+22068, dvrr_stack+1876, dvrr_stack+8098, dvrr_stack+17978);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+17876, dvrr_stack+22236, dvrr_stack+1876);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,36,dvrr_stack+8098, dvrr_stack+2149, NULL);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+22516, dvrr_stack+497, dvrr_stack+742, NULL, NULL, dvrr_stack+469);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+22624, dvrr_stack+13777, dvrr_stack+22516, dvrr_stack+277, dvrr_stack+497, dvrr_stack+13693);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+22840, dvrr_stack+13885, dvrr_stack+22624, dvrr_stack+2149, dvrr_stack+13777, dvrr_stack+22068);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+23200, dvrr_stack+22840, dvrr_stack+2149);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,45,dvrr_stack+22068, dvrr_stack+3076, NULL);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+13693, dvrr_stack+778, dvrr_stack+423, NULL, NULL, dvrr_stack+742);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+23416, dvrr_stack+823, dvrr_stack+13693, dvrr_stack+533, dvrr_stack+778, dvrr_stack+22516);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+23686, dvrr_stack+14917, dvrr_stack+23416, dvrr_stack+3076, dvrr_stack+823, dvrr_stack+22624);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+22516, dvrr_stack+23686, dvrr_stack+3076);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,55,dvrr_stack+22113, dvrr_stack+1318, NULL);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+24136, dvrr_stack+1098, dvrr_stack+678, NULL, NULL, dvrr_stack+423);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+24301, dvrr_stack+1153, dvrr_stack+24136, dvrr_stack+958, dvrr_stack+1098, dvrr_stack+13693);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+24631, dvrr_stack+1483, dvrr_stack+24301, dvrr_stack+1318, dvrr_stack+1153, dvrr_stack+23416);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+24136, dvrr_stack+24631, dvrr_stack+1318);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,21,dvrr_stack+23416, dvrr_stack+1813, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+23437, dvrr_stack+21858, dvrr_stack+1813);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,28,dvrr_stack+23563, dvrr_stack+1876, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+13693, dvrr_stack+22236, dvrr_stack+1876);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,36,dvrr_stack+23591, dvrr_stack+2149, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+678, dvrr_stack+22840, dvrr_stack+2149);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,45,dvrr_stack+23627, dvrr_stack+3076, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+894, dvrr_stack+23686, dvrr_stack+3076);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,55,dvrr_stack+24466, dvrr_stack+1318, NULL);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+25181, dvrr_stack+24631, dvrr_stack+1318);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+13861, dvrr_stack+1813, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+423, dvrr_stack+21858, dvrr_stack+1813);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+1813, dvrr_stack+1876, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+21858, dvrr_stack+22236, dvrr_stack+1876);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+1841, dvrr_stack+2149, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+22168, dvrr_stack+22840, dvrr_stack+2149);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+1877, dvrr_stack+3076, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+22786, dvrr_stack+23686, dvrr_stack+3076);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,55,dvrr_stack+3076, dvrr_stack+1318, NULL);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+23672, dvrr_stack+24631, dvrr_stack+1318);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+24521, dvrr_stack+1483, dvrr_stack+623);
 tmp = dvrr_stack + 24521;
 target_ptr = Libderiv->deriv_classes[1][9][2];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+24686, dvrr_stack+1483, dvrr_stack+623);
 tmp = dvrr_stack + 24686;
 target_ptr = Libderiv->deriv_classes[1][9][1];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+24851, dvrr_stack+1483, dvrr_stack+623);
 tmp = dvrr_stack + 24851;
 target_ptr = Libderiv->deriv_classes[1][9][0];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,63,dvrr_stack+3131, dvrr_stack+2887, NULL);
 tmp = dvrr_stack + 3131;
 target_ptr = Libderiv->deriv2_classes[1][5][143];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,84,dvrr_stack+24002, dvrr_stack+4039, NULL);
 tmp = dvrr_stack + 24002;
 target_ptr = Libderiv->deriv2_classes[1][6][143];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,108,dvrr_stack+25016, dvrr_stack+5344, NULL);
 tmp = dvrr_stack + 25016;
 target_ptr = Libderiv->deriv2_classes[1][7][143];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,135,dvrr_stack+1164, dvrr_stack+7303, NULL);
 tmp = dvrr_stack + 1164;
 target_ptr = Libderiv->deriv2_classes[1][8][143];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,165,dvrr_stack+1299, dvrr_stack+9748, NULL);
 tmp = dvrr_stack + 1299;
 target_ptr = Libderiv->deriv2_classes[1][9][143];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,63,dvrr_stack+1464, dvrr_stack+2887, NULL);
 tmp = dvrr_stack + 1464;
 target_ptr = Libderiv->deriv2_classes[1][5][131];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,84,dvrr_stack+1527, dvrr_stack+4039, NULL);
 tmp = dvrr_stack + 1527;
 target_ptr = Libderiv->deriv2_classes[1][6][131];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,108,dvrr_stack+1611, dvrr_stack+5344, NULL);
 tmp = dvrr_stack + 1611;
 target_ptr = Libderiv->deriv2_classes[1][7][131];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,135,dvrr_stack+23056, dvrr_stack+7303, NULL);
 tmp = dvrr_stack + 23056;
 target_ptr = Libderiv->deriv2_classes[1][8][131];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,165,dvrr_stack+2068, dvrr_stack+9748, NULL);
 tmp = dvrr_stack + 2068;
 target_ptr = Libderiv->deriv2_classes[1][9][131];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,63,dvrr_stack+1719, dvrr_stack+10243, NULL);
 tmp = dvrr_stack + 1719;
 target_ptr = Libderiv->deriv2_classes[1][5][130];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,84,dvrr_stack+22384, dvrr_stack+10432, NULL);
 tmp = dvrr_stack + 22384;
 target_ptr = Libderiv->deriv2_classes[1][6][130];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,108,dvrr_stack+25511, dvrr_stack+10684, NULL);
 tmp = dvrr_stack + 25511;
 target_ptr = Libderiv->deriv2_classes[1][7][130];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,135,dvrr_stack+25619, dvrr_stack+11008, NULL);
 tmp = dvrr_stack + 25619;
 target_ptr = Libderiv->deriv2_classes[1][8][130];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,165,dvrr_stack+25754, dvrr_stack+11413, NULL);
 tmp = dvrr_stack + 25754;
 target_ptr = Libderiv->deriv2_classes[1][9][130];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,63,dvrr_stack+18044, dvrr_stack+2887, NULL);
 tmp = dvrr_stack + 18044;
 target_ptr = Libderiv->deriv2_classes[1][5][119];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,84,dvrr_stack+2869, dvrr_stack+4039, NULL);
 tmp = dvrr_stack + 2869;
 target_ptr = Libderiv->deriv2_classes[1][6][119];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,108,dvrr_stack+4024, dvrr_stack+5344, NULL);
 tmp = dvrr_stack + 4024;
 target_ptr = Libderiv->deriv2_classes[1][7][119];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,135,dvrr_stack+5344, dvrr_stack+7303, NULL);
 tmp = dvrr_stack + 5344;
 target_ptr = Libderiv->deriv2_classes[1][8][119];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,165,dvrr_stack+5479, dvrr_stack+9748, NULL);
 tmp = dvrr_stack + 5479;
 target_ptr = Libderiv->deriv2_classes[1][9][119];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,63,dvrr_stack+14533, dvrr_stack+10243, NULL);
 tmp = dvrr_stack + 14533;
 target_ptr = Libderiv->deriv2_classes[1][5][118];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,84,dvrr_stack+9736, dvrr_stack+10432, NULL);
 tmp = dvrr_stack + 9736;
 target_ptr = Libderiv->deriv2_classes[1][6][118];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,108,dvrr_stack+9820, dvrr_stack+10684, NULL);
 tmp = dvrr_stack + 9820;
 target_ptr = Libderiv->deriv2_classes[1][7][118];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,135,dvrr_stack+9928, dvrr_stack+11008, NULL);
 tmp = dvrr_stack + 9928;
 target_ptr = Libderiv->deriv2_classes[1][8][118];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,165,dvrr_stack+10063, dvrr_stack+11413, NULL);
 tmp = dvrr_stack + 10063;
 target_ptr = Libderiv->deriv2_classes[1][9][118];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,63,dvrr_stack+5717, dvrr_stack+11908, NULL);
 tmp = dvrr_stack + 5717;
 target_ptr = Libderiv->deriv2_classes[1][5][117];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,84,dvrr_stack+10228, dvrr_stack+2509, NULL);
 tmp = dvrr_stack + 10228;
 target_ptr = Libderiv->deriv2_classes[1][6][117];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,108,dvrr_stack+2476, dvrr_stack+3535, NULL);
 tmp = dvrr_stack + 2476;
 target_ptr = Libderiv->deriv2_classes[1][7][117];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,135,dvrr_stack+3517, dvrr_stack+4696, NULL);
 tmp = dvrr_stack + 3517;
 target_ptr = Libderiv->deriv2_classes[1][8][117];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,165,dvrr_stack+4682, dvrr_stack+6493, NULL);
 tmp = dvrr_stack + 4682;
 target_ptr = Libderiv->deriv2_classes[1][9][117];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+6490, dvrr_stack+8983, dvrr_stack+8938);
 tmp = dvrr_stack + 6490;
 target_ptr = Libderiv->deriv2_classes[1][5][107];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+6553, dvrr_stack+9130, dvrr_stack+9067);
 tmp = dvrr_stack + 6553;
 target_ptr = Libderiv->deriv2_classes[1][6][107];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+6637, dvrr_stack+9238, dvrr_stack+8983);
 tmp = dvrr_stack + 6637;
 target_ptr = Libderiv->deriv2_classes[1][7][107];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+6745, dvrr_stack+9373, dvrr_stack+9130);
 tmp = dvrr_stack + 6745;
 target_ptr = Libderiv->deriv2_classes[1][8][107];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+4847, dvrr_stack+9538, dvrr_stack+9238);
 tmp = dvrr_stack + 4847;
 target_ptr = Libderiv->deriv2_classes[1][9][107];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+6880, dvrr_stack+7033, dvrr_stack+6988);
 tmp = dvrr_stack + 6880;
 target_ptr = Libderiv->deriv2_classes[1][5][106];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+5012, dvrr_stack+7180, dvrr_stack+7117);
 tmp = dvrr_stack + 5012;
 target_ptr = Libderiv->deriv2_classes[1][6][106];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+3652, dvrr_stack+5101, dvrr_stack+7033);
 tmp = dvrr_stack + 3652;
 target_ptr = Libderiv->deriv2_classes[1][7][106];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+2584, dvrr_stack+3859, dvrr_stack+7180);
 tmp = dvrr_stack + 2584;
 target_ptr = Libderiv->deriv2_classes[1][8][106];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+10312, dvrr_stack+12097, dvrr_stack+5101);
 tmp = dvrr_stack + 10312;
 target_ptr = Libderiv->deriv2_classes[1][9][106];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+3760, dvrr_stack+8803, dvrr_stack+5236);
 tmp = dvrr_stack + 3760;
 target_ptr = Libderiv->deriv2_classes[1][5][105];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+10477, dvrr_stack+1960, dvrr_stack+5281);
 tmp = dvrr_stack + 10477;
 target_ptr = Libderiv->deriv2_classes[1][6][105];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+10561, dvrr_stack+3211, dvrr_stack+8803);
 tmp = dvrr_stack + 10561;
 target_ptr = Libderiv->deriv2_classes[1][7][105];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+10669, dvrr_stack+4291, dvrr_stack+1960);
 tmp = dvrr_stack + 10669;
 target_ptr = Libderiv->deriv2_classes[1][8][105];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+10804, dvrr_stack+5998, dvrr_stack+3211);
 tmp = dvrr_stack + 10804;
 target_ptr = Libderiv->deriv2_classes[1][9][105];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+10969, dvrr_stack+8239, dvrr_stack+8194);
 tmp = dvrr_stack + 10969;
 target_ptr = Libderiv->deriv2_classes[1][5][104];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+11032, dvrr_stack+8386, dvrr_stack+8323);
 tmp = dvrr_stack + 11032;
 target_ptr = Libderiv->deriv2_classes[1][6][104];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+11116, dvrr_stack+8494, dvrr_stack+8239);
 tmp = dvrr_stack + 11116;
 target_ptr = Libderiv->deriv2_classes[1][7][104];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+11224, dvrr_stack+6196, dvrr_stack+8386);
 tmp = dvrr_stack + 11224;
 target_ptr = Libderiv->deriv2_classes[1][8][104];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+11359, dvrr_stack+4456, dvrr_stack+8494);
 tmp = dvrr_stack + 11359;
 target_ptr = Libderiv->deriv2_classes[1][9][104];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+11524, dvrr_stack+8983, dvrr_stack+8938);
 tmp = dvrr_stack + 11524;
 target_ptr = Libderiv->deriv2_classes[1][5][95];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+11587, dvrr_stack+9130, dvrr_stack+9067);
 tmp = dvrr_stack + 11587;
 target_ptr = Libderiv->deriv2_classes[1][6][95];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+11671, dvrr_stack+9238, dvrr_stack+8983);
 tmp = dvrr_stack + 11671;
 target_ptr = Libderiv->deriv2_classes[1][7][95];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+11779, dvrr_stack+9373, dvrr_stack+9130);
 tmp = dvrr_stack + 11779;
 target_ptr = Libderiv->deriv2_classes[1][8][95];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+11914, dvrr_stack+9538, dvrr_stack+9238);
 tmp = dvrr_stack + 11914;
 target_ptr = Libderiv->deriv2_classes[1][9][95];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+7288, dvrr_stack+7033, dvrr_stack+6988);
 tmp = dvrr_stack + 7288;
 target_ptr = Libderiv->deriv2_classes[1][5][94];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+7351, dvrr_stack+7180, dvrr_stack+7117);
 tmp = dvrr_stack + 7351;
 target_ptr = Libderiv->deriv2_classes[1][6][94];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+7435, dvrr_stack+5101, dvrr_stack+7033);
 tmp = dvrr_stack + 7435;
 target_ptr = Libderiv->deriv2_classes[1][7][94];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+7543, dvrr_stack+3859, dvrr_stack+7180);
 tmp = dvrr_stack + 7543;
 target_ptr = Libderiv->deriv2_classes[1][8][94];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+0, dvrr_stack+12097, dvrr_stack+5101);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv2_classes[1][9][94];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+4132, dvrr_stack+8803, dvrr_stack+5236);
 tmp = dvrr_stack + 4132;
 target_ptr = Libderiv->deriv2_classes[1][5][93];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+4195, dvrr_stack+1960, dvrr_stack+5281);
 tmp = dvrr_stack + 4195;
 target_ptr = Libderiv->deriv2_classes[1][6][93];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+2953, dvrr_stack+3211, dvrr_stack+8803);
 tmp = dvrr_stack + 2953;
 target_ptr = Libderiv->deriv2_classes[1][7][93];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+165, dvrr_stack+4291, dvrr_stack+1960);
 tmp = dvrr_stack + 165;
 target_ptr = Libderiv->deriv2_classes[1][8][93];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+25919, dvrr_stack+5998, dvrr_stack+3211);
 tmp = dvrr_stack + 25919;
 target_ptr = Libderiv->deriv2_classes[1][9][93];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+26084, dvrr_stack+8239, dvrr_stack+8194);
 tmp = dvrr_stack + 26084;
 target_ptr = Libderiv->deriv2_classes[1][5][92];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+26147, dvrr_stack+8386, dvrr_stack+8323);
 tmp = dvrr_stack + 26147;
 target_ptr = Libderiv->deriv2_classes[1][6][92];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+26231, dvrr_stack+8494, dvrr_stack+8239);
 tmp = dvrr_stack + 26231;
 target_ptr = Libderiv->deriv2_classes[1][7][92];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+26339, dvrr_stack+6196, dvrr_stack+8386);
 tmp = dvrr_stack + 26339;
 target_ptr = Libderiv->deriv2_classes[1][8][92];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+26474, dvrr_stack+4456, dvrr_stack+8494);
 tmp = dvrr_stack + 26474;
 target_ptr = Libderiv->deriv2_classes[1][9][92];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+26639, dvrr_stack+8674, dvrr_stack+8629);
 tmp = dvrr_stack + 26639;
 target_ptr = Libderiv->deriv2_classes[1][5][91];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+26702, dvrr_stack+3346, dvrr_stack+6361);
 tmp = dvrr_stack + 26702;
 target_ptr = Libderiv->deriv2_classes[1][6][91];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+26786, dvrr_stack+2257, dvrr_stack+8674);
 tmp = dvrr_stack + 26786;
 target_ptr = Libderiv->deriv2_classes[1][7][91];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+26894, dvrr_stack+12295, dvrr_stack+3346);
 tmp = dvrr_stack + 26894;
 target_ptr = Libderiv->deriv2_classes[1][8][91];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+27029, dvrr_stack+12460, dvrr_stack+2257);
 tmp = dvrr_stack + 27029;
 target_ptr = Libderiv->deriv2_classes[1][9][91];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+27194, dvrr_stack+8983, dvrr_stack+8938);
 tmp = dvrr_stack + 27194;
 target_ptr = Libderiv->deriv2_classes[1][5][83];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+8887, dvrr_stack+9130, dvrr_stack+9067);
 tmp = dvrr_stack + 8887;
 target_ptr = Libderiv->deriv2_classes[1][6][83];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+27257, dvrr_stack+9238, dvrr_stack+8983);
 tmp = dvrr_stack + 27257;
 target_ptr = Libderiv->deriv2_classes[1][7][83];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+8971, dvrr_stack+9373, dvrr_stack+9130);
 tmp = dvrr_stack + 8971;
 target_ptr = Libderiv->deriv2_classes[1][8][83];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+9373, dvrr_stack+9538, dvrr_stack+9238);
 tmp = dvrr_stack + 9373;
 target_ptr = Libderiv->deriv2_classes[1][9][83];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+9538, dvrr_stack+7033, dvrr_stack+6988);
 tmp = dvrr_stack + 9538;
 target_ptr = Libderiv->deriv2_classes[1][5][82];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+9601, dvrr_stack+7180, dvrr_stack+7117);
 tmp = dvrr_stack + 9601;
 target_ptr = Libderiv->deriv2_classes[1][6][82];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+9106, dvrr_stack+5101, dvrr_stack+7033);
 tmp = dvrr_stack + 9106;
 target_ptr = Libderiv->deriv2_classes[1][7][82];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+9214, dvrr_stack+3859, dvrr_stack+7180);
 tmp = dvrr_stack + 9214;
 target_ptr = Libderiv->deriv2_classes[1][8][82];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+6943, dvrr_stack+12097, dvrr_stack+5101);
 tmp = dvrr_stack + 6943;
 target_ptr = Libderiv->deriv2_classes[1][9][82];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+7108, dvrr_stack+8803, dvrr_stack+5236);
 tmp = dvrr_stack + 7108;
 target_ptr = Libderiv->deriv2_classes[1][5][81];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+7171, dvrr_stack+1960, dvrr_stack+5281);
 tmp = dvrr_stack + 7171;
 target_ptr = Libderiv->deriv2_classes[1][6][81];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+5096, dvrr_stack+3211, dvrr_stack+8803);
 tmp = dvrr_stack + 5096;
 target_ptr = Libderiv->deriv2_classes[1][7][81];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+5204, dvrr_stack+4291, dvrr_stack+1960);
 tmp = dvrr_stack + 5204;
 target_ptr = Libderiv->deriv2_classes[1][8][81];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+3823, dvrr_stack+5998, dvrr_stack+3211);
 tmp = dvrr_stack + 3823;
 target_ptr = Libderiv->deriv2_classes[1][9][81];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+3194, dvrr_stack+8239, dvrr_stack+8194);
 tmp = dvrr_stack + 3194;
 target_ptr = Libderiv->deriv2_classes[1][5][80];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+3257, dvrr_stack+8386, dvrr_stack+8323);
 tmp = dvrr_stack + 3257;
 target_ptr = Libderiv->deriv2_classes[1][6][80];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+1922, dvrr_stack+8494, dvrr_stack+8239);
 tmp = dvrr_stack + 1922;
 target_ptr = Libderiv->deriv2_classes[1][7][80];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+8134, dvrr_stack+6196, dvrr_stack+8386);
 tmp = dvrr_stack + 8134;
 target_ptr = Libderiv->deriv2_classes[1][8][80];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+8269, dvrr_stack+4456, dvrr_stack+8494);
 tmp = dvrr_stack + 8269;
 target_ptr = Libderiv->deriv2_classes[1][9][80];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+8434, dvrr_stack+8674, dvrr_stack+8629);
 tmp = dvrr_stack + 8434;
 target_ptr = Libderiv->deriv2_classes[1][5][79];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+8497, dvrr_stack+3346, dvrr_stack+6361);
 tmp = dvrr_stack + 8497;
 target_ptr = Libderiv->deriv2_classes[1][6][79];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+5996, dvrr_stack+2257, dvrr_stack+8674);
 tmp = dvrr_stack + 5996;
 target_ptr = Libderiv->deriv2_classes[1][7][79];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+8581, dvrr_stack+12295, dvrr_stack+3346);
 tmp = dvrr_stack + 8581;
 target_ptr = Libderiv->deriv2_classes[1][8][79];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+6104, dvrr_stack+12460, dvrr_stack+2257);
 tmp = dvrr_stack + 6104;
 target_ptr = Libderiv->deriv2_classes[1][9][79];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+3341, dvrr_stack+2392, dvrr_stack+6424);
 tmp = dvrr_stack + 3341;
 target_ptr = Libderiv->deriv2_classes[1][5][78];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+6269, dvrr_stack+2761, dvrr_stack+3454);
 tmp = dvrr_stack + 6269;
 target_ptr = Libderiv->deriv2_classes[1][6][78];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+3404, dvrr_stack+7774, dvrr_stack+2392);
 tmp = dvrr_stack + 3404;
 target_ptr = Libderiv->deriv2_classes[1][7][78];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+2233, dvrr_stack+12658, dvrr_stack+2761);
 tmp = dvrr_stack + 2233;
 target_ptr = Libderiv->deriv2_classes[1][8][78];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+12079, dvrr_stack+12823, dvrr_stack+7774);
 tmp = dvrr_stack + 12079;
 target_ptr = Libderiv->deriv2_classes[1][9][78];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,21,dvrr_stack+7774, dvrr_stack+13567, dvrr_stack+6469);
 tmp = dvrr_stack + 7774;
 target_ptr = Libderiv->deriv2_classes[1][5][35];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,28,dvrr_stack+6353, dvrr_stack+14605, dvrr_stack+4654);
 tmp = dvrr_stack + 6353;
 target_ptr = Libderiv->deriv2_classes[1][6][35];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,36,dvrr_stack+2368, dvrr_stack+15835, dvrr_stack+14881);
 tmp = dvrr_stack + 2368;
 target_ptr = Libderiv->deriv2_classes[1][7][35];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,45,dvrr_stack+2719, dvrr_stack+17041, dvrr_stack+16186);
 tmp = dvrr_stack + 2719;
 target_ptr = Libderiv->deriv2_classes[1][8][35];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,55,dvrr_stack+12244, dvrr_stack+19115, dvrr_stack+17476);
 tmp = dvrr_stack + 12244;
 target_ptr = Libderiv->deriv2_classes[1][9][35];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+7837, dvrr_stack+17531, dvrr_stack+5668);
 tmp = dvrr_stack + 7837;
 target_ptr = Libderiv->deriv2_classes[1][5][34];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+8794, dvrr_stack+5800, dvrr_stack+5689);
 tmp = dvrr_stack + 8794;
 target_ptr = Libderiv->deriv2_classes[1][6][34];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+12409, dvrr_stack+19445, dvrr_stack+17657);
 tmp = dvrr_stack + 12409;
 target_ptr = Libderiv->deriv2_classes[1][7][34];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+12517, dvrr_stack+19661, dvrr_stack+7708);
 tmp = dvrr_stack + 12517;
 target_ptr = Libderiv->deriv2_classes[1][8][34];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+12652, dvrr_stack+19986, dvrr_stack+19931);
 tmp = dvrr_stack + 12652;
 target_ptr = Libderiv->deriv2_classes[1][9][34];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+12817, dvrr_stack+20316, dvrr_stack+7753);
 tmp = dvrr_stack + 12817;
 target_ptr = Libderiv->deriv2_classes[1][5][33];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+12880, dvrr_stack+13217, dvrr_stack+13189);
 tmp = dvrr_stack + 12880;
 target_ptr = Libderiv->deriv2_classes[1][6][33];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+4279, dvrr_stack+14101, dvrr_stack+17693);
 tmp = dvrr_stack + 4279;
 target_ptr = Libderiv->deriv2_classes[1][7][33];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+4387, dvrr_stack+15232, dvrr_stack+15187);
 tmp = dvrr_stack + 4387;
 target_ptr = Libderiv->deriv2_classes[1][8][33];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+27365, dvrr_stack+16286, dvrr_stack+16231);
 tmp = dvrr_stack + 27365;
 target_ptr = Libderiv->deriv2_classes[1][9][33];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+4522, dvrr_stack+18236, dvrr_stack+18125);
 tmp = dvrr_stack + 4522;
 target_ptr = Libderiv->deriv2_classes[1][5][32];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+27530, dvrr_stack+18362, dvrr_stack+5968);
 tmp = dvrr_stack + 27530;
 target_ptr = Libderiv->deriv2_classes[1][6][32];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+27614, dvrr_stack+18530, dvrr_stack+8758);
 tmp = dvrr_stack + 27614;
 target_ptr = Libderiv->deriv2_classes[1][7][32];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+27722, dvrr_stack+18791, dvrr_stack+18746);
 tmp = dvrr_stack + 27722;
 target_ptr = Libderiv->deriv2_classes[1][8][32];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+27857, dvrr_stack+16616, dvrr_stack+17311);
 tmp = dvrr_stack + 27857;
 target_ptr = Libderiv->deriv2_classes[1][9][32];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+4585, dvrr_stack+16051, dvrr_stack+19061);
 tmp = dvrr_stack + 4585;
 target_ptr = Libderiv->deriv2_classes[1][5][31];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+28022, dvrr_stack+15502, dvrr_stack+19082);
 tmp = dvrr_stack + 28022;
 target_ptr = Libderiv->deriv2_classes[1][6][31];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+28106, dvrr_stack+14317, dvrr_stack+17366);
 tmp = dvrr_stack + 28106;
 target_ptr = Libderiv->deriv2_classes[1][7][31];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+28214, dvrr_stack+20442, dvrr_stack+17402);
 tmp = dvrr_stack + 28214;
 target_ptr = Libderiv->deriv2_classes[1][8][31];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+28349, dvrr_stack+20712, dvrr_stack+16946);
 tmp = dvrr_stack + 28349;
 target_ptr = Libderiv->deriv2_classes[1][9][31];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+28514, dvrr_stack+7972, dvrr_stack+338);
 tmp = dvrr_stack + 28514;
 target_ptr = Libderiv->deriv_classes[1][5][2];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+28577, dvrr_stack+15670, dvrr_stack+17447);
 tmp = dvrr_stack + 28577;
 target_ptr = Libderiv->deriv2_classes[1][5][30];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+28640, dvrr_stack+13021, dvrr_stack+359);
 tmp = dvrr_stack + 28640;
 target_ptr = Libderiv->deriv_classes[1][6][2];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+28724, dvrr_stack+13385, dvrr_stack+18146);
 tmp = dvrr_stack + 28724;
 target_ptr = Libderiv->deriv2_classes[1][6][30];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+28808, dvrr_stack+13885, dvrr_stack+387);
 tmp = dvrr_stack + 28808;
 target_ptr = Libderiv->deriv_classes[1][7][2];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+28916, dvrr_stack+21042, dvrr_stack+18174);
 tmp = dvrr_stack + 28916;
 target_ptr = Libderiv->deriv2_classes[1][7][30];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+29024, dvrr_stack+14917, dvrr_stack+578);
 tmp = dvrr_stack + 29024;
 target_ptr = Libderiv->deriv_classes[1][8][2];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+29159, dvrr_stack+21258, dvrr_stack+14773);
 tmp = dvrr_stack + 29159;
 target_ptr = Libderiv->deriv2_classes[1][8][30];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+29294, dvrr_stack+21528, dvrr_stack+14818);
 tmp = dvrr_stack + 29294;
 target_ptr = Libderiv->deriv2_classes[1][9][30];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+29459, dvrr_stack+17750, dvrr_stack+17729);
 tmp = dvrr_stack + 29459;
 target_ptr = Libderiv->deriv2_classes[1][5][26];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+29522, dvrr_stack+17876, dvrr_stack+7909);
 tmp = dvrr_stack + 29522;
 target_ptr = Libderiv->deriv2_classes[1][6][26];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+29606, dvrr_stack+23200, dvrr_stack+8098);
 tmp = dvrr_stack + 29606;
 target_ptr = Libderiv->deriv2_classes[1][7][26];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+29714, dvrr_stack+22516, dvrr_stack+22068);
 tmp = dvrr_stack + 29714;
 target_ptr = Libderiv->deriv2_classes[1][8][26];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+29849, dvrr_stack+24136, dvrr_stack+22113);
 tmp = dvrr_stack + 29849;
 target_ptr = Libderiv->deriv2_classes[1][9][26];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,21,dvrr_stack+30014, dvrr_stack+13567, dvrr_stack+6469);
 tmp = dvrr_stack + 30014;
 target_ptr = Libderiv->deriv2_classes[1][5][23];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,28,dvrr_stack+30077, dvrr_stack+14605, dvrr_stack+4654);
 tmp = dvrr_stack + 30077;
 target_ptr = Libderiv->deriv2_classes[1][6][23];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,36,dvrr_stack+30161, dvrr_stack+15835, dvrr_stack+14881);
 tmp = dvrr_stack + 30161;
 target_ptr = Libderiv->deriv2_classes[1][7][23];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,45,dvrr_stack+30269, dvrr_stack+17041, dvrr_stack+16186);
 tmp = dvrr_stack + 30269;
 target_ptr = Libderiv->deriv2_classes[1][8][23];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,55,dvrr_stack+30404, dvrr_stack+19115, dvrr_stack+17476);
 tmp = dvrr_stack + 30404;
 target_ptr = Libderiv->deriv2_classes[1][9][23];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+30569, dvrr_stack+17531, dvrr_stack+5668);
 tmp = dvrr_stack + 30569;
 target_ptr = Libderiv->deriv2_classes[1][5][22];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+30632, dvrr_stack+5800, dvrr_stack+5689);
 tmp = dvrr_stack + 30632;
 target_ptr = Libderiv->deriv2_classes[1][6][22];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+30716, dvrr_stack+19445, dvrr_stack+17657);
 tmp = dvrr_stack + 30716;
 target_ptr = Libderiv->deriv2_classes[1][7][22];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+30824, dvrr_stack+19661, dvrr_stack+7708);
 tmp = dvrr_stack + 30824;
 target_ptr = Libderiv->deriv2_classes[1][8][22];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+30959, dvrr_stack+19986, dvrr_stack+19931);
 tmp = dvrr_stack + 30959;
 target_ptr = Libderiv->deriv2_classes[1][9][22];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+31124, dvrr_stack+20316, dvrr_stack+7753);
 tmp = dvrr_stack + 31124;
 target_ptr = Libderiv->deriv2_classes[1][5][21];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+31187, dvrr_stack+13217, dvrr_stack+13189);
 tmp = dvrr_stack + 31187;
 target_ptr = Libderiv->deriv2_classes[1][6][21];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+31271, dvrr_stack+14101, dvrr_stack+17693);
 tmp = dvrr_stack + 31271;
 target_ptr = Libderiv->deriv2_classes[1][7][21];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+31379, dvrr_stack+15232, dvrr_stack+15187);
 tmp = dvrr_stack + 31379;
 target_ptr = Libderiv->deriv2_classes[1][8][21];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+31514, dvrr_stack+16286, dvrr_stack+16231);
 tmp = dvrr_stack + 31514;
 target_ptr = Libderiv->deriv2_classes[1][9][21];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+31679, dvrr_stack+18236, dvrr_stack+18125);
 tmp = dvrr_stack + 31679;
 target_ptr = Libderiv->deriv2_classes[1][5][20];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+31742, dvrr_stack+18362, dvrr_stack+5968);
 tmp = dvrr_stack + 31742;
 target_ptr = Libderiv->deriv2_classes[1][6][20];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+31826, dvrr_stack+18530, dvrr_stack+8758);
 tmp = dvrr_stack + 31826;
 target_ptr = Libderiv->deriv2_classes[1][7][20];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+31934, dvrr_stack+18791, dvrr_stack+18746);
 tmp = dvrr_stack + 31934;
 target_ptr = Libderiv->deriv2_classes[1][8][20];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+32069, dvrr_stack+16616, dvrr_stack+17311);
 tmp = dvrr_stack + 32069;
 target_ptr = Libderiv->deriv2_classes[1][9][20];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+32234, dvrr_stack+16051, dvrr_stack+19061);
 tmp = dvrr_stack + 32234;
 target_ptr = Libderiv->deriv2_classes[1][5][19];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+32297, dvrr_stack+15502, dvrr_stack+19082);
 tmp = dvrr_stack + 32297;
 target_ptr = Libderiv->deriv2_classes[1][6][19];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+32381, dvrr_stack+14317, dvrr_stack+17366);
 tmp = dvrr_stack + 32381;
 target_ptr = Libderiv->deriv2_classes[1][7][19];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+32489, dvrr_stack+20442, dvrr_stack+17402);
 tmp = dvrr_stack + 32489;
 target_ptr = Libderiv->deriv2_classes[1][8][19];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+32624, dvrr_stack+20712, dvrr_stack+16946);
 tmp = dvrr_stack + 32624;
 target_ptr = Libderiv->deriv2_classes[1][9][19];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+32789, dvrr_stack+7972, dvrr_stack+338);
 tmp = dvrr_stack + 32789;
 target_ptr = Libderiv->deriv_classes[1][5][1];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+32852, dvrr_stack+15670, dvrr_stack+17447);
 tmp = dvrr_stack + 32852;
 target_ptr = Libderiv->deriv2_classes[1][5][18];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+32915, dvrr_stack+13021, dvrr_stack+359);
 tmp = dvrr_stack + 32915;
 target_ptr = Libderiv->deriv_classes[1][6][1];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+32999, dvrr_stack+13385, dvrr_stack+18146);
 tmp = dvrr_stack + 32999;
 target_ptr = Libderiv->deriv2_classes[1][6][18];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+33083, dvrr_stack+13885, dvrr_stack+387);
 tmp = dvrr_stack + 33083;
 target_ptr = Libderiv->deriv_classes[1][7][1];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+33191, dvrr_stack+21042, dvrr_stack+18174);
 tmp = dvrr_stack + 33191;
 target_ptr = Libderiv->deriv2_classes[1][7][18];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+33299, dvrr_stack+14917, dvrr_stack+578);
 tmp = dvrr_stack + 33299;
 target_ptr = Libderiv->deriv_classes[1][8][1];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+33434, dvrr_stack+21258, dvrr_stack+14773);
 tmp = dvrr_stack + 33434;
 target_ptr = Libderiv->deriv2_classes[1][8][18];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+33569, dvrr_stack+21528, dvrr_stack+14818);
 tmp = dvrr_stack + 33569;
 target_ptr = Libderiv->deriv2_classes[1][9][18];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+33734, dvrr_stack+17750, dvrr_stack+17729);
 tmp = dvrr_stack + 33734;
 target_ptr = Libderiv->deriv2_classes[1][5][14];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+33797, dvrr_stack+17876, dvrr_stack+7909);
 tmp = dvrr_stack + 33797;
 target_ptr = Libderiv->deriv2_classes[1][6][14];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+33881, dvrr_stack+23200, dvrr_stack+8098);
 tmp = dvrr_stack + 33881;
 target_ptr = Libderiv->deriv2_classes[1][7][14];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+33989, dvrr_stack+22516, dvrr_stack+22068);
 tmp = dvrr_stack + 33989;
 target_ptr = Libderiv->deriv2_classes[1][8][14];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+34124, dvrr_stack+24136, dvrr_stack+22113);
 tmp = dvrr_stack + 34124;
 target_ptr = Libderiv->deriv2_classes[1][9][14];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+34289, dvrr_stack+23437, dvrr_stack+23416);
 tmp = dvrr_stack + 34289;
 target_ptr = Libderiv->deriv2_classes[1][5][13];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+34352, dvrr_stack+13693, dvrr_stack+23563);
 tmp = dvrr_stack + 34352;
 target_ptr = Libderiv->deriv2_classes[1][6][13];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+34436, dvrr_stack+678, dvrr_stack+23591);
 tmp = dvrr_stack + 34436;
 target_ptr = Libderiv->deriv2_classes[1][7][13];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+34544, dvrr_stack+894, dvrr_stack+23627);
 tmp = dvrr_stack + 34544;
 target_ptr = Libderiv->deriv2_classes[1][8][13];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+34679, dvrr_stack+25181, dvrr_stack+24466);
 tmp = dvrr_stack + 34679;
 target_ptr = Libderiv->deriv2_classes[1][9][13];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,21,dvrr_stack+34844, dvrr_stack+13567, dvrr_stack+6469);
 tmp = dvrr_stack + 34844;
 target_ptr = Libderiv->deriv2_classes[1][5][11];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,28,dvrr_stack+13553, dvrr_stack+14605, dvrr_stack+4654);
 tmp = dvrr_stack + 13553;
 target_ptr = Libderiv->deriv2_classes[1][6][11];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,36,dvrr_stack+14596, dvrr_stack+15835, dvrr_stack+14881);
 tmp = dvrr_stack + 14596;
 target_ptr = Libderiv->deriv2_classes[1][7][11];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,45,dvrr_stack+15796, dvrr_stack+17041, dvrr_stack+16186);
 tmp = dvrr_stack + 15796;
 target_ptr = Libderiv->deriv2_classes[1][8][11];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,55,dvrr_stack+17001, dvrr_stack+19115, dvrr_stack+17476);
 tmp = dvrr_stack + 17001;
 target_ptr = Libderiv->deriv2_classes[1][9][11];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+17468, dvrr_stack+17531, dvrr_stack+5668);
 tmp = dvrr_stack + 17468;
 target_ptr = Libderiv->deriv2_classes[1][5][10];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+17531, dvrr_stack+5800, dvrr_stack+5689);
 tmp = dvrr_stack + 17531;
 target_ptr = Libderiv->deriv2_classes[1][6][10];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+19110, dvrr_stack+19445, dvrr_stack+17657);
 tmp = dvrr_stack + 19110;
 target_ptr = Libderiv->deriv2_classes[1][7][10];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+19218, dvrr_stack+19661, dvrr_stack+7708);
 tmp = dvrr_stack + 19218;
 target_ptr = Libderiv->deriv2_classes[1][8][10];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+19353, dvrr_stack+19986, dvrr_stack+19931);
 tmp = dvrr_stack + 19353;
 target_ptr = Libderiv->deriv2_classes[1][9][10];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+17615, dvrr_stack+20316, dvrr_stack+7753);
 tmp = dvrr_stack + 17615;
 target_ptr = Libderiv->deriv2_classes[1][5][9];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+19518, dvrr_stack+13217, dvrr_stack+13189);
 tmp = dvrr_stack + 19518;
 target_ptr = Libderiv->deriv2_classes[1][6][9];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+13189, dvrr_stack+14101, dvrr_stack+17693);
 tmp = dvrr_stack + 13189;
 target_ptr = Libderiv->deriv2_classes[1][7][9];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+14101, dvrr_stack+15232, dvrr_stack+15187);
 tmp = dvrr_stack + 14101;
 target_ptr = Libderiv->deriv2_classes[1][8][9];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+15187, dvrr_stack+16286, dvrr_stack+16231);
 tmp = dvrr_stack + 15187;
 target_ptr = Libderiv->deriv2_classes[1][9][9];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+15352, dvrr_stack+18236, dvrr_stack+18125);
 tmp = dvrr_stack + 15352;
 target_ptr = Libderiv->deriv2_classes[1][5][8];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+15415, dvrr_stack+18362, dvrr_stack+5968);
 tmp = dvrr_stack + 15415;
 target_ptr = Libderiv->deriv2_classes[1][6][8];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+18210, dvrr_stack+18530, dvrr_stack+8758);
 tmp = dvrr_stack + 18210;
 target_ptr = Libderiv->deriv2_classes[1][7][8];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+18318, dvrr_stack+18791, dvrr_stack+18746);
 tmp = dvrr_stack + 18318;
 target_ptr = Libderiv->deriv2_classes[1][8][8];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+18453, dvrr_stack+16616, dvrr_stack+17311);
 tmp = dvrr_stack + 18453;
 target_ptr = Libderiv->deriv2_classes[1][9][8];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+14236, dvrr_stack+16051, dvrr_stack+19061);
 tmp = dvrr_stack + 14236;
 target_ptr = Libderiv->deriv2_classes[1][5][7];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+13297, dvrr_stack+15502, dvrr_stack+19082);
 tmp = dvrr_stack + 13297;
 target_ptr = Libderiv->deriv2_classes[1][6][7];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+15499, dvrr_stack+14317, dvrr_stack+17366);
 tmp = dvrr_stack + 15499;
 target_ptr = Libderiv->deriv2_classes[1][7][7];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+14299, dvrr_stack+20442, dvrr_stack+17402);
 tmp = dvrr_stack + 14299;
 target_ptr = Libderiv->deriv2_classes[1][8][7];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+18618, dvrr_stack+20712, dvrr_stack+16946);
 tmp = dvrr_stack + 18618;
 target_ptr = Libderiv->deriv2_classes[1][9][7];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+15607, dvrr_stack+7972, dvrr_stack+338);
 tmp = dvrr_stack + 15607;
 target_ptr = Libderiv->deriv_classes[1][5][0];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+14434, dvrr_stack+15670, dvrr_stack+17447);
 tmp = dvrr_stack + 14434;
 target_ptr = Libderiv->deriv2_classes[1][5][6];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+15670, dvrr_stack+13021, dvrr_stack+359);
 tmp = dvrr_stack + 15670;
 target_ptr = Libderiv->deriv_classes[1][6][0];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+7937, dvrr_stack+13385, dvrr_stack+18146);
 tmp = dvrr_stack + 7937;
 target_ptr = Libderiv->deriv2_classes[1][6][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+13381, dvrr_stack+13885, dvrr_stack+387);
 tmp = dvrr_stack + 13381;
 target_ptr = Libderiv->deriv_classes[1][7][0];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+13882, dvrr_stack+21042, dvrr_stack+18174);
 tmp = dvrr_stack + 13882;
 target_ptr = Libderiv->deriv2_classes[1][7][6];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+18783, dvrr_stack+14917, dvrr_stack+578);
 tmp = dvrr_stack + 18783;
 target_ptr = Libderiv->deriv_classes[1][8][0];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+18918, dvrr_stack+21258, dvrr_stack+14773);
 tmp = dvrr_stack + 18918;
 target_ptr = Libderiv->deriv2_classes[1][8][6];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+19602, dvrr_stack+21528, dvrr_stack+14818);
 tmp = dvrr_stack + 19602;
 target_ptr = Libderiv->deriv2_classes[1][9][6];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+13489, dvrr_stack+17750, dvrr_stack+17729);
 tmp = dvrr_stack + 13489;
 target_ptr = Libderiv->deriv2_classes[1][5][2];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+17678, dvrr_stack+17876, dvrr_stack+7909);
 tmp = dvrr_stack + 17678;
 target_ptr = Libderiv->deriv2_classes[1][6][2];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+17762, dvrr_stack+23200, dvrr_stack+8098);
 tmp = dvrr_stack + 17762;
 target_ptr = Libderiv->deriv2_classes[1][7][2];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+17870, dvrr_stack+22516, dvrr_stack+22068);
 tmp = dvrr_stack + 17870;
 target_ptr = Libderiv->deriv2_classes[1][8][2];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+23191, dvrr_stack+24136, dvrr_stack+22113);
 tmp = dvrr_stack + 23191;
 target_ptr = Libderiv->deriv2_classes[1][9][2];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+5644, dvrr_stack+23437, dvrr_stack+23416);
 tmp = dvrr_stack + 5644;
 target_ptr = Libderiv->deriv2_classes[1][5][1];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+22026, dvrr_stack+13693, dvrr_stack+23563);
 tmp = dvrr_stack + 22026;
 target_ptr = Libderiv->deriv2_classes[1][6][1];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+24086, dvrr_stack+678, dvrr_stack+23591);
 tmp = dvrr_stack + 24086;
 target_ptr = Libderiv->deriv2_classes[1][7][1];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+24194, dvrr_stack+894, dvrr_stack+23627);
 tmp = dvrr_stack + 24194;
 target_ptr = Libderiv->deriv2_classes[1][8][1];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+549, dvrr_stack+25181, dvrr_stack+24466);
 tmp = dvrr_stack + 549;
 target_ptr = Libderiv->deriv2_classes[1][9][1];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+24329, dvrr_stack+423, dvrr_stack+13861);
 tmp = dvrr_stack + 24329;
 target_ptr = Libderiv->deriv2_classes[1][5][0];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+24392, dvrr_stack+21858, dvrr_stack+1813);
 tmp = dvrr_stack + 24392;
 target_ptr = Libderiv->deriv2_classes[1][6][0];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+13990, dvrr_stack+22168, dvrr_stack+1841);
 tmp = dvrr_stack + 13990;
 target_ptr = Libderiv->deriv2_classes[1][7][0];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+22110, dvrr_stack+22786, dvrr_stack+1877);
 tmp = dvrr_stack + 22110;
 target_ptr = Libderiv->deriv2_classes[1][8][0];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+25124, dvrr_stack+23672, dvrr_stack+3076);
 tmp = dvrr_stack + 25124;
 target_ptr = Libderiv->deriv2_classes[1][9][0];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];


}

