/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (p0|hh) integrals */

void d12vrr_order_p0hh(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6, dvrr_stack+3, dvrr_stack+0, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+12, dvrr_stack+3, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+21, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+24, dvrr_stack+0, dvrr_stack+21, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+30, dvrr_stack+6, dvrr_stack+24, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+40, dvrr_stack+15, dvrr_stack+6, dvrr_stack+12, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+50, dvrr_stack+40, dvrr_stack+30, dvrr_stack+15, dvrr_stack+6, NULL);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+65, dvrr_stack+3, dvrr_stack+12, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+71, dvrr_stack+65, dvrr_stack+15, dvrr_stack+3, dvrr_stack+12, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+81, dvrr_stack+71, dvrr_stack+40, dvrr_stack+65, dvrr_stack+15, NULL);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+96, dvrr_stack+21, dvrr_stack+12, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+102, dvrr_stack+24, dvrr_stack+96, dvrr_stack+0, dvrr_stack+21, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+112, dvrr_stack+30, dvrr_stack+102, dvrr_stack+6, dvrr_stack+24, NULL);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+127, dvrr_stack+50, dvrr_stack+112, dvrr_stack+40, dvrr_stack+30, NULL);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+148, dvrr_stack+81, dvrr_stack+50, dvrr_stack+71, dvrr_stack+40, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+169, dvrr_stack+148, dvrr_stack+127, dvrr_stack+81, dvrr_stack+50, NULL);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6, dvrr_stack+0, dvrr_stack+3, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+197, dvrr_stack+6, dvrr_stack+65, dvrr_stack+0, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+207, dvrr_stack+197, dvrr_stack+71, dvrr_stack+6, dvrr_stack+65, NULL);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+222, dvrr_stack+207, dvrr_stack+81, dvrr_stack+197, dvrr_stack+71, NULL);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+243, dvrr_stack+222, dvrr_stack+148, dvrr_stack+207, dvrr_stack+81, NULL);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+271, dvrr_stack+12, dvrr_stack+3, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+277, dvrr_stack+96, dvrr_stack+271, dvrr_stack+21, dvrr_stack+12, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+287, dvrr_stack+102, dvrr_stack+277, dvrr_stack+24, dvrr_stack+96, NULL);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+302, dvrr_stack+112, dvrr_stack+287, dvrr_stack+30, dvrr_stack+102, NULL);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+323, dvrr_stack+127, dvrr_stack+302, dvrr_stack+50, dvrr_stack+112, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+351, dvrr_stack+169, dvrr_stack+323, dvrr_stack+148, dvrr_stack+127, NULL);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+387, dvrr_stack+243, dvrr_stack+169, dvrr_stack+222, dvrr_stack+148, NULL);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+423, dvrr_stack+387, dvrr_stack+351, dvrr_stack+243, dvrr_stack+169, NULL);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+21, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+24, dvrr_stack+21, dvrr_stack+0, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+30, dvrr_stack+24, dvrr_stack+6, dvrr_stack+21, dvrr_stack+0, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+468, dvrr_stack+30, dvrr_stack+197, dvrr_stack+24, dvrr_stack+6, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+483, dvrr_stack+468, dvrr_stack+207, dvrr_stack+30, dvrr_stack+197, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+504, dvrr_stack+483, dvrr_stack+222, dvrr_stack+468, dvrr_stack+207, NULL);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+532, dvrr_stack+504, dvrr_stack+243, dvrr_stack+483, dvrr_stack+222, NULL);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+568, dvrr_stack+532, dvrr_stack+387, dvrr_stack+504, dvrr_stack+243, NULL);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+21, dvrr_stack+3, dvrr_stack+0, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+613, dvrr_stack+271, dvrr_stack+21, dvrr_stack+12, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+623, dvrr_stack+277, dvrr_stack+613, dvrr_stack+96, dvrr_stack+271, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+638, dvrr_stack+287, dvrr_stack+623, dvrr_stack+102, dvrr_stack+277, NULL);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+659, dvrr_stack+302, dvrr_stack+638, dvrr_stack+112, dvrr_stack+287, NULL);

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+687, dvrr_stack+323, dvrr_stack+659, dvrr_stack+127, dvrr_stack+302, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+723, dvrr_stack+351, dvrr_stack+687, dvrr_stack+169, dvrr_stack+323, NULL);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+768, dvrr_stack+423, dvrr_stack+723, dvrr_stack+387, dvrr_stack+351, NULL);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+823, dvrr_stack+568, dvrr_stack+423, dvrr_stack+532, dvrr_stack+387, NULL);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+878, dvrr_stack+823, dvrr_stack+768, dvrr_stack+568, dvrr_stack+423, NULL);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+96, dvrr_stack+0, dvrr_stack+12, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+102, dvrr_stack+21, dvrr_stack+96, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+112, dvrr_stack+613, dvrr_stack+102, dvrr_stack+271, dvrr_stack+21, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+944, dvrr_stack+623, dvrr_stack+112, dvrr_stack+277, dvrr_stack+613, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+965, dvrr_stack+638, dvrr_stack+944, dvrr_stack+287, dvrr_stack+623, NULL);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+993, dvrr_stack+659, dvrr_stack+965, dvrr_stack+302, dvrr_stack+638, NULL);

 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+271, dvrr_stack+687, dvrr_stack+993, dvrr_stack+323, dvrr_stack+659, NULL);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1029, dvrr_stack+723, dvrr_stack+271, dvrr_stack+351, dvrr_stack+687, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1084, dvrr_stack+768, dvrr_stack+1029, NULL, NULL, dvrr_stack+723);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1249, dvrr_stack+768, dvrr_stack+1029, dvrr_stack+423, dvrr_stack+723, NULL);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+316, dvrr_stack+12, dvrr_stack+3, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1315, dvrr_stack+96, dvrr_stack+316, dvrr_stack+0, dvrr_stack+12, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1325, dvrr_stack+102, dvrr_stack+1315, dvrr_stack+21, dvrr_stack+96, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1340, dvrr_stack+112, dvrr_stack+1325, dvrr_stack+613, dvrr_stack+102, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1361, dvrr_stack+944, dvrr_stack+1340, dvrr_stack+623, dvrr_stack+112, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1389, dvrr_stack+965, dvrr_stack+1361, dvrr_stack+638, dvrr_stack+944, NULL);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+613, dvrr_stack+993, dvrr_stack+1389, dvrr_stack+659, dvrr_stack+965, NULL);

 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1425, dvrr_stack+271, dvrr_stack+613, dvrr_stack+687, dvrr_stack+993, NULL);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1480, dvrr_stack+1029, dvrr_stack+1425, dvrr_stack+723, dvrr_stack+271, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1546, dvrr_stack+1249, dvrr_stack+1480, NULL, NULL, dvrr_stack+1029);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1744, dvrr_stack+878, dvrr_stack+1249, NULL, NULL, dvrr_stack+768);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1942, dvrr_stack+1744, dvrr_stack+1546, dvrr_stack+878, dvrr_stack+1249, dvrr_stack+1084);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+2338, dvrr_stack+483, dvrr_stack+222, NULL, NULL, dvrr_stack+207);
 tmp = dvrr_stack + 2338;
 target_ptr = Libderiv->dvrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2401, dvrr_stack+504, dvrr_stack+243, NULL, NULL, dvrr_stack+222);
 tmp = dvrr_stack + 2401;
 target_ptr = Libderiv->dvrr_classes[1][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+2485,dvrr_stack+2401,dvrr_stack+2338,3);


 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2674, dvrr_stack+532, dvrr_stack+387, NULL, NULL, dvrr_stack+243);
 tmp = dvrr_stack + 2674;
 target_ptr = Libderiv->dvrr_classes[1][7];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+2782,dvrr_stack+2674,dvrr_stack+2401,3);


 /* compute (1 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+3034,dvrr_stack+2782,dvrr_stack+2485,3);


 /* compute (1 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,63,dvrr_stack+3412, dvrr_stack+3034, dvrr_stack+2338);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3601, dvrr_stack+568, dvrr_stack+423, NULL, NULL, dvrr_stack+387);
 tmp = dvrr_stack + 3601;
 target_ptr = Libderiv->dvrr_classes[1][8];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+3736,dvrr_stack+3601,dvrr_stack+2674,3);


 /* compute (1 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+4060,dvrr_stack+3736,dvrr_stack+2782,3);


 /* compute (1 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,84,dvrr_stack+4564, dvrr_stack+4060, dvrr_stack+2401);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4816, dvrr_stack+823, dvrr_stack+768, NULL, NULL, dvrr_stack+423);
 tmp = dvrr_stack + 4816;
 target_ptr = Libderiv->dvrr_classes[1][9];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+4981,dvrr_stack+4816,dvrr_stack+3601,3);


 /* compute (1 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+5386,dvrr_stack+4981,dvrr_stack+3736,3);


 /* compute (1 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,108,dvrr_stack+6034, dvrr_stack+5386, dvrr_stack+2674);

 /* compute (1 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+6358,dvrr_stack+1744,dvrr_stack+4816,3);


 /* compute (1 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+6853,dvrr_stack+6358,dvrr_stack+4981,3);


 /* compute (1 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,135,dvrr_stack+7663, dvrr_stack+6853, dvrr_stack+3601);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+8068, dvrr_stack+1249, dvrr_stack+1480, dvrr_stack+768, dvrr_stack+1029, NULL);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+8146, dvrr_stack+878, dvrr_stack+1249, dvrr_stack+823, dvrr_stack+768, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+8224, dvrr_stack+8146, dvrr_stack+8068, NULL, NULL, dvrr_stack+1249);

 /* compute (1 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+8458,dvrr_stack+8224,dvrr_stack+1744,3);


 /* compute (1 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+9052,dvrr_stack+8458,dvrr_stack+6358,3);


 /* compute (1 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,165,dvrr_stack+10042, dvrr_stack+9052, dvrr_stack+4816);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+658, dvrr_stack+3, dvrr_stack+0, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+664, dvrr_stack+316, dvrr_stack+658, dvrr_stack+12, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+10537, dvrr_stack+1315, dvrr_stack+664, dvrr_stack+96, dvrr_stack+316, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+658, dvrr_stack+1325, dvrr_stack+10537, dvrr_stack+102, dvrr_stack+1315, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+10537, dvrr_stack+1340, dvrr_stack+658, dvrr_stack+112, dvrr_stack+1325, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10565, dvrr_stack+1361, dvrr_stack+10537, dvrr_stack+944, dvrr_stack+1340, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1315, dvrr_stack+1389, dvrr_stack+10565, dvrr_stack+965, dvrr_stack+1361, NULL);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+10537, dvrr_stack+613, dvrr_stack+1315, dvrr_stack+993, dvrr_stack+1389, NULL);

 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1315, dvrr_stack+1425, dvrr_stack+10537, dvrr_stack+271, dvrr_stack+613, NULL);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+10537, dvrr_stack+1480, dvrr_stack+1315, dvrr_stack+1029, dvrr_stack+1425, NULL);

 /* compute (0 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+10615, dvrr_stack+8068, dvrr_stack+10537, dvrr_stack+1249, dvrr_stack+1480, NULL);

 /* compute (0 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+10706, dvrr_stack+8146, dvrr_stack+8068, dvrr_stack+878, dvrr_stack+1249, NULL);

 /* compute (1 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+10797, dvrr_stack+10706, dvrr_stack+10615, NULL, NULL, dvrr_stack+8068);

 /* compute (1 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+11070,dvrr_stack+10797,dvrr_stack+8224,3);


 /* compute (1 0 | 10 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_nd(Libderiv->CD,dvrr_stack+11772,dvrr_stack+11070,dvrr_stack+8458,3);


 /* compute (1 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,198,dvrr_stack+12960, dvrr_stack+11772, dvrr_stack+1744);

 /* compute (1 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,63,dvrr_stack+13554, dvrr_stack+3034, dvrr_stack+2338);

 /* compute (1 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,84,dvrr_stack+13743, dvrr_stack+4060, dvrr_stack+2401);

 /* compute (1 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,108,dvrr_stack+13995, dvrr_stack+5386, dvrr_stack+2674);

 /* compute (1 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,135,dvrr_stack+14319, dvrr_stack+6853, dvrr_stack+3601);

 /* compute (1 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,165,dvrr_stack+14724, dvrr_stack+9052, dvrr_stack+4816);

 /* compute (1 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,198,dvrr_stack+15219, dvrr_stack+11772, dvrr_stack+1744);

 /* compute (1 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,63,dvrr_stack+15813, dvrr_stack+3034, dvrr_stack+2338);

 /* compute (1 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,84,dvrr_stack+3034, dvrr_stack+4060, dvrr_stack+2401);

 /* compute (1 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,108,dvrr_stack+4060, dvrr_stack+5386, dvrr_stack+2674);

 /* compute (1 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,135,dvrr_stack+5386, dvrr_stack+6853, dvrr_stack+3601);

 /* compute (1 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,165,dvrr_stack+6853, dvrr_stack+9052, dvrr_stack+4816);

 /* compute (1 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,198,dvrr_stack+9052, dvrr_stack+11772, dvrr_stack+1744);

 /* compute (1 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+11772, dvrr_stack+468, dvrr_stack+207, NULL, NULL, dvrr_stack+197);

 /* compute (1 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+11817,dvrr_stack+2338,dvrr_stack+11772,3);


 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,45,dvrr_stack+11952, dvrr_stack+11817, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,84,dvrr_stack+11997, dvrr_stack+2782, NULL);
 tmp = dvrr_stack + 11997;
 target_ptr = Libderiv->deriv_classes[1][6][11];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,63,dvrr_stack+12081, dvrr_stack+2485, NULL);
 tmp = dvrr_stack + 12081;
 target_ptr = Libderiv->deriv_classes[1][5][11];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,108,dvrr_stack+12144, dvrr_stack+3736, NULL);
 tmp = dvrr_stack + 12144;
 target_ptr = Libderiv->deriv_classes[1][7][11];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,135,dvrr_stack+12252, dvrr_stack+4981, NULL);
 tmp = dvrr_stack + 12252;
 target_ptr = Libderiv->deriv_classes[1][8][11];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,165,dvrr_stack+12387, dvrr_stack+6358, NULL);
 tmp = dvrr_stack + 12387;
 target_ptr = Libderiv->deriv_classes[1][9][11];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,198,dvrr_stack+12552, dvrr_stack+8458, NULL);
 tmp = dvrr_stack + 12552;
 target_ptr = Libderiv->deriv_classes[1][10][11];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,234,dvrr_stack+9646, dvrr_stack+11070, NULL);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,45,dvrr_stack+12750, dvrr_stack+11817, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,84,dvrr_stack+12795, dvrr_stack+2782, NULL);
 tmp = dvrr_stack + 12795;
 target_ptr = Libderiv->deriv_classes[1][6][10];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,63,dvrr_stack+12879, dvrr_stack+2485, NULL);
 tmp = dvrr_stack + 12879;
 target_ptr = Libderiv->deriv_classes[1][5][10];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,108,dvrr_stack+9880, dvrr_stack+3736, NULL);
 tmp = dvrr_stack + 9880;
 target_ptr = Libderiv->deriv_classes[1][7][10];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,135,dvrr_stack+7348, dvrr_stack+4981, NULL);
 tmp = dvrr_stack + 7348;
 target_ptr = Libderiv->deriv_classes[1][8][10];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,165,dvrr_stack+7483, dvrr_stack+6358, NULL);
 tmp = dvrr_stack + 7483;
 target_ptr = Libderiv->deriv_classes[1][9][10];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,198,dvrr_stack+5791, dvrr_stack+8458, NULL);
 tmp = dvrr_stack + 5791;
 target_ptr = Libderiv->deriv_classes[1][10][10];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,234,dvrr_stack+16002, dvrr_stack+11070, NULL);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,45,dvrr_stack+5989, dvrr_stack+11817, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,84,dvrr_stack+11817, dvrr_stack+2782, NULL);
 tmp = dvrr_stack + 11817;
 target_ptr = Libderiv->deriv_classes[1][6][9];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,63,dvrr_stack+2782, dvrr_stack+2485, NULL);
 tmp = dvrr_stack + 2782;
 target_ptr = Libderiv->deriv_classes[1][5][9];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,108,dvrr_stack+2485, dvrr_stack+3736, NULL);
 tmp = dvrr_stack + 2485;
 target_ptr = Libderiv->deriv_classes[1][7][9];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,135,dvrr_stack+3736, dvrr_stack+4981, NULL);
 tmp = dvrr_stack + 3736;
 target_ptr = Libderiv->deriv_classes[1][8][9];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,165,dvrr_stack+4981, dvrr_stack+6358, NULL);
 tmp = dvrr_stack + 4981;
 target_ptr = Libderiv->deriv_classes[1][9][9];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,198,dvrr_stack+6358, dvrr_stack+8458, NULL);
 tmp = dvrr_stack + 6358;
 target_ptr = Libderiv->deriv_classes[1][10][9];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,234,dvrr_stack+8458, dvrr_stack+11070, NULL);

 /* compute (1 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+11070, dvrr_stack+30, dvrr_stack+197, NULL, NULL, dvrr_stack+6);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,3,1,dvrr_stack+11100, dvrr_stack+2338, dvrr_stack+11070);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+11145, dvrr_stack+2674, dvrr_stack+2338);
 tmp = dvrr_stack + 11145;
 target_ptr = Libderiv->deriv_classes[1][6][8];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+11229, dvrr_stack+2401, dvrr_stack+11772);
 tmp = dvrr_stack + 11229;
 target_ptr = Libderiv->deriv_classes[1][5][8];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+11292, dvrr_stack+3601, dvrr_stack+2401);
 tmp = dvrr_stack + 11292;
 target_ptr = Libderiv->deriv_classes[1][7][8];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+11400, dvrr_stack+4816, dvrr_stack+2674);
 tmp = dvrr_stack + 11400;
 target_ptr = Libderiv->deriv_classes[1][8][8];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+11535, dvrr_stack+1744, dvrr_stack+3601);
 tmp = dvrr_stack + 11535;
 target_ptr = Libderiv->deriv_classes[1][9][8];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,3,1,dvrr_stack+8692, dvrr_stack+8224, dvrr_stack+4816);
 tmp = dvrr_stack + 8692;
 target_ptr = Libderiv->deriv_classes[1][10][8];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,3,1,dvrr_stack+6556, dvrr_stack+10797, dvrr_stack+1744);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,3,1,dvrr_stack+11700, dvrr_stack+2338, dvrr_stack+11070);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+8890, dvrr_stack+2674, dvrr_stack+2338);
 tmp = dvrr_stack + 8890;
 target_ptr = Libderiv->deriv_classes[1][6][7];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+6790, dvrr_stack+2401, dvrr_stack+11772);
 tmp = dvrr_stack + 6790;
 target_ptr = Libderiv->deriv_classes[1][5][7];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+5146, dvrr_stack+3601, dvrr_stack+2401);
 tmp = dvrr_stack + 5146;
 target_ptr = Libderiv->deriv_classes[1][7][7];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+3871, dvrr_stack+4816, dvrr_stack+2674);
 tmp = dvrr_stack + 3871;
 target_ptr = Libderiv->deriv_classes[1][8][7];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+2845, dvrr_stack+1744, dvrr_stack+3601);
 tmp = dvrr_stack + 2845;
 target_ptr = Libderiv->deriv_classes[1][9][7];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,3,1,dvrr_stack+16236, dvrr_stack+8224, dvrr_stack+4816);
 tmp = dvrr_stack + 16236;
 target_ptr = Libderiv->deriv_classes[1][10][7];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,3,1,dvrr_stack+16434, dvrr_stack+10797, dvrr_stack+1744);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,3,1,dvrr_stack+8974, dvrr_stack+2338, dvrr_stack+11070);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+5254, dvrr_stack+2674, dvrr_stack+2338);
 tmp = dvrr_stack + 5254;
 target_ptr = Libderiv->deriv_classes[1][6][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+2593, dvrr_stack+2401, dvrr_stack+11772);
 tmp = dvrr_stack + 2593;
 target_ptr = Libderiv->deriv_classes[1][5][6];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+4384, dvrr_stack+3601, dvrr_stack+2401);
 tmp = dvrr_stack + 4384;
 target_ptr = Libderiv->deriv_classes[1][7][6];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+10615, dvrr_stack+4816, dvrr_stack+2674);
 tmp = dvrr_stack + 10615;
 target_ptr = Libderiv->deriv_classes[1][8][6];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+16668, dvrr_stack+1744, dvrr_stack+3601);
 tmp = dvrr_stack + 16668;
 target_ptr = Libderiv->deriv_classes[1][9][6];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,3,1,dvrr_stack+16833, dvrr_stack+8224, dvrr_stack+4816);
 tmp = dvrr_stack + 16833;
 target_ptr = Libderiv->deriv_classes[1][10][6];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,3,1,dvrr_stack+17031, dvrr_stack+10797, dvrr_stack+1744);

 /* compute (0 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+4492,dvrr_stack+504,dvrr_stack+483,1);


 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,21,dvrr_stack+11745, dvrr_stack+4492, NULL);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+5338, dvrr_stack+207, dvrr_stack+81, NULL, NULL, dvrr_stack+71);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+3286, dvrr_stack+222, dvrr_stack+148, NULL, NULL, dvrr_stack+81);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+10750, dvrr_stack+2338, dvrr_stack+3286, dvrr_stack+483, dvrr_stack+222, dvrr_stack+5338);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+10876, dvrr_stack+243, dvrr_stack+169, NULL, NULL, dvrr_stack+148);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+17265, dvrr_stack+2401, dvrr_stack+10876, dvrr_stack+504, dvrr_stack+243, dvrr_stack+3286);

 /* compute (2 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+17433,dvrr_stack+17265,dvrr_stack+10750,6);


 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,126,dvrr_stack+10960, dvrr_stack+17433, NULL);

 /* compute (0 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+17811,dvrr_stack+532,dvrr_stack+504,1);


 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,28,dvrr_stack+9019, dvrr_stack+17811, NULL);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+17895, dvrr_stack+387, dvrr_stack+351, NULL, NULL, dvrr_stack+169);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+18003, dvrr_stack+2674, dvrr_stack+17895, dvrr_stack+532, dvrr_stack+387, dvrr_stack+10876);

 /* compute (2 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+18219,dvrr_stack+18003,dvrr_stack+17265,6);


 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,168,dvrr_stack+18723, dvrr_stack+18219, NULL);

 /* compute (0 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+18891,dvrr_stack+568,dvrr_stack+532,1);


 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,36,dvrr_stack+4006, dvrr_stack+18891, NULL);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18999, dvrr_stack+423, dvrr_stack+723, NULL, NULL, dvrr_stack+351);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19134, dvrr_stack+3601, dvrr_stack+18999, dvrr_stack+568, dvrr_stack+423, dvrr_stack+17895);

 /* compute (2 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+19404,dvrr_stack+19134,dvrr_stack+18003,6);


 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,216,dvrr_stack+20052, dvrr_stack+19404, NULL);

 /* compute (0 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+20268,dvrr_stack+823,dvrr_stack+568,1);


 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,45,dvrr_stack+11901, dvrr_stack+20268, NULL);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20403, dvrr_stack+4816, dvrr_stack+1084, dvrr_stack+823, dvrr_stack+768, dvrr_stack+18999);

 /* compute (2 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+20733,dvrr_stack+20403,dvrr_stack+19134,6);


 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,270,dvrr_stack+21543, dvrr_stack+20733, NULL);

 /* compute (0 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+21813,dvrr_stack+878,dvrr_stack+823,1);


 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,55,dvrr_stack+3349, dvrr_stack+21813, NULL);

 /* compute (2 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+21978,dvrr_stack+1942,dvrr_stack+20403,6);


 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,330,dvrr_stack+22968, dvrr_stack+21978, NULL);

 /* compute (0 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+23298,dvrr_stack+8146,dvrr_stack+878,1);


 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,66,dvrr_stack+613, dvrr_stack+23298, NULL);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+23496, dvrr_stack+8068, dvrr_stack+10537, NULL, NULL, dvrr_stack+1480);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+23730, dvrr_stack+8224, dvrr_stack+23496, dvrr_stack+8146, dvrr_stack+8068, dvrr_stack+1546);

 /* compute (2 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+24198,dvrr_stack+23730,dvrr_stack+1942,6);


 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,396,dvrr_stack+25386, dvrr_stack+24198, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,21,dvrr_stack+8068, dvrr_stack+4492, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,126,dvrr_stack+23496, dvrr_stack+17433, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,28,dvrr_stack+8089, dvrr_stack+17811, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,168,dvrr_stack+8224, dvrr_stack+18219, NULL);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,36,dvrr_stack+23622, dvrr_stack+18891, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,216,dvrr_stack+25782, dvrr_stack+19404, NULL);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,45,dvrr_stack+23658, dvrr_stack+20268, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,270,dvrr_stack+25998, dvrr_stack+20733, NULL);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,55,dvrr_stack+8392, dvrr_stack+21813, NULL);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,330,dvrr_stack+26268, dvrr_stack+21978, NULL);

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,66,dvrr_stack+10537, dvrr_stack+23298, NULL);

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,396,dvrr_stack+26598, dvrr_stack+24198, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,21,dvrr_stack+8117, dvrr_stack+4492, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+26994, dvrr_stack+17433, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,28,dvrr_stack+17433, dvrr_stack+17811, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+17461, dvrr_stack+18219, NULL);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,36,dvrr_stack+18219, dvrr_stack+18891, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+18255, dvrr_stack+19404, NULL);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,45,dvrr_stack+19404, dvrr_stack+20268, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+19449, dvrr_stack+20733, NULL);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,55,dvrr_stack+20733, dvrr_stack+21813, NULL);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+20788, dvrr_stack+21978, NULL);

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,66,dvrr_stack+21813, dvrr_stack+23298, NULL);

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,396,dvrr_stack+21879, dvrr_stack+24198, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,1,1,dvrr_stack+24198, dvrr_stack+504, dvrr_stack+468);

 /* compute (1 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+24219, dvrr_stack+197, dvrr_stack+71, NULL, NULL, dvrr_stack+65);

 /* compute (2 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+24249, dvrr_stack+11772, dvrr_stack+5338, dvrr_stack+468, dvrr_stack+207, dvrr_stack+24219);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+24339, dvrr_stack+17265, dvrr_stack+24249);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,1,1,dvrr_stack+24219, dvrr_stack+532, dvrr_stack+483);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+24465, dvrr_stack+18003, dvrr_stack+10750);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,1,1,dvrr_stack+24633, dvrr_stack+568, dvrr_stack+504);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+24669, dvrr_stack+19134, dvrr_stack+17265);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,1,1,dvrr_stack+24885, dvrr_stack+823, dvrr_stack+532);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+24930, dvrr_stack+20403, dvrr_stack+18003);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,1,1,dvrr_stack+25200, dvrr_stack+878, dvrr_stack+568);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+22275, dvrr_stack+1942, dvrr_stack+19134);

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,1,1,dvrr_stack+25255, dvrr_stack+8146, dvrr_stack+823);

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,6,1,dvrr_stack+21118, dvrr_stack+23730, dvrr_stack+20403);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,1,1,dvrr_stack+25321, dvrr_stack+504, dvrr_stack+468);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+23298, dvrr_stack+17265, dvrr_stack+24249);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,1,1,dvrr_stack+25342, dvrr_stack+532, dvrr_stack+483);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+22605, dvrr_stack+18003, dvrr_stack+10750);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,1,1,dvrr_stack+23424, dvrr_stack+568, dvrr_stack+504);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+19719, dvrr_stack+19134, dvrr_stack+17265);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,1,1,dvrr_stack+22773, dvrr_stack+823, dvrr_stack+532);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+27120, dvrr_stack+20403, dvrr_stack+18003);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,1,1,dvrr_stack+22818, dvrr_stack+878, dvrr_stack+568);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+27390, dvrr_stack+1942, dvrr_stack+19134);

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,1,1,dvrr_stack+22873, dvrr_stack+8146, dvrr_stack+823);

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,6,1,dvrr_stack+27720, dvrr_stack+23730, dvrr_stack+20403);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,1,1,dvrr_stack+23460, dvrr_stack+504, dvrr_stack+468);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+20268, dvrr_stack+17265, dvrr_stack+24249);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,1,1,dvrr_stack+24247, dvrr_stack+532, dvrr_stack+483);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+18471, dvrr_stack+18003, dvrr_stack+10750);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,1,1,dvrr_stack+24275, dvrr_stack+568, dvrr_stack+504);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+17629, dvrr_stack+19134, dvrr_stack+17265);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,1,1,dvrr_stack+19935, dvrr_stack+823, dvrr_stack+532);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+28116, dvrr_stack+20403, dvrr_stack+18003);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,1,1,dvrr_stack+19980, dvrr_stack+878, dvrr_stack+568);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+28386, dvrr_stack+1942, dvrr_stack+19134);

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,1,1,dvrr_stack+18891, dvrr_stack+8146, dvrr_stack+823);

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,6,1,dvrr_stack+28716, dvrr_stack+23730, dvrr_stack+20403);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,21,dvrr_stack+24311, dvrr_stack+2338, NULL);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+18957, dvrr_stack+71, dvrr_stack+40, NULL, NULL, dvrr_stack+15);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+18639, dvrr_stack+81, dvrr_stack+50, NULL, NULL, dvrr_stack+40);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+23703, dvrr_stack+5338, dvrr_stack+18639, dvrr_stack+207, dvrr_stack+81, dvrr_stack+18957);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+4492, dvrr_stack+148, dvrr_stack+127, NULL, NULL, dvrr_stack+50);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+23793, dvrr_stack+3286, dvrr_stack+4492, dvrr_stack+222, dvrr_stack+148, dvrr_stack+18639);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+23919, dvrr_stack+10750, dvrr_stack+23793, dvrr_stack+2338, dvrr_stack+3286, dvrr_stack+23703);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+29112, dvrr_stack+23919, dvrr_stack+2338);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,28,dvrr_stack+23703, dvrr_stack+2401, NULL);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+18639, dvrr_stack+169, dvrr_stack+323, NULL, NULL, dvrr_stack+127);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+29238, dvrr_stack+10876, dvrr_stack+18639, dvrr_stack+243, dvrr_stack+169, dvrr_stack+4492);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+29406, dvrr_stack+17265, dvrr_stack+29238, dvrr_stack+2401, dvrr_stack+10876, dvrr_stack+23793);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+23731, dvrr_stack+29406, dvrr_stack+2401);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,36,dvrr_stack+10876, dvrr_stack+2674, NULL);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+29686, dvrr_stack+351, dvrr_stack+687, NULL, NULL, dvrr_stack+323);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+0, dvrr_stack+17895, dvrr_stack+29686, dvrr_stack+387, dvrr_stack+351, dvrr_stack+18639);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+29794, dvrr_stack+18003, dvrr_stack+0, dvrr_stack+2674, dvrr_stack+17895, dvrr_stack+29238);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+30154, dvrr_stack+29794, dvrr_stack+2674);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,45,dvrr_stack+29238, dvrr_stack+3601, NULL);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+17845, dvrr_stack+723, dvrr_stack+271, NULL, NULL, dvrr_stack+687);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+30370, dvrr_stack+18999, dvrr_stack+17845, dvrr_stack+423, dvrr_stack+723, dvrr_stack+29686);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+30640, dvrr_stack+19134, dvrr_stack+30370, dvrr_stack+3601, dvrr_stack+18999, dvrr_stack+0);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+0, dvrr_stack+30640, dvrr_stack+3601);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,55,dvrr_stack+29686, dvrr_stack+4816, NULL);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18957, dvrr_stack+1029, dvrr_stack+1425, NULL, NULL, dvrr_stack+271);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31090, dvrr_stack+1084, dvrr_stack+18957, dvrr_stack+768, dvrr_stack+1029, dvrr_stack+17845);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31420, dvrr_stack+20403, dvrr_stack+31090, dvrr_stack+4816, dvrr_stack+1084, dvrr_stack+30370);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+31970, dvrr_stack+31420, dvrr_stack+4816);

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,66,dvrr_stack+30370, dvrr_stack+1744, NULL);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+30436, dvrr_stack+1480, dvrr_stack+1315, NULL, NULL, dvrr_stack+1425);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32300, dvrr_stack+1546, dvrr_stack+30436, dvrr_stack+1249, dvrr_stack+1480, dvrr_stack+18957);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32696, dvrr_stack+1942, dvrr_stack+32300, dvrr_stack+1744, dvrr_stack+1546, dvrr_stack+31090);

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,66,dvrr_stack+32300, dvrr_stack+32696, dvrr_stack+1744);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,21,dvrr_stack+31090, dvrr_stack+2338, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+31111, dvrr_stack+23919, dvrr_stack+2338);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,28,dvrr_stack+31237, dvrr_stack+2401, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+18957, dvrr_stack+29406, dvrr_stack+2401);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,36,dvrr_stack+31265, dvrr_stack+2674, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+33356, dvrr_stack+29794, dvrr_stack+2674);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,45,dvrr_stack+31301, dvrr_stack+3601, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+33572, dvrr_stack+30640, dvrr_stack+3601);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,55,dvrr_stack+31346, dvrr_stack+4816, NULL);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+944, dvrr_stack+31420, dvrr_stack+4816);

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,66,dvrr_stack+30436, dvrr_stack+1744, NULL);

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,66,dvrr_stack+1274, dvrr_stack+32696, dvrr_stack+1744);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+30502, dvrr_stack+2338, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+17845, dvrr_stack+23919, dvrr_stack+2338);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+2338, dvrr_stack+2401, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+270, dvrr_stack+29406, dvrr_stack+2401);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+2366, dvrr_stack+2674, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+29283, dvrr_stack+29794, dvrr_stack+2674);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+438, dvrr_stack+3601, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+29741, dvrr_stack+30640, dvrr_stack+3601);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,55,dvrr_stack+3601, dvrr_stack+4816, NULL);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+30523, dvrr_stack+31420, dvrr_stack+4816);

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,66,dvrr_stack+4816, dvrr_stack+1744, NULL);

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,66,dvrr_stack+31401, dvrr_stack+32696, dvrr_stack+1744);

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,66,dvrr_stack+32696, dvrr_stack+1942, dvrr_stack+878);
 tmp = dvrr_stack + 32696;
 target_ptr = Libderiv->deriv_classes[1][10][2];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,66,dvrr_stack+32894, dvrr_stack+1942, dvrr_stack+878);
 tmp = dvrr_stack + 32894;
 target_ptr = Libderiv->deriv_classes[1][10][1];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,66,dvrr_stack+33092, dvrr_stack+1942, dvrr_stack+878);
 tmp = dvrr_stack + 33092;
 target_ptr = Libderiv->deriv_classes[1][10][0];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,63,dvrr_stack+3286, dvrr_stack+3412, NULL);
 tmp = dvrr_stack + 3286;
 target_ptr = Libderiv->deriv2_classes[1][5][143];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,84,dvrr_stack+18639, dvrr_stack+4564, NULL);
 tmp = dvrr_stack + 18639;
 target_ptr = Libderiv->deriv2_classes[1][6][143];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,108,dvrr_stack+31797, dvrr_stack+6034, NULL);
 tmp = dvrr_stack + 31797;
 target_ptr = Libderiv->deriv2_classes[1][7][143];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,135,dvrr_stack+30853, dvrr_stack+7663, NULL);
 tmp = dvrr_stack + 30853;
 target_ptr = Libderiv->deriv2_classes[1][8][143];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,165,dvrr_stack+29499, dvrr_stack+10042, NULL);
 tmp = dvrr_stack + 29499;
 target_ptr = Libderiv->deriv2_classes[1][9][143];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,198,dvrr_stack+23899, dvrr_stack+12960, NULL);
 tmp = dvrr_stack + 23899;
 target_ptr = Libderiv->deriv2_classes[1][10][143];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,63,dvrr_stack+878, dvrr_stack+3412, NULL);
 tmp = dvrr_stack + 878;
 target_ptr = Libderiv->deriv2_classes[1][5][131];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,84,dvrr_stack+4882, dvrr_stack+4564, NULL);
 tmp = dvrr_stack + 4882;
 target_ptr = Libderiv->deriv2_classes[1][6][131];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,108,dvrr_stack+30011, dvrr_stack+6034, NULL);
 tmp = dvrr_stack + 30011;
 target_ptr = Libderiv->deriv2_classes[1][7][131];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,135,dvrr_stack+679, dvrr_stack+7663, NULL);
 tmp = dvrr_stack + 679;
 target_ptr = Libderiv->deriv2_classes[1][8][131];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,165,dvrr_stack+1670, dvrr_stack+10042, NULL);
 tmp = dvrr_stack + 1670;
 target_ptr = Libderiv->deriv2_classes[1][9][131];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,198,dvrr_stack+1835, dvrr_stack+12960, NULL);
 tmp = dvrr_stack + 1835;
 target_ptr = Libderiv->deriv2_classes[1][10][131];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,63,dvrr_stack+33290, dvrr_stack+13554, NULL);
 tmp = dvrr_stack + 33290;
 target_ptr = Libderiv->deriv2_classes[1][5][130];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,84,dvrr_stack+30988, dvrr_stack+13743, NULL);
 tmp = dvrr_stack + 30988;
 target_ptr = Libderiv->deriv2_classes[1][6][130];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,108,dvrr_stack+2656, dvrr_stack+13995, NULL);
 tmp = dvrr_stack + 2656;
 target_ptr = Libderiv->deriv2_classes[1][7][130];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,135,dvrr_stack+33842, dvrr_stack+14319, NULL);
 tmp = dvrr_stack + 33842;
 target_ptr = Libderiv->deriv2_classes[1][8][130];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,165,dvrr_stack+2033, dvrr_stack+14724, NULL);
 tmp = dvrr_stack + 2033;
 target_ptr = Libderiv->deriv2_classes[1][9][130];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,198,dvrr_stack+33977, dvrr_stack+15219, NULL);
 tmp = dvrr_stack + 33977;
 target_ptr = Libderiv->deriv2_classes[1][10][130];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,63,dvrr_stack+3656, dvrr_stack+3412, NULL);
 tmp = dvrr_stack + 3656;
 target_ptr = Libderiv->deriv2_classes[1][5][119];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,84,dvrr_stack+24097, dvrr_stack+4564, NULL);
 tmp = dvrr_stack + 24097;
 target_ptr = Libderiv->deriv2_classes[1][6][119];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,108,dvrr_stack+4492, dvrr_stack+6034, NULL);
 tmp = dvrr_stack + 4492;
 target_ptr = Libderiv->deriv2_classes[1][7][119];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,135,dvrr_stack+6034, dvrr_stack+7663, NULL);
 tmp = dvrr_stack + 6034;
 target_ptr = Libderiv->deriv2_classes[1][8][119];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,165,dvrr_stack+6169, dvrr_stack+10042, NULL);
 tmp = dvrr_stack + 6169;
 target_ptr = Libderiv->deriv2_classes[1][9][119];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,198,dvrr_stack+4600, dvrr_stack+12960, NULL);
 tmp = dvrr_stack + 4600;
 target_ptr = Libderiv->deriv2_classes[1][10][119];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,63,dvrr_stack+2402, dvrr_stack+13554, NULL);
 tmp = dvrr_stack + 2402;
 target_ptr = Libderiv->deriv2_classes[1][5][118];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,84,dvrr_stack+8138, dvrr_stack+13743, NULL);
 tmp = dvrr_stack + 8138;
 target_ptr = Libderiv->deriv2_classes[1][6][118];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,108,dvrr_stack+12942, dvrr_stack+13995, NULL);
 tmp = dvrr_stack + 12942;
 target_ptr = Libderiv->deriv2_classes[1][7][118];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,135,dvrr_stack+13050, dvrr_stack+14319, NULL);
 tmp = dvrr_stack + 13050;
 target_ptr = Libderiv->deriv2_classes[1][8][118];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,165,dvrr_stack+13185, dvrr_stack+14724, NULL);
 tmp = dvrr_stack + 13185;
 target_ptr = Libderiv->deriv2_classes[1][9][118];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,198,dvrr_stack+13350, dvrr_stack+15219, NULL);
 tmp = dvrr_stack + 13350;
 target_ptr = Libderiv->deriv2_classes[1][10][118];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,63,dvrr_stack+31905, dvrr_stack+15813, NULL);
 tmp = dvrr_stack + 31905;
 target_ptr = Libderiv->deriv2_classes[1][5][117];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,84,dvrr_stack+13548, dvrr_stack+3034, NULL);
 tmp = dvrr_stack + 13548;
 target_ptr = Libderiv->deriv2_classes[1][6][117];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,108,dvrr_stack+3010, dvrr_stack+4060, NULL);
 tmp = dvrr_stack + 3010;
 target_ptr = Libderiv->deriv2_classes[1][7][117];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,135,dvrr_stack+4042, dvrr_stack+5386, NULL);
 tmp = dvrr_stack + 4042;
 target_ptr = Libderiv->deriv2_classes[1][8][117];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,165,dvrr_stack+5338, dvrr_stack+6853, NULL);
 tmp = dvrr_stack + 5338;
 target_ptr = Libderiv->deriv2_classes[1][9][117];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,198,dvrr_stack+6853, dvrr_stack+9052, NULL);
 tmp = dvrr_stack + 6853;
 target_ptr = Libderiv->deriv2_classes[1][10][117];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+7051, dvrr_stack+11997, dvrr_stack+11952);
 tmp = dvrr_stack + 7051;
 target_ptr = Libderiv->deriv2_classes[1][5][107];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+7114, dvrr_stack+12144, dvrr_stack+12081);
 tmp = dvrr_stack + 7114;
 target_ptr = Libderiv->deriv2_classes[1][6][107];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+7198, dvrr_stack+12252, dvrr_stack+11997);
 tmp = dvrr_stack + 7198;
 target_ptr = Libderiv->deriv2_classes[1][7][107];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+5503, dvrr_stack+12387, dvrr_stack+12144);
 tmp = dvrr_stack + 5503;
 target_ptr = Libderiv->deriv2_classes[1][8][107];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+9047, dvrr_stack+12552, dvrr_stack+12252);
 tmp = dvrr_stack + 9047;
 target_ptr = Libderiv->deriv2_classes[1][9][107];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_n(Data,3,1,dvrr_stack+9212, dvrr_stack+9646, dvrr_stack+12387);
 tmp = dvrr_stack + 9212;
 target_ptr = Libderiv->deriv2_classes[1][10][107];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+5638, dvrr_stack+12795, dvrr_stack+12750);
 tmp = dvrr_stack + 5638;
 target_ptr = Libderiv->deriv2_classes[1][5][106];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+5701, dvrr_stack+9880, dvrr_stack+12879);
 tmp = dvrr_stack + 5701;
 target_ptr = Libderiv->deriv2_classes[1][6][106];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+9410, dvrr_stack+7348, dvrr_stack+12795);
 tmp = dvrr_stack + 9410;
 target_ptr = Libderiv->deriv2_classes[1][7][106];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+4177, dvrr_stack+7483, dvrr_stack+9880);
 tmp = dvrr_stack + 4177;
 target_ptr = Libderiv->deriv2_classes[1][8][106];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+3118, dvrr_stack+5791, dvrr_stack+7348);
 tmp = dvrr_stack + 3118;
 target_ptr = Libderiv->deriv2_classes[1][9][106];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_n(Data,3,1,dvrr_stack+13632, dvrr_stack+16002, dvrr_stack+7483);
 tmp = dvrr_stack + 13632;
 target_ptr = Libderiv->deriv2_classes[1][10][106];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+9518, dvrr_stack+11817, dvrr_stack+5989);
 tmp = dvrr_stack + 9518;
 target_ptr = Libderiv->deriv2_classes[1][5][105];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+13830, dvrr_stack+2485, dvrr_stack+2782);
 tmp = dvrr_stack + 13830;
 target_ptr = Libderiv->deriv2_classes[1][6][105];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+13914, dvrr_stack+3736, dvrr_stack+11817);
 tmp = dvrr_stack + 13914;
 target_ptr = Libderiv->deriv2_classes[1][7][105];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+14022, dvrr_stack+4981, dvrr_stack+2485);
 tmp = dvrr_stack + 14022;
 target_ptr = Libderiv->deriv2_classes[1][8][105];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+14157, dvrr_stack+6358, dvrr_stack+3736);
 tmp = dvrr_stack + 14157;
 target_ptr = Libderiv->deriv2_classes[1][9][105];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_n(Data,3,1,dvrr_stack+14322, dvrr_stack+8458, dvrr_stack+4981);
 tmp = dvrr_stack + 14322;
 target_ptr = Libderiv->deriv2_classes[1][10][105];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+9581, dvrr_stack+11145, dvrr_stack+11100);
 tmp = dvrr_stack + 9581;
 target_ptr = Libderiv->deriv2_classes[1][5][104];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+14520, dvrr_stack+11292, dvrr_stack+11229);
 tmp = dvrr_stack + 14520;
 target_ptr = Libderiv->deriv2_classes[1][6][104];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+14604, dvrr_stack+11400, dvrr_stack+11145);
 tmp = dvrr_stack + 14604;
 target_ptr = Libderiv->deriv2_classes[1][7][104];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+14712, dvrr_stack+11535, dvrr_stack+11292);
 tmp = dvrr_stack + 14712;
 target_ptr = Libderiv->deriv2_classes[1][8][104];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+14847, dvrr_stack+8692, dvrr_stack+11400);
 tmp = dvrr_stack + 14847;
 target_ptr = Libderiv->deriv2_classes[1][9][104];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_n(Data,3,1,dvrr_stack+15012, dvrr_stack+6556, dvrr_stack+11535);
 tmp = dvrr_stack + 15012;
 target_ptr = Libderiv->deriv2_classes[1][10][104];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+4312, dvrr_stack+11997, dvrr_stack+11952);
 tmp = dvrr_stack + 4312;
 target_ptr = Libderiv->deriv2_classes[1][5][95];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+15210, dvrr_stack+12144, dvrr_stack+12081);
 tmp = dvrr_stack + 15210;
 target_ptr = Libderiv->deriv2_classes[1][6][95];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+15294, dvrr_stack+12252, dvrr_stack+11997);
 tmp = dvrr_stack + 15294;
 target_ptr = Libderiv->deriv2_classes[1][7][95];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+15402, dvrr_stack+12387, dvrr_stack+12144);
 tmp = dvrr_stack + 15402;
 target_ptr = Libderiv->deriv2_classes[1][8][95];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+15537, dvrr_stack+12552, dvrr_stack+12252);
 tmp = dvrr_stack + 15537;
 target_ptr = Libderiv->deriv2_classes[1][9][95];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_n(Data,3,1,dvrr_stack+15702, dvrr_stack+9646, dvrr_stack+12387);
 tmp = dvrr_stack + 15702;
 target_ptr = Libderiv->deriv2_classes[1][10][95];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+15900, dvrr_stack+12795, dvrr_stack+12750);
 tmp = dvrr_stack + 15900;
 target_ptr = Libderiv->deriv2_classes[1][5][94];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+9988, dvrr_stack+9880, dvrr_stack+12879);
 tmp = dvrr_stack + 9988;
 target_ptr = Libderiv->deriv2_classes[1][6][94];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+10072, dvrr_stack+7348, dvrr_stack+12795);
 tmp = dvrr_stack + 10072;
 target_ptr = Libderiv->deriv2_classes[1][7][94];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+10180, dvrr_stack+7483, dvrr_stack+9880);
 tmp = dvrr_stack + 10180;
 target_ptr = Libderiv->deriv2_classes[1][8][94];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+10315, dvrr_stack+5791, dvrr_stack+7348);
 tmp = dvrr_stack + 10315;
 target_ptr = Libderiv->deriv2_classes[1][9][94];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_n(Data,3,1,dvrr_stack+7648, dvrr_stack+16002, dvrr_stack+7483);
 tmp = dvrr_stack + 7648;
 target_ptr = Libderiv->deriv2_classes[1][10][94];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+7846, dvrr_stack+11817, dvrr_stack+5989);
 tmp = dvrr_stack + 7846;
 target_ptr = Libderiv->deriv2_classes[1][5][93];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+7909, dvrr_stack+2485, dvrr_stack+2782);
 tmp = dvrr_stack + 7909;
 target_ptr = Libderiv->deriv2_classes[1][6][93];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+3404, dvrr_stack+3736, dvrr_stack+11817);
 tmp = dvrr_stack + 3404;
 target_ptr = Libderiv->deriv2_classes[1][7][93];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+34175, dvrr_stack+4981, dvrr_stack+2485);
 tmp = dvrr_stack + 34175;
 target_ptr = Libderiv->deriv2_classes[1][8][93];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+34310, dvrr_stack+6358, dvrr_stack+3736);
 tmp = dvrr_stack + 34310;
 target_ptr = Libderiv->deriv2_classes[1][9][93];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_n(Data,3,1,dvrr_stack+34475, dvrr_stack+8458, dvrr_stack+4981);
 tmp = dvrr_stack + 34475;
 target_ptr = Libderiv->deriv2_classes[1][10][93];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+7993, dvrr_stack+11145, dvrr_stack+11100);
 tmp = dvrr_stack + 7993;
 target_ptr = Libderiv->deriv2_classes[1][5][92];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+3512, dvrr_stack+11292, dvrr_stack+11229);
 tmp = dvrr_stack + 3512;
 target_ptr = Libderiv->deriv2_classes[1][6][92];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+34673, dvrr_stack+11400, dvrr_stack+11145);
 tmp = dvrr_stack + 34673;
 target_ptr = Libderiv->deriv2_classes[1][7][92];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+34781, dvrr_stack+11535, dvrr_stack+11292);
 tmp = dvrr_stack + 34781;
 target_ptr = Libderiv->deriv2_classes[1][8][92];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+34916, dvrr_stack+8692, dvrr_stack+11400);
 tmp = dvrr_stack + 34916;
 target_ptr = Libderiv->deriv2_classes[1][9][92];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_n(Data,3,1,dvrr_stack+35081, dvrr_stack+6556, dvrr_stack+11535);
 tmp = dvrr_stack + 35081;
 target_ptr = Libderiv->deriv2_classes[1][10][92];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+35279, dvrr_stack+8890, dvrr_stack+11700);
 tmp = dvrr_stack + 35279;
 target_ptr = Libderiv->deriv2_classes[1][5][91];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+35342, dvrr_stack+5146, dvrr_stack+6790);
 tmp = dvrr_stack + 35342;
 target_ptr = Libderiv->deriv2_classes[1][6][91];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+35426, dvrr_stack+3871, dvrr_stack+8890);
 tmp = dvrr_stack + 35426;
 target_ptr = Libderiv->deriv2_classes[1][7][91];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+35534, dvrr_stack+2845, dvrr_stack+5146);
 tmp = dvrr_stack + 35534;
 target_ptr = Libderiv->deriv2_classes[1][8][91];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+35669, dvrr_stack+16236, dvrr_stack+3871);
 tmp = dvrr_stack + 35669;
 target_ptr = Libderiv->deriv2_classes[1][9][91];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_n(Data,3,1,dvrr_stack+35834, dvrr_stack+16434, dvrr_stack+2845);
 tmp = dvrr_stack + 35834;
 target_ptr = Libderiv->deriv2_classes[1][10][91];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+36032, dvrr_stack+11997, dvrr_stack+11952);
 tmp = dvrr_stack + 36032;
 target_ptr = Libderiv->deriv2_classes[1][5][83];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+36095, dvrr_stack+12144, dvrr_stack+12081);
 tmp = dvrr_stack + 36095;
 target_ptr = Libderiv->deriv2_classes[1][6][83];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+36179, dvrr_stack+12252, dvrr_stack+11997);
 tmp = dvrr_stack + 36179;
 target_ptr = Libderiv->deriv2_classes[1][7][83];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+11946, dvrr_stack+12387, dvrr_stack+12144);
 tmp = dvrr_stack + 11946;
 target_ptr = Libderiv->deriv2_classes[1][8][83];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+12081, dvrr_stack+12552, dvrr_stack+12252);
 tmp = dvrr_stack + 12081;
 target_ptr = Libderiv->deriv2_classes[1][9][83];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_n(Data,3,1,dvrr_stack+12552, dvrr_stack+9646, dvrr_stack+12387);
 tmp = dvrr_stack + 12552;
 target_ptr = Libderiv->deriv2_classes[1][10][83];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+9644, dvrr_stack+12795, dvrr_stack+12750);
 tmp = dvrr_stack + 9644;
 target_ptr = Libderiv->deriv2_classes[1][5][82];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+9707, dvrr_stack+9880, dvrr_stack+12879);
 tmp = dvrr_stack + 9707;
 target_ptr = Libderiv->deriv2_classes[1][6][82];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+12246, dvrr_stack+7348, dvrr_stack+12795);
 tmp = dvrr_stack + 12246;
 target_ptr = Libderiv->deriv2_classes[1][7][82];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+12750, dvrr_stack+7483, dvrr_stack+9880);
 tmp = dvrr_stack + 12750;
 target_ptr = Libderiv->deriv2_classes[1][8][82];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+9791, dvrr_stack+5791, dvrr_stack+7348);
 tmp = dvrr_stack + 9791;
 target_ptr = Libderiv->deriv2_classes[1][9][82];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_n(Data,3,1,dvrr_stack+12354, dvrr_stack+16002, dvrr_stack+7483);
 tmp = dvrr_stack + 12354;
 target_ptr = Libderiv->deriv2_classes[1][10][82];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+7306, dvrr_stack+11817, dvrr_stack+5989);
 tmp = dvrr_stack + 7306;
 target_ptr = Libderiv->deriv2_classes[1][5][81];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+7369, dvrr_stack+2485, dvrr_stack+2782);
 tmp = dvrr_stack + 7369;
 target_ptr = Libderiv->deriv2_classes[1][6][81];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+7453, dvrr_stack+3736, dvrr_stack+11817);
 tmp = dvrr_stack + 7453;
 target_ptr = Libderiv->deriv2_classes[1][7][81];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+11766, dvrr_stack+4981, dvrr_stack+2485);
 tmp = dvrr_stack + 11766;
 target_ptr = Libderiv->deriv2_classes[1][8][81];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+5785, dvrr_stack+6358, dvrr_stack+3736);
 tmp = dvrr_stack + 5785;
 target_ptr = Libderiv->deriv2_classes[1][9][81];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_n(Data,3,1,dvrr_stack+6334, dvrr_stack+8458, dvrr_stack+4981);
 tmp = dvrr_stack + 6334;
 target_ptr = Libderiv->deriv2_classes[1][10][81];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+7561, dvrr_stack+11145, dvrr_stack+11100);
 tmp = dvrr_stack + 7561;
 target_ptr = Libderiv->deriv2_classes[1][5][80];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+5950, dvrr_stack+11292, dvrr_stack+11229);
 tmp = dvrr_stack + 5950;
 target_ptr = Libderiv->deriv2_classes[1][6][80];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+4966, dvrr_stack+11400, dvrr_stack+11145);
 tmp = dvrr_stack + 4966;
 target_ptr = Libderiv->deriv2_classes[1][7][80];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+3719, dvrr_stack+11535, dvrr_stack+11292);
 tmp = dvrr_stack + 3719;
 target_ptr = Libderiv->deriv2_classes[1][8][80];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+8447, dvrr_stack+8692, dvrr_stack+11400);
 tmp = dvrr_stack + 8447;
 target_ptr = Libderiv->deriv2_classes[1][9][80];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_n(Data,3,1,dvrr_stack+8612, dvrr_stack+6556, dvrr_stack+11535);
 tmp = dvrr_stack + 8612;
 target_ptr = Libderiv->deriv2_classes[1][10][80];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+6532, dvrr_stack+8890, dvrr_stack+11700);
 tmp = dvrr_stack + 6532;
 target_ptr = Libderiv->deriv2_classes[1][5][79];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+6595, dvrr_stack+5146, dvrr_stack+6790);
 tmp = dvrr_stack + 6595;
 target_ptr = Libderiv->deriv2_classes[1][6][79];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+6679, dvrr_stack+3871, dvrr_stack+8890);
 tmp = dvrr_stack + 6679;
 target_ptr = Libderiv->deriv2_classes[1][7][79];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+8810, dvrr_stack+2845, dvrr_stack+5146);
 tmp = dvrr_stack + 8810;
 target_ptr = Libderiv->deriv2_classes[1][8][79];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+5074, dvrr_stack+16236, dvrr_stack+3871);
 tmp = dvrr_stack + 5074;
 target_ptr = Libderiv->deriv2_classes[1][9][79];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_n(Data,3,1,dvrr_stack+15963, dvrr_stack+16434, dvrr_stack+2845);
 tmp = dvrr_stack + 15963;
 target_ptr = Libderiv->deriv2_classes[1][10][79];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+6787, dvrr_stack+5254, dvrr_stack+8974);
 tmp = dvrr_stack + 6787;
 target_ptr = Libderiv->deriv2_classes[1][5][78];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+3854, dvrr_stack+4384, dvrr_stack+2593);
 tmp = dvrr_stack + 3854;
 target_ptr = Libderiv->deriv2_classes[1][6][78];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+2465, dvrr_stack+10615, dvrr_stack+5254);
 tmp = dvrr_stack + 2465;
 target_ptr = Libderiv->deriv2_classes[1][7][78];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+2764, dvrr_stack+16668, dvrr_stack+4384);
 tmp = dvrr_stack + 2764;
 target_ptr = Libderiv->deriv2_classes[1][8][78];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+16161, dvrr_stack+16833, dvrr_stack+10615);
 tmp = dvrr_stack + 16161;
 target_ptr = Libderiv->deriv2_classes[1][9][78];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_n(Data,3,1,dvrr_stack+16833, dvrr_stack+17031, dvrr_stack+16668);
 tmp = dvrr_stack + 16833;
 target_ptr = Libderiv->deriv2_classes[1][10][78];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,21,dvrr_stack+17031, dvrr_stack+10960, dvrr_stack+11745);
 tmp = dvrr_stack + 17031;
 target_ptr = Libderiv->deriv2_classes[1][5][35];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,28,dvrr_stack+17094, dvrr_stack+18723, dvrr_stack+9019);
 tmp = dvrr_stack + 17094;
 target_ptr = Libderiv->deriv2_classes[1][6][35];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,36,dvrr_stack+10603, dvrr_stack+20052, dvrr_stack+4006);
 tmp = dvrr_stack + 10603;
 target_ptr = Libderiv->deriv2_classes[1][7][35];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,45,dvrr_stack+16326, dvrr_stack+21543, dvrr_stack+11901);
 tmp = dvrr_stack + 16326;
 target_ptr = Libderiv->deriv2_classes[1][8][35];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,55,dvrr_stack+16461, dvrr_stack+22968, dvrr_stack+3349);
 tmp = dvrr_stack + 16461;
 target_ptr = Libderiv->deriv2_classes[1][9][35];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,66,dvrr_stack+16626, dvrr_stack+25386, dvrr_stack+613);
 tmp = dvrr_stack + 16626;
 target_ptr = Libderiv->deriv2_classes[1][10][35];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+17178, dvrr_stack+23496, dvrr_stack+8068);
 tmp = dvrr_stack + 17178;
 target_ptr = Libderiv->deriv2_classes[1][5][34];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+5239, dvrr_stack+8224, dvrr_stack+8089);
 tmp = dvrr_stack + 5239;
 target_ptr = Libderiv->deriv2_classes[1][6][34];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+4375, dvrr_stack+25782, dvrr_stack+23622);
 tmp = dvrr_stack + 4375;
 target_ptr = Libderiv->deriv2_classes[1][7][34];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+11086, dvrr_stack+25998, dvrr_stack+23658);
 tmp = dvrr_stack + 11086;
 target_ptr = Libderiv->deriv2_classes[1][8][34];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+11221, dvrr_stack+26268, dvrr_stack+8392);
 tmp = dvrr_stack + 11221;
 target_ptr = Libderiv->deriv2_classes[1][9][34];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,66,dvrr_stack+11386, dvrr_stack+26598, dvrr_stack+10537);
 tmp = dvrr_stack + 11386;
 target_ptr = Libderiv->deriv2_classes[1][10][34];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+3938, dvrr_stack+26994, dvrr_stack+8117);
 tmp = dvrr_stack + 3938;
 target_ptr = Libderiv->deriv2_classes[1][5][33];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+2899, dvrr_stack+17461, dvrr_stack+17433);
 tmp = dvrr_stack + 2899;
 target_ptr = Libderiv->deriv2_classes[1][6][33];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+11584, dvrr_stack+18255, dvrr_stack+18219);
 tmp = dvrr_stack + 11584;
 target_ptr = Libderiv->deriv2_classes[1][7][33];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+36287, dvrr_stack+19449, dvrr_stack+19404);
 tmp = dvrr_stack + 36287;
 target_ptr = Libderiv->deriv2_classes[1][8][33];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+36422, dvrr_stack+20788, dvrr_stack+20733);
 tmp = dvrr_stack + 36422;
 target_ptr = Libderiv->deriv2_classes[1][9][33];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,66,dvrr_stack+36587, dvrr_stack+21879, dvrr_stack+21813);
 tmp = dvrr_stack + 36587;
 target_ptr = Libderiv->deriv2_classes[1][10][33];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+2573, dvrr_stack+24339, dvrr_stack+24198);
 tmp = dvrr_stack + 2573;
 target_ptr = Libderiv->deriv2_classes[1][5][32];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+36785, dvrr_stack+24465, dvrr_stack+24219);
 tmp = dvrr_stack + 36785;
 target_ptr = Libderiv->deriv2_classes[1][6][32];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+36869, dvrr_stack+24669, dvrr_stack+24633);
 tmp = dvrr_stack + 36869;
 target_ptr = Libderiv->deriv2_classes[1][7][32];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+2198, dvrr_stack+24930, dvrr_stack+24885);
 tmp = dvrr_stack + 2198;
 target_ptr = Libderiv->deriv2_classes[1][8][32];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+36977, dvrr_stack+22275, dvrr_stack+25200);
 tmp = dvrr_stack + 36977;
 target_ptr = Libderiv->deriv2_classes[1][9][32];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,66,dvrr_stack+37142, dvrr_stack+21118, dvrr_stack+25255);
 tmp = dvrr_stack + 37142;
 target_ptr = Libderiv->deriv2_classes[1][10][32];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+8945, dvrr_stack+23298, dvrr_stack+25321);
 tmp = dvrr_stack + 8945;
 target_ptr = Libderiv->deriv2_classes[1][5][31];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+37340, dvrr_stack+22605, dvrr_stack+25342);
 tmp = dvrr_stack + 37340;
 target_ptr = Libderiv->deriv2_classes[1][6][31];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+37424, dvrr_stack+19719, dvrr_stack+23424);
 tmp = dvrr_stack + 37424;
 target_ptr = Libderiv->deriv2_classes[1][7][31];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+37532, dvrr_stack+27120, dvrr_stack+22773);
 tmp = dvrr_stack + 37532;
 target_ptr = Libderiv->deriv2_classes[1][8][31];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+37667, dvrr_stack+27390, dvrr_stack+22818);
 tmp = dvrr_stack + 37667;
 target_ptr = Libderiv->deriv2_classes[1][9][31];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,66,dvrr_stack+37832, dvrr_stack+27720, dvrr_stack+22873);
 tmp = dvrr_stack + 37832;
 target_ptr = Libderiv->deriv2_classes[1][10][31];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+38030, dvrr_stack+10750, dvrr_stack+483);
 tmp = dvrr_stack + 38030;
 target_ptr = Libderiv->deriv_classes[1][5][2];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+38093, dvrr_stack+20268, dvrr_stack+23460);
 tmp = dvrr_stack + 38093;
 target_ptr = Libderiv->deriv2_classes[1][5][30];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+38156, dvrr_stack+17265, dvrr_stack+504);
 tmp = dvrr_stack + 38156;
 target_ptr = Libderiv->deriv_classes[1][6][2];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+38240, dvrr_stack+18471, dvrr_stack+24247);
 tmp = dvrr_stack + 38240;
 target_ptr = Libderiv->deriv2_classes[1][6][30];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+38324, dvrr_stack+18003, dvrr_stack+532);
 tmp = dvrr_stack + 38324;
 target_ptr = Libderiv->deriv_classes[1][7][2];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+38432, dvrr_stack+17629, dvrr_stack+24275);
 tmp = dvrr_stack + 38432;
 target_ptr = Libderiv->deriv2_classes[1][7][30];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+38540, dvrr_stack+19134, dvrr_stack+568);
 tmp = dvrr_stack + 38540;
 target_ptr = Libderiv->deriv_classes[1][8][2];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+38675, dvrr_stack+28116, dvrr_stack+19935);
 tmp = dvrr_stack + 38675;
 target_ptr = Libderiv->deriv2_classes[1][8][30];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+38810, dvrr_stack+20403, dvrr_stack+823);
 tmp = dvrr_stack + 38810;
 target_ptr = Libderiv->deriv_classes[1][9][2];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+38975, dvrr_stack+28386, dvrr_stack+19980);
 tmp = dvrr_stack + 38975;
 target_ptr = Libderiv->deriv2_classes[1][9][30];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,66,dvrr_stack+39140, dvrr_stack+28716, dvrr_stack+18891);
 tmp = dvrr_stack + 39140;
 target_ptr = Libderiv->deriv2_classes[1][10][30];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+39338, dvrr_stack+29112, dvrr_stack+24311);
 tmp = dvrr_stack + 39338;
 target_ptr = Libderiv->deriv2_classes[1][5][26];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+39401, dvrr_stack+23731, dvrr_stack+23703);
 tmp = dvrr_stack + 39401;
 target_ptr = Libderiv->deriv2_classes[1][6][26];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+39485, dvrr_stack+30154, dvrr_stack+10876);
 tmp = dvrr_stack + 39485;
 target_ptr = Libderiv->deriv2_classes[1][7][26];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+39593, dvrr_stack+0, dvrr_stack+29238);
 tmp = dvrr_stack + 39593;
 target_ptr = Libderiv->deriv2_classes[1][8][26];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+39728, dvrr_stack+31970, dvrr_stack+29686);
 tmp = dvrr_stack + 39728;
 target_ptr = Libderiv->deriv2_classes[1][9][26];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,66,dvrr_stack+39893, dvrr_stack+32300, dvrr_stack+30370);
 tmp = dvrr_stack + 39893;
 target_ptr = Libderiv->deriv2_classes[1][10][26];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,21,dvrr_stack+40091, dvrr_stack+10960, dvrr_stack+11745);
 tmp = dvrr_stack + 40091;
 target_ptr = Libderiv->deriv2_classes[1][5][23];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,28,dvrr_stack+40154, dvrr_stack+18723, dvrr_stack+9019);
 tmp = dvrr_stack + 40154;
 target_ptr = Libderiv->deriv2_classes[1][6][23];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,36,dvrr_stack+40238, dvrr_stack+20052, dvrr_stack+4006);
 tmp = dvrr_stack + 40238;
 target_ptr = Libderiv->deriv2_classes[1][7][23];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,45,dvrr_stack+40346, dvrr_stack+21543, dvrr_stack+11901);
 tmp = dvrr_stack + 40346;
 target_ptr = Libderiv->deriv2_classes[1][8][23];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,55,dvrr_stack+40481, dvrr_stack+22968, dvrr_stack+3349);
 tmp = dvrr_stack + 40481;
 target_ptr = Libderiv->deriv2_classes[1][9][23];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,66,dvrr_stack+40646, dvrr_stack+25386, dvrr_stack+613);
 tmp = dvrr_stack + 40646;
 target_ptr = Libderiv->deriv2_classes[1][10][23];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+40844, dvrr_stack+23496, dvrr_stack+8068);
 tmp = dvrr_stack + 40844;
 target_ptr = Libderiv->deriv2_classes[1][5][22];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+40907, dvrr_stack+8224, dvrr_stack+8089);
 tmp = dvrr_stack + 40907;
 target_ptr = Libderiv->deriv2_classes[1][6][22];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+40991, dvrr_stack+25782, dvrr_stack+23622);
 tmp = dvrr_stack + 40991;
 target_ptr = Libderiv->deriv2_classes[1][7][22];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+41099, dvrr_stack+25998, dvrr_stack+23658);
 tmp = dvrr_stack + 41099;
 target_ptr = Libderiv->deriv2_classes[1][8][22];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+41234, dvrr_stack+26268, dvrr_stack+8392);
 tmp = dvrr_stack + 41234;
 target_ptr = Libderiv->deriv2_classes[1][9][22];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,66,dvrr_stack+41399, dvrr_stack+26598, dvrr_stack+10537);
 tmp = dvrr_stack + 41399;
 target_ptr = Libderiv->deriv2_classes[1][10][22];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+41597, dvrr_stack+26994, dvrr_stack+8117);
 tmp = dvrr_stack + 41597;
 target_ptr = Libderiv->deriv2_classes[1][5][21];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+41660, dvrr_stack+17461, dvrr_stack+17433);
 tmp = dvrr_stack + 41660;
 target_ptr = Libderiv->deriv2_classes[1][6][21];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+41744, dvrr_stack+18255, dvrr_stack+18219);
 tmp = dvrr_stack + 41744;
 target_ptr = Libderiv->deriv2_classes[1][7][21];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+41852, dvrr_stack+19449, dvrr_stack+19404);
 tmp = dvrr_stack + 41852;
 target_ptr = Libderiv->deriv2_classes[1][8][21];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+41987, dvrr_stack+20788, dvrr_stack+20733);
 tmp = dvrr_stack + 41987;
 target_ptr = Libderiv->deriv2_classes[1][9][21];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,66,dvrr_stack+42152, dvrr_stack+21879, dvrr_stack+21813);
 tmp = dvrr_stack + 42152;
 target_ptr = Libderiv->deriv2_classes[1][10][21];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+42350, dvrr_stack+24339, dvrr_stack+24198);
 tmp = dvrr_stack + 42350;
 target_ptr = Libderiv->deriv2_classes[1][5][20];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+42413, dvrr_stack+24465, dvrr_stack+24219);
 tmp = dvrr_stack + 42413;
 target_ptr = Libderiv->deriv2_classes[1][6][20];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+42497, dvrr_stack+24669, dvrr_stack+24633);
 tmp = dvrr_stack + 42497;
 target_ptr = Libderiv->deriv2_classes[1][7][20];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+42605, dvrr_stack+24930, dvrr_stack+24885);
 tmp = dvrr_stack + 42605;
 target_ptr = Libderiv->deriv2_classes[1][8][20];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+42740, dvrr_stack+22275, dvrr_stack+25200);
 tmp = dvrr_stack + 42740;
 target_ptr = Libderiv->deriv2_classes[1][9][20];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,66,dvrr_stack+42905, dvrr_stack+21118, dvrr_stack+25255);
 tmp = dvrr_stack + 42905;
 target_ptr = Libderiv->deriv2_classes[1][10][20];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+43103, dvrr_stack+23298, dvrr_stack+25321);
 tmp = dvrr_stack + 43103;
 target_ptr = Libderiv->deriv2_classes[1][5][19];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+43166, dvrr_stack+22605, dvrr_stack+25342);
 tmp = dvrr_stack + 43166;
 target_ptr = Libderiv->deriv2_classes[1][6][19];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+43250, dvrr_stack+19719, dvrr_stack+23424);
 tmp = dvrr_stack + 43250;
 target_ptr = Libderiv->deriv2_classes[1][7][19];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+43358, dvrr_stack+27120, dvrr_stack+22773);
 tmp = dvrr_stack + 43358;
 target_ptr = Libderiv->deriv2_classes[1][8][19];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+43493, dvrr_stack+27390, dvrr_stack+22818);
 tmp = dvrr_stack + 43493;
 target_ptr = Libderiv->deriv2_classes[1][9][19];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,66,dvrr_stack+43658, dvrr_stack+27720, dvrr_stack+22873);
 tmp = dvrr_stack + 43658;
 target_ptr = Libderiv->deriv2_classes[1][10][19];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+43856, dvrr_stack+10750, dvrr_stack+483);
 tmp = dvrr_stack + 43856;
 target_ptr = Libderiv->deriv_classes[1][5][1];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+43919, dvrr_stack+20268, dvrr_stack+23460);
 tmp = dvrr_stack + 43919;
 target_ptr = Libderiv->deriv2_classes[1][5][18];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+43982, dvrr_stack+17265, dvrr_stack+504);
 tmp = dvrr_stack + 43982;
 target_ptr = Libderiv->deriv_classes[1][6][1];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+44066, dvrr_stack+18471, dvrr_stack+24247);
 tmp = dvrr_stack + 44066;
 target_ptr = Libderiv->deriv2_classes[1][6][18];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+44150, dvrr_stack+18003, dvrr_stack+532);
 tmp = dvrr_stack + 44150;
 target_ptr = Libderiv->deriv_classes[1][7][1];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+44258, dvrr_stack+17629, dvrr_stack+24275);
 tmp = dvrr_stack + 44258;
 target_ptr = Libderiv->deriv2_classes[1][7][18];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+44366, dvrr_stack+19134, dvrr_stack+568);
 tmp = dvrr_stack + 44366;
 target_ptr = Libderiv->deriv_classes[1][8][1];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+44501, dvrr_stack+28116, dvrr_stack+19935);
 tmp = dvrr_stack + 44501;
 target_ptr = Libderiv->deriv2_classes[1][8][18];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+44636, dvrr_stack+20403, dvrr_stack+823);
 tmp = dvrr_stack + 44636;
 target_ptr = Libderiv->deriv_classes[1][9][1];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+44801, dvrr_stack+28386, dvrr_stack+19980);
 tmp = dvrr_stack + 44801;
 target_ptr = Libderiv->deriv2_classes[1][9][18];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,66,dvrr_stack+44966, dvrr_stack+28716, dvrr_stack+18891);
 tmp = dvrr_stack + 44966;
 target_ptr = Libderiv->deriv2_classes[1][10][18];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+45164, dvrr_stack+29112, dvrr_stack+24311);
 tmp = dvrr_stack + 45164;
 target_ptr = Libderiv->deriv2_classes[1][5][14];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+45227, dvrr_stack+23731, dvrr_stack+23703);
 tmp = dvrr_stack + 45227;
 target_ptr = Libderiv->deriv2_classes[1][6][14];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+45311, dvrr_stack+30154, dvrr_stack+10876);
 tmp = dvrr_stack + 45311;
 target_ptr = Libderiv->deriv2_classes[1][7][14];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+45419, dvrr_stack+0, dvrr_stack+29238);
 tmp = dvrr_stack + 45419;
 target_ptr = Libderiv->deriv2_classes[1][8][14];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+45554, dvrr_stack+31970, dvrr_stack+29686);
 tmp = dvrr_stack + 45554;
 target_ptr = Libderiv->deriv2_classes[1][9][14];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,66,dvrr_stack+45719, dvrr_stack+32300, dvrr_stack+30370);
 tmp = dvrr_stack + 45719;
 target_ptr = Libderiv->deriv2_classes[1][10][14];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+45917, dvrr_stack+31111, dvrr_stack+31090);
 tmp = dvrr_stack + 45917;
 target_ptr = Libderiv->deriv2_classes[1][5][13];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+45980, dvrr_stack+18957, dvrr_stack+31237);
 tmp = dvrr_stack + 45980;
 target_ptr = Libderiv->deriv2_classes[1][6][13];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+46064, dvrr_stack+33356, dvrr_stack+31265);
 tmp = dvrr_stack + 46064;
 target_ptr = Libderiv->deriv2_classes[1][7][13];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+46172, dvrr_stack+33572, dvrr_stack+31301);
 tmp = dvrr_stack + 46172;
 target_ptr = Libderiv->deriv2_classes[1][8][13];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+46307, dvrr_stack+944, dvrr_stack+31346);
 tmp = dvrr_stack + 46307;
 target_ptr = Libderiv->deriv2_classes[1][9][13];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,66,dvrr_stack+46472, dvrr_stack+1274, dvrr_stack+30436);
 tmp = dvrr_stack + 46472;
 target_ptr = Libderiv->deriv2_classes[1][10][13];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,21,dvrr_stack+46670, dvrr_stack+10960, dvrr_stack+11745);
 tmp = dvrr_stack + 46670;
 target_ptr = Libderiv->deriv2_classes[1][5][11];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,28,dvrr_stack+10912, dvrr_stack+18723, dvrr_stack+9019);
 tmp = dvrr_stack + 10912;
 target_ptr = Libderiv->deriv2_classes[1][6][11];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,36,dvrr_stack+18723, dvrr_stack+20052, dvrr_stack+4006);
 tmp = dvrr_stack + 18723;
 target_ptr = Libderiv->deriv2_classes[1][7][11];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,45,dvrr_stack+20035, dvrr_stack+21543, dvrr_stack+11901);
 tmp = dvrr_stack + 20035;
 target_ptr = Libderiv->deriv2_classes[1][8][11];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,55,dvrr_stack+21514, dvrr_stack+22968, dvrr_stack+3349);
 tmp = dvrr_stack + 21514;
 target_ptr = Libderiv->deriv2_classes[1][9][11];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,66,dvrr_stack+22939, dvrr_stack+25386, dvrr_stack+613);
 tmp = dvrr_stack + 22939;
 target_ptr = Libderiv->deriv2_classes[1][10][11];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+613, dvrr_stack+23496, dvrr_stack+8068);
 tmp = dvrr_stack + 613;
 target_ptr = Libderiv->deriv2_classes[1][5][10];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+10996, dvrr_stack+8224, dvrr_stack+8089);
 tmp = dvrr_stack + 10996;
 target_ptr = Libderiv->deriv2_classes[1][6][10];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+25370, dvrr_stack+25782, dvrr_stack+23622);
 tmp = dvrr_stack + 25370;
 target_ptr = Libderiv->deriv2_classes[1][7][10];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+25478, dvrr_stack+25998, dvrr_stack+23658);
 tmp = dvrr_stack + 25478;
 target_ptr = Libderiv->deriv2_classes[1][8][10];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+25613, dvrr_stack+26268, dvrr_stack+8392);
 tmp = dvrr_stack + 25613;
 target_ptr = Libderiv->deriv2_classes[1][9][10];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,66,dvrr_stack+25778, dvrr_stack+26598, dvrr_stack+10537);
 tmp = dvrr_stack + 25778;
 target_ptr = Libderiv->deriv2_classes[1][10][10];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+25976, dvrr_stack+26994, dvrr_stack+8117);
 tmp = dvrr_stack + 25976;
 target_ptr = Libderiv->deriv2_classes[1][5][9];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+26039, dvrr_stack+17461, dvrr_stack+17433);
 tmp = dvrr_stack + 26039;
 target_ptr = Libderiv->deriv2_classes[1][6][9];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+17433, dvrr_stack+18255, dvrr_stack+18219);
 tmp = dvrr_stack + 17433;
 target_ptr = Libderiv->deriv2_classes[1][7][9];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+18219, dvrr_stack+19449, dvrr_stack+19404);
 tmp = dvrr_stack + 18219;
 target_ptr = Libderiv->deriv2_classes[1][8][9];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+19404, dvrr_stack+20788, dvrr_stack+20733);
 tmp = dvrr_stack + 19404;
 target_ptr = Libderiv->deriv2_classes[1][9][9];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,66,dvrr_stack+20733, dvrr_stack+21879, dvrr_stack+21813);
 tmp = dvrr_stack + 20733;
 target_ptr = Libderiv->deriv2_classes[1][10][9];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+20931, dvrr_stack+24339, dvrr_stack+24198);
 tmp = dvrr_stack + 20931;
 target_ptr = Libderiv->deriv2_classes[1][5][8];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+20994, dvrr_stack+24465, dvrr_stack+24219);
 tmp = dvrr_stack + 20994;
 target_ptr = Libderiv->deriv2_classes[1][6][8];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+19569, dvrr_stack+24669, dvrr_stack+24633);
 tmp = dvrr_stack + 19569;
 target_ptr = Libderiv->deriv2_classes[1][7][8];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+24332, dvrr_stack+24930, dvrr_stack+24885);
 tmp = dvrr_stack + 24332;
 target_ptr = Libderiv->deriv2_classes[1][8][8];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+24467, dvrr_stack+22275, dvrr_stack+25200);
 tmp = dvrr_stack + 24467;
 target_ptr = Libderiv->deriv2_classes[1][9][8];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,66,dvrr_stack+24632, dvrr_stack+21118, dvrr_stack+25255);
 tmp = dvrr_stack + 24632;
 target_ptr = Libderiv->deriv2_classes[1][10][8];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+21078, dvrr_stack+23298, dvrr_stack+25321);
 tmp = dvrr_stack + 21078;
 target_ptr = Libderiv->deriv2_classes[1][5][7];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+21141, dvrr_stack+22605, dvrr_stack+25342);
 tmp = dvrr_stack + 21141;
 target_ptr = Libderiv->deriv2_classes[1][6][7];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+21225, dvrr_stack+19719, dvrr_stack+23424);
 tmp = dvrr_stack + 21225;
 target_ptr = Libderiv->deriv2_classes[1][7][7];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+21333, dvrr_stack+27120, dvrr_stack+22773);
 tmp = dvrr_stack + 21333;
 target_ptr = Libderiv->deriv2_classes[1][8][7];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+19677, dvrr_stack+27390, dvrr_stack+22818);
 tmp = dvrr_stack + 19677;
 target_ptr = Libderiv->deriv2_classes[1][9][7];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,66,dvrr_stack+24830, dvrr_stack+27720, dvrr_stack+22873);
 tmp = dvrr_stack + 24830;
 target_ptr = Libderiv->deriv2_classes[1][10][7];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+19842, dvrr_stack+10750, dvrr_stack+483);
 tmp = dvrr_stack + 19842;
 target_ptr = Libderiv->deriv_classes[1][5][0];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+18354, dvrr_stack+20268, dvrr_stack+23460);
 tmp = dvrr_stack + 18354;
 target_ptr = Libderiv->deriv2_classes[1][5][6];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+17541, dvrr_stack+17265, dvrr_stack+504);
 tmp = dvrr_stack + 17541;
 target_ptr = Libderiv->deriv_classes[1][6][0];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+17241, dvrr_stack+18471, dvrr_stack+24247);
 tmp = dvrr_stack + 17241;
 target_ptr = Libderiv->deriv2_classes[1][6][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+17325, dvrr_stack+18003, dvrr_stack+532);
 tmp = dvrr_stack + 17325;
 target_ptr = Libderiv->deriv_classes[1][7][0];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+18417, dvrr_stack+17629, dvrr_stack+24275);
 tmp = dvrr_stack + 18417;
 target_ptr = Libderiv->deriv2_classes[1][7][6];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+17625, dvrr_stack+19134, dvrr_stack+568);
 tmp = dvrr_stack + 17625;
 target_ptr = Libderiv->deriv_classes[1][8][0];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+19125, dvrr_stack+28116, dvrr_stack+19935);
 tmp = dvrr_stack + 19125;
 target_ptr = Libderiv->deriv2_classes[1][8][6];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+10711, dvrr_stack+20403, dvrr_stack+823);
 tmp = dvrr_stack + 10711;
 target_ptr = Libderiv->deriv_classes[1][9][0];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+17971, dvrr_stack+28386, dvrr_stack+19980);
 tmp = dvrr_stack + 17971;
 target_ptr = Libderiv->deriv2_classes[1][9][6];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,66,dvrr_stack+25028, dvrr_stack+28716, dvrr_stack+18891);
 tmp = dvrr_stack + 25028;
 target_ptr = Libderiv->deriv2_classes[1][10][6];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+483, dvrr_stack+29112, dvrr_stack+24311);
 tmp = dvrr_stack + 483;
 target_ptr = Libderiv->deriv2_classes[1][5][2];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+19905, dvrr_stack+23731, dvrr_stack+23703);
 tmp = dvrr_stack + 19905;
 target_ptr = Libderiv->deriv2_classes[1][6][2];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+18525, dvrr_stack+30154, dvrr_stack+10876);
 tmp = dvrr_stack + 18525;
 target_ptr = Libderiv->deriv2_classes[1][7][2];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+19260, dvrr_stack+0, dvrr_stack+29238);
 tmp = dvrr_stack + 19260;
 target_ptr = Libderiv->deriv2_classes[1][8][2];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+0, dvrr_stack+31970, dvrr_stack+29686);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv2_classes[1][9][2];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,66,dvrr_stack+31968, dvrr_stack+32300, dvrr_stack+30370);
 tmp = dvrr_stack + 31968;
 target_ptr = Libderiv->deriv2_classes[1][10][2];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+165, dvrr_stack+31111, dvrr_stack+31090);
 tmp = dvrr_stack + 165;
 target_ptr = Libderiv->deriv2_classes[1][5][1];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+17760, dvrr_stack+18957, dvrr_stack+31237);
 tmp = dvrr_stack + 17760;
 target_ptr = Libderiv->deriv2_classes[1][6][1];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+18831, dvrr_stack+33356, dvrr_stack+31265);
 tmp = dvrr_stack + 18831;
 target_ptr = Libderiv->deriv2_classes[1][7][1];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+18939, dvrr_stack+33572, dvrr_stack+31301);
 tmp = dvrr_stack + 18939;
 target_ptr = Libderiv->deriv2_classes[1][8][1];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+33353, dvrr_stack+944, dvrr_stack+31346);
 tmp = dvrr_stack + 33353;
 target_ptr = Libderiv->deriv2_classes[1][9][1];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,66,dvrr_stack+941, dvrr_stack+1274, dvrr_stack+30436);
 tmp = dvrr_stack + 941;
 target_ptr = Libderiv->deriv2_classes[1][10][1];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+546, dvrr_stack+17845, dvrr_stack+30502);
 tmp = dvrr_stack + 546;
 target_ptr = Libderiv->deriv2_classes[1][5][0];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+17844, dvrr_stack+270, dvrr_stack+2338);
 tmp = dvrr_stack + 17844;
 target_ptr = Libderiv->deriv2_classes[1][6][0];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+228, dvrr_stack+29283, dvrr_stack+2366);
 tmp = dvrr_stack + 228;
 target_ptr = Libderiv->deriv2_classes[1][7][0];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+1139, dvrr_stack+29741, dvrr_stack+438);
 tmp = dvrr_stack + 1139;
 target_ptr = Libderiv->deriv2_classes[1][8][0];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+1274, dvrr_stack+30523, dvrr_stack+3601);
 tmp = dvrr_stack + 1274;
 target_ptr = Libderiv->deriv2_classes[1][9][0];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,66,dvrr_stack+1439, dvrr_stack+31401, dvrr_stack+4816);
 tmp = dvrr_stack + 1439;
 target_ptr = Libderiv->deriv2_classes[1][10][0];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];


}

