/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (pp|hh) integrals */

void d12vrr_order_pphh(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6, dvrr_stack+3, dvrr_stack+0, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+12, dvrr_stack+3, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+21, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+24, dvrr_stack+0, dvrr_stack+21, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+30, dvrr_stack+6, dvrr_stack+24, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+40, dvrr_stack+15, dvrr_stack+6, dvrr_stack+12, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+50, dvrr_stack+40, dvrr_stack+30, dvrr_stack+15, dvrr_stack+6, NULL);

 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+65, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+68, dvrr_stack+21, dvrr_stack+65, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+74, dvrr_stack+24, dvrr_stack+68, dvrr_stack+0, dvrr_stack+21, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+84, dvrr_stack+30, dvrr_stack+74, dvrr_stack+6, dvrr_stack+24, NULL);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+99, dvrr_stack+50, dvrr_stack+84, dvrr_stack+40, dvrr_stack+30, NULL);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+120, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+123, dvrr_stack+120, dvrr_stack+12, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+129, dvrr_stack+123, dvrr_stack+15, dvrr_stack+120, dvrr_stack+12, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+139, dvrr_stack+129, dvrr_stack+40, dvrr_stack+123, dvrr_stack+15, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+154, dvrr_stack+139, dvrr_stack+50, dvrr_stack+129, dvrr_stack+40, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+175, dvrr_stack+154, dvrr_stack+99, NULL, NULL, dvrr_stack+50);
 tmp = dvrr_stack + 175;
 target_ptr = Libderiv->dvrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+120, dvrr_stack+65, dvrr_stack+12, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+238, dvrr_stack+68, dvrr_stack+120, dvrr_stack+21, dvrr_stack+65, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+248, dvrr_stack+74, dvrr_stack+238, dvrr_stack+24, dvrr_stack+68, NULL);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+263, dvrr_stack+84, dvrr_stack+248, dvrr_stack+30, dvrr_stack+74, NULL);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+284, dvrr_stack+99, dvrr_stack+263, dvrr_stack+50, dvrr_stack+84, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+312, dvrr_stack+154, dvrr_stack+99, dvrr_stack+139, dvrr_stack+50, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+340, dvrr_stack+312, dvrr_stack+284, NULL, NULL, dvrr_stack+99);
 tmp = dvrr_stack + 340;
 target_ptr = Libderiv->dvrr_classes[1][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+424,dvrr_stack+340,dvrr_stack+175,3);


 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+126, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+613, dvrr_stack+12, dvrr_stack+126, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+619, dvrr_stack+120, dvrr_stack+613, dvrr_stack+65, dvrr_stack+12, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+629, dvrr_stack+238, dvrr_stack+619, dvrr_stack+68, dvrr_stack+120, NULL);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+644, dvrr_stack+248, dvrr_stack+629, dvrr_stack+74, dvrr_stack+238, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+665, dvrr_stack+263, dvrr_stack+644, dvrr_stack+84, dvrr_stack+248, NULL);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+693, dvrr_stack+284, dvrr_stack+665, dvrr_stack+99, dvrr_stack+263, NULL);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+729, dvrr_stack+312, dvrr_stack+284, dvrr_stack+154, dvrr_stack+99, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+765, dvrr_stack+729, dvrr_stack+693, NULL, NULL, dvrr_stack+284);
 tmp = dvrr_stack + 765;
 target_ptr = Libderiv->dvrr_classes[1][7];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+873,dvrr_stack+765,dvrr_stack+340,3);


 /* compute (1 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+1125,dvrr_stack+873,dvrr_stack+424,3);


 /* compute (1 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,63,dvrr_stack+1503, dvrr_stack+1125, dvrr_stack+175);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+65, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1692, dvrr_stack+126, dvrr_stack+65, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1698, dvrr_stack+613, dvrr_stack+1692, dvrr_stack+12, dvrr_stack+126, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1708, dvrr_stack+619, dvrr_stack+1698, dvrr_stack+120, dvrr_stack+613, NULL);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1723, dvrr_stack+629, dvrr_stack+1708, dvrr_stack+238, dvrr_stack+619, NULL);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1744, dvrr_stack+644, dvrr_stack+1723, dvrr_stack+248, dvrr_stack+629, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1772, dvrr_stack+665, dvrr_stack+1744, dvrr_stack+263, dvrr_stack+644, NULL);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1808, dvrr_stack+693, dvrr_stack+1772, dvrr_stack+284, dvrr_stack+665, NULL);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1853, dvrr_stack+729, dvrr_stack+693, dvrr_stack+312, dvrr_stack+284, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1898, dvrr_stack+1853, dvrr_stack+1808, NULL, NULL, dvrr_stack+693);
 tmp = dvrr_stack + 1898;
 target_ptr = Libderiv->dvrr_classes[1][8];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+2033,dvrr_stack+1898,dvrr_stack+765,3);


 /* compute (1 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+2357,dvrr_stack+2033,dvrr_stack+873,3);


 /* compute (1 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,84,dvrr_stack+2861, dvrr_stack+2357, dvrr_stack+340);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+120, dvrr_stack+65, dvrr_stack+12, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+3113, dvrr_stack+1692, dvrr_stack+120, dvrr_stack+126, dvrr_stack+65, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+3123, dvrr_stack+1698, dvrr_stack+3113, dvrr_stack+613, dvrr_stack+1692, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+3138, dvrr_stack+1708, dvrr_stack+3123, dvrr_stack+619, dvrr_stack+1698, NULL);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3159, dvrr_stack+1723, dvrr_stack+3138, dvrr_stack+629, dvrr_stack+1708, NULL);

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3187, dvrr_stack+1744, dvrr_stack+3159, dvrr_stack+644, dvrr_stack+1723, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3223, dvrr_stack+1772, dvrr_stack+3187, dvrr_stack+665, dvrr_stack+1744, NULL);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3268, dvrr_stack+1808, dvrr_stack+3223, dvrr_stack+693, dvrr_stack+1772, NULL);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3323, dvrr_stack+1853, dvrr_stack+1808, dvrr_stack+729, dvrr_stack+693, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3378, dvrr_stack+3323, dvrr_stack+3268, NULL, NULL, dvrr_stack+1808);
 tmp = dvrr_stack + 3378;
 target_ptr = Libderiv->dvrr_classes[1][9];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+3543,dvrr_stack+3378,dvrr_stack+1898,3);


 /* compute (1 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+3948,dvrr_stack+3543,dvrr_stack+2033,3);


 /* compute (1 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,108,dvrr_stack+4596, dvrr_stack+3948, dvrr_stack+765);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+126, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+613, dvrr_stack+12, dvrr_stack+126, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+619, dvrr_stack+120, dvrr_stack+613, dvrr_stack+65, dvrr_stack+12, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+4920, dvrr_stack+3113, dvrr_stack+619, dvrr_stack+1692, dvrr_stack+120, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+4935, dvrr_stack+3123, dvrr_stack+4920, dvrr_stack+1698, dvrr_stack+3113, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+4956, dvrr_stack+3138, dvrr_stack+4935, dvrr_stack+1708, dvrr_stack+3123, NULL);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4984, dvrr_stack+3159, dvrr_stack+4956, dvrr_stack+1723, dvrr_stack+3138, NULL);

 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+5020, dvrr_stack+3187, dvrr_stack+4984, dvrr_stack+1744, dvrr_stack+3159, NULL);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+5065, dvrr_stack+3223, dvrr_stack+5020, dvrr_stack+1772, dvrr_stack+3187, NULL);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+5120, dvrr_stack+3268, dvrr_stack+5065, dvrr_stack+1808, dvrr_stack+3223, NULL);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+5186, dvrr_stack+3323, dvrr_stack+3268, dvrr_stack+1853, dvrr_stack+1808, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+5252, dvrr_stack+5186, dvrr_stack+5120, NULL, NULL, dvrr_stack+3268);
 tmp = dvrr_stack + 5252;
 target_ptr = Libderiv->dvrr_classes[1][10];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+5450,dvrr_stack+5252,dvrr_stack+3378,3);


 /* compute (1 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+5945,dvrr_stack+5450,dvrr_stack+3543,3);


 /* compute (1 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,135,dvrr_stack+6755, dvrr_stack+5945, dvrr_stack+1898);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+65, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1692, dvrr_stack+126, dvrr_stack+65, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1698, dvrr_stack+613, dvrr_stack+1692, dvrr_stack+12, dvrr_stack+126, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1708, dvrr_stack+619, dvrr_stack+1698, dvrr_stack+120, dvrr_stack+613, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+7160, dvrr_stack+4920, dvrr_stack+1708, dvrr_stack+3113, dvrr_stack+619, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+7181, dvrr_stack+4935, dvrr_stack+7160, dvrr_stack+3123, dvrr_stack+4920, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7209, dvrr_stack+4956, dvrr_stack+7181, dvrr_stack+3138, dvrr_stack+4935, NULL);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3113, dvrr_stack+4984, dvrr_stack+7209, dvrr_stack+3159, dvrr_stack+4956, NULL);

 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+7245, dvrr_stack+5020, dvrr_stack+3113, dvrr_stack+3187, dvrr_stack+4984, NULL);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+7300, dvrr_stack+5065, dvrr_stack+7245, dvrr_stack+3223, dvrr_stack+5020, NULL);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+7366, dvrr_stack+5120, dvrr_stack+7300, dvrr_stack+3268, dvrr_stack+5065, NULL);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+7444, dvrr_stack+5186, dvrr_stack+5120, dvrr_stack+3323, dvrr_stack+3268, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+7522, dvrr_stack+7444, dvrr_stack+7366, NULL, NULL, dvrr_stack+5120);

 /* compute (1 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+7756,dvrr_stack+7522,dvrr_stack+5252,3);


 /* compute (1 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+8350,dvrr_stack+7756,dvrr_stack+5450,3);


 /* compute (1 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,165,dvrr_stack+9340, dvrr_stack+8350, dvrr_stack+3378);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+120, dvrr_stack+65, dvrr_stack+12, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+9835, dvrr_stack+1692, dvrr_stack+120, dvrr_stack+126, dvrr_stack+65, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+9845, dvrr_stack+1698, dvrr_stack+9835, dvrr_stack+613, dvrr_stack+1692, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+9860, dvrr_stack+1708, dvrr_stack+9845, dvrr_stack+619, dvrr_stack+1698, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+9881, dvrr_stack+7160, dvrr_stack+9860, dvrr_stack+4920, dvrr_stack+1708, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9909, dvrr_stack+7181, dvrr_stack+9881, dvrr_stack+4935, dvrr_stack+7160, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9945, dvrr_stack+7209, dvrr_stack+9909, dvrr_stack+4956, dvrr_stack+7181, NULL);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4920, dvrr_stack+3113, dvrr_stack+9945, dvrr_stack+4984, dvrr_stack+7209, NULL);

 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+9990, dvrr_stack+7245, dvrr_stack+4920, dvrr_stack+5020, dvrr_stack+3113, NULL);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+10056, dvrr_stack+7300, dvrr_stack+9990, dvrr_stack+5065, dvrr_stack+7245, NULL);

 /* compute (0 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+10134, dvrr_stack+7366, dvrr_stack+10056, dvrr_stack+5120, dvrr_stack+7300, NULL);

 /* compute (0 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+10225, dvrr_stack+7444, dvrr_stack+7366, dvrr_stack+5186, dvrr_stack+5120, NULL);

 /* compute (1 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+10316, dvrr_stack+10225, dvrr_stack+10134, NULL, NULL, dvrr_stack+7366);

 /* compute (1 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+10589,dvrr_stack+10316,dvrr_stack+7522,3);


 /* compute (1 0 | 10 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_nd(Libderiv->CD,dvrr_stack+11291,dvrr_stack+10589,dvrr_stack+7756,3);


 /* compute (1 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,198,dvrr_stack+12479, dvrr_stack+11291, dvrr_stack+5252);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+13073, dvrr_stack+50, dvrr_stack+84, NULL, NULL, dvrr_stack+30);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+13118, dvrr_stack+99, dvrr_stack+263, NULL, NULL, dvrr_stack+84);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+13181, dvrr_stack+175, dvrr_stack+13118, dvrr_stack+154, dvrr_stack+99, dvrr_stack+13073);
 tmp = dvrr_stack + 13181;
 target_ptr = Libderiv->dvrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+13307, dvrr_stack+284, dvrr_stack+665, NULL, NULL, dvrr_stack+263);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+13391, dvrr_stack+340, dvrr_stack+13307, dvrr_stack+312, dvrr_stack+284, dvrr_stack+13118);
 tmp = dvrr_stack + 13391;
 target_ptr = Libderiv->dvrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+13559,dvrr_stack+13391,dvrr_stack+13181,6);


 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+13937, dvrr_stack+693, dvrr_stack+1772, NULL, NULL, dvrr_stack+665);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+14045, dvrr_stack+765, dvrr_stack+13937, dvrr_stack+729, dvrr_stack+693, dvrr_stack+13307);
 tmp = dvrr_stack + 14045;
 target_ptr = Libderiv->dvrr_classes[2][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+14261,dvrr_stack+14045,dvrr_stack+13391,6);


 /* compute (2 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+14765,dvrr_stack+14261,dvrr_stack+13559,6);


 /* compute (2 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,126,dvrr_stack+15521, dvrr_stack+14765, dvrr_stack+13181);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+15899, dvrr_stack+1808, dvrr_stack+3223, NULL, NULL, dvrr_stack+1772);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+16034, dvrr_stack+1898, dvrr_stack+15899, dvrr_stack+1853, dvrr_stack+1808, dvrr_stack+13937);
 tmp = dvrr_stack + 16034;
 target_ptr = Libderiv->dvrr_classes[2][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+16304,dvrr_stack+16034,dvrr_stack+14045,6);


 /* compute (2 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+16952,dvrr_stack+16304,dvrr_stack+14261,6);


 /* compute (2 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,168,dvrr_stack+17960, dvrr_stack+16952, dvrr_stack+13391);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18464, dvrr_stack+3268, dvrr_stack+5065, NULL, NULL, dvrr_stack+3223);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18629, dvrr_stack+3378, dvrr_stack+18464, dvrr_stack+3323, dvrr_stack+3268, dvrr_stack+15899);
 tmp = dvrr_stack + 18629;
 target_ptr = Libderiv->dvrr_classes[2][9];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+18959,dvrr_stack+18629,dvrr_stack+16034,6);


 /* compute (2 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+19769,dvrr_stack+18959,dvrr_stack+16304,6);


 /* compute (2 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,216,dvrr_stack+21065, dvrr_stack+19769, dvrr_stack+14045);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+21713, dvrr_stack+5120, dvrr_stack+7300, NULL, NULL, dvrr_stack+5065);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+21911, dvrr_stack+5252, dvrr_stack+21713, dvrr_stack+5186, dvrr_stack+5120, dvrr_stack+18464);

 /* compute (2 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+22307,dvrr_stack+21911,dvrr_stack+18629,6);


 /* compute (2 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+23297,dvrr_stack+22307,dvrr_stack+18959,6);


 /* compute (2 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,270,dvrr_stack+24917, dvrr_stack+23297, dvrr_stack+16034);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+25727, dvrr_stack+7366, dvrr_stack+10056, NULL, NULL, dvrr_stack+7300);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+25961, dvrr_stack+7522, dvrr_stack+25727, dvrr_stack+7444, dvrr_stack+7366, dvrr_stack+21713);

 /* compute (2 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+26429,dvrr_stack+25961,dvrr_stack+21911,6);


 /* compute (2 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+27617,dvrr_stack+26429,dvrr_stack+22307,6);


 /* compute (2 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,330,dvrr_stack+29597, dvrr_stack+27617, dvrr_stack+18629);

 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+126, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+4975, dvrr_stack+12, dvrr_stack+126, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+613, dvrr_stack+120, dvrr_stack+4975, dvrr_stack+65, dvrr_stack+12, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+30587, dvrr_stack+9835, dvrr_stack+613, dvrr_stack+1692, dvrr_stack+120, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+30602, dvrr_stack+9845, dvrr_stack+30587, dvrr_stack+1698, dvrr_stack+9835, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+30623, dvrr_stack+9860, dvrr_stack+30602, dvrr_stack+1708, dvrr_stack+9845, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+30587, dvrr_stack+9881, dvrr_stack+30623, dvrr_stack+7160, dvrr_stack+9860, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+30623, dvrr_stack+9909, dvrr_stack+30587, dvrr_stack+7181, dvrr_stack+9881, NULL);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+30668, dvrr_stack+9945, dvrr_stack+30623, dvrr_stack+7209, dvrr_stack+9909, NULL);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+30587, dvrr_stack+4920, dvrr_stack+30668, dvrr_stack+3113, dvrr_stack+9945, NULL);

 /* compute (0 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+30653, dvrr_stack+9990, dvrr_stack+30587, dvrr_stack+7245, dvrr_stack+4920, NULL);

 /* compute (0 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+30731, dvrr_stack+10056, dvrr_stack+30653, dvrr_stack+7300, dvrr_stack+9990, NULL);

 /* compute (1 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+30822, dvrr_stack+10134, dvrr_stack+30731, NULL, NULL, dvrr_stack+10056);

 /* compute (2 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+31095, dvrr_stack+10316, dvrr_stack+30822, dvrr_stack+10225, dvrr_stack+10134, dvrr_stack+25727);

 /* compute (2 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+31641,dvrr_stack+31095,dvrr_stack+25961,6);


 /* compute (2 0 | 10 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_nd(Libderiv->CD,dvrr_stack+33045,dvrr_stack+31641,dvrr_stack+26429,6);


 /* compute (2 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,396,dvrr_stack+35421, dvrr_stack+33045, dvrr_stack+21911);

 /* compute (1 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,63,dvrr_stack+30731, dvrr_stack+1125, dvrr_stack+175);

 /* compute (1 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,84,dvrr_stack+36609, dvrr_stack+2357, dvrr_stack+340);

 /* compute (1 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,108,dvrr_stack+36861, dvrr_stack+3948, dvrr_stack+765);

 /* compute (1 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,135,dvrr_stack+37185, dvrr_stack+5945, dvrr_stack+1898);

 /* compute (1 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,165,dvrr_stack+37590, dvrr_stack+8350, dvrr_stack+3378);

 /* compute (1 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,198,dvrr_stack+38085, dvrr_stack+11291, dvrr_stack+5252);

 /* compute (2 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,126,dvrr_stack+38679, dvrr_stack+14765, dvrr_stack+13181);

 /* compute (2 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,168,dvrr_stack+39057, dvrr_stack+16952, dvrr_stack+13391);

 /* compute (2 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,216,dvrr_stack+39561, dvrr_stack+19769, dvrr_stack+14045);

 /* compute (2 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,270,dvrr_stack+40209, dvrr_stack+23297, dvrr_stack+16034);

 /* compute (2 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,330,dvrr_stack+41019, dvrr_stack+27617, dvrr_stack+18629);

 /* compute (2 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,396,dvrr_stack+42009, dvrr_stack+33045, dvrr_stack+21911);

 /* compute (1 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,63,dvrr_stack+43197, dvrr_stack+1125, dvrr_stack+175);

 /* compute (1 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,84,dvrr_stack+1125, dvrr_stack+2357, dvrr_stack+340);

 /* compute (1 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,108,dvrr_stack+2357, dvrr_stack+3948, dvrr_stack+765);

 /* compute (1 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,135,dvrr_stack+3948, dvrr_stack+5945, dvrr_stack+1898);

 /* compute (1 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,165,dvrr_stack+5945, dvrr_stack+8350, dvrr_stack+3378);

 /* compute (1 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,198,dvrr_stack+8350, dvrr_stack+11291, dvrr_stack+5252);

 /* compute (2 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,126,dvrr_stack+11291, dvrr_stack+14765, dvrr_stack+13181);

 /* compute (2 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,168,dvrr_stack+14765, dvrr_stack+16952, dvrr_stack+13391);

 /* compute (2 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,216,dvrr_stack+16952, dvrr_stack+19769, dvrr_stack+14045);

 /* compute (2 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,270,dvrr_stack+11669, dvrr_stack+23297, dvrr_stack+16034);

 /* compute (2 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,330,dvrr_stack+23297, dvrr_stack+27617, dvrr_stack+18629);

 /* compute (2 0 | 10 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,396,dvrr_stack+27617, dvrr_stack+33045, dvrr_stack+21911);

 /* compute (1 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+33045, dvrr_stack+139, dvrr_stack+50, NULL, NULL, dvrr_stack+40);

 /* compute (1 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+33090,dvrr_stack+175,dvrr_stack+33045,3);


 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,45,dvrr_stack+33225, dvrr_stack+33090, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,84,dvrr_stack+33270, dvrr_stack+873, NULL);
 tmp = dvrr_stack + 33270;
 target_ptr = Libderiv->deriv_classes[1][6][11];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,63,dvrr_stack+33354, dvrr_stack+424, NULL);
 tmp = dvrr_stack + 33354;
 target_ptr = Libderiv->deriv_classes[1][5][11];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,108,dvrr_stack+33417, dvrr_stack+2033, NULL);
 tmp = dvrr_stack + 33417;
 target_ptr = Libderiv->deriv_classes[1][7][11];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,135,dvrr_stack+33525, dvrr_stack+3543, NULL);
 tmp = dvrr_stack + 33525;
 target_ptr = Libderiv->deriv_classes[1][8][11];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,165,dvrr_stack+33660, dvrr_stack+5450, NULL);
 tmp = dvrr_stack + 33660;
 target_ptr = Libderiv->deriv_classes[1][9][11];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,198,dvrr_stack+33825, dvrr_stack+7756, NULL);
 tmp = dvrr_stack + 33825;
 target_ptr = Libderiv->deriv_classes[1][10][11];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,234,dvrr_stack+34023, dvrr_stack+10589, NULL);

 /* compute (1 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+34257, dvrr_stack+40, dvrr_stack+30, NULL, NULL, dvrr_stack+6);

 /* compute (2 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+34287, dvrr_stack+33045, dvrr_stack+13073, dvrr_stack+139, dvrr_stack+50, dvrr_stack+34257);

 /* compute (2 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+34377,dvrr_stack+13181,dvrr_stack+34287,6);


 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,90,dvrr_stack+34647, dvrr_stack+34377, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,168,dvrr_stack+34737, dvrr_stack+14261, NULL);
 tmp = dvrr_stack + 34737;
 target_ptr = Libderiv->deriv_classes[2][6][11];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,126,dvrr_stack+1377, dvrr_stack+13559, NULL);
 tmp = dvrr_stack + 1377;
 target_ptr = Libderiv->deriv_classes[2][5][11];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,216,dvrr_stack+34905, dvrr_stack+16304, NULL);
 tmp = dvrr_stack + 34905;
 target_ptr = Libderiv->deriv_classes[2][7][11];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,270,dvrr_stack+35121, dvrr_stack+18959, NULL);
 tmp = dvrr_stack + 35121;
 target_ptr = Libderiv->deriv_classes[2][8][11];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,330,dvrr_stack+28805, dvrr_stack+22307, NULL);
 tmp = dvrr_stack + 28805;
 target_ptr = Libderiv->deriv_classes[2][9][11];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,396,dvrr_stack+8944, dvrr_stack+26429, NULL);
 tmp = dvrr_stack + 8944;
 target_ptr = Libderiv->deriv_classes[2][10][11];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,468,dvrr_stack+24287, dvrr_stack+31641, NULL);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,45,dvrr_stack+29135, dvrr_stack+33090, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,84,dvrr_stack+29180, dvrr_stack+873, NULL);
 tmp = dvrr_stack + 29180;
 target_ptr = Libderiv->deriv_classes[1][6][10];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,63,dvrr_stack+29264, dvrr_stack+424, NULL);
 tmp = dvrr_stack + 29264;
 target_ptr = Libderiv->deriv_classes[1][5][10];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,108,dvrr_stack+29327, dvrr_stack+2033, NULL);
 tmp = dvrr_stack + 29327;
 target_ptr = Libderiv->deriv_classes[1][7][10];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,135,dvrr_stack+29435, dvrr_stack+3543, NULL);
 tmp = dvrr_stack + 29435;
 target_ptr = Libderiv->deriv_classes[1][8][10];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,165,dvrr_stack+19769, dvrr_stack+5450, NULL);
 tmp = dvrr_stack + 19769;
 target_ptr = Libderiv->deriv_classes[1][9][10];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,198,dvrr_stack+19934, dvrr_stack+7756, NULL);
 tmp = dvrr_stack + 19934;
 target_ptr = Libderiv->deriv_classes[1][10][10];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,234,dvrr_stack+20132, dvrr_stack+10589, NULL);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,90,dvrr_stack+24755, dvrr_stack+34377, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,168,dvrr_stack+20366, dvrr_stack+14261, NULL);
 tmp = dvrr_stack + 20366;
 target_ptr = Libderiv->deriv_classes[2][6][10];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,126,dvrr_stack+20534, dvrr_stack+13559, NULL);
 tmp = dvrr_stack + 20534;
 target_ptr = Libderiv->deriv_classes[2][5][10];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,216,dvrr_stack+20660, dvrr_stack+16304, NULL);
 tmp = dvrr_stack + 20660;
 target_ptr = Libderiv->deriv_classes[2][7][10];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,270,dvrr_stack+17600, dvrr_stack+18959, NULL);
 tmp = dvrr_stack + 17600;
 target_ptr = Libderiv->deriv_classes[2][8][10];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,330,dvrr_stack+43386, dvrr_stack+22307, NULL);
 tmp = dvrr_stack + 43386;
 target_ptr = Libderiv->deriv_classes[2][9][10];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,396,dvrr_stack+43716, dvrr_stack+26429, NULL);
 tmp = dvrr_stack + 43716;
 target_ptr = Libderiv->deriv_classes[2][10][10];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,468,dvrr_stack+44112, dvrr_stack+31641, NULL);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,45,dvrr_stack+24845, dvrr_stack+33090, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,84,dvrr_stack+33090, dvrr_stack+873, NULL);
 tmp = dvrr_stack + 33090;
 target_ptr = Libderiv->deriv_classes[1][6][9];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,63,dvrr_stack+873, dvrr_stack+424, NULL);
 tmp = dvrr_stack + 873;
 target_ptr = Libderiv->deriv_classes[1][5][9];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,108,dvrr_stack+424, dvrr_stack+2033, NULL);
 tmp = dvrr_stack + 424;
 target_ptr = Libderiv->deriv_classes[1][7][9];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,135,dvrr_stack+2033, dvrr_stack+3543, NULL);
 tmp = dvrr_stack + 2033;
 target_ptr = Libderiv->deriv_classes[1][8][9];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,165,dvrr_stack+3543, dvrr_stack+5450, NULL);
 tmp = dvrr_stack + 3543;
 target_ptr = Libderiv->deriv_classes[1][9][9];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,198,dvrr_stack+5450, dvrr_stack+7756, NULL);
 tmp = dvrr_stack + 5450;
 target_ptr = Libderiv->deriv_classes[1][10][9];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,234,dvrr_stack+7756, dvrr_stack+10589, NULL);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,90,dvrr_stack+17870, dvrr_stack+34377, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+34377, dvrr_stack+14261, NULL);
 tmp = dvrr_stack + 34377;
 target_ptr = Libderiv->deriv_classes[2][6][9];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+14261, dvrr_stack+13559, NULL);
 tmp = dvrr_stack + 14261;
 target_ptr = Libderiv->deriv_classes[2][5][9];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+13559, dvrr_stack+16304, NULL);
 tmp = dvrr_stack + 13559;
 target_ptr = Libderiv->deriv_classes[2][7][9];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+16304, dvrr_stack+18959, NULL);
 tmp = dvrr_stack + 16304;
 target_ptr = Libderiv->deriv_classes[2][8][9];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+18959, dvrr_stack+22307, NULL);
 tmp = dvrr_stack + 18959;
 target_ptr = Libderiv->deriv_classes[2][9][9];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,396,dvrr_stack+22307, dvrr_stack+26429, NULL);
 tmp = dvrr_stack + 22307;
 target_ptr = Libderiv->deriv_classes[2][10][9];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,468,dvrr_stack+26429, dvrr_stack+31641, NULL);

 /* compute (1 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+35391, dvrr_stack+129, dvrr_stack+40, NULL, NULL, dvrr_stack+15);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,3,1,dvrr_stack+31641, dvrr_stack+175, dvrr_stack+35391);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+31686, dvrr_stack+765, dvrr_stack+175);
 tmp = dvrr_stack + 31686;
 target_ptr = Libderiv->deriv_classes[1][6][8];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+31770, dvrr_stack+340, dvrr_stack+33045);
 tmp = dvrr_stack + 31770;
 target_ptr = Libderiv->deriv_classes[1][5][8];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+31833, dvrr_stack+1898, dvrr_stack+340);
 tmp = dvrr_stack + 31833;
 target_ptr = Libderiv->deriv_classes[1][7][8];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+31941, dvrr_stack+3378, dvrr_stack+765);
 tmp = dvrr_stack + 31941;
 target_ptr = Libderiv->deriv_classes[1][8][8];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+32076, dvrr_stack+5252, dvrr_stack+1898);
 tmp = dvrr_stack + 32076;
 target_ptr = Libderiv->deriv_classes[1][9][8];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,3,1,dvrr_stack+32241, dvrr_stack+7522, dvrr_stack+3378);
 tmp = dvrr_stack + 32241;
 target_ptr = Libderiv->deriv_classes[1][10][8];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,3,1,dvrr_stack+32439, dvrr_stack+10316, dvrr_stack+5252);

 /* compute (1 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+32673, dvrr_stack+15, dvrr_stack+6, NULL, NULL, dvrr_stack+3);

 /* compute (2 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+32691, dvrr_stack+35391, dvrr_stack+34257, dvrr_stack+129, dvrr_stack+40, dvrr_stack+32673);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,6,1,dvrr_stack+32751, dvrr_stack+13181, dvrr_stack+32691);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+32841, dvrr_stack+14045, dvrr_stack+13181);
 tmp = dvrr_stack + 32841;
 target_ptr = Libderiv->deriv_classes[2][6][8];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+26897, dvrr_stack+13391, dvrr_stack+34287);
 tmp = dvrr_stack + 26897;
 target_ptr = Libderiv->deriv_classes[2][5][8];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+27023, dvrr_stack+16034, dvrr_stack+13391);
 tmp = dvrr_stack + 27023;
 target_ptr = Libderiv->deriv_classes[2][7][8];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+27239, dvrr_stack+18629, dvrr_stack+14045);
 tmp = dvrr_stack + 27239;
 target_ptr = Libderiv->deriv_classes[2][8][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+22703, dvrr_stack+21911, dvrr_stack+16034);
 tmp = dvrr_stack + 22703;
 target_ptr = Libderiv->deriv_classes[2][9][8];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,6,1,dvrr_stack+19289, dvrr_stack+25961, dvrr_stack+18629);
 tmp = dvrr_stack + 19289;
 target_ptr = Libderiv->deriv_classes[2][10][8];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,6,1,dvrr_stack+10589, dvrr_stack+31095, dvrr_stack+21911);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,3,1,dvrr_stack+27509, dvrr_stack+175, dvrr_stack+35391);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+19685, dvrr_stack+765, dvrr_stack+175);
 tmp = dvrr_stack + 19685;
 target_ptr = Libderiv->deriv_classes[1][6][7];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+27554, dvrr_stack+340, dvrr_stack+33045);
 tmp = dvrr_stack + 27554;
 target_ptr = Libderiv->deriv_classes[1][5][7];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+23033, dvrr_stack+1898, dvrr_stack+340);
 tmp = dvrr_stack + 23033;
 target_ptr = Libderiv->deriv_classes[1][7][7];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+23141, dvrr_stack+3378, dvrr_stack+765);
 tmp = dvrr_stack + 23141;
 target_ptr = Libderiv->deriv_classes[1][8][7];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+16574, dvrr_stack+5252, dvrr_stack+1898);
 tmp = dvrr_stack + 16574;
 target_ptr = Libderiv->deriv_classes[1][9][7];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,3,1,dvrr_stack+16739, dvrr_stack+7522, dvrr_stack+3378);
 tmp = dvrr_stack + 16739;
 target_ptr = Libderiv->deriv_classes[1][10][7];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,3,1,dvrr_stack+11057, dvrr_stack+10316, dvrr_stack+5252);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,6,1,dvrr_stack+13775, dvrr_stack+13181, dvrr_stack+32691);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+14387, dvrr_stack+14045, dvrr_stack+13181);
 tmp = dvrr_stack + 14387;
 target_ptr = Libderiv->deriv_classes[2][6][7];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+14555, dvrr_stack+13391, dvrr_stack+34287);
 tmp = dvrr_stack + 14555;
 target_ptr = Libderiv->deriv_classes[2][5][7];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+7990, dvrr_stack+16034, dvrr_stack+13391);
 tmp = dvrr_stack + 7990;
 target_ptr = Libderiv->deriv_classes[2][7][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+5648, dvrr_stack+18629, dvrr_stack+14045);
 tmp = dvrr_stack + 5648;
 target_ptr = Libderiv->deriv_classes[2][8][7];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+44580, dvrr_stack+21911, dvrr_stack+16034);
 tmp = dvrr_stack + 44580;
 target_ptr = Libderiv->deriv_classes[2][9][7];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,6,1,dvrr_stack+44910, dvrr_stack+25961, dvrr_stack+18629);
 tmp = dvrr_stack + 44910;
 target_ptr = Libderiv->deriv_classes[2][10][7];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,6,1,dvrr_stack+45306, dvrr_stack+31095, dvrr_stack+21911);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,3,1,dvrr_stack+13865, dvrr_stack+175, dvrr_stack+35391);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+14681, dvrr_stack+765, dvrr_stack+175);
 tmp = dvrr_stack + 14681;
 target_ptr = Libderiv->deriv_classes[1][6][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+34545, dvrr_stack+340, dvrr_stack+33045);
 tmp = dvrr_stack + 34545;
 target_ptr = Libderiv->deriv_classes[1][5][6];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+8206, dvrr_stack+1898, dvrr_stack+340);
 tmp = dvrr_stack + 8206;
 target_ptr = Libderiv->deriv_classes[1][7][6];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+3708, dvrr_stack+3378, dvrr_stack+765);
 tmp = dvrr_stack + 3708;
 target_ptr = Libderiv->deriv_classes[1][8][6];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+2168, dvrr_stack+5252, dvrr_stack+1898);
 tmp = dvrr_stack + 2168;
 target_ptr = Libderiv->deriv_classes[1][9][6];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,3,1,dvrr_stack+15269, dvrr_stack+7522, dvrr_stack+3378);
 tmp = dvrr_stack + 15269;
 target_ptr = Libderiv->deriv_classes[1][10][6];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,3,1,dvrr_stack+6440, dvrr_stack+10316, dvrr_stack+5252);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,6,1,dvrr_stack+3843, dvrr_stack+13181, dvrr_stack+32691);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+936, dvrr_stack+14045, dvrr_stack+13181);
 tmp = dvrr_stack + 936;
 target_ptr = Libderiv->deriv_classes[2][6][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+20876, dvrr_stack+13391, dvrr_stack+34287);
 tmp = dvrr_stack + 20876;
 target_ptr = Libderiv->deriv_classes[2][5][6];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+4353, dvrr_stack+16034, dvrr_stack+13391);
 tmp = dvrr_stack + 4353;
 target_ptr = Libderiv->deriv_classes[2][7][6];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+10134, dvrr_stack+18629, dvrr_stack+14045);
 tmp = dvrr_stack + 10134;
 target_ptr = Libderiv->deriv_classes[2][8][6];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+45774, dvrr_stack+21911, dvrr_stack+16034);
 tmp = dvrr_stack + 45774;
 target_ptr = Libderiv->deriv_classes[2][9][6];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,6,1,dvrr_stack+46104, dvrr_stack+25961, dvrr_stack+18629);
 tmp = dvrr_stack + 46104;
 target_ptr = Libderiv->deriv_classes[2][10][6];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,6,1,dvrr_stack+46500, dvrr_stack+31095, dvrr_stack+21911);

 /* compute (0 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+21002,dvrr_stack+312,dvrr_stack+154,1);


 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,21,dvrr_stack+23276, dvrr_stack+21002, NULL);

 /* compute (0 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+532,dvrr_stack+729,dvrr_stack+312,1);


 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,28,dvrr_stack+35391, dvrr_stack+532, NULL);

 /* compute (0 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+2681,dvrr_stack+1853,dvrr_stack+729,1);


 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,36,dvrr_stack+33009, dvrr_stack+2681, NULL);

 /* compute (0 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+10404,dvrr_stack+3323,dvrr_stack+1853,1);


 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,45,dvrr_stack+32673, dvrr_stack+10404, NULL);

 /* compute (0 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+30920,dvrr_stack+5186,dvrr_stack+3323,1);


 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,55,dvrr_stack+6674, dvrr_stack+30920, NULL);

 /* compute (0 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+31085,dvrr_stack+7444,dvrr_stack+5186,1);


 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,66,dvrr_stack+2789, dvrr_stack+31085, NULL);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+32718, dvrr_stack+30, dvrr_stack+74, NULL, NULL, dvrr_stack+24);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+33174, dvrr_stack+84, dvrr_stack+248, NULL, NULL, dvrr_stack+74);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+31283, dvrr_stack+13073, dvrr_stack+33174, dvrr_stack+50, dvrr_stack+84, dvrr_stack+32718);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+31373, dvrr_stack+263, dvrr_stack+644, NULL, NULL, dvrr_stack+248);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+31436, dvrr_stack+13118, dvrr_stack+31373, dvrr_stack+99, dvrr_stack+263, dvrr_stack+33174);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+46968, dvrr_stack+13181, dvrr_stack+31436, dvrr_stack+175, dvrr_stack+13118, dvrr_stack+31283);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+47178, dvrr_stack+665, dvrr_stack+1744, NULL, NULL, dvrr_stack+644);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+47262, dvrr_stack+13307, dvrr_stack+47178, dvrr_stack+284, dvrr_stack+665, dvrr_stack+31373);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+47430, dvrr_stack+13391, dvrr_stack+47262, dvrr_stack+340, dvrr_stack+13307, dvrr_stack+31436);

 /* compute (3 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+47710,dvrr_stack+47430,dvrr_stack+46968,10);


 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,210,dvrr_stack+48340, dvrr_stack+47710, NULL);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+48550, dvrr_stack+1772, dvrr_stack+3187, NULL, NULL, dvrr_stack+1744);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+48658, dvrr_stack+13937, dvrr_stack+48550, dvrr_stack+693, dvrr_stack+1772, dvrr_stack+47178);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+48874, dvrr_stack+14045, dvrr_stack+48658, dvrr_stack+765, dvrr_stack+13937, dvrr_stack+47262);

 /* compute (3 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+49234,dvrr_stack+48874,dvrr_stack+47430,10);


 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,280,dvrr_stack+50074, dvrr_stack+49234, NULL);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+50354, dvrr_stack+3223, dvrr_stack+5020, NULL, NULL, dvrr_stack+3187);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+50489, dvrr_stack+15899, dvrr_stack+50354, dvrr_stack+1808, dvrr_stack+3223, dvrr_stack+48550);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+50759, dvrr_stack+16034, dvrr_stack+50489, dvrr_stack+1898, dvrr_stack+15899, dvrr_stack+48658);

 /* compute (3 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+51209,dvrr_stack+50759,dvrr_stack+48874,10);


 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,360,dvrr_stack+52289, dvrr_stack+51209, NULL);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+52649, dvrr_stack+5065, dvrr_stack+7245, NULL, NULL, dvrr_stack+5020);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+52814, dvrr_stack+18464, dvrr_stack+52649, dvrr_stack+3268, dvrr_stack+5065, dvrr_stack+50354);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+53144, dvrr_stack+18629, dvrr_stack+52814, dvrr_stack+3378, dvrr_stack+18464, dvrr_stack+50489);

 /* compute (3 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+53694,dvrr_stack+53144,dvrr_stack+50759,10);


 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,450,dvrr_stack+55044, dvrr_stack+53694, NULL);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+55494, dvrr_stack+7300, dvrr_stack+9990, NULL, NULL, dvrr_stack+7245);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+55692, dvrr_stack+21713, dvrr_stack+55494, dvrr_stack+5120, dvrr_stack+7300, dvrr_stack+52649);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+56088, dvrr_stack+21911, dvrr_stack+55692, dvrr_stack+5252, dvrr_stack+21713, dvrr_stack+52814);

 /* compute (3 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+56748,dvrr_stack+56088,dvrr_stack+53144,10);


 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,550,dvrr_stack+58398, dvrr_stack+56748, NULL);

 /* compute (1 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+58948, dvrr_stack+10056, dvrr_stack+30653, NULL, NULL, dvrr_stack+9990);

 /* compute (2 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+59182, dvrr_stack+25727, dvrr_stack+58948, dvrr_stack+7366, dvrr_stack+10056, dvrr_stack+55494);

 /* compute (3 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+59650, dvrr_stack+25961, dvrr_stack+59182, dvrr_stack+7522, dvrr_stack+25727, dvrr_stack+55692);

 /* compute (3 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+60430,dvrr_stack+59650,dvrr_stack+56088,10);


 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,660,dvrr_stack+25727, dvrr_stack+60430, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,21,dvrr_stack+1104, dvrr_stack+21002, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,28,dvrr_stack+284, dvrr_stack+532, NULL);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,36,dvrr_stack+693, dvrr_stack+2681, NULL);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,45,dvrr_stack+1808, dvrr_stack+10404, NULL);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,55,dvrr_stack+3268, dvrr_stack+30920, NULL);

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,66,dvrr_stack+5120, dvrr_stack+31085, NULL);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,210,dvrr_stack+7522, dvrr_stack+47710, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,280,dvrr_stack+58948, dvrr_stack+49234, NULL);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,360,dvrr_stack+59228, dvrr_stack+51209, NULL);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,450,dvrr_stack+62410, dvrr_stack+53694, NULL);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,550,dvrr_stack+62860, dvrr_stack+56748, NULL);

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,660,dvrr_stack+63410, dvrr_stack+60430, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,21,dvrr_stack+26387, dvrr_stack+21002, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,28,dvrr_stack+21002, dvrr_stack+532, NULL);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,36,dvrr_stack+8314, dvrr_stack+2681, NULL);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,45,dvrr_stack+2681, dvrr_stack+10404, NULL);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,55,dvrr_stack+10404, dvrr_stack+30920, NULL);

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,66,dvrr_stack+30920, dvrr_stack+31085, NULL);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+30986, dvrr_stack+47710, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+47710, dvrr_stack+49234, NULL);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+49234, dvrr_stack+51209, NULL);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+51209, dvrr_stack+53694, NULL);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+53694, dvrr_stack+56748, NULL);

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,660,dvrr_stack+56748, dvrr_stack+60430, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,1,1,dvrr_stack+26408, dvrr_stack+312, dvrr_stack+139);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,1,1,dvrr_stack+60430, dvrr_stack+729, dvrr_stack+154);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,1,1,dvrr_stack+60458, dvrr_stack+1853, dvrr_stack+312);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,1,1,dvrr_stack+60494, dvrr_stack+3323, dvrr_stack+729);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,1,1,dvrr_stack+60539, dvrr_stack+5186, dvrr_stack+1853);

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,1,1,dvrr_stack+60594, dvrr_stack+7444, dvrr_stack+3323);

 /* compute (1 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+50, dvrr_stack+6, dvrr_stack+24, NULL, NULL, dvrr_stack+0);

 /* compute (2 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+60660, dvrr_stack+34257, dvrr_stack+32718, dvrr_stack+40, dvrr_stack+30, dvrr_stack+50);

 /* compute (3 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+60720, dvrr_stack+34287, dvrr_stack+31283, dvrr_stack+33045, dvrr_stack+13073, dvrr_stack+60660);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+60870, dvrr_stack+47430, dvrr_stack+60720);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+61080, dvrr_stack+48874, dvrr_stack+46968);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+61360, dvrr_stack+50759, dvrr_stack+47430);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+61720, dvrr_stack+53144, dvrr_stack+48874);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+57408, dvrr_stack+56088, dvrr_stack+50759);

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,10,1,dvrr_stack+54244, dvrr_stack+59650, dvrr_stack+53144);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,1,1,dvrr_stack+0, dvrr_stack+312, dvrr_stack+139);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,1,1,dvrr_stack+40, dvrr_stack+729, dvrr_stack+154);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,1,1,dvrr_stack+60660, dvrr_stack+1853, dvrr_stack+312);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,1,1,dvrr_stack+33045, dvrr_stack+3323, dvrr_stack+729);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,1,1,dvrr_stack+34257, dvrr_stack+5186, dvrr_stack+1853);

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,1,1,dvrr_stack+62170, dvrr_stack+7444, dvrr_stack+3323);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+57958, dvrr_stack+47430, dvrr_stack+60720);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+51659, dvrr_stack+48874, dvrr_stack+46968);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+49594, dvrr_stack+50759, dvrr_stack+47430);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+64070, dvrr_stack+53144, dvrr_stack+48874);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+64520, dvrr_stack+56088, dvrr_stack+50759);

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,10,1,dvrr_stack+65070, dvrr_stack+59650, dvrr_stack+53144);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,1,1,dvrr_stack+60696, dvrr_stack+312, dvrr_stack+139);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,1,1,dvrr_stack+34312, dvrr_stack+729, dvrr_stack+154);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,1,1,dvrr_stack+34340, dvrr_stack+1853, dvrr_stack+312);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,1,1,dvrr_stack+62236, dvrr_stack+3323, dvrr_stack+729);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,1,1,dvrr_stack+99, dvrr_stack+5186, dvrr_stack+1853);

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,1,1,dvrr_stack+62281, dvrr_stack+7444, dvrr_stack+3323);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+58168, dvrr_stack+47430, dvrr_stack+60720);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+51939, dvrr_stack+48874, dvrr_stack+46968);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+65730, dvrr_stack+50759, dvrr_stack+47430);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+66090, dvrr_stack+53144, dvrr_stack+48874);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+66540, dvrr_stack+56088, dvrr_stack+50759);

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,10,1,dvrr_stack+67090, dvrr_stack+59650, dvrr_stack+53144);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,21,dvrr_stack+60717, dvrr_stack+175, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+60738, dvrr_stack+46968, dvrr_stack+175);
 tmp = dvrr_stack + 60738;
 target_ptr = Libderiv->deriv_classes[2][5][2];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,28,dvrr_stack+62347, dvrr_stack+340, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+47990, dvrr_stack+47430, dvrr_stack+340);
 tmp = dvrr_stack + 47990;
 target_ptr = Libderiv->deriv_classes[2][6][2];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,36,dvrr_stack+54904, dvrr_stack+765, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+59588, dvrr_stack+48874, dvrr_stack+765);
 tmp = dvrr_stack + 59588;
 target_ptr = Libderiv->deriv_classes[2][7][2];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,45,dvrr_stack+54940, dvrr_stack+1898, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+59804, dvrr_stack+50759, dvrr_stack+1898);
 tmp = dvrr_stack + 59804;
 target_ptr = Libderiv->deriv_classes[2][8][2];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,55,dvrr_stack+54985, dvrr_stack+3378, NULL);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+60074, dvrr_stack+53144, dvrr_stack+3378);
 tmp = dvrr_stack + 60074;
 target_ptr = Libderiv->deriv_classes[2][9][2];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,66,dvrr_stack+52219, dvrr_stack+5252, NULL);

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,66,dvrr_stack+67750, dvrr_stack+56088, dvrr_stack+5252);
 tmp = dvrr_stack + 67750;
 target_ptr = Libderiv->deriv_classes[2][10][2];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+2726, dvrr_stack+13181, dvrr_stack+154);
 tmp = dvrr_stack + 2726;
 target_ptr = Libderiv->deriv_classes[1][5][2];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+62375, dvrr_stack+24, dvrr_stack+68, NULL, NULL, dvrr_stack+21);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+49954, dvrr_stack+74, dvrr_stack+238, NULL, NULL, dvrr_stack+68);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+49984, dvrr_stack+32718, dvrr_stack+49954, dvrr_stack+30, dvrr_stack+74, dvrr_stack+62375);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+48158, dvrr_stack+248, dvrr_stack+629, NULL, NULL, dvrr_stack+238);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+48203, dvrr_stack+33174, dvrr_stack+48158, dvrr_stack+84, dvrr_stack+248, dvrr_stack+49954);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+7366, dvrr_stack+31283, dvrr_stack+48203, dvrr_stack+13073, dvrr_stack+33174, dvrr_stack+49984);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+49954, dvrr_stack+644, dvrr_stack+1723, NULL, NULL, dvrr_stack+629);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+31196, dvrr_stack+31373, dvrr_stack+49954, dvrr_stack+263, dvrr_stack+644, dvrr_stack+48158);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+68146, dvrr_stack+31436, dvrr_stack+31196, dvrr_stack+13118, dvrr_stack+31373, dvrr_stack+48203);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+68356, dvrr_stack+46968, dvrr_stack+68146, dvrr_stack+13181, dvrr_stack+31436, dvrr_stack+7366);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+31322, dvrr_stack+68356, dvrr_stack+13181);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+7366, dvrr_stack+13391, dvrr_stack+312);
 tmp = dvrr_stack + 7366;
 target_ptr = Libderiv->deriv_classes[1][6][2];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+48158, dvrr_stack+1744, dvrr_stack+3159, NULL, NULL, dvrr_stack+1723);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+68671, dvrr_stack+47178, dvrr_stack+48158, dvrr_stack+665, dvrr_stack+1744, dvrr_stack+49954);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+68839, dvrr_stack+47262, dvrr_stack+68671, dvrr_stack+13307, dvrr_stack+47178, dvrr_stack+31196);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+69119, dvrr_stack+47430, dvrr_stack+68839, dvrr_stack+13391, dvrr_stack+47262, dvrr_stack+68146);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+69539, dvrr_stack+69119, dvrr_stack+13391);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+13073, dvrr_stack+14045, dvrr_stack+729);
 tmp = dvrr_stack + 13073;
 target_ptr = Libderiv->deriv_classes[1][7][2];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+68146, dvrr_stack+3187, dvrr_stack+4984, NULL, NULL, dvrr_stack+3159);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+47178, dvrr_stack+48550, dvrr_stack+68146, dvrr_stack+1772, dvrr_stack+3187, dvrr_stack+48158);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+69819, dvrr_stack+48658, dvrr_stack+47178, dvrr_stack+13937, dvrr_stack+48550, dvrr_stack+68671);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+70179, dvrr_stack+48874, dvrr_stack+69819, dvrr_stack+14045, dvrr_stack+48658, dvrr_stack+68839);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+68671, dvrr_stack+70179, dvrr_stack+14045);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+13910, dvrr_stack+16034, dvrr_stack+1853);
 tmp = dvrr_stack + 13910;
 target_ptr = Libderiv->deriv_classes[1][8][2];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+48550, dvrr_stack+5020, dvrr_stack+3113, NULL, NULL, dvrr_stack+4984);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+70719, dvrr_stack+50354, dvrr_stack+48550, dvrr_stack+3223, dvrr_stack+5020, dvrr_stack+68146);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+70989, dvrr_stack+50489, dvrr_stack+70719, dvrr_stack+15899, dvrr_stack+50354, dvrr_stack+47178);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+71439, dvrr_stack+50759, dvrr_stack+70989, dvrr_stack+16034, dvrr_stack+50489, dvrr_stack+69819);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+72114, dvrr_stack+71439, dvrr_stack+16034);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+69819, dvrr_stack+18629, dvrr_stack+3323);
 tmp = dvrr_stack + 69819;
 target_ptr = Libderiv->deriv_classes[1][9][2];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+69984, dvrr_stack+7245, dvrr_stack+4920, NULL, NULL, dvrr_stack+3113);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+50354, dvrr_stack+52649, dvrr_stack+69984, dvrr_stack+5065, dvrr_stack+7245, dvrr_stack+48550);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+72564, dvrr_stack+52814, dvrr_stack+50354, dvrr_stack+18464, dvrr_stack+52649, dvrr_stack+70719);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+73114, dvrr_stack+53144, dvrr_stack+72564, dvrr_stack+18629, dvrr_stack+52814, dvrr_stack+70989);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+70719, dvrr_stack+73114, dvrr_stack+18629);

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,66,dvrr_stack+52649, dvrr_stack+21911, dvrr_stack+5186);
 tmp = dvrr_stack + 52649;
 target_ptr = Libderiv->deriv_classes[1][10][2];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+52847, dvrr_stack+9990, dvrr_stack+30587, NULL, NULL, dvrr_stack+4920);

 /* compute (2 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+73939, dvrr_stack+55494, dvrr_stack+52847, dvrr_stack+7300, dvrr_stack+9990, dvrr_stack+69984);

 /* compute (3 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+74335, dvrr_stack+55692, dvrr_stack+73939, dvrr_stack+21713, dvrr_stack+55494, dvrr_stack+50354);

 /* compute (4 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+74995, dvrr_stack+56088, dvrr_stack+74335, dvrr_stack+21911, dvrr_stack+55692, dvrr_stack+72564);

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,66,dvrr_stack+73939, dvrr_stack+74995, dvrr_stack+21911);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,21,dvrr_stack+72564, dvrr_stack+175, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+31196, dvrr_stack+46968, dvrr_stack+175);
 tmp = dvrr_stack + 31196;
 target_ptr = Libderiv->deriv_classes[2][5][1];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,28,dvrr_stack+72585, dvrr_stack+340, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+72613, dvrr_stack+47430, dvrr_stack+340);
 tmp = dvrr_stack + 72613;
 target_ptr = Libderiv->deriv_classes[2][6][1];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,36,dvrr_stack+72781, dvrr_stack+765, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+72817, dvrr_stack+48874, dvrr_stack+765);
 tmp = dvrr_stack + 72817;
 target_ptr = Libderiv->deriv_classes[2][7][1];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,45,dvrr_stack+73033, dvrr_stack+1898, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+50354, dvrr_stack+50759, dvrr_stack+1898);
 tmp = dvrr_stack + 50354;
 target_ptr = Libderiv->deriv_classes[2][8][1];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,55,dvrr_stack+50624, dvrr_stack+3378, NULL);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+55494, dvrr_stack+53144, dvrr_stack+3378);
 tmp = dvrr_stack + 55494;
 target_ptr = Libderiv->deriv_classes[2][9][1];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,66,dvrr_stack+50679, dvrr_stack+5252, NULL);

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,66,dvrr_stack+74599, dvrr_stack+56088, dvrr_stack+5252);
 tmp = dvrr_stack + 74599;
 target_ptr = Libderiv->deriv_classes[2][10][1];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+55824, dvrr_stack+13181, dvrr_stack+154);
 tmp = dvrr_stack + 55824;
 target_ptr = Libderiv->deriv_classes[1][5][1];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+68146, dvrr_stack+68356, dvrr_stack+13181);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+13307, dvrr_stack+13391, dvrr_stack+312);
 tmp = dvrr_stack + 13307;
 target_ptr = Libderiv->deriv_classes[1][6][1];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+52847, dvrr_stack+69119, dvrr_stack+13391);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+55887, dvrr_stack+14045, dvrr_stack+729);
 tmp = dvrr_stack + 55887;
 target_ptr = Libderiv->deriv_classes[1][7][1];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+75985, dvrr_stack+70179, dvrr_stack+14045);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+15899, dvrr_stack+16034, dvrr_stack+1853);
 tmp = dvrr_stack + 15899;
 target_ptr = Libderiv->deriv_classes[1][8][1];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+76345, dvrr_stack+71439, dvrr_stack+16034);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+18464, dvrr_stack+18629, dvrr_stack+3323);
 tmp = dvrr_stack + 18464;
 target_ptr = Libderiv->deriv_classes[1][9][1];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+76795, dvrr_stack+73114, dvrr_stack+18629);

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,66,dvrr_stack+21713, dvrr_stack+21911, dvrr_stack+5186);
 tmp = dvrr_stack + 21713;
 target_ptr = Libderiv->deriv_classes[1][10][1];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,66,dvrr_stack+77345, dvrr_stack+74995, dvrr_stack+21911);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+73078, dvrr_stack+175, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+69984, dvrr_stack+46968, dvrr_stack+175);
 tmp = dvrr_stack + 69984;
 target_ptr = Libderiv->deriv_classes[2][5][0];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+175, dvrr_stack+340, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+46968, dvrr_stack+47430, dvrr_stack+340);
 tmp = dvrr_stack + 46968;
 target_ptr = Libderiv->deriv_classes[2][6][0];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+340, dvrr_stack+765, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+47136, dvrr_stack+48874, dvrr_stack+765);
 tmp = dvrr_stack + 47136;
 target_ptr = Libderiv->deriv_classes[2][7][0];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+765, dvrr_stack+1898, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+47352, dvrr_stack+50759, dvrr_stack+1898);
 tmp = dvrr_stack + 47352;
 target_ptr = Libderiv->deriv_classes[2][8][0];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,55,dvrr_stack+1898, dvrr_stack+3378, NULL);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+50745, dvrr_stack+53144, dvrr_stack+3378);
 tmp = dvrr_stack + 50745;
 target_ptr = Libderiv->deriv_classes[2][9][0];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,66,dvrr_stack+3378, dvrr_stack+5252, NULL);

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,66,dvrr_stack+53127, dvrr_stack+56088, dvrr_stack+5252);
 tmp = dvrr_stack + 53127;
 target_ptr = Libderiv->deriv_classes[2][10][0];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+810, dvrr_stack+13181, dvrr_stack+154);
 tmp = dvrr_stack + 810;
 target_ptr = Libderiv->deriv_classes[1][5][0];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+55995, dvrr_stack+68356, dvrr_stack+13181);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+13181, dvrr_stack+13391, dvrr_stack+312);
 tmp = dvrr_stack + 13181;
 target_ptr = Libderiv->deriv_classes[1][6][0];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+68356, dvrr_stack+69119, dvrr_stack+13391);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+13391, dvrr_stack+14045, dvrr_stack+729);
 tmp = dvrr_stack + 13391;
 target_ptr = Libderiv->deriv_classes[1][7][0];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+56205, dvrr_stack+70179, dvrr_stack+14045);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+14045, dvrr_stack+16034, dvrr_stack+1853);
 tmp = dvrr_stack + 14045;
 target_ptr = Libderiv->deriv_classes[1][8][0];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+70110, dvrr_stack+71439, dvrr_stack+16034);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+16034, dvrr_stack+18629, dvrr_stack+3323);
 tmp = dvrr_stack + 16034;
 target_ptr = Libderiv->deriv_classes[1][9][0];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+71269, dvrr_stack+73114, dvrr_stack+18629);

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,66,dvrr_stack+5252, dvrr_stack+21911, dvrr_stack+5186);
 tmp = dvrr_stack + 5252;
 target_ptr = Libderiv->deriv_classes[1][10][0];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,66,dvrr_stack+73099, dvrr_stack+74995, dvrr_stack+21911);

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,63,dvrr_stack+21911, dvrr_stack+1503, NULL);
 tmp = dvrr_stack + 21911;
 target_ptr = Libderiv->deriv2_classes[1][5][143];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,84,dvrr_stack+21974, dvrr_stack+2861, NULL);
 tmp = dvrr_stack + 21974;
 target_ptr = Libderiv->deriv2_classes[1][6][143];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,108,dvrr_stack+22058, dvrr_stack+4596, NULL);
 tmp = dvrr_stack + 22058;
 target_ptr = Libderiv->deriv2_classes[1][7][143];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,135,dvrr_stack+22166, dvrr_stack+6755, NULL);
 tmp = dvrr_stack + 22166;
 target_ptr = Libderiv->deriv2_classes[1][8][143];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,165,dvrr_stack+74995, dvrr_stack+9340, NULL);
 tmp = dvrr_stack + 74995;
 target_ptr = Libderiv->deriv2_classes[1][9][143];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,198,dvrr_stack+75160, dvrr_stack+12479, NULL);
 tmp = dvrr_stack + 75160;
 target_ptr = Libderiv->deriv2_classes[1][10][143];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,126,dvrr_stack+75358, dvrr_stack+15521, NULL);
 tmp = dvrr_stack + 75358;
 target_ptr = Libderiv->deriv2_classes[2][5][143];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,168,dvrr_stack+75484, dvrr_stack+17960, NULL);
 tmp = dvrr_stack + 75484;
 target_ptr = Libderiv->deriv2_classes[2][6][143];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,216,dvrr_stack+75652, dvrr_stack+21065, NULL);
 tmp = dvrr_stack + 75652;
 target_ptr = Libderiv->deriv2_classes[2][7][143];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,270,dvrr_stack+18629, dvrr_stack+24917, NULL);
 tmp = dvrr_stack + 18629;
 target_ptr = Libderiv->deriv2_classes[2][8][143];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,330,dvrr_stack+48550, dvrr_stack+29597, NULL);
 tmp = dvrr_stack + 48550;
 target_ptr = Libderiv->deriv2_classes[2][9][143];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,396,dvrr_stack+69031, dvrr_stack+35421, NULL);
 tmp = dvrr_stack + 69031;
 target_ptr = Libderiv->deriv2_classes[2][10][143];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,63,dvrr_stack+75868, dvrr_stack+1503, NULL);
 tmp = dvrr_stack + 75868;
 target_ptr = Libderiv->deriv2_classes[1][5][131];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,84,dvrr_stack+16199, dvrr_stack+2861, NULL);
 tmp = dvrr_stack + 16199;
 target_ptr = Libderiv->deriv2_classes[1][6][131];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,108,dvrr_stack+73759, dvrr_stack+4596, NULL);
 tmp = dvrr_stack + 73759;
 target_ptr = Libderiv->deriv2_classes[1][7][131];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,135,dvrr_stack+56565, dvrr_stack+6755, NULL);
 tmp = dvrr_stack + 56565;
 target_ptr = Libderiv->deriv2_classes[1][8][131];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,165,dvrr_stack+53523, dvrr_stack+9340, NULL);
 tmp = dvrr_stack + 53523;
 target_ptr = Libderiv->deriv2_classes[1][9][131];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,198,dvrr_stack+4920, dvrr_stack+12479, NULL);
 tmp = dvrr_stack + 4920;
 target_ptr = Libderiv->deriv2_classes[1][10][131];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,126,dvrr_stack+51075, dvrr_stack+15521, NULL);
 tmp = dvrr_stack + 51075;
 target_ptr = Libderiv->deriv2_classes[2][5][131];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,168,dvrr_stack+71819, dvrr_stack+17960, NULL);
 tmp = dvrr_stack + 71819;
 target_ptr = Libderiv->deriv2_classes[2][6][131];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,216,dvrr_stack+48880, dvrr_stack+21065, NULL);
 tmp = dvrr_stack + 48880;
 target_ptr = Libderiv->deriv2_classes[2][7][131];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,270,dvrr_stack+78005, dvrr_stack+24917, NULL);
 tmp = dvrr_stack + 78005;
 target_ptr = Libderiv->deriv2_classes[2][8][131];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,330,dvrr_stack+78275, dvrr_stack+29597, NULL);
 tmp = dvrr_stack + 78275;
 target_ptr = Libderiv->deriv2_classes[2][9][131];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,396,dvrr_stack+78605, dvrr_stack+35421, NULL);
 tmp = dvrr_stack + 78605;
 target_ptr = Libderiv->deriv2_classes[2][10][131];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,63,dvrr_stack+5186, dvrr_stack+30731, NULL);
 tmp = dvrr_stack + 5186;
 target_ptr = Libderiv->deriv2_classes[1][5][130];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,84,dvrr_stack+3444, dvrr_stack+36609, NULL);
 tmp = dvrr_stack + 3444;
 target_ptr = Libderiv->deriv2_classes[1][6][130];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,108,dvrr_stack+70560, dvrr_stack+36861, NULL);
 tmp = dvrr_stack + 70560;
 target_ptr = Libderiv->deriv2_classes[1][7][130];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,135,dvrr_stack+30587, dvrr_stack+37185, NULL);
 tmp = dvrr_stack + 30587;
 target_ptr = Libderiv->deriv2_classes[1][8][130];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,165,dvrr_stack+48158, dvrr_stack+37590, NULL);
 tmp = dvrr_stack + 48158;
 target_ptr = Libderiv->deriv2_classes[1][9][130];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,198,dvrr_stack+79001, dvrr_stack+38085, NULL);
 tmp = dvrr_stack + 79001;
 target_ptr = Libderiv->deriv2_classes[1][10][130];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,126,dvrr_stack+71987, dvrr_stack+38679, NULL);
 tmp = dvrr_stack + 71987;
 target_ptr = Libderiv->deriv2_classes[2][5][130];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,168,dvrr_stack+79199, dvrr_stack+39057, NULL);
 tmp = dvrr_stack + 79199;
 target_ptr = Libderiv->deriv2_classes[2][6][130];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,216,dvrr_stack+9835, dvrr_stack+39561, NULL);
 tmp = dvrr_stack + 9835;
 target_ptr = Libderiv->deriv2_classes[2][7][130];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,270,dvrr_stack+79367, dvrr_stack+40209, NULL);
 tmp = dvrr_stack + 79367;
 target_ptr = Libderiv->deriv2_classes[2][8][130];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,330,dvrr_stack+79637, dvrr_stack+41019, NULL);
 tmp = dvrr_stack + 79637;
 target_ptr = Libderiv->deriv2_classes[2][9][130];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,396,dvrr_stack+79967, dvrr_stack+42009, NULL);
 tmp = dvrr_stack + 79967;
 target_ptr = Libderiv->deriv2_classes[2][10][130];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,63,dvrr_stack+14180, dvrr_stack+1503, NULL);
 tmp = dvrr_stack + 14180;
 target_ptr = Libderiv->deriv2_classes[1][5][119];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,84,dvrr_stack+1503, dvrr_stack+2861, NULL);
 tmp = dvrr_stack + 1503;
 target_ptr = Libderiv->deriv2_classes[1][6][119];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,108,dvrr_stack+1587, dvrr_stack+4596, NULL);
 tmp = dvrr_stack + 1587;
 target_ptr = Libderiv->deriv2_classes[1][7][119];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,135,dvrr_stack+49096, dvrr_stack+6755, NULL);
 tmp = dvrr_stack + 49096;
 target_ptr = Libderiv->deriv2_classes[1][8][119];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,165,dvrr_stack+6729, dvrr_stack+9340, NULL);
 tmp = dvrr_stack + 6729;
 target_ptr = Libderiv->deriv2_classes[1][9][119];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,198,dvrr_stack+9340, dvrr_stack+12479, NULL);
 tmp = dvrr_stack + 9340;
 target_ptr = Libderiv->deriv2_classes[1][10][119];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,126,dvrr_stack+12479, dvrr_stack+15521, NULL);
 tmp = dvrr_stack + 12479;
 target_ptr = Libderiv->deriv2_classes[2][5][119];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,168,dvrr_stack+12605, dvrr_stack+17960, NULL);
 tmp = dvrr_stack + 12605;
 target_ptr = Libderiv->deriv2_classes[2][6][119];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,216,dvrr_stack+17960, dvrr_stack+21065, NULL);
 tmp = dvrr_stack + 17960;
 target_ptr = Libderiv->deriv2_classes[2][7][119];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,270,dvrr_stack+18176, dvrr_stack+24917, NULL);
 tmp = dvrr_stack + 18176;
 target_ptr = Libderiv->deriv2_classes[2][8][119];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,330,dvrr_stack+21030, dvrr_stack+29597, NULL);
 tmp = dvrr_stack + 21030;
 target_ptr = Libderiv->deriv2_classes[2][9][119];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,396,dvrr_stack+29570, dvrr_stack+35421, NULL);
 tmp = dvrr_stack + 29570;
 target_ptr = Libderiv->deriv2_classes[2][10][119];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,63,dvrr_stack+12773, dvrr_stack+30731, NULL);
 tmp = dvrr_stack + 12773;
 target_ptr = Libderiv->deriv2_classes[1][5][118];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,84,dvrr_stack+12836, dvrr_stack+36609, NULL);
 tmp = dvrr_stack + 12836;
 target_ptr = Libderiv->deriv2_classes[1][6][118];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,108,dvrr_stack+12920, dvrr_stack+36861, NULL);
 tmp = dvrr_stack + 12920;
 target_ptr = Libderiv->deriv2_classes[1][7][118];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,135,dvrr_stack+9538, dvrr_stack+37185, NULL);
 tmp = dvrr_stack + 9538;
 target_ptr = Libderiv->deriv2_classes[1][8][118];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,165,dvrr_stack+30722, dvrr_stack+37590, NULL);
 tmp = dvrr_stack + 30722;
 target_ptr = Libderiv->deriv2_classes[1][9][118];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,198,dvrr_stack+21360, dvrr_stack+38085, NULL);
 tmp = dvrr_stack + 21360;
 target_ptr = Libderiv->deriv2_classes[1][10][118];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+9673, dvrr_stack+38679, NULL);
 tmp = dvrr_stack + 9673;
 target_ptr = Libderiv->deriv2_classes[2][5][118];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+35419, dvrr_stack+39057, NULL);
 tmp = dvrr_stack + 35419;
 target_ptr = Libderiv->deriv2_classes[2][6][118];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+35587, dvrr_stack+39561, NULL);
 tmp = dvrr_stack + 35587;
 target_ptr = Libderiv->deriv2_classes[2][7][118];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+35803, dvrr_stack+40209, NULL);
 tmp = dvrr_stack + 35803;
 target_ptr = Libderiv->deriv2_classes[2][8][118];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+36073, dvrr_stack+41019, NULL);
 tmp = dvrr_stack + 36073;
 target_ptr = Libderiv->deriv2_classes[2][9][118];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,396,dvrr_stack+36403, dvrr_stack+42009, NULL);
 tmp = dvrr_stack + 36403;
 target_ptr = Libderiv->deriv2_classes[2][10][118];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,63,dvrr_stack+1695, dvrr_stack+43197, NULL);
 tmp = dvrr_stack + 1695;
 target_ptr = Libderiv->deriv2_classes[1][5][117];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,84,dvrr_stack+47622, dvrr_stack+1125, NULL);
 tmp = dvrr_stack + 47622;
 target_ptr = Libderiv->deriv2_classes[1][6][117];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,108,dvrr_stack+1125, dvrr_stack+2357, NULL);
 tmp = dvrr_stack + 1125;
 target_ptr = Libderiv->deriv2_classes[1][7][117];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,135,dvrr_stack+1233, dvrr_stack+3948, NULL);
 tmp = dvrr_stack + 1233;
 target_ptr = Libderiv->deriv2_classes[1][8][117];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,165,dvrr_stack+36799, dvrr_stack+5945, NULL);
 tmp = dvrr_stack + 36799;
 target_ptr = Libderiv->deriv2_classes[1][9][117];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,198,dvrr_stack+36964, dvrr_stack+8350, NULL);
 tmp = dvrr_stack + 36964;
 target_ptr = Libderiv->deriv2_classes[1][10][117];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+8350, dvrr_stack+11291, NULL);
 tmp = dvrr_stack + 8350;
 target_ptr = Libderiv->deriv2_classes[2][5][117];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+11291, dvrr_stack+14765, NULL);
 tmp = dvrr_stack + 11291;
 target_ptr = Libderiv->deriv2_classes[2][6][117];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+14765, dvrr_stack+16952, NULL);
 tmp = dvrr_stack + 14765;
 target_ptr = Libderiv->deriv2_classes[2][7][117];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+14981, dvrr_stack+11669, NULL);
 tmp = dvrr_stack + 14981;
 target_ptr = Libderiv->deriv2_classes[2][8][117];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+11459, dvrr_stack+23297, NULL);
 tmp = dvrr_stack + 11459;
 target_ptr = Libderiv->deriv2_classes[2][9][117];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,396,dvrr_stack+23297, dvrr_stack+27617, NULL);
 tmp = dvrr_stack + 23297;
 target_ptr = Libderiv->deriv2_classes[2][10][117];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+27617, dvrr_stack+33270, dvrr_stack+33225);
 tmp = dvrr_stack + 27617;
 target_ptr = Libderiv->deriv2_classes[1][5][107];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+27680, dvrr_stack+33417, dvrr_stack+33354);
 tmp = dvrr_stack + 27680;
 target_ptr = Libderiv->deriv2_classes[1][6][107];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+27764, dvrr_stack+33525, dvrr_stack+33270);
 tmp = dvrr_stack + 27764;
 target_ptr = Libderiv->deriv2_classes[1][7][107];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+27872, dvrr_stack+33660, dvrr_stack+33417);
 tmp = dvrr_stack + 27872;
 target_ptr = Libderiv->deriv2_classes[1][8][107];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+28007, dvrr_stack+33825, dvrr_stack+33525);
 tmp = dvrr_stack + 28007;
 target_ptr = Libderiv->deriv2_classes[1][9][107];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_n(Data,3,1,dvrr_stack+28172, dvrr_stack+34023, dvrr_stack+33660);
 tmp = dvrr_stack + 28172;
 target_ptr = Libderiv->deriv2_classes[1][10][107];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+28370, dvrr_stack+34737, dvrr_stack+34647);
 tmp = dvrr_stack + 28370;
 target_ptr = Libderiv->deriv2_classes[2][5][107];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+28496, dvrr_stack+34905, dvrr_stack+1377);
 tmp = dvrr_stack + 28496;
 target_ptr = Libderiv->deriv2_classes[2][6][107];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+23693, dvrr_stack+35121, dvrr_stack+34737);
 tmp = dvrr_stack + 23693;
 target_ptr = Libderiv->deriv2_classes[2][7][107];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+23909, dvrr_stack+28805, dvrr_stack+34905);
 tmp = dvrr_stack + 23909;
 target_ptr = Libderiv->deriv2_classes[2][8][107];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+11789, dvrr_stack+8944, dvrr_stack+35121);
 tmp = dvrr_stack + 11789;
 target_ptr = Libderiv->deriv2_classes[2][9][107];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_n(Data,6,1,dvrr_stack+8476, dvrr_stack+24287, dvrr_stack+28805);
 tmp = dvrr_stack + 8476;
 target_ptr = Libderiv->deriv2_classes[2][10][107];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+28664, dvrr_stack+29180, dvrr_stack+29135);
 tmp = dvrr_stack + 28664;
 target_ptr = Libderiv->deriv2_classes[1][5][106];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+24179, dvrr_stack+29327, dvrr_stack+29264);
 tmp = dvrr_stack + 24179;
 target_ptr = Libderiv->deriv2_classes[1][6][106];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+12119, dvrr_stack+29435, dvrr_stack+29180);
 tmp = dvrr_stack + 12119;
 target_ptr = Libderiv->deriv2_classes[1][7][106];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+12227, dvrr_stack+19769, dvrr_stack+29327);
 tmp = dvrr_stack + 12227;
 target_ptr = Libderiv->deriv2_classes[1][8][106];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+37162, dvrr_stack+19934, dvrr_stack+29435);
 tmp = dvrr_stack + 37162;
 target_ptr = Libderiv->deriv2_classes[1][9][106];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_n(Data,3,1,dvrr_stack+37327, dvrr_stack+20132, dvrr_stack+19769);
 tmp = dvrr_stack + 37327;
 target_ptr = Libderiv->deriv2_classes[1][10][106];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+10459, dvrr_stack+20366, dvrr_stack+24755);
 tmp = dvrr_stack + 10459;
 target_ptr = Libderiv->deriv2_classes[2][5][106];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+37525, dvrr_stack+20660, dvrr_stack+20534);
 tmp = dvrr_stack + 37525;
 target_ptr = Libderiv->deriv2_classes[2][6][106];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+37693, dvrr_stack+17600, dvrr_stack+20366);
 tmp = dvrr_stack + 37693;
 target_ptr = Libderiv->deriv2_classes[2][7][106];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+37909, dvrr_stack+43386, dvrr_stack+20660);
 tmp = dvrr_stack + 37909;
 target_ptr = Libderiv->deriv2_classes[2][8][106];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+38179, dvrr_stack+43716, dvrr_stack+17600);
 tmp = dvrr_stack + 38179;
 target_ptr = Libderiv->deriv2_classes[2][9][106];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_n(Data,6,1,dvrr_stack+38509, dvrr_stack+44112, dvrr_stack+43386);
 tmp = dvrr_stack + 38509;
 target_ptr = Libderiv->deriv2_classes[2][10][106];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+28727, dvrr_stack+33090, dvrr_stack+24845);
 tmp = dvrr_stack + 28727;
 target_ptr = Libderiv->deriv2_classes[1][5][105];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+12362, dvrr_stack+424, dvrr_stack+873);
 tmp = dvrr_stack + 12362;
 target_ptr = Libderiv->deriv2_classes[1][6][105];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+69427, dvrr_stack+2033, dvrr_stack+33090);
 tmp = dvrr_stack + 69427;
 target_ptr = Libderiv->deriv2_classes[1][7][105];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+532, dvrr_stack+3543, dvrr_stack+424);
 tmp = dvrr_stack + 532;
 target_ptr = Libderiv->deriv2_classes[1][8][105];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+38905, dvrr_stack+5450, dvrr_stack+2033);
 tmp = dvrr_stack + 38905;
 target_ptr = Libderiv->deriv2_classes[1][9][105];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_n(Data,3,1,dvrr_stack+39070, dvrr_stack+7756, dvrr_stack+3543);
 tmp = dvrr_stack + 39070;
 target_ptr = Libderiv->deriv2_classes[1][10][105];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+21558, dvrr_stack+34377, dvrr_stack+17870);
 tmp = dvrr_stack + 21558;
 target_ptr = Libderiv->deriv2_classes[2][5][105];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+39268, dvrr_stack+13559, dvrr_stack+14261);
 tmp = dvrr_stack + 39268;
 target_ptr = Libderiv->deriv2_classes[2][6][105];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+39436, dvrr_stack+16304, dvrr_stack+34377);
 tmp = dvrr_stack + 39436;
 target_ptr = Libderiv->deriv2_classes[2][7][105];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+39652, dvrr_stack+18959, dvrr_stack+13559);
 tmp = dvrr_stack + 39652;
 target_ptr = Libderiv->deriv2_classes[2][8][105];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+39922, dvrr_stack+22307, dvrr_stack+16304);
 tmp = dvrr_stack + 39922;
 target_ptr = Libderiv->deriv2_classes[2][9][105];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_n(Data,6,1,dvrr_stack+40252, dvrr_stack+26429, dvrr_stack+18959);
 tmp = dvrr_stack + 40252;
 target_ptr = Libderiv->deriv2_classes[2][10][105];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+8872, dvrr_stack+31686, dvrr_stack+31641);
 tmp = dvrr_stack + 8872;
 target_ptr = Libderiv->deriv2_classes[1][5][104];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+49954, dvrr_stack+31833, dvrr_stack+31770);
 tmp = dvrr_stack + 49954;
 target_ptr = Libderiv->deriv2_classes[1][6][104];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+31532, dvrr_stack+31941, dvrr_stack+31686);
 tmp = dvrr_stack + 31532;
 target_ptr = Libderiv->deriv2_classes[1][7][104];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+40648, dvrr_stack+32076, dvrr_stack+31833);
 tmp = dvrr_stack + 40648;
 target_ptr = Libderiv->deriv2_classes[1][8][104];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+40783, dvrr_stack+32241, dvrr_stack+31941);
 tmp = dvrr_stack + 40783;
 target_ptr = Libderiv->deriv2_classes[1][9][104];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_n(Data,3,1,dvrr_stack+40948, dvrr_stack+32439, dvrr_stack+32076);
 tmp = dvrr_stack + 40948;
 target_ptr = Libderiv->deriv2_classes[1][10][104];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+41146, dvrr_stack+32841, dvrr_stack+32751);
 tmp = dvrr_stack + 41146;
 target_ptr = Libderiv->deriv2_classes[2][5][104];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+41272, dvrr_stack+27023, dvrr_stack+26897);
 tmp = dvrr_stack + 41272;
 target_ptr = Libderiv->deriv2_classes[2][6][104];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+41440, dvrr_stack+27239, dvrr_stack+32841);
 tmp = dvrr_stack + 41440;
 target_ptr = Libderiv->deriv2_classes[2][7][104];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+41656, dvrr_stack+22703, dvrr_stack+27023);
 tmp = dvrr_stack + 41656;
 target_ptr = Libderiv->deriv2_classes[2][8][104];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+41926, dvrr_stack+19289, dvrr_stack+27239);
 tmp = dvrr_stack + 41926;
 target_ptr = Libderiv->deriv2_classes[2][9][104];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_n(Data,6,1,dvrr_stack+42256, dvrr_stack+10589, dvrr_stack+22703);
 tmp = dvrr_stack + 42256;
 target_ptr = Libderiv->deriv2_classes[2][10][104];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+1953, dvrr_stack+33270, dvrr_stack+33225);
 tmp = dvrr_stack + 1953;
 target_ptr = Libderiv->deriv2_classes[1][5][95];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+42652, dvrr_stack+33417, dvrr_stack+33354);
 tmp = dvrr_stack + 42652;
 target_ptr = Libderiv->deriv2_classes[1][6][95];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+42736, dvrr_stack+33525, dvrr_stack+33270);
 tmp = dvrr_stack + 42736;
 target_ptr = Libderiv->deriv2_classes[1][7][95];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+42844, dvrr_stack+33660, dvrr_stack+33417);
 tmp = dvrr_stack + 42844;
 target_ptr = Libderiv->deriv2_classes[1][8][95];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+42979, dvrr_stack+33825, dvrr_stack+33525);
 tmp = dvrr_stack + 42979;
 target_ptr = Libderiv->deriv2_classes[1][9][95];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_n(Data,3,1,dvrr_stack+43144, dvrr_stack+34023, dvrr_stack+33660);
 tmp = dvrr_stack + 43144;
 target_ptr = Libderiv->deriv2_classes[1][10][95];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+16937, dvrr_stack+34737, dvrr_stack+34647);
 tmp = dvrr_stack + 16937;
 target_ptr = Libderiv->deriv2_classes[2][5][95];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+17063, dvrr_stack+34905, dvrr_stack+1377);
 tmp = dvrr_stack + 17063;
 target_ptr = Libderiv->deriv2_classes[2][6][95];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+17231, dvrr_stack+35121, dvrr_stack+34737);
 tmp = dvrr_stack + 17231;
 target_ptr = Libderiv->deriv2_classes[2][7][95];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+5918, dvrr_stack+28805, dvrr_stack+34905);
 tmp = dvrr_stack + 5918;
 target_ptr = Libderiv->deriv2_classes[2][8][95];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+3933, dvrr_stack+8944, dvrr_stack+35121);
 tmp = dvrr_stack + 3933;
 target_ptr = Libderiv->deriv2_classes[2][9][95];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_n(Data,6,1,dvrr_stack+29966, dvrr_stack+24287, dvrr_stack+28805);
 tmp = dvrr_stack + 29966;
 target_ptr = Libderiv->deriv2_classes[2][10][95];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+203, dvrr_stack+29180, dvrr_stack+29135);
 tmp = dvrr_stack + 203;
 target_ptr = Libderiv->deriv2_classes[1][5][94];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+17447, dvrr_stack+29327, dvrr_stack+29264);
 tmp = dvrr_stack + 17447;
 target_ptr = Libderiv->deriv2_classes[1][6][94];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+6188, dvrr_stack+29435, dvrr_stack+29180);
 tmp = dvrr_stack + 6188;
 target_ptr = Libderiv->deriv2_classes[1][7][94];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+6296, dvrr_stack+19769, dvrr_stack+29327);
 tmp = dvrr_stack + 6296;
 target_ptr = Libderiv->deriv2_classes[1][8][94];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+2333, dvrr_stack+19934, dvrr_stack+29435);
 tmp = dvrr_stack + 2333;
 target_ptr = Libderiv->deriv2_classes[1][9][94];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_n(Data,3,1,dvrr_stack+30362, dvrr_stack+20132, dvrr_stack+19769);
 tmp = dvrr_stack + 30362;
 target_ptr = Libderiv->deriv2_classes[1][10][94];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+2498, dvrr_stack+20366, dvrr_stack+24755);
 tmp = dvrr_stack + 2498;
 target_ptr = Libderiv->deriv2_classes[2][5][94];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+24890, dvrr_stack+20660, dvrr_stack+20534);
 tmp = dvrr_stack + 24890;
 target_ptr = Libderiv->deriv2_classes[2][6][94];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+25058, dvrr_stack+17600, dvrr_stack+20366);
 tmp = dvrr_stack + 25058;
 target_ptr = Libderiv->deriv2_classes[2][7][94];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+25274, dvrr_stack+43386, dvrr_stack+20660);
 tmp = dvrr_stack + 25274;
 target_ptr = Libderiv->deriv2_classes[2][8][94];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+15467, dvrr_stack+43716, dvrr_stack+17600);
 tmp = dvrr_stack + 15467;
 target_ptr = Libderiv->deriv2_classes[2][9][94];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_n(Data,6,1,dvrr_stack+6894, dvrr_stack+44112, dvrr_stack+43386);
 tmp = dvrr_stack + 6894;
 target_ptr = Libderiv->deriv2_classes[2][10][94];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+73867, dvrr_stack+33090, dvrr_stack+24845);
 tmp = dvrr_stack + 73867;
 target_ptr = Libderiv->deriv2_classes[1][5][93];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+4263, dvrr_stack+424, dvrr_stack+873);
 tmp = dvrr_stack + 4263;
 target_ptr = Libderiv->deriv2_classes[1][6][93];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+25544, dvrr_stack+2033, dvrr_stack+33090);
 tmp = dvrr_stack + 25544;
 target_ptr = Libderiv->deriv2_classes[1][7][93];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+4569, dvrr_stack+3543, dvrr_stack+424);
 tmp = dvrr_stack + 4569;
 target_ptr = Libderiv->deriv2_classes[1][8][93];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+4704, dvrr_stack+5450, dvrr_stack+2033);
 tmp = dvrr_stack + 4704;
 target_ptr = Libderiv->deriv2_classes[1][9][93];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_n(Data,3,1,dvrr_stack+2855, dvrr_stack+7756, dvrr_stack+3543);
 tmp = dvrr_stack + 2855;
 target_ptr = Libderiv->deriv2_classes[1][10][93];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+3053, dvrr_stack+34377, dvrr_stack+17870);
 tmp = dvrr_stack + 3053;
 target_ptr = Libderiv->deriv2_classes[2][5][93];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+80363, dvrr_stack+13559, dvrr_stack+14261);
 tmp = dvrr_stack + 80363;
 target_ptr = Libderiv->deriv2_classes[2][6][93];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+80531, dvrr_stack+16304, dvrr_stack+34377);
 tmp = dvrr_stack + 80531;
 target_ptr = Libderiv->deriv2_classes[2][7][93];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+80747, dvrr_stack+18959, dvrr_stack+13559);
 tmp = dvrr_stack + 80747;
 target_ptr = Libderiv->deriv2_classes[2][8][93];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+81017, dvrr_stack+22307, dvrr_stack+16304);
 tmp = dvrr_stack + 81017;
 target_ptr = Libderiv->deriv2_classes[2][9][93];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_n(Data,6,1,dvrr_stack+81347, dvrr_stack+26429, dvrr_stack+18959);
 tmp = dvrr_stack + 81347;
 target_ptr = Libderiv->deriv2_classes[2][10][93];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+7450, dvrr_stack+31686, dvrr_stack+31641);
 tmp = dvrr_stack + 7450;
 target_ptr = Libderiv->deriv2_classes[1][5][92];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+15797, dvrr_stack+31833, dvrr_stack+31770);
 tmp = dvrr_stack + 15797;
 target_ptr = Libderiv->deriv2_classes[1][6][92];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+81743, dvrr_stack+31941, dvrr_stack+31686);
 tmp = dvrr_stack + 81743;
 target_ptr = Libderiv->deriv2_classes[1][7][92];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+81851, dvrr_stack+32076, dvrr_stack+31833);
 tmp = dvrr_stack + 81851;
 target_ptr = Libderiv->deriv2_classes[1][8][92];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+81986, dvrr_stack+32241, dvrr_stack+31941);
 tmp = dvrr_stack + 81986;
 target_ptr = Libderiv->deriv2_classes[1][9][92];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_n(Data,3,1,dvrr_stack+82151, dvrr_stack+32439, dvrr_stack+32076);
 tmp = dvrr_stack + 82151;
 target_ptr = Libderiv->deriv2_classes[1][10][92];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+82349, dvrr_stack+32841, dvrr_stack+32751);
 tmp = dvrr_stack + 82349;
 target_ptr = Libderiv->deriv2_classes[2][5][92];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+82475, dvrr_stack+27023, dvrr_stack+26897);
 tmp = dvrr_stack + 82475;
 target_ptr = Libderiv->deriv2_classes[2][6][92];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+82643, dvrr_stack+27239, dvrr_stack+32841);
 tmp = dvrr_stack + 82643;
 target_ptr = Libderiv->deriv2_classes[2][7][92];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+82859, dvrr_stack+22703, dvrr_stack+27023);
 tmp = dvrr_stack + 82859;
 target_ptr = Libderiv->deriv2_classes[2][8][92];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+83129, dvrr_stack+19289, dvrr_stack+27239);
 tmp = dvrr_stack + 83129;
 target_ptr = Libderiv->deriv2_classes[2][9][92];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_n(Data,6,1,dvrr_stack+83459, dvrr_stack+10589, dvrr_stack+22703);
 tmp = dvrr_stack + 83459;
 target_ptr = Libderiv->deriv2_classes[2][10][92];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+17531, dvrr_stack+19685, dvrr_stack+27509);
 tmp = dvrr_stack + 17531;
 target_ptr = Libderiv->deriv2_classes[1][5][91];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+3179, dvrr_stack+23033, dvrr_stack+27554);
 tmp = dvrr_stack + 3179;
 target_ptr = Libderiv->deriv2_classes[1][6][91];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+83855, dvrr_stack+23141, dvrr_stack+19685);
 tmp = dvrr_stack + 83855;
 target_ptr = Libderiv->deriv2_classes[1][7][91];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+83963, dvrr_stack+16574, dvrr_stack+23033);
 tmp = dvrr_stack + 83963;
 target_ptr = Libderiv->deriv2_classes[1][8][91];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+84098, dvrr_stack+16739, dvrr_stack+23141);
 tmp = dvrr_stack + 84098;
 target_ptr = Libderiv->deriv2_classes[1][9][91];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_n(Data,3,1,dvrr_stack+84263, dvrr_stack+11057, dvrr_stack+16574);
 tmp = dvrr_stack + 84263;
 target_ptr = Libderiv->deriv2_classes[1][10][91];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+84461, dvrr_stack+14387, dvrr_stack+13775);
 tmp = dvrr_stack + 84461;
 target_ptr = Libderiv->deriv2_classes[2][5][91];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+84587, dvrr_stack+7990, dvrr_stack+14555);
 tmp = dvrr_stack + 84587;
 target_ptr = Libderiv->deriv2_classes[2][6][91];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+84755, dvrr_stack+5648, dvrr_stack+14387);
 tmp = dvrr_stack + 84755;
 target_ptr = Libderiv->deriv2_classes[2][7][91];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+84971, dvrr_stack+44580, dvrr_stack+7990);
 tmp = dvrr_stack + 84971;
 target_ptr = Libderiv->deriv2_classes[2][8][91];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+85241, dvrr_stack+44910, dvrr_stack+5648);
 tmp = dvrr_stack + 85241;
 target_ptr = Libderiv->deriv2_classes[2][9][91];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_n(Data,6,1,dvrr_stack+85571, dvrr_stack+45306, dvrr_stack+44580);
 tmp = dvrr_stack + 85571;
 target_ptr = Libderiv->deriv2_classes[2][10][91];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+25652, dvrr_stack+33270, dvrr_stack+33225);
 tmp = dvrr_stack + 25652;
 target_ptr = Libderiv->deriv2_classes[1][5][83];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+33174, dvrr_stack+33417, dvrr_stack+33354);
 tmp = dvrr_stack + 33174;
 target_ptr = Libderiv->deriv2_classes[1][6][83];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+85967, dvrr_stack+33525, dvrr_stack+33270);
 tmp = dvrr_stack + 85967;
 target_ptr = Libderiv->deriv2_classes[1][7][83];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+86075, dvrr_stack+33660, dvrr_stack+33417);
 tmp = dvrr_stack + 86075;
 target_ptr = Libderiv->deriv2_classes[1][8][83];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+86210, dvrr_stack+33825, dvrr_stack+33525);
 tmp = dvrr_stack + 86210;
 target_ptr = Libderiv->deriv2_classes[1][9][83];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_n(Data,3,1,dvrr_stack+86375, dvrr_stack+34023, dvrr_stack+33660);
 tmp = dvrr_stack + 86375;
 target_ptr = Libderiv->deriv2_classes[1][10][83];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+34023, dvrr_stack+34737, dvrr_stack+34647);
 tmp = dvrr_stack + 34023;
 target_ptr = Libderiv->deriv2_classes[2][5][83];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+86573, dvrr_stack+34905, dvrr_stack+1377);
 tmp = dvrr_stack + 86573;
 target_ptr = Libderiv->deriv2_classes[2][6][83];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+86741, dvrr_stack+35121, dvrr_stack+34737);
 tmp = dvrr_stack + 86741;
 target_ptr = Libderiv->deriv2_classes[2][7][83];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+86957, dvrr_stack+28805, dvrr_stack+34905);
 tmp = dvrr_stack + 86957;
 target_ptr = Libderiv->deriv2_classes[2][8][83];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+87227, dvrr_stack+8944, dvrr_stack+35121);
 tmp = dvrr_stack + 87227;
 target_ptr = Libderiv->deriv2_classes[2][9][83];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_n(Data,6,1,dvrr_stack+87557, dvrr_stack+24287, dvrr_stack+28805);
 tmp = dvrr_stack + 87557;
 target_ptr = Libderiv->deriv2_classes[2][10][83];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+34149, dvrr_stack+29180, dvrr_stack+29135);
 tmp = dvrr_stack + 34149;
 target_ptr = Libderiv->deriv2_classes[1][5][82];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+24263, dvrr_stack+29327, dvrr_stack+29264);
 tmp = dvrr_stack + 24263;
 target_ptr = Libderiv->deriv2_classes[1][6][82];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+24347, dvrr_stack+29435, dvrr_stack+29180);
 tmp = dvrr_stack + 24347;
 target_ptr = Libderiv->deriv2_classes[1][7][82];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+24455, dvrr_stack+19769, dvrr_stack+29327);
 tmp = dvrr_stack + 24455;
 target_ptr = Libderiv->deriv2_classes[1][8][82];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+24590, dvrr_stack+19934, dvrr_stack+29435);
 tmp = dvrr_stack + 24590;
 target_ptr = Libderiv->deriv2_classes[1][9][82];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_n(Data,3,1,dvrr_stack+87953, dvrr_stack+20132, dvrr_stack+19769);
 tmp = dvrr_stack + 87953;
 target_ptr = Libderiv->deriv2_classes[1][10][82];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+20132, dvrr_stack+20366, dvrr_stack+24755);
 tmp = dvrr_stack + 20132;
 target_ptr = Libderiv->deriv2_classes[2][5][82];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+88151, dvrr_stack+20660, dvrr_stack+20534);
 tmp = dvrr_stack + 88151;
 target_ptr = Libderiv->deriv2_classes[2][6][82];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+88319, dvrr_stack+17600, dvrr_stack+20366);
 tmp = dvrr_stack + 88319;
 target_ptr = Libderiv->deriv2_classes[2][7][82];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+88535, dvrr_stack+43386, dvrr_stack+20660);
 tmp = dvrr_stack + 88535;
 target_ptr = Libderiv->deriv2_classes[2][8][82];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+88805, dvrr_stack+43716, dvrr_stack+17600);
 tmp = dvrr_stack + 88805;
 target_ptr = Libderiv->deriv2_classes[2][9][82];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_n(Data,6,1,dvrr_stack+89135, dvrr_stack+44112, dvrr_stack+43386);
 tmp = dvrr_stack + 89135;
 target_ptr = Libderiv->deriv2_classes[2][10][82];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+44112, dvrr_stack+33090, dvrr_stack+24845);
 tmp = dvrr_stack + 44112;
 target_ptr = Libderiv->deriv2_classes[1][5][81];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+44175, dvrr_stack+424, dvrr_stack+873);
 tmp = dvrr_stack + 44175;
 target_ptr = Libderiv->deriv2_classes[1][6][81];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+20258, dvrr_stack+2033, dvrr_stack+33090);
 tmp = dvrr_stack + 20258;
 target_ptr = Libderiv->deriv2_classes[1][7][81];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+24755, dvrr_stack+3543, dvrr_stack+424);
 tmp = dvrr_stack + 24755;
 target_ptr = Libderiv->deriv2_classes[1][8][81];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+44259, dvrr_stack+5450, dvrr_stack+2033);
 tmp = dvrr_stack + 44259;
 target_ptr = Libderiv->deriv2_classes[1][9][81];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_n(Data,3,1,dvrr_stack+89531, dvrr_stack+7756, dvrr_stack+3543);
 tmp = dvrr_stack + 89531;
 target_ptr = Libderiv->deriv2_classes[1][10][81];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+44424, dvrr_stack+34377, dvrr_stack+17870);
 tmp = dvrr_stack + 44424;
 target_ptr = Libderiv->deriv2_classes[2][5][81];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+7732, dvrr_stack+13559, dvrr_stack+14261);
 tmp = dvrr_stack + 7732;
 target_ptr = Libderiv->deriv2_classes[2][6][81];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+89729, dvrr_stack+16304, dvrr_stack+34377);
 tmp = dvrr_stack + 89729;
 target_ptr = Libderiv->deriv2_classes[2][7][81];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+89945, dvrr_stack+18959, dvrr_stack+13559);
 tmp = dvrr_stack + 89945;
 target_ptr = Libderiv->deriv2_classes[2][8][81];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+90215, dvrr_stack+22307, dvrr_stack+16304);
 tmp = dvrr_stack + 90215;
 target_ptr = Libderiv->deriv2_classes[2][9][81];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_n(Data,6,1,dvrr_stack+90545, dvrr_stack+26429, dvrr_stack+18959);
 tmp = dvrr_stack + 90545;
 target_ptr = Libderiv->deriv2_classes[2][10][81];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+26429, dvrr_stack+31686, dvrr_stack+31641);
 tmp = dvrr_stack + 26429;
 target_ptr = Libderiv->deriv2_classes[1][5][80];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+26492, dvrr_stack+31833, dvrr_stack+31770);
 tmp = dvrr_stack + 26492;
 target_ptr = Libderiv->deriv2_classes[1][6][80];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+26576, dvrr_stack+31941, dvrr_stack+31686);
 tmp = dvrr_stack + 26576;
 target_ptr = Libderiv->deriv2_classes[1][7][80];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+26684, dvrr_stack+32076, dvrr_stack+31833);
 tmp = dvrr_stack + 26684;
 target_ptr = Libderiv->deriv2_classes[1][8][80];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+90941, dvrr_stack+32241, dvrr_stack+31941);
 tmp = dvrr_stack + 90941;
 target_ptr = Libderiv->deriv2_classes[1][9][80];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_n(Data,3,1,dvrr_stack+91106, dvrr_stack+32439, dvrr_stack+32076);
 tmp = dvrr_stack + 91106;
 target_ptr = Libderiv->deriv2_classes[1][10][80];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+32439, dvrr_stack+32841, dvrr_stack+32751);
 tmp = dvrr_stack + 32439;
 target_ptr = Libderiv->deriv2_classes[2][5][80];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+91304, dvrr_stack+27023, dvrr_stack+26897);
 tmp = dvrr_stack + 91304;
 target_ptr = Libderiv->deriv2_classes[2][6][80];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+91472, dvrr_stack+27239, dvrr_stack+32841);
 tmp = dvrr_stack + 91472;
 target_ptr = Libderiv->deriv2_classes[2][7][80];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+91688, dvrr_stack+22703, dvrr_stack+27023);
 tmp = dvrr_stack + 91688;
 target_ptr = Libderiv->deriv2_classes[2][8][80];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+91958, dvrr_stack+19289, dvrr_stack+27239);
 tmp = dvrr_stack + 91958;
 target_ptr = Libderiv->deriv2_classes[2][9][80];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_n(Data,6,1,dvrr_stack+92288, dvrr_stack+10589, dvrr_stack+22703);
 tmp = dvrr_stack + 92288;
 target_ptr = Libderiv->deriv2_classes[2][10][80];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+32565, dvrr_stack+19685, dvrr_stack+27509);
 tmp = dvrr_stack + 32565;
 target_ptr = Libderiv->deriv2_classes[1][5][79];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+17870, dvrr_stack+23033, dvrr_stack+27554);
 tmp = dvrr_stack + 17870;
 target_ptr = Libderiv->deriv2_classes[1][6][79];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+32718, dvrr_stack+23141, dvrr_stack+19685);
 tmp = dvrr_stack + 32718;
 target_ptr = Libderiv->deriv2_classes[1][7][79];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+10585, dvrr_stack+16574, dvrr_stack+23033);
 tmp = dvrr_stack + 10585;
 target_ptr = Libderiv->deriv2_classes[1][8][79];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+10720, dvrr_stack+16739, dvrr_stack+23141);
 tmp = dvrr_stack + 10720;
 target_ptr = Libderiv->deriv2_classes[1][9][79];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_n(Data,3,1,dvrr_stack+92684, dvrr_stack+11057, dvrr_stack+16574);
 tmp = dvrr_stack + 92684;
 target_ptr = Libderiv->deriv2_classes[1][10][79];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+10885, dvrr_stack+14387, dvrr_stack+13775);
 tmp = dvrr_stack + 10885;
 target_ptr = Libderiv->deriv2_classes[2][5][79];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+11011, dvrr_stack+7990, dvrr_stack+14555);
 tmp = dvrr_stack + 11011;
 target_ptr = Libderiv->deriv2_classes[2][6][79];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+92882, dvrr_stack+5648, dvrr_stack+14387);
 tmp = dvrr_stack + 92882;
 target_ptr = Libderiv->deriv2_classes[2][7][79];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+93098, dvrr_stack+44580, dvrr_stack+7990);
 tmp = dvrr_stack + 93098;
 target_ptr = Libderiv->deriv2_classes[2][8][79];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+93368, dvrr_stack+44910, dvrr_stack+5648);
 tmp = dvrr_stack + 93368;
 target_ptr = Libderiv->deriv2_classes[2][9][79];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_n(Data,6,1,dvrr_stack+93698, dvrr_stack+45306, dvrr_stack+44580);
 tmp = dvrr_stack + 93698;
 target_ptr = Libderiv->deriv2_classes[2][10][79];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+45306, dvrr_stack+14681, dvrr_stack+13865);
 tmp = dvrr_stack + 45306;
 target_ptr = Libderiv->deriv2_classes[1][5][78];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+45369, dvrr_stack+8206, dvrr_stack+34545);
 tmp = dvrr_stack + 45369;
 target_ptr = Libderiv->deriv2_classes[1][6][78];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+45453, dvrr_stack+3708, dvrr_stack+14681);
 tmp = dvrr_stack + 45453;
 target_ptr = Libderiv->deriv2_classes[1][7][78];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+13775, dvrr_stack+2168, dvrr_stack+8206);
 tmp = dvrr_stack + 13775;
 target_ptr = Libderiv->deriv2_classes[1][8][78];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+45561, dvrr_stack+15269, dvrr_stack+3708);
 tmp = dvrr_stack + 45561;
 target_ptr = Libderiv->deriv2_classes[1][9][78];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_n(Data,3,1,dvrr_stack+94094, dvrr_stack+6440, dvrr_stack+2168);
 tmp = dvrr_stack + 94094;
 target_ptr = Libderiv->deriv2_classes[1][10][78];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+34608, dvrr_stack+936, dvrr_stack+3843);
 tmp = dvrr_stack + 34608;
 target_ptr = Libderiv->deriv2_classes[2][5][78];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+6431, dvrr_stack+4353, dvrr_stack+20876);
 tmp = dvrr_stack + 6431;
 target_ptr = Libderiv->deriv2_classes[2][6][78];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+94292, dvrr_stack+10134, dvrr_stack+936);
 tmp = dvrr_stack + 94292;
 target_ptr = Libderiv->deriv2_classes[2][7][78];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+94508, dvrr_stack+45774, dvrr_stack+4353);
 tmp = dvrr_stack + 94508;
 target_ptr = Libderiv->deriv2_classes[2][8][78];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+94778, dvrr_stack+46104, dvrr_stack+10134);
 tmp = dvrr_stack + 94778;
 target_ptr = Libderiv->deriv2_classes[2][9][78];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_n(Data,6,1,dvrr_stack+95108, dvrr_stack+46500, dvrr_stack+45774);
 tmp = dvrr_stack + 95108;
 target_ptr = Libderiv->deriv2_classes[2][10][78];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,21,dvrr_stack+46500, dvrr_stack+1377, dvrr_stack+23276);
 tmp = dvrr_stack + 46500;
 target_ptr = Libderiv->deriv2_classes[1][5][35];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,28,dvrr_stack+46563, dvrr_stack+34737, dvrr_stack+35391);
 tmp = dvrr_stack + 46563;
 target_ptr = Libderiv->deriv2_classes[1][6][35];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,36,dvrr_stack+46647, dvrr_stack+34905, dvrr_stack+33009);
 tmp = dvrr_stack + 46647;
 target_ptr = Libderiv->deriv2_classes[1][7][35];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,45,dvrr_stack+46755, dvrr_stack+35121, dvrr_stack+32673);
 tmp = dvrr_stack + 46755;
 target_ptr = Libderiv->deriv2_classes[1][8][35];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,55,dvrr_stack+95504, dvrr_stack+28805, dvrr_stack+6674);
 tmp = dvrr_stack + 95504;
 target_ptr = Libderiv->deriv2_classes[1][9][35];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,66,dvrr_stack+95669, dvrr_stack+8944, dvrr_stack+2789);
 tmp = dvrr_stack + 95669;
 target_ptr = Libderiv->deriv2_classes[1][10][35];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,21,dvrr_stack+95867, dvrr_stack+48340, dvrr_stack+33354);
 tmp = dvrr_stack + 95867;
 target_ptr = Libderiv->deriv2_classes[2][5][35];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,28,dvrr_stack+95993, dvrr_stack+50074, dvrr_stack+33270);
 tmp = dvrr_stack + 95993;
 target_ptr = Libderiv->deriv2_classes[2][6][35];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,36,dvrr_stack+96161, dvrr_stack+52289, dvrr_stack+33417);
 tmp = dvrr_stack + 96161;
 target_ptr = Libderiv->deriv2_classes[2][7][35];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,45,dvrr_stack+96377, dvrr_stack+55044, dvrr_stack+33525);
 tmp = dvrr_stack + 96377;
 target_ptr = Libderiv->deriv2_classes[2][8][35];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,55,dvrr_stack+96647, dvrr_stack+58398, dvrr_stack+33660);
 tmp = dvrr_stack + 96647;
 target_ptr = Libderiv->deriv2_classes[2][9][35];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,66,dvrr_stack+96977, dvrr_stack+25727, dvrr_stack+33825);
 tmp = dvrr_stack + 96977;
 target_ptr = Libderiv->deriv2_classes[2][10][35];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+46890, dvrr_stack+20534, dvrr_stack+1104);
 tmp = dvrr_stack + 46890;
 target_ptr = Libderiv->deriv2_classes[1][5][34];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+3843, dvrr_stack+20366, dvrr_stack+284);
 tmp = dvrr_stack + 3843;
 target_ptr = Libderiv->deriv2_classes[1][6][34];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+11179, dvrr_stack+20660, dvrr_stack+693);
 tmp = dvrr_stack + 11179;
 target_ptr = Libderiv->deriv2_classes[1][7][34];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+97373, dvrr_stack+17600, dvrr_stack+1808);
 tmp = dvrr_stack + 97373;
 target_ptr = Libderiv->deriv2_classes[1][8][34];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+97508, dvrr_stack+43386, dvrr_stack+3268);
 tmp = dvrr_stack + 97508;
 target_ptr = Libderiv->deriv2_classes[1][9][34];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,66,dvrr_stack+97673, dvrr_stack+43716, dvrr_stack+5120);
 tmp = dvrr_stack + 97673;
 target_ptr = Libderiv->deriv2_classes[1][10][34];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+97871, dvrr_stack+7522, dvrr_stack+29264);
 tmp = dvrr_stack + 97871;
 target_ptr = Libderiv->deriv2_classes[2][5][34];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+97997, dvrr_stack+58948, dvrr_stack+29180);
 tmp = dvrr_stack + 97997;
 target_ptr = Libderiv->deriv2_classes[2][6][34];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+98165, dvrr_stack+59228, dvrr_stack+29327);
 tmp = dvrr_stack + 98165;
 target_ptr = Libderiv->deriv2_classes[2][7][34];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+98381, dvrr_stack+62410, dvrr_stack+29435);
 tmp = dvrr_stack + 98381;
 target_ptr = Libderiv->deriv2_classes[2][8][34];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+98651, dvrr_stack+62860, dvrr_stack+19769);
 tmp = dvrr_stack + 98651;
 target_ptr = Libderiv->deriv2_classes[2][9][34];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,66,dvrr_stack+98981, dvrr_stack+63410, dvrr_stack+19934);
 tmp = dvrr_stack + 98981;
 target_ptr = Libderiv->deriv2_classes[2][10][34];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+26819, dvrr_stack+14261, dvrr_stack+26387);
 tmp = dvrr_stack + 26819;
 target_ptr = Libderiv->deriv2_classes[1][5][33];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+7900, dvrr_stack+34377, dvrr_stack+21002);
 tmp = dvrr_stack + 7900;
 target_ptr = Libderiv->deriv2_classes[1][6][33];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+99377, dvrr_stack+13559, dvrr_stack+8314);
 tmp = dvrr_stack + 99377;
 target_ptr = Libderiv->deriv2_classes[1][7][33];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+99485, dvrr_stack+16304, dvrr_stack+2681);
 tmp = dvrr_stack + 99485;
 target_ptr = Libderiv->deriv2_classes[1][8][33];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+99620, dvrr_stack+18959, dvrr_stack+10404);
 tmp = dvrr_stack + 99620;
 target_ptr = Libderiv->deriv2_classes[1][9][33];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,66,dvrr_stack+99785, dvrr_stack+22307, dvrr_stack+30920);
 tmp = dvrr_stack + 99785;
 target_ptr = Libderiv->deriv2_classes[1][10][33];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+99983, dvrr_stack+30986, dvrr_stack+873);
 tmp = dvrr_stack + 99983;
 target_ptr = Libderiv->deriv2_classes[2][5][33];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+100109, dvrr_stack+47710, dvrr_stack+33090);
 tmp = dvrr_stack + 100109;
 target_ptr = Libderiv->deriv2_classes[2][6][33];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+100277, dvrr_stack+49234, dvrr_stack+424);
 tmp = dvrr_stack + 100277;
 target_ptr = Libderiv->deriv2_classes[2][7][33];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+100493, dvrr_stack+51209, dvrr_stack+2033);
 tmp = dvrr_stack + 100493;
 target_ptr = Libderiv->deriv2_classes[2][8][33];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+100763, dvrr_stack+53694, dvrr_stack+3543);
 tmp = dvrr_stack + 100763;
 target_ptr = Libderiv->deriv2_classes[2][9][33];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,66,dvrr_stack+101093, dvrr_stack+56748, dvrr_stack+5450);
 tmp = dvrr_stack + 101093;
 target_ptr = Libderiv->deriv2_classes[2][10][33];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+6599, dvrr_stack+26897, dvrr_stack+26408);
 tmp = dvrr_stack + 6599;
 target_ptr = Libderiv->deriv2_classes[1][5][32];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+101489, dvrr_stack+32841, dvrr_stack+60430);
 tmp = dvrr_stack + 101489;
 target_ptr = Libderiv->deriv2_classes[1][6][32];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+101573, dvrr_stack+27023, dvrr_stack+60458);
 tmp = dvrr_stack + 101573;
 target_ptr = Libderiv->deriv2_classes[1][7][32];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+101681, dvrr_stack+27239, dvrr_stack+60494);
 tmp = dvrr_stack + 101681;
 target_ptr = Libderiv->deriv2_classes[1][8][32];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+101816, dvrr_stack+22703, dvrr_stack+60539);
 tmp = dvrr_stack + 101816;
 target_ptr = Libderiv->deriv2_classes[1][9][32];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,66,dvrr_stack+101981, dvrr_stack+19289, dvrr_stack+60594);
 tmp = dvrr_stack + 101981;
 target_ptr = Libderiv->deriv2_classes[1][10][32];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+102179, dvrr_stack+60870, dvrr_stack+31770);
 tmp = dvrr_stack + 102179;
 target_ptr = Libderiv->deriv2_classes[2][5][32];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+102305, dvrr_stack+61080, dvrr_stack+31686);
 tmp = dvrr_stack + 102305;
 target_ptr = Libderiv->deriv2_classes[2][6][32];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+102473, dvrr_stack+61360, dvrr_stack+31833);
 tmp = dvrr_stack + 102473;
 target_ptr = Libderiv->deriv2_classes[2][7][32];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+102689, dvrr_stack+61720, dvrr_stack+31941);
 tmp = dvrr_stack + 102689;
 target_ptr = Libderiv->deriv2_classes[2][8][32];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+102959, dvrr_stack+57408, dvrr_stack+32076);
 tmp = dvrr_stack + 102959;
 target_ptr = Libderiv->deriv2_classes[2][9][32];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,66,dvrr_stack+103289, dvrr_stack+54244, dvrr_stack+32241);
 tmp = dvrr_stack + 103289;
 target_ptr = Libderiv->deriv2_classes[2][10][32];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+7290, dvrr_stack+14555, dvrr_stack+0);
 tmp = dvrr_stack + 7290;
 target_ptr = Libderiv->deriv2_classes[1][5][31];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+103685, dvrr_stack+14387, dvrr_stack+40);
 tmp = dvrr_stack + 103685;
 target_ptr = Libderiv->deriv2_classes[1][6][31];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+103769, dvrr_stack+7990, dvrr_stack+60660);
 tmp = dvrr_stack + 103769;
 target_ptr = Libderiv->deriv2_classes[1][7][31];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+103877, dvrr_stack+5648, dvrr_stack+33045);
 tmp = dvrr_stack + 103877;
 target_ptr = Libderiv->deriv2_classes[1][8][31];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+104012, dvrr_stack+44580, dvrr_stack+34257);
 tmp = dvrr_stack + 104012;
 target_ptr = Libderiv->deriv2_classes[1][9][31];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,66,dvrr_stack+104177, dvrr_stack+44910, dvrr_stack+62170);
 tmp = dvrr_stack + 104177;
 target_ptr = Libderiv->deriv2_classes[1][10][31];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+104375, dvrr_stack+57958, dvrr_stack+27554);
 tmp = dvrr_stack + 104375;
 target_ptr = Libderiv->deriv2_classes[2][5][31];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+104501, dvrr_stack+51659, dvrr_stack+19685);
 tmp = dvrr_stack + 104501;
 target_ptr = Libderiv->deriv2_classes[2][6][31];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+104669, dvrr_stack+49594, dvrr_stack+23033);
 tmp = dvrr_stack + 104669;
 target_ptr = Libderiv->deriv2_classes[2][7][31];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+104885, dvrr_stack+64070, dvrr_stack+23141);
 tmp = dvrr_stack + 104885;
 target_ptr = Libderiv->deriv2_classes[2][8][31];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+105155, dvrr_stack+64520, dvrr_stack+16574);
 tmp = dvrr_stack + 105155;
 target_ptr = Libderiv->deriv2_classes[2][9][31];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,66,dvrr_stack+105485, dvrr_stack+65070, dvrr_stack+16739);
 tmp = dvrr_stack + 105485;
 target_ptr = Libderiv->deriv2_classes[2][10][31];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+105881, dvrr_stack+20876, dvrr_stack+60696);
 tmp = dvrr_stack + 105881;
 target_ptr = Libderiv->deriv2_classes[1][5][30];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+105944, dvrr_stack+936, dvrr_stack+34312);
 tmp = dvrr_stack + 105944;
 target_ptr = Libderiv->deriv2_classes[1][6][30];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+106028, dvrr_stack+4353, dvrr_stack+34340);
 tmp = dvrr_stack + 106028;
 target_ptr = Libderiv->deriv2_classes[1][7][30];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+106136, dvrr_stack+10134, dvrr_stack+62236);
 tmp = dvrr_stack + 106136;
 target_ptr = Libderiv->deriv2_classes[1][8][30];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+106271, dvrr_stack+45774, dvrr_stack+99);
 tmp = dvrr_stack + 106271;
 target_ptr = Libderiv->deriv2_classes[1][9][30];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,66,dvrr_stack+106436, dvrr_stack+46104, dvrr_stack+62281);
 tmp = dvrr_stack + 106436;
 target_ptr = Libderiv->deriv2_classes[1][10][30];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+106634, dvrr_stack+58168, dvrr_stack+34545);
 tmp = dvrr_stack + 106634;
 target_ptr = Libderiv->deriv2_classes[2][5][30];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+106760, dvrr_stack+51939, dvrr_stack+14681);
 tmp = dvrr_stack + 106760;
 target_ptr = Libderiv->deriv2_classes[2][6][30];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+106928, dvrr_stack+65730, dvrr_stack+8206);
 tmp = dvrr_stack + 106928;
 target_ptr = Libderiv->deriv2_classes[2][7][30];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+107144, dvrr_stack+66090, dvrr_stack+3708);
 tmp = dvrr_stack + 107144;
 target_ptr = Libderiv->deriv2_classes[2][8][30];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+107414, dvrr_stack+66540, dvrr_stack+2168);
 tmp = dvrr_stack + 107414;
 target_ptr = Libderiv->deriv2_classes[2][9][30];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,66,dvrr_stack+107744, dvrr_stack+67090, dvrr_stack+15269);
 tmp = dvrr_stack + 107744;
 target_ptr = Libderiv->deriv2_classes[2][10][30];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+108140, dvrr_stack+60738, dvrr_stack+60717);
 tmp = dvrr_stack + 108140;
 target_ptr = Libderiv->deriv2_classes[1][5][26];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+108203, dvrr_stack+47990, dvrr_stack+62347);
 tmp = dvrr_stack + 108203;
 target_ptr = Libderiv->deriv2_classes[1][6][26];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+108287, dvrr_stack+59588, dvrr_stack+54904);
 tmp = dvrr_stack + 108287;
 target_ptr = Libderiv->deriv2_classes[1][7][26];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+108395, dvrr_stack+59804, dvrr_stack+54940);
 tmp = dvrr_stack + 108395;
 target_ptr = Libderiv->deriv2_classes[1][8][26];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+108530, dvrr_stack+60074, dvrr_stack+54985);
 tmp = dvrr_stack + 108530;
 target_ptr = Libderiv->deriv2_classes[1][9][26];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,66,dvrr_stack+108695, dvrr_stack+67750, dvrr_stack+52219);
 tmp = dvrr_stack + 108695;
 target_ptr = Libderiv->deriv2_classes[1][10][26];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+108893, dvrr_stack+31322, dvrr_stack+2726);
 tmp = dvrr_stack + 108893;
 target_ptr = Libderiv->deriv2_classes[2][5][26];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+109019, dvrr_stack+69539, dvrr_stack+7366);
 tmp = dvrr_stack + 109019;
 target_ptr = Libderiv->deriv2_classes[2][6][26];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+109187, dvrr_stack+68671, dvrr_stack+13073);
 tmp = dvrr_stack + 109187;
 target_ptr = Libderiv->deriv2_classes[2][7][26];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+109403, dvrr_stack+72114, dvrr_stack+13910);
 tmp = dvrr_stack + 109403;
 target_ptr = Libderiv->deriv2_classes[2][8][26];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+109673, dvrr_stack+70719, dvrr_stack+69819);
 tmp = dvrr_stack + 109673;
 target_ptr = Libderiv->deriv2_classes[2][9][26];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,66,dvrr_stack+110003, dvrr_stack+73939, dvrr_stack+52649);
 tmp = dvrr_stack + 110003;
 target_ptr = Libderiv->deriv2_classes[2][10][26];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,21,dvrr_stack+110399, dvrr_stack+1377, dvrr_stack+23276);
 tmp = dvrr_stack + 110399;
 target_ptr = Libderiv->deriv2_classes[1][5][23];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,28,dvrr_stack+110462, dvrr_stack+34737, dvrr_stack+35391);
 tmp = dvrr_stack + 110462;
 target_ptr = Libderiv->deriv2_classes[1][6][23];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,36,dvrr_stack+110546, dvrr_stack+34905, dvrr_stack+33009);
 tmp = dvrr_stack + 110546;
 target_ptr = Libderiv->deriv2_classes[1][7][23];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,45,dvrr_stack+110654, dvrr_stack+35121, dvrr_stack+32673);
 tmp = dvrr_stack + 110654;
 target_ptr = Libderiv->deriv2_classes[1][8][23];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,55,dvrr_stack+110789, dvrr_stack+28805, dvrr_stack+6674);
 tmp = dvrr_stack + 110789;
 target_ptr = Libderiv->deriv2_classes[1][9][23];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,66,dvrr_stack+110954, dvrr_stack+8944, dvrr_stack+2789);
 tmp = dvrr_stack + 110954;
 target_ptr = Libderiv->deriv2_classes[1][10][23];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,21,dvrr_stack+111152, dvrr_stack+48340, dvrr_stack+33354);
 tmp = dvrr_stack + 111152;
 target_ptr = Libderiv->deriv2_classes[2][5][23];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,28,dvrr_stack+111278, dvrr_stack+50074, dvrr_stack+33270);
 tmp = dvrr_stack + 111278;
 target_ptr = Libderiv->deriv2_classes[2][6][23];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,36,dvrr_stack+111446, dvrr_stack+52289, dvrr_stack+33417);
 tmp = dvrr_stack + 111446;
 target_ptr = Libderiv->deriv2_classes[2][7][23];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,45,dvrr_stack+111662, dvrr_stack+55044, dvrr_stack+33525);
 tmp = dvrr_stack + 111662;
 target_ptr = Libderiv->deriv2_classes[2][8][23];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,55,dvrr_stack+111932, dvrr_stack+58398, dvrr_stack+33660);
 tmp = dvrr_stack + 111932;
 target_ptr = Libderiv->deriv2_classes[2][9][23];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,66,dvrr_stack+112262, dvrr_stack+25727, dvrr_stack+33825);
 tmp = dvrr_stack + 112262;
 target_ptr = Libderiv->deriv2_classes[2][10][23];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+112658, dvrr_stack+20534, dvrr_stack+1104);
 tmp = dvrr_stack + 112658;
 target_ptr = Libderiv->deriv2_classes[1][5][22];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+112721, dvrr_stack+20366, dvrr_stack+284);
 tmp = dvrr_stack + 112721;
 target_ptr = Libderiv->deriv2_classes[1][6][22];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+112805, dvrr_stack+20660, dvrr_stack+693);
 tmp = dvrr_stack + 112805;
 target_ptr = Libderiv->deriv2_classes[1][7][22];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+112913, dvrr_stack+17600, dvrr_stack+1808);
 tmp = dvrr_stack + 112913;
 target_ptr = Libderiv->deriv2_classes[1][8][22];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+113048, dvrr_stack+43386, dvrr_stack+3268);
 tmp = dvrr_stack + 113048;
 target_ptr = Libderiv->deriv2_classes[1][9][22];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,66,dvrr_stack+113213, dvrr_stack+43716, dvrr_stack+5120);
 tmp = dvrr_stack + 113213;
 target_ptr = Libderiv->deriv2_classes[1][10][22];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+113411, dvrr_stack+7522, dvrr_stack+29264);
 tmp = dvrr_stack + 113411;
 target_ptr = Libderiv->deriv2_classes[2][5][22];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+113537, dvrr_stack+58948, dvrr_stack+29180);
 tmp = dvrr_stack + 113537;
 target_ptr = Libderiv->deriv2_classes[2][6][22];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+113705, dvrr_stack+59228, dvrr_stack+29327);
 tmp = dvrr_stack + 113705;
 target_ptr = Libderiv->deriv2_classes[2][7][22];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+113921, dvrr_stack+62410, dvrr_stack+29435);
 tmp = dvrr_stack + 113921;
 target_ptr = Libderiv->deriv2_classes[2][8][22];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+114191, dvrr_stack+62860, dvrr_stack+19769);
 tmp = dvrr_stack + 114191;
 target_ptr = Libderiv->deriv2_classes[2][9][22];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,66,dvrr_stack+114521, dvrr_stack+63410, dvrr_stack+19934);
 tmp = dvrr_stack + 114521;
 target_ptr = Libderiv->deriv2_classes[2][10][22];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+114917, dvrr_stack+14261, dvrr_stack+26387);
 tmp = dvrr_stack + 114917;
 target_ptr = Libderiv->deriv2_classes[1][5][21];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+114980, dvrr_stack+34377, dvrr_stack+21002);
 tmp = dvrr_stack + 114980;
 target_ptr = Libderiv->deriv2_classes[1][6][21];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+115064, dvrr_stack+13559, dvrr_stack+8314);
 tmp = dvrr_stack + 115064;
 target_ptr = Libderiv->deriv2_classes[1][7][21];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+115172, dvrr_stack+16304, dvrr_stack+2681);
 tmp = dvrr_stack + 115172;
 target_ptr = Libderiv->deriv2_classes[1][8][21];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+115307, dvrr_stack+18959, dvrr_stack+10404);
 tmp = dvrr_stack + 115307;
 target_ptr = Libderiv->deriv2_classes[1][9][21];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,66,dvrr_stack+115472, dvrr_stack+22307, dvrr_stack+30920);
 tmp = dvrr_stack + 115472;
 target_ptr = Libderiv->deriv2_classes[1][10][21];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+115670, dvrr_stack+30986, dvrr_stack+873);
 tmp = dvrr_stack + 115670;
 target_ptr = Libderiv->deriv2_classes[2][5][21];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+115796, dvrr_stack+47710, dvrr_stack+33090);
 tmp = dvrr_stack + 115796;
 target_ptr = Libderiv->deriv2_classes[2][6][21];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+115964, dvrr_stack+49234, dvrr_stack+424);
 tmp = dvrr_stack + 115964;
 target_ptr = Libderiv->deriv2_classes[2][7][21];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+116180, dvrr_stack+51209, dvrr_stack+2033);
 tmp = dvrr_stack + 116180;
 target_ptr = Libderiv->deriv2_classes[2][8][21];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+116450, dvrr_stack+53694, dvrr_stack+3543);
 tmp = dvrr_stack + 116450;
 target_ptr = Libderiv->deriv2_classes[2][9][21];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,66,dvrr_stack+116780, dvrr_stack+56748, dvrr_stack+5450);
 tmp = dvrr_stack + 116780;
 target_ptr = Libderiv->deriv2_classes[2][10][21];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+117176, dvrr_stack+26897, dvrr_stack+26408);
 tmp = dvrr_stack + 117176;
 target_ptr = Libderiv->deriv2_classes[1][5][20];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+117239, dvrr_stack+32841, dvrr_stack+60430);
 tmp = dvrr_stack + 117239;
 target_ptr = Libderiv->deriv2_classes[1][6][20];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+117323, dvrr_stack+27023, dvrr_stack+60458);
 tmp = dvrr_stack + 117323;
 target_ptr = Libderiv->deriv2_classes[1][7][20];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+117431, dvrr_stack+27239, dvrr_stack+60494);
 tmp = dvrr_stack + 117431;
 target_ptr = Libderiv->deriv2_classes[1][8][20];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+117566, dvrr_stack+22703, dvrr_stack+60539);
 tmp = dvrr_stack + 117566;
 target_ptr = Libderiv->deriv2_classes[1][9][20];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,66,dvrr_stack+117731, dvrr_stack+19289, dvrr_stack+60594);
 tmp = dvrr_stack + 117731;
 target_ptr = Libderiv->deriv2_classes[1][10][20];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+117929, dvrr_stack+60870, dvrr_stack+31770);
 tmp = dvrr_stack + 117929;
 target_ptr = Libderiv->deriv2_classes[2][5][20];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+118055, dvrr_stack+61080, dvrr_stack+31686);
 tmp = dvrr_stack + 118055;
 target_ptr = Libderiv->deriv2_classes[2][6][20];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+118223, dvrr_stack+61360, dvrr_stack+31833);
 tmp = dvrr_stack + 118223;
 target_ptr = Libderiv->deriv2_classes[2][7][20];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+118439, dvrr_stack+61720, dvrr_stack+31941);
 tmp = dvrr_stack + 118439;
 target_ptr = Libderiv->deriv2_classes[2][8][20];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+118709, dvrr_stack+57408, dvrr_stack+32076);
 tmp = dvrr_stack + 118709;
 target_ptr = Libderiv->deriv2_classes[2][9][20];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,66,dvrr_stack+119039, dvrr_stack+54244, dvrr_stack+32241);
 tmp = dvrr_stack + 119039;
 target_ptr = Libderiv->deriv2_classes[2][10][20];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+119435, dvrr_stack+14555, dvrr_stack+0);
 tmp = dvrr_stack + 119435;
 target_ptr = Libderiv->deriv2_classes[1][5][19];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+119498, dvrr_stack+14387, dvrr_stack+40);
 tmp = dvrr_stack + 119498;
 target_ptr = Libderiv->deriv2_classes[1][6][19];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+119582, dvrr_stack+7990, dvrr_stack+60660);
 tmp = dvrr_stack + 119582;
 target_ptr = Libderiv->deriv2_classes[1][7][19];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+119690, dvrr_stack+5648, dvrr_stack+33045);
 tmp = dvrr_stack + 119690;
 target_ptr = Libderiv->deriv2_classes[1][8][19];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+119825, dvrr_stack+44580, dvrr_stack+34257);
 tmp = dvrr_stack + 119825;
 target_ptr = Libderiv->deriv2_classes[1][9][19];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,66,dvrr_stack+119990, dvrr_stack+44910, dvrr_stack+62170);
 tmp = dvrr_stack + 119990;
 target_ptr = Libderiv->deriv2_classes[1][10][19];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+120188, dvrr_stack+57958, dvrr_stack+27554);
 tmp = dvrr_stack + 120188;
 target_ptr = Libderiv->deriv2_classes[2][5][19];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+120314, dvrr_stack+51659, dvrr_stack+19685);
 tmp = dvrr_stack + 120314;
 target_ptr = Libderiv->deriv2_classes[2][6][19];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+120482, dvrr_stack+49594, dvrr_stack+23033);
 tmp = dvrr_stack + 120482;
 target_ptr = Libderiv->deriv2_classes[2][7][19];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+120698, dvrr_stack+64070, dvrr_stack+23141);
 tmp = dvrr_stack + 120698;
 target_ptr = Libderiv->deriv2_classes[2][8][19];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+120968, dvrr_stack+64520, dvrr_stack+16574);
 tmp = dvrr_stack + 120968;
 target_ptr = Libderiv->deriv2_classes[2][9][19];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,66,dvrr_stack+121298, dvrr_stack+65070, dvrr_stack+16739);
 tmp = dvrr_stack + 121298;
 target_ptr = Libderiv->deriv2_classes[2][10][19];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+121694, dvrr_stack+20876, dvrr_stack+60696);
 tmp = dvrr_stack + 121694;
 target_ptr = Libderiv->deriv2_classes[1][5][18];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+121757, dvrr_stack+936, dvrr_stack+34312);
 tmp = dvrr_stack + 121757;
 target_ptr = Libderiv->deriv2_classes[1][6][18];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+121841, dvrr_stack+4353, dvrr_stack+34340);
 tmp = dvrr_stack + 121841;
 target_ptr = Libderiv->deriv2_classes[1][7][18];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+121949, dvrr_stack+10134, dvrr_stack+62236);
 tmp = dvrr_stack + 121949;
 target_ptr = Libderiv->deriv2_classes[1][8][18];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+122084, dvrr_stack+45774, dvrr_stack+99);
 tmp = dvrr_stack + 122084;
 target_ptr = Libderiv->deriv2_classes[1][9][18];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,66,dvrr_stack+122249, dvrr_stack+46104, dvrr_stack+62281);
 tmp = dvrr_stack + 122249;
 target_ptr = Libderiv->deriv2_classes[1][10][18];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+122447, dvrr_stack+58168, dvrr_stack+34545);
 tmp = dvrr_stack + 122447;
 target_ptr = Libderiv->deriv2_classes[2][5][18];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+122573, dvrr_stack+51939, dvrr_stack+14681);
 tmp = dvrr_stack + 122573;
 target_ptr = Libderiv->deriv2_classes[2][6][18];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+122741, dvrr_stack+65730, dvrr_stack+8206);
 tmp = dvrr_stack + 122741;
 target_ptr = Libderiv->deriv2_classes[2][7][18];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+122957, dvrr_stack+66090, dvrr_stack+3708);
 tmp = dvrr_stack + 122957;
 target_ptr = Libderiv->deriv2_classes[2][8][18];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+123227, dvrr_stack+66540, dvrr_stack+2168);
 tmp = dvrr_stack + 123227;
 target_ptr = Libderiv->deriv2_classes[2][9][18];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,66,dvrr_stack+123557, dvrr_stack+67090, dvrr_stack+15269);
 tmp = dvrr_stack + 123557;
 target_ptr = Libderiv->deriv2_classes[2][10][18];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+10051, dvrr_stack+60738, dvrr_stack+60717);
 tmp = dvrr_stack + 10051;
 target_ptr = Libderiv->deriv2_classes[1][5][14];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+123953, dvrr_stack+47990, dvrr_stack+62347);
 tmp = dvrr_stack + 123953;
 target_ptr = Libderiv->deriv2_classes[1][6][14];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+124037, dvrr_stack+59588, dvrr_stack+54904);
 tmp = dvrr_stack + 124037;
 target_ptr = Libderiv->deriv2_classes[1][7][14];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+124145, dvrr_stack+59804, dvrr_stack+54940);
 tmp = dvrr_stack + 124145;
 target_ptr = Libderiv->deriv2_classes[1][8][14];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+124280, dvrr_stack+60074, dvrr_stack+54985);
 tmp = dvrr_stack + 124280;
 target_ptr = Libderiv->deriv2_classes[1][9][14];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,66,dvrr_stack+124445, dvrr_stack+67750, dvrr_stack+52219);
 tmp = dvrr_stack + 124445;
 target_ptr = Libderiv->deriv2_classes[1][10][14];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+124643, dvrr_stack+31322, dvrr_stack+2726);
 tmp = dvrr_stack + 124643;
 target_ptr = Libderiv->deriv2_classes[2][5][14];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+124769, dvrr_stack+69539, dvrr_stack+7366);
 tmp = dvrr_stack + 124769;
 target_ptr = Libderiv->deriv2_classes[2][6][14];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+124937, dvrr_stack+68671, dvrr_stack+13073);
 tmp = dvrr_stack + 124937;
 target_ptr = Libderiv->deriv2_classes[2][7][14];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+125153, dvrr_stack+72114, dvrr_stack+13910);
 tmp = dvrr_stack + 125153;
 target_ptr = Libderiv->deriv2_classes[2][8][14];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+125423, dvrr_stack+70719, dvrr_stack+69819);
 tmp = dvrr_stack + 125423;
 target_ptr = Libderiv->deriv2_classes[2][9][14];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,66,dvrr_stack+125753, dvrr_stack+73939, dvrr_stack+52649);
 tmp = dvrr_stack + 125753;
 target_ptr = Libderiv->deriv2_classes[2][10][14];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+126149, dvrr_stack+31196, dvrr_stack+72564);
 tmp = dvrr_stack + 126149;
 target_ptr = Libderiv->deriv2_classes[1][5][13];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+126212, dvrr_stack+72613, dvrr_stack+72585);
 tmp = dvrr_stack + 126212;
 target_ptr = Libderiv->deriv2_classes[1][6][13];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+126296, dvrr_stack+72817, dvrr_stack+72781);
 tmp = dvrr_stack + 126296;
 target_ptr = Libderiv->deriv2_classes[1][7][13];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+126404, dvrr_stack+50354, dvrr_stack+73033);
 tmp = dvrr_stack + 126404;
 target_ptr = Libderiv->deriv2_classes[1][8][13];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+126539, dvrr_stack+55494, dvrr_stack+50624);
 tmp = dvrr_stack + 126539;
 target_ptr = Libderiv->deriv2_classes[1][9][13];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,66,dvrr_stack+126704, dvrr_stack+74599, dvrr_stack+50679);
 tmp = dvrr_stack + 126704;
 target_ptr = Libderiv->deriv2_classes[1][10][13];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+126902, dvrr_stack+68146, dvrr_stack+55824);
 tmp = dvrr_stack + 126902;
 target_ptr = Libderiv->deriv2_classes[2][5][13];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+127028, dvrr_stack+52847, dvrr_stack+13307);
 tmp = dvrr_stack + 127028;
 target_ptr = Libderiv->deriv2_classes[2][6][13];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+127196, dvrr_stack+75985, dvrr_stack+55887);
 tmp = dvrr_stack + 127196;
 target_ptr = Libderiv->deriv2_classes[2][7][13];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+127412, dvrr_stack+76345, dvrr_stack+15899);
 tmp = dvrr_stack + 127412;
 target_ptr = Libderiv->deriv2_classes[2][8][13];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+127682, dvrr_stack+76795, dvrr_stack+18464);
 tmp = dvrr_stack + 127682;
 target_ptr = Libderiv->deriv2_classes[2][9][13];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,66,dvrr_stack+128012, dvrr_stack+77345, dvrr_stack+21713);
 tmp = dvrr_stack + 128012;
 target_ptr = Libderiv->deriv2_classes[2][10][13];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,21,dvrr_stack+128408, dvrr_stack+1377, dvrr_stack+23276);
 tmp = dvrr_stack + 128408;
 target_ptr = Libderiv->deriv2_classes[1][5][11];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,28,dvrr_stack+1368, dvrr_stack+34737, dvrr_stack+35391);
 tmp = dvrr_stack + 1368;
 target_ptr = Libderiv->deriv2_classes[1][6][11];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,36,dvrr_stack+34734, dvrr_stack+34905, dvrr_stack+33009);
 tmp = dvrr_stack + 34734;
 target_ptr = Libderiv->deriv2_classes[1][7][11];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,45,dvrr_stack+34842, dvrr_stack+35121, dvrr_stack+32673);
 tmp = dvrr_stack + 34842;
 target_ptr = Libderiv->deriv2_classes[1][8][11];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,55,dvrr_stack+34977, dvrr_stack+28805, dvrr_stack+6674);
 tmp = dvrr_stack + 34977;
 target_ptr = Libderiv->deriv2_classes[1][9][11];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,66,dvrr_stack+28790, dvrr_stack+8944, dvrr_stack+2789);
 tmp = dvrr_stack + 28790;
 target_ptr = Libderiv->deriv2_classes[1][10][11];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,21,dvrr_stack+28988, dvrr_stack+48340, dvrr_stack+33354);
 tmp = dvrr_stack + 28988;
 target_ptr = Libderiv->deriv2_classes[2][5][11];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,28,dvrr_stack+8935, dvrr_stack+50074, dvrr_stack+33270);
 tmp = dvrr_stack + 8935;
 target_ptr = Libderiv->deriv2_classes[2][6][11];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,36,dvrr_stack+9103, dvrr_stack+52289, dvrr_stack+33417);
 tmp = dvrr_stack + 9103;
 target_ptr = Libderiv->deriv2_classes[2][7][11];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,45,dvrr_stack+50038, dvrr_stack+55044, dvrr_stack+33525);
 tmp = dvrr_stack + 50038;
 target_ptr = Libderiv->deriv2_classes[2][8][11];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,55,dvrr_stack+33258, dvrr_stack+58398, dvrr_stack+33660);
 tmp = dvrr_stack + 33258;
 target_ptr = Libderiv->deriv2_classes[2][9][11];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,66,dvrr_stack+58378, dvrr_stack+25727, dvrr_stack+33825);
 tmp = dvrr_stack + 58378;
 target_ptr = Libderiv->deriv2_classes[2][10][11];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+2789, dvrr_stack+20534, dvrr_stack+1104);
 tmp = dvrr_stack + 2789;
 target_ptr = Libderiv->deriv2_classes[1][5][10];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+20534, dvrr_stack+20366, dvrr_stack+284);
 tmp = dvrr_stack + 20534;
 target_ptr = Libderiv->deriv2_classes[1][6][10];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+20366, dvrr_stack+20660, dvrr_stack+693);
 tmp = dvrr_stack + 20366;
 target_ptr = Libderiv->deriv2_classes[1][7][10];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+20618, dvrr_stack+17600, dvrr_stack+1808);
 tmp = dvrr_stack + 20618;
 target_ptr = Libderiv->deriv2_classes[1][8][10];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+48323, dvrr_stack+43386, dvrr_stack+3268);
 tmp = dvrr_stack + 48323;
 target_ptr = Libderiv->deriv2_classes[1][9][10];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,66,dvrr_stack+33588, dvrr_stack+43716, dvrr_stack+5120);
 tmp = dvrr_stack + 33588;
 target_ptr = Libderiv->deriv2_classes[1][10][10];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+1758, dvrr_stack+7522, dvrr_stack+29264);
 tmp = dvrr_stack + 1758;
 target_ptr = Libderiv->deriv2_classes[2][5][10];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+7513, dvrr_stack+58948, dvrr_stack+29180);
 tmp = dvrr_stack + 7513;
 target_ptr = Libderiv->deriv2_classes[2][6][10];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+33786, dvrr_stack+59228, dvrr_stack+29327);
 tmp = dvrr_stack + 33786;
 target_ptr = Libderiv->deriv2_classes[2][7][10];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+29114, dvrr_stack+62410, dvrr_stack+29435);
 tmp = dvrr_stack + 29114;
 target_ptr = Libderiv->deriv2_classes[2][8][10];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+62375, dvrr_stack+62860, dvrr_stack+19769);
 tmp = dvrr_stack + 62375;
 target_ptr = Libderiv->deriv2_classes[2][9][10];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,66,dvrr_stack+62705, dvrr_stack+63410, dvrr_stack+19934);
 tmp = dvrr_stack + 62705;
 target_ptr = Libderiv->deriv2_classes[2][10][10];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+19769, dvrr_stack+14261, dvrr_stack+26387);
 tmp = dvrr_stack + 19769;
 target_ptr = Libderiv->deriv2_classes[1][5][9];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+19832, dvrr_stack+34377, dvrr_stack+21002);
 tmp = dvrr_stack + 19832;
 target_ptr = Libderiv->deriv2_classes[1][6][9];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+19916, dvrr_stack+13559, dvrr_stack+8314);
 tmp = dvrr_stack + 19916;
 target_ptr = Libderiv->deriv2_classes[1][7][9];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+29384, dvrr_stack+16304, dvrr_stack+2681);
 tmp = dvrr_stack + 29384;
 target_ptr = Libderiv->deriv2_classes[1][8][9];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+16283, dvrr_stack+18959, dvrr_stack+10404);
 tmp = dvrr_stack + 16283;
 target_ptr = Libderiv->deriv2_classes[1][9][9];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,66,dvrr_stack+18899, dvrr_stack+22307, dvrr_stack+30920);
 tmp = dvrr_stack + 18899;
 target_ptr = Libderiv->deriv2_classes[1][10][9];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+16448, dvrr_stack+30986, dvrr_stack+873);
 tmp = dvrr_stack + 16448;
 target_ptr = Libderiv->deriv2_classes[2][5][9];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+22301, dvrr_stack+47710, dvrr_stack+33090);
 tmp = dvrr_stack + 22301;
 target_ptr = Libderiv->deriv2_classes[2][6][9];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+22469, dvrr_stack+49234, dvrr_stack+424);
 tmp = dvrr_stack + 22469;
 target_ptr = Libderiv->deriv2_classes[2][7][9];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+13499, dvrr_stack+51209, dvrr_stack+2033);
 tmp = dvrr_stack + 13499;
 target_ptr = Libderiv->deriv2_classes[2][8][9];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+51201, dvrr_stack+53694, dvrr_stack+3543);
 tmp = dvrr_stack + 51201;
 target_ptr = Libderiv->deriv2_classes[2][9][9];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,66,dvrr_stack+53688, dvrr_stack+56748, dvrr_stack+5450);
 tmp = dvrr_stack + 53688;
 target_ptr = Libderiv->deriv2_classes[2][10][9];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+873, dvrr_stack+26897, dvrr_stack+26408);
 tmp = dvrr_stack + 873;
 target_ptr = Libderiv->deriv2_classes[1][5][8];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+33090, dvrr_stack+32841, dvrr_stack+60430);
 tmp = dvrr_stack + 33090;
 target_ptr = Libderiv->deriv2_classes[1][6][8];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+20024, dvrr_stack+27023, dvrr_stack+60458);
 tmp = dvrr_stack + 20024;
 target_ptr = Libderiv->deriv2_classes[1][7][8];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+5450, dvrr_stack+27239, dvrr_stack+60494);
 tmp = dvrr_stack + 5450;
 target_ptr = Libderiv->deriv2_classes[1][8][8];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+26882, dvrr_stack+22703, dvrr_stack+60539);
 tmp = dvrr_stack + 26882;
 target_ptr = Libderiv->deriv2_classes[1][9][8];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,66,dvrr_stack+27047, dvrr_stack+19289, dvrr_stack+60594);
 tmp = dvrr_stack + 27047;
 target_ptr = Libderiv->deriv2_classes[1][10][8];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+27245, dvrr_stack+60870, dvrr_stack+31770);
 tmp = dvrr_stack + 27245;
 target_ptr = Libderiv->deriv2_classes[2][5][8];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+27371, dvrr_stack+61080, dvrr_stack+31686);
 tmp = dvrr_stack + 27371;
 target_ptr = Libderiv->deriv2_classes[2][6][8];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+22685, dvrr_stack+61360, dvrr_stack+31833);
 tmp = dvrr_stack + 22685;
 target_ptr = Libderiv->deriv2_classes[2][7][8];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+19097, dvrr_stack+61720, dvrr_stack+31941);
 tmp = dvrr_stack + 19097;
 target_ptr = Libderiv->deriv2_classes[2][8][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+56700, dvrr_stack+57408, dvrr_stack+32076);
 tmp = dvrr_stack + 56700;
 target_ptr = Libderiv->deriv2_classes[2][9][8];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,66,dvrr_stack+57030, dvrr_stack+54244, dvrr_stack+32241);
 tmp = dvrr_stack + 57030;
 target_ptr = Libderiv->deriv2_classes[2][10][8];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+5585, dvrr_stack+14555, dvrr_stack+0);
 tmp = dvrr_stack + 5585;
 target_ptr = Libderiv->deriv2_classes[1][5][7];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+14555, dvrr_stack+14387, dvrr_stack+40);
 tmp = dvrr_stack + 14555;
 target_ptr = Libderiv->deriv2_classes[1][6][7];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+20753, dvrr_stack+7990, dvrr_stack+60660);
 tmp = dvrr_stack + 20753;
 target_ptr = Libderiv->deriv2_classes[1][7][7];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+19367, dvrr_stack+5648, dvrr_stack+33045);
 tmp = dvrr_stack + 19367;
 target_ptr = Libderiv->deriv2_classes[1][8][7];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+5648, dvrr_stack+44580, dvrr_stack+34257);
 tmp = dvrr_stack + 5648;
 target_ptr = Libderiv->deriv2_classes[1][9][7];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,66,dvrr_stack+44550, dvrr_stack+44910, dvrr_stack+62170);
 tmp = dvrr_stack + 44550;
 target_ptr = Libderiv->deriv2_classes[1][10][7];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+44748, dvrr_stack+57958, dvrr_stack+27554);
 tmp = dvrr_stack + 44748;
 target_ptr = Libderiv->deriv2_classes[2][5][7];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+44874, dvrr_stack+51659, dvrr_stack+19685);
 tmp = dvrr_stack + 44874;
 target_ptr = Libderiv->deriv2_classes[2][6][7];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+45042, dvrr_stack+49594, dvrr_stack+23033);
 tmp = dvrr_stack + 45042;
 target_ptr = Libderiv->deriv2_classes[2][7][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+14243, dvrr_stack+64070, dvrr_stack+23141);
 tmp = dvrr_stack + 14243;
 target_ptr = Libderiv->deriv2_classes[2][8][7];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+22901, dvrr_stack+64520, dvrr_stack+16574);
 tmp = dvrr_stack + 22901;
 target_ptr = Libderiv->deriv2_classes[2][9][7];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,66,dvrr_stack+51531, dvrr_stack+65070, dvrr_stack+16739);
 tmp = dvrr_stack + 51531;
 target_ptr = Libderiv->deriv2_classes[2][10][7];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+16574, dvrr_stack+20876, dvrr_stack+60696);
 tmp = dvrr_stack + 16574;
 target_ptr = Libderiv->deriv2_classes[1][5][6];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+16637, dvrr_stack+936, dvrr_stack+34312);
 tmp = dvrr_stack + 16637;
 target_ptr = Libderiv->deriv2_classes[1][6][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+936, dvrr_stack+4353, dvrr_stack+34340);
 tmp = dvrr_stack + 936;
 target_ptr = Libderiv->deriv2_classes[1][7][6];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+16721, dvrr_stack+10134, dvrr_stack+62236);
 tmp = dvrr_stack + 16721;
 target_ptr = Libderiv->deriv2_classes[1][8][6];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+20861, dvrr_stack+45774, dvrr_stack+99);
 tmp = dvrr_stack + 20861;
 target_ptr = Libderiv->deriv2_classes[1][9][6];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,66,dvrr_stack+45726, dvrr_stack+46104, dvrr_stack+62281);
 tmp = dvrr_stack + 45726;
 target_ptr = Libderiv->deriv2_classes[1][10][6];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+0, dvrr_stack+58168, dvrr_stack+34545);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv2_classes[2][5][6];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+45924, dvrr_stack+51939, dvrr_stack+14681);
 tmp = dvrr_stack + 45924;
 target_ptr = Libderiv->deriv2_classes[2][6][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+46092, dvrr_stack+65730, dvrr_stack+8206);
 tmp = dvrr_stack + 46092;
 target_ptr = Libderiv->deriv2_classes[2][7][6];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+34212, dvrr_stack+66090, dvrr_stack+3708);
 tmp = dvrr_stack + 34212;
 target_ptr = Libderiv->deriv2_classes[2][8][6];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+57426, dvrr_stack+66540, dvrr_stack+2168);
 tmp = dvrr_stack + 57426;
 target_ptr = Libderiv->deriv2_classes[2][9][6];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,66,dvrr_stack+57756, dvrr_stack+67090, dvrr_stack+15269);
 tmp = dvrr_stack + 57756;
 target_ptr = Libderiv->deriv2_classes[2][10][6];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+1044, dvrr_stack+60738, dvrr_stack+60717);
 tmp = dvrr_stack + 1044;
 target_ptr = Libderiv->deriv2_classes[1][5][2];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+5813, dvrr_stack+47990, dvrr_stack+62347);
 tmp = dvrr_stack + 5813;
 target_ptr = Libderiv->deriv2_classes[1][6][2];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+14639, dvrr_stack+59588, dvrr_stack+54904);
 tmp = dvrr_stack + 14639;
 target_ptr = Libderiv->deriv2_classes[1][7][2];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+46308, dvrr_stack+59804, dvrr_stack+54940);
 tmp = dvrr_stack + 46308;
 target_ptr = Libderiv->deriv2_classes[1][8][2];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+15251, dvrr_stack+60074, dvrr_stack+54985);
 tmp = dvrr_stack + 15251;
 target_ptr = Libderiv->deriv2_classes[1][9][2];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,66,dvrr_stack+19502, dvrr_stack+67750, dvrr_stack+52219);
 tmp = dvrr_stack + 19502;
 target_ptr = Libderiv->deriv2_classes[1][10][2];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+34482, dvrr_stack+31322, dvrr_stack+2726);
 tmp = dvrr_stack + 34482;
 target_ptr = Libderiv->deriv2_classes[2][5][2];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+31322, dvrr_stack+69539, dvrr_stack+7366);
 tmp = dvrr_stack + 31322;
 target_ptr = Libderiv->deriv2_classes[2][6][2];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+3528, dvrr_stack+68671, dvrr_stack+13073);
 tmp = dvrr_stack + 3528;
 target_ptr = Libderiv->deriv2_classes[2][7][2];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+68636, dvrr_stack+72114, dvrr_stack+13910);
 tmp = dvrr_stack + 68636;
 target_ptr = Libderiv->deriv2_classes[2][8][2];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+47706, dvrr_stack+70719, dvrr_stack+69819);
 tmp = dvrr_stack + 47706;
 target_ptr = Libderiv->deriv2_classes[2][9][2];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,66,dvrr_stack+51927, dvrr_stack+73939, dvrr_stack+52649);
 tmp = dvrr_stack + 51927;
 target_ptr = Libderiv->deriv2_classes[2][10][2];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+13910, dvrr_stack+31196, dvrr_stack+72564);
 tmp = dvrr_stack + 13910;
 target_ptr = Libderiv->deriv2_classes[1][5][1];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+32628, dvrr_stack+72613, dvrr_stack+72585);
 tmp = dvrr_stack + 32628;
 target_ptr = Libderiv->deriv2_classes[1][6][1];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+13028, dvrr_stack+72817, dvrr_stack+72781);
 tmp = dvrr_stack + 13028;
 target_ptr = Libderiv->deriv2_classes[1][7][1];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+2016, dvrr_stack+50354, dvrr_stack+73033);
 tmp = dvrr_stack + 2016;
 target_ptr = Libderiv->deriv2_classes[1][8][1];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+2624, dvrr_stack+55494, dvrr_stack+50624);
 tmp = dvrr_stack + 2624;
 target_ptr = Libderiv->deriv2_classes[1][9][1];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,66,dvrr_stack+73930, dvrr_stack+74599, dvrr_stack+50679);
 tmp = dvrr_stack + 73930;
 target_ptr = Libderiv->deriv2_classes[1][10][1];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+2151, dvrr_stack+68146, dvrr_stack+55824);
 tmp = dvrr_stack + 2151;
 target_ptr = Libderiv->deriv2_classes[2][5][1];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+74128, dvrr_stack+52847, dvrr_stack+13307);
 tmp = dvrr_stack + 74128;
 target_ptr = Libderiv->deriv2_classes[2][6][1];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+74296, dvrr_stack+75985, dvrr_stack+55887);
 tmp = dvrr_stack + 74296;
 target_ptr = Libderiv->deriv2_classes[2][7][1];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+75931, dvrr_stack+76345, dvrr_stack+15899);
 tmp = dvrr_stack + 75931;
 target_ptr = Libderiv->deriv2_classes[2][8][1];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+76201, dvrr_stack+76795, dvrr_stack+18464);
 tmp = dvrr_stack + 76201;
 target_ptr = Libderiv->deriv2_classes[2][9][1];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,66,dvrr_stack+76531, dvrr_stack+77345, dvrr_stack+21713);
 tmp = dvrr_stack + 76531;
 target_ptr = Libderiv->deriv2_classes[2][10][1];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+13973, dvrr_stack+69984, dvrr_stack+73078);
 tmp = dvrr_stack + 13973;
 target_ptr = Libderiv->deriv2_classes[1][5][0];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+18446, dvrr_stack+46968, dvrr_stack+175);
 tmp = dvrr_stack + 18446;
 target_ptr = Libderiv->deriv2_classes[1][6][0];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+46953, dvrr_stack+47136, dvrr_stack+340);
 tmp = dvrr_stack + 46953;
 target_ptr = Libderiv->deriv2_classes[1][7][0];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+47061, dvrr_stack+47352, dvrr_stack+765);
 tmp = dvrr_stack + 47061;
 target_ptr = Libderiv->deriv2_classes[1][8][0];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+47196, dvrr_stack+50745, dvrr_stack+1898);
 tmp = dvrr_stack + 47196;
 target_ptr = Libderiv->deriv2_classes[1][9][0];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,66,dvrr_stack+47361, dvrr_stack+53127, dvrr_stack+3378);
 tmp = dvrr_stack + 47361;
 target_ptr = Libderiv->deriv2_classes[1][10][0];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+13265, dvrr_stack+55995, dvrr_stack+810);
 tmp = dvrr_stack + 13265;
 target_ptr = Libderiv->deriv2_classes[2][5][0];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+76927, dvrr_stack+68356, dvrr_stack+13181);
 tmp = dvrr_stack + 76927;
 target_ptr = Libderiv->deriv2_classes[2][6][0];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+77095, dvrr_stack+56205, dvrr_stack+13391);
 tmp = dvrr_stack + 77095;
 target_ptr = Libderiv->deriv2_classes[2][7][0];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+77311, dvrr_stack+70110, dvrr_stack+14045);
 tmp = dvrr_stack + 77311;
 target_ptr = Libderiv->deriv2_classes[2][8][0];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+77581, dvrr_stack+71269, dvrr_stack+16034);
 tmp = dvrr_stack + 77581;
 target_ptr = Libderiv->deriv2_classes[2][9][0];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,66,dvrr_stack+74512, dvrr_stack+73099, dvrr_stack+5252);
 tmp = dvrr_stack + 74512;
 target_ptr = Libderiv->deriv2_classes[2][10][0];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];


}

